(window["webpackJsonp"] = window["webpackJsonp"] || []).push([["vendor"],{

/***/ "+s0g":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/nl.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Dutch [nl]
//! author : Joris Röling : https://github.com/jorisroling
//! author : Jacob Middag : https://github.com/middagj
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortWithDots = 'jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.'.split('_'),
      monthsShortWithoutDots = 'jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec'.split('_'),
      monthsParse = [/^jan/i, /^feb/i, /^maart|mrt.?$/i, /^apr/i, /^mei$/i, /^jun[i.]?$/i, /^jul[i.]?$/i, /^aug/i, /^sep/i, /^okt/i, /^nov/i, /^dec/i],
      monthsRegex = /^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i;
  var nl = moment.defineLocale('nl', {
    months: 'januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortWithDots;
      } else if (/-MMM-/.test(format)) {
        return monthsShortWithoutDots[m.month()];
      } else {
        return monthsShortWithDots[m.month()];
      }
    },
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: /^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,
    monthsShortStrictRegex: /^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag'.split('_'),
    weekdaysShort: 'zo._ma._di._wo._do._vr._za.'.split('_'),
    weekdaysMin: 'zo_ma_di_wo_do_vr_za'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD-MM-YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[vandaag om] LT',
      nextDay: '[morgen om] LT',
      nextWeek: 'dddd [om] LT',
      lastDay: '[gisteren om] LT',
      lastWeek: '[afgelopen] dddd [om] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'over %s',
      past: '%s geleden',
      s: 'een paar seconden',
      ss: '%d seconden',
      m: 'één minuut',
      mm: '%d minuten',
      h: 'één uur',
      hh: '%d uur',
      d: 'één dag',
      dd: '%d dagen',
      w: 'één week',
      ww: '%d weken',
      M: 'één maand',
      MM: '%d maanden',
      y: 'één jaar',
      yy: '%d jaar'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(ste|de)/,
    ordinal: function ordinal(number) {
      return number + (number === 1 || number === 8 || number >= 20 ? 'ste' : 'de');
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return nl;
});

/***/ }),

/***/ "//9w":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/se.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Northern Sami [se]
//! authors : Bård Rolstad Henriksen : https://github.com/karamell
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var se = moment.defineLocale('se', {
    months: 'ođđajagemánnu_guovvamánnu_njukčamánnu_cuoŋománnu_miessemánnu_geassemánnu_suoidnemánnu_borgemánnu_čakčamánnu_golggotmánnu_skábmamánnu_juovlamánnu'.split('_'),
    monthsShort: 'ođđj_guov_njuk_cuo_mies_geas_suoi_borg_čakč_golg_skáb_juov'.split('_'),
    weekdays: 'sotnabeaivi_vuossárga_maŋŋebárga_gaskavahkku_duorastat_bearjadat_lávvardat'.split('_'),
    weekdaysShort: 'sotn_vuos_maŋ_gask_duor_bear_láv'.split('_'),
    weekdaysMin: 's_v_m_g_d_b_L'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'MMMM D. [b.] YYYY',
      LLL: 'MMMM D. [b.] YYYY [ti.] HH:mm',
      LLLL: 'dddd, MMMM D. [b.] YYYY [ti.] HH:mm'
    },
    calendar: {
      sameDay: '[otne ti] LT',
      nextDay: '[ihttin ti] LT',
      nextWeek: 'dddd [ti] LT',
      lastDay: '[ikte ti] LT',
      lastWeek: '[ovddit] dddd [ti] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s geažes',
      past: 'maŋit %s',
      s: 'moadde sekunddat',
      ss: '%d sekunddat',
      m: 'okta minuhta',
      mm: '%d minuhtat',
      h: 'okta diimmu',
      hh: '%d diimmut',
      d: 'okta beaivi',
      dd: '%d beaivvit',
      M: 'okta mánnu',
      MM: '%d mánut',
      y: 'okta jahki',
      yy: '%d jagit'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return se;
});

/***/ }),

/***/ "/X5v":
/*!************************************************!*\
  !*** ./node_modules/moment/locale/x-pseudo.js ***!
  \************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Pseudo [x-pseudo]
//! author : Andrew Hood : https://github.com/andrewhood125
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var xPseudo = moment.defineLocale('x-pseudo', {
    months: 'J~áñúá~rý_F~ébrú~árý_~Márc~h_Áp~ríl_~Máý_~Júñé~_Júl~ý_Áú~gúst~_Sép~témb~ér_Ó~ctób~ér_Ñ~óvém~bér_~Décé~mbér'.split('_'),
    monthsShort: 'J~áñ_~Féb_~Már_~Ápr_~Máý_~Júñ_~Júl_~Áúg_~Sép_~Óct_~Ñóv_~Déc'.split('_'),
    monthsParseExact: true,
    weekdays: 'S~úñdá~ý_Mó~ñdáý~_Túé~sdáý~_Wéd~ñésd~áý_T~húrs~dáý_~Fríd~áý_S~átúr~dáý'.split('_'),
    weekdaysShort: 'S~úñ_~Móñ_~Túé_~Wéd_~Thú_~Frí_~Sát'.split('_'),
    weekdaysMin: 'S~ú_Mó~_Tú_~Wé_T~h_Fr~_Sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[T~ódá~ý át] LT',
      nextDay: '[T~ómó~rró~w át] LT',
      nextWeek: 'dddd [át] LT',
      lastDay: '[Ý~ést~érdá~ý át] LT',
      lastWeek: '[L~ást] dddd [át] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'í~ñ %s',
      past: '%s á~gó',
      s: 'á ~féw ~sécó~ñds',
      ss: '%d s~écóñ~ds',
      m: 'á ~míñ~úté',
      mm: '%d m~íñú~tés',
      h: 'á~ñ hó~úr',
      hh: '%d h~óúrs',
      d: 'á ~dáý',
      dd: '%d d~áýs',
      M: 'á ~móñ~th',
      MM: '%d m~óñt~hs',
      y: 'á ~ýéár',
      yy: '%d ý~éárs'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(th|st|nd|rd)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return xPseudo;
});

/***/ }),

/***/ "/d8p":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/repeat.js ***!
  \*****************************************************************/
/*! exports provided: repeat */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "repeat", function() { return repeat; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _observable_empty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../observable/empty */ "EY2u");








function repeat() {
  var count = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : -1;
  return function (source) {
    if (count === 0) {
      return Object(_observable_empty__WEBPACK_IMPORTED_MODULE_7__["empty"])();
    } else if (count < 0) {
      return source.lift(new RepeatOperator(-1, source));
    } else {
      return source.lift(new RepeatOperator(count - 1, source));
    }
  };
}

var RepeatOperator = /*#__PURE__*/function () {
  function RepeatOperator(count, source) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RepeatOperator);

    this.count = count;
    this.source = source;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RepeatOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new RepeatSubscriber(subscriber, this.count, this.source));
    }
  }]);

  return RepeatOperator;
}();

var RepeatSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(RepeatSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(RepeatSubscriber);

  function RepeatSubscriber(destination, count, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RepeatSubscriber);

    _this = _super.call(this, destination);
    _this.count = count;
    _this.source = source;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RepeatSubscriber, [{
    key: "complete",
    value: function complete() {
      if (!this.isStopped) {
        var source = this.source,
            count = this.count;

        if (count === 0) {
          return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RepeatSubscriber.prototype), "complete", this).call(this);
        } else if (count > -1) {
          this.count = count - 1;
        }

        source.subscribe(this._unsubscribeAndRecycle());
      }
    }
  }]);

  return RepeatSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

/***/ }),

/***/ "/uUt":
/*!*******************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/distinctUntilChanged.js ***!
  \*******************************************************************************/
/*! exports provided: distinctUntilChanged */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "distinctUntilChanged", function() { return distinctUntilChanged; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function distinctUntilChanged(compare, keySelector) {
  return function (source) {
    return source.lift(new DistinctUntilChangedOperator(compare, keySelector));
  };
}

var DistinctUntilChangedOperator = /*#__PURE__*/function () {
  function DistinctUntilChangedOperator(compare, keySelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DistinctUntilChangedOperator);

    this.compare = compare;
    this.keySelector = keySelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DistinctUntilChangedOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DistinctUntilChangedSubscriber(subscriber, this.compare, this.keySelector));
    }
  }]);

  return DistinctUntilChangedOperator;
}();

var DistinctUntilChangedSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(DistinctUntilChangedSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(DistinctUntilChangedSubscriber);

  function DistinctUntilChangedSubscriber(destination, compare, keySelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DistinctUntilChangedSubscriber);

    _this = _super.call(this, destination);
    _this.keySelector = keySelector;
    _this.hasKey = false;

    if (typeof compare === 'function') {
      _this.compare = compare;
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DistinctUntilChangedSubscriber, [{
    key: "compare",
    value: function compare(x, y) {
      return x === y;
    }
  }, {
    key: "_next",
    value: function _next(value) {
      var key;

      try {
        var keySelector = this.keySelector;
        key = keySelector ? keySelector(value) : value;
      } catch (err) {
        return this.destination.error(err);
      }

      var result = false;

      if (this.hasKey) {
        try {
          var compare = this.compare;
          result = compare(this.key, key);
        } catch (err) {
          return this.destination.error(err);
        }
      } else {
        this.hasKey = true;
      }

      if (!result) {
        this.key = key;
        this.destination.next(value);
      }
    }
  }]);

  return DistinctUntilChangedSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "02Lk":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/distinct.js ***!
  \*******************************************************************/
/*! exports provided: distinct, DistinctSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "distinct", function() { return distinct; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DistinctSubscriber", function() { return DistinctSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");






function distinct(keySelector, flushes) {
  return function (source) {
    return source.lift(new DistinctOperator(keySelector, flushes));
  };
}

var DistinctOperator = /*#__PURE__*/function () {
  function DistinctOperator(keySelector, flushes) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, DistinctOperator);

    this.keySelector = keySelector;
    this.flushes = flushes;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(DistinctOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DistinctSubscriber(subscriber, this.keySelector, this.flushes));
    }
  }]);

  return DistinctOperator;
}();

var DistinctSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(DistinctSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(DistinctSubscriber);

  function DistinctSubscriber(destination, keySelector, flushes) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, DistinctSubscriber);

    _this = _super.call(this, destination);
    _this.keySelector = keySelector;
    _this.values = new Set();

    if (flushes) {
      _this.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["innerSubscribe"])(flushes, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["SimpleInnerSubscriber"](Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this))));
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(DistinctSubscriber, [{
    key: "notifyNext",
    value: function notifyNext() {
      this.values.clear();
    }
  }, {
    key: "notifyError",
    value: function notifyError(error) {
      this._error(error);
    }
  }, {
    key: "_next",
    value: function _next(value) {
      if (this.keySelector) {
        this._useKeySelector(value);
      } else {
        this._finalizeNext(value, value);
      }
    }
  }, {
    key: "_useKeySelector",
    value: function _useKeySelector(value) {
      var key;
      var destination = this.destination;

      try {
        key = this.keySelector(value);
      } catch (err) {
        destination.error(err);
        return;
      }

      this._finalizeNext(key, value);
    }
  }, {
    key: "_finalizeNext",
    value: function _finalizeNext(key, value) {
      var values = this.values;

      if (!values.has(key)) {
        values.add(key);
        this.destination.next(value);
      }
    }
  }]);

  return DistinctSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "04ZW":
/*!****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/fromEventPattern.js ***!
  \****************************************************************************/
/*! exports provided: fromEventPattern */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "fromEventPattern", function() { return fromEventPattern; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _util_isFunction__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/isFunction */ "n6bG");
/* harmony import */ var _operators_map__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../operators/map */ "lJxs");





function fromEventPattern(addHandler, removeHandler, resultSelector) {
  if (resultSelector) {
    return fromEventPattern(addHandler, removeHandler).pipe(Object(_operators_map__WEBPACK_IMPORTED_MODULE_4__["map"])(function (args) {
      return Object(_util_isArray__WEBPACK_IMPORTED_MODULE_2__["isArray"])(args) ? resultSelector.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args)) : resultSelector(args);
    }));
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_1__["Observable"](function (subscriber) {
    var handler = function handler() {
      for (var _len = arguments.length, e = new Array(_len), _key = 0; _key < _len; _key++) {
        e[_key] = arguments[_key];
      }

      return subscriber.next(e.length === 1 ? e[0] : e);
    };

    var retValue;

    try {
      retValue = addHandler(handler);
    } catch (err) {
      subscriber.error(err);
      return undefined;
    }

    if (!Object(_util_isFunction__WEBPACK_IMPORTED_MODULE_3__["isFunction"])(removeHandler)) {
      return undefined;
    }

    return function () {
      return removeHandler(handler, retValue);
    };
  });
}

/***/ }),

/***/ "05l1":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/publishReplay.js ***!
  \************************************************************************/
/*! exports provided: publishReplay */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "publishReplay", function() { return publishReplay; });
/* harmony import */ var _ReplaySubject__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../ReplaySubject */ "jtHE");
/* harmony import */ var _multicast__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./multicast */ "oB13");


function publishReplay(bufferSize, windowTime, selectorOrScheduler, scheduler) {
  if (selectorOrScheduler && typeof selectorOrScheduler !== 'function') {
    scheduler = selectorOrScheduler;
  }

  var selector = typeof selectorOrScheduler === 'function' ? selectorOrScheduler : undefined;
  var subject = new _ReplaySubject__WEBPACK_IMPORTED_MODULE_0__["ReplaySubject"](bufferSize, windowTime, scheduler);
  return function (source) {
    return Object(_multicast__WEBPACK_IMPORTED_MODULE_1__["multicast"])(function () {
      return subject;
    }, selector)(source);
  };
}

/***/ }),

/***/ "0EUg":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/concatAll.js ***!
  \********************************************************************/
/*! exports provided: concatAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "concatAll", function() { return concatAll; });
/* harmony import */ var _mergeAll__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./mergeAll */ "bHdf");

function concatAll() {
  return Object(_mergeAll__WEBPACK_IMPORTED_MODULE_0__["mergeAll"])(1);
}

/***/ }),

/***/ "0Pi8":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/endWith.js ***!
  \******************************************************************/
/*! exports provided: endWith */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "endWith", function() { return endWith; });
/* harmony import */ var _observable_concat__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/concat */ "GyhO");
/* harmony import */ var _observable_of__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../observable/of */ "LRne");


function endWith() {
  for (var _len = arguments.length, array = new Array(_len), _key = 0; _key < _len; _key++) {
    array[_key] = arguments[_key];
  }

  return function (source) {
    return Object(_observable_concat__WEBPACK_IMPORTED_MODULE_0__["concat"])(source, _observable_of__WEBPACK_IMPORTED_MODULE_1__["of"].apply(void 0, array));
  };
}

/***/ }),

/***/ "0mo+":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/bo.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Tibetan [bo]
//! author : Thupten N. Chakrishar : https://github.com/vajradog
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '༡',
    2: '༢',
    3: '༣',
    4: '༤',
    5: '༥',
    6: '༦',
    7: '༧',
    8: '༨',
    9: '༩',
    0: '༠'
  },
      numberMap = {
    '༡': '1',
    '༢': '2',
    '༣': '3',
    '༤': '4',
    '༥': '5',
    '༦': '6',
    '༧': '7',
    '༨': '8',
    '༩': '9',
    '༠': '0'
  };
  var bo = moment.defineLocale('bo', {
    months: 'ཟླ་བ་དང་པོ_ཟླ་བ་གཉིས་པ_ཟླ་བ་གསུམ་པ_ཟླ་བ་བཞི་པ_ཟླ་བ་ལྔ་པ_ཟླ་བ་དྲུག་པ_ཟླ་བ་བདུན་པ_ཟླ་བ་བརྒྱད་པ_ཟླ་བ་དགུ་པ_ཟླ་བ་བཅུ་པ_ཟླ་བ་བཅུ་གཅིག་པ_ཟླ་བ་བཅུ་གཉིས་པ'.split('_'),
    monthsShort: 'ཟླ་1_ཟླ་2_ཟླ་3_ཟླ་4_ཟླ་5_ཟླ་6_ཟླ་7_ཟླ་8_ཟླ་9_ཟླ་10_ཟླ་11_ཟླ་12'.split('_'),
    monthsShortRegex: /^(ཟླ་\d{1,2})/,
    monthsParseExact: true,
    weekdays: 'གཟའ་ཉི་མ་_གཟའ་ཟླ་བ་_གཟའ་མིག་དམར་_གཟའ་ལྷག་པ་_གཟའ་ཕུར་བུ_གཟའ་པ་སངས་_གཟའ་སྤེན་པ་'.split('_'),
    weekdaysShort: 'ཉི་མ་_ཟླ་བ་_མིག་དམར་_ལྷག་པ་_ཕུར་བུ_པ་སངས་_སྤེན་པ་'.split('_'),
    weekdaysMin: 'ཉི_ཟླ_མིག_ལྷག_ཕུར_སངས_སྤེན'.split('_'),
    longDateFormat: {
      LT: 'A h:mm',
      LTS: 'A h:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm',
      LLLL: 'dddd, D MMMM YYYY, A h:mm'
    },
    calendar: {
      sameDay: '[དི་རིང] LT',
      nextDay: '[སང་ཉིན] LT',
      nextWeek: '[བདུན་ཕྲག་རྗེས་མ], LT',
      lastDay: '[ཁ་སང] LT',
      lastWeek: '[བདུན་ཕྲག་མཐའ་མ] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s ལ་',
      past: '%s སྔན་ལ',
      s: 'ལམ་སང',
      ss: '%d སྐར་ཆ།',
      m: 'སྐར་མ་གཅིག',
      mm: '%d སྐར་མ',
      h: 'ཆུ་ཚོད་གཅིག',
      hh: '%d ཆུ་ཚོད',
      d: 'ཉིན་གཅིག',
      dd: '%d ཉིན་',
      M: 'ཟླ་བ་གཅིག',
      MM: '%d ཟླ་བ',
      y: 'ལོ་གཅིག',
      yy: '%d ལོ'
    },
    preparse: function preparse(string) {
      return string.replace(/[༡༢༣༤༥༦༧༨༩༠]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    meridiemParse: /མཚན་མོ|ཞོགས་ཀས|ཉིན་གུང|དགོང་དག|མཚན་མོ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'མཚན་མོ' && hour >= 4 || meridiem === 'ཉིན་གུང' && hour < 5 || meridiem === 'དགོང་དག') {
        return hour + 12;
      } else {
        return hour;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'མཚན་མོ';
      } else if (hour < 10) {
        return 'ཞོགས་ཀས';
      } else if (hour < 17) {
        return 'ཉིན་གུང';
      } else if (hour < 20) {
        return 'དགོང་དག';
      } else {
        return 'མཚན་མོ';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return bo;
});

/***/ }),

/***/ "0tRk":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/pt-br.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Portuguese (Brazil) [pt-br]
//! author : Caio Ribeiro Pereira : https://github.com/caio-ribeiro-pereira
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ptBr = moment.defineLocale('pt-br', {
    months: 'janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro'.split('_'),
    monthsShort: 'jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez'.split('_'),
    weekdays: 'domingo_segunda-feira_terça-feira_quarta-feira_quinta-feira_sexta-feira_sábado'.split('_'),
    weekdaysShort: 'dom_seg_ter_qua_qui_sex_sáb'.split('_'),
    weekdaysMin: 'do_2ª_3ª_4ª_5ª_6ª_sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY [às] HH:mm',
      LLLL: 'dddd, D [de] MMMM [de] YYYY [às] HH:mm'
    },
    calendar: {
      sameDay: '[Hoje às] LT',
      nextDay: '[Amanhã às] LT',
      nextWeek: 'dddd [às] LT',
      lastDay: '[Ontem às] LT',
      lastWeek: function lastWeek() {
        return this.day() === 0 || this.day() === 6 ? '[Último] dddd [às] LT' // Saturday + Sunday
        : '[Última] dddd [às] LT'; // Monday - Friday
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'em %s',
      past: 'há %s',
      s: 'poucos segundos',
      ss: '%d segundos',
      m: 'um minuto',
      mm: '%d minutos',
      h: 'uma hora',
      hh: '%d horas',
      d: 'um dia',
      dd: '%d dias',
      M: 'um mês',
      MM: '%d meses',
      y: 'um ano',
      yy: '%d anos'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    invalidDate: 'Data inválida'
  });
  return ptBr;
});

/***/ }),

/***/ "128B":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/reduce.js ***!
  \*****************************************************************/
/*! exports provided: reduce */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "reduce", function() { return reduce; });
/* harmony import */ var _scan__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./scan */ "Kqap");
/* harmony import */ var _takeLast__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./takeLast */ "BFxc");
/* harmony import */ var _defaultIfEmpty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./defaultIfEmpty */ "xbPD");
/* harmony import */ var _util_pipe__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/pipe */ "mCNh");




function reduce(accumulator, seed) {
  if (arguments.length >= 2) {
    return function reduceOperatorFunctionWithSeed(source) {
      return Object(_util_pipe__WEBPACK_IMPORTED_MODULE_3__["pipe"])(Object(_scan__WEBPACK_IMPORTED_MODULE_0__["scan"])(accumulator, seed), Object(_takeLast__WEBPACK_IMPORTED_MODULE_1__["takeLast"])(1), Object(_defaultIfEmpty__WEBPACK_IMPORTED_MODULE_2__["defaultIfEmpty"])(seed))(source);
    };
  }

  return function reduceOperatorFunction(source) {
    return Object(_util_pipe__WEBPACK_IMPORTED_MODULE_3__["pipe"])(Object(_scan__WEBPACK_IMPORTED_MODULE_0__["scan"])(function (acc, value, index) {
      return accumulator(acc, value, index + 1);
    }), Object(_takeLast__WEBPACK_IMPORTED_MODULE_1__["takeLast"])(1))(source);
  };
}

/***/ }),

/***/ "1G5W":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/takeUntil.js ***!
  \********************************************************************/
/*! exports provided: takeUntil */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "takeUntil", function() { return takeUntil; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





function takeUntil(notifier) {
  return function (source) {
    return source.lift(new TakeUntilOperator(notifier));
  };
}

var TakeUntilOperator = /*#__PURE__*/function () {
  function TakeUntilOperator(notifier) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeUntilOperator);

    this.notifier = notifier;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeUntilOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      var takeUntilSubscriber = new TakeUntilSubscriber(subscriber);
      var notifierSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(this.notifier, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](takeUntilSubscriber));

      if (notifierSubscription && !takeUntilSubscriber.seenValue) {
        takeUntilSubscriber.add(notifierSubscription);
        return source.subscribe(takeUntilSubscriber);
      }

      return takeUntilSubscriber;
    }
  }]);

  return TakeUntilOperator;
}();

var TakeUntilSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(TakeUntilSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(TakeUntilSubscriber);

  function TakeUntilSubscriber(destination) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeUntilSubscriber);

    _this = _super.call(this, destination);
    _this.seenValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeUntilSubscriber, [{
    key: "notifyNext",
    value: function notifyNext() {
      this.seenValue = true;
      this.complete();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {}
  }]);

  return TakeUntilSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "1OyB":
/*!*******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/classCallCheck.js ***!
  \*******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _classCallCheck; });
function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

/***/ }),

/***/ "1Ykd":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/sampleTime.js ***!
  \*********************************************************************/
/*! exports provided: sampleTime */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "sampleTime", function() { return sampleTime; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");







function sampleTime(period) {
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_6__["async"];
  return function (source) {
    return source.lift(new SampleTimeOperator(period, scheduler));
  };
}

var SampleTimeOperator = /*#__PURE__*/function () {
  function SampleTimeOperator(period, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, SampleTimeOperator);

    this.period = period;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(SampleTimeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SampleTimeSubscriber(subscriber, this.period, this.scheduler));
    }
  }]);

  return SampleTimeOperator;
}();

var SampleTimeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(SampleTimeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(SampleTimeSubscriber);

  function SampleTimeSubscriber(destination, period, scheduler) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, SampleTimeSubscriber);

    _this = _super.call(this, destination);
    _this.period = period;
    _this.scheduler = scheduler;
    _this.hasValue = false;

    _this.add(scheduler.schedule(dispatchNotification, period, {
      subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this),
      period: period
    }));

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(SampleTimeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.lastValue = value;
      this.hasValue = true;
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      if (this.hasValue) {
        this.hasValue = false;
        this.destination.next(this.lastValue);
      }
    }
  }]);

  return SampleTimeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

function dispatchNotification(state) {
  var subscriber = state.subscriber,
      period = state.period;
  subscriber.notifyNext();
  this.schedule(state, period);
}

/***/ }),

/***/ "1ppg":
/*!*******************************************!*\
  !*** ./node_modules/moment/locale/fil.js ***!
  \*******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Filipino [fil]
//! author : Dan Hagman : https://github.com/hagmandan
//! author : Matthew Co : https://github.com/matthewdeeco
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var fil = moment.defineLocale('fil', {
    months: 'Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre'.split('_'),
    monthsShort: 'Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis'.split('_'),
    weekdays: 'Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado'.split('_'),
    weekdaysShort: 'Lin_Lun_Mar_Miy_Huw_Biy_Sab'.split('_'),
    weekdaysMin: 'Li_Lu_Ma_Mi_Hu_Bi_Sab'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'MM/D/YYYY',
      LL: 'MMMM D, YYYY',
      LLL: 'MMMM D, YYYY HH:mm',
      LLLL: 'dddd, MMMM DD, YYYY HH:mm'
    },
    calendar: {
      sameDay: 'LT [ngayong araw]',
      nextDay: '[Bukas ng] LT',
      nextWeek: 'LT [sa susunod na] dddd',
      lastDay: 'LT [kahapon]',
      lastWeek: 'LT [noong nakaraang] dddd',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'sa loob ng %s',
      past: '%s ang nakalipas',
      s: 'ilang segundo',
      ss: '%d segundo',
      m: 'isang minuto',
      mm: '%d minuto',
      h: 'isang oras',
      hh: '%d oras',
      d: 'isang araw',
      dd: '%d araw',
      M: 'isang buwan',
      MM: '%d buwan',
      y: 'isang taon',
      yy: '%d taon'
    },
    dayOfMonthOrdinalParse: /\d{1,2}/,
    ordinal: function ordinal(number) {
      return number;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return fil;
});

/***/ }),

/***/ "1rYy":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/hy-am.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Armenian [hy-am]
//! author : Armendarabyan : https://github.com/armendarabyan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var hyAm = moment.defineLocale('hy-am', {
    months: {
      format: 'հունվարի_փետրվարի_մարտի_ապրիլի_մայիսի_հունիսի_հուլիսի_օգոստոսի_սեպտեմբերի_հոկտեմբերի_նոյեմբերի_դեկտեմբերի'.split('_'),
      standalone: 'հունվար_փետրվար_մարտ_ապրիլ_մայիս_հունիս_հուլիս_օգոստոս_սեպտեմբեր_հոկտեմբեր_նոյեմբեր_դեկտեմբեր'.split('_')
    },
    monthsShort: 'հնվ_փտր_մրտ_ապր_մյս_հնս_հլս_օգս_սպտ_հկտ_նմբ_դկտ'.split('_'),
    weekdays: 'կիրակի_երկուշաբթի_երեքշաբթի_չորեքշաբթի_հինգշաբթի_ուրբաթ_շաբաթ'.split('_'),
    weekdaysShort: 'կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ'.split('_'),
    weekdaysMin: 'կրկ_երկ_երք_չրք_հնգ_ուրբ_շբթ'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY թ.',
      LLL: 'D MMMM YYYY թ., HH:mm',
      LLLL: 'dddd, D MMMM YYYY թ., HH:mm'
    },
    calendar: {
      sameDay: '[այսօր] LT',
      nextDay: '[վաղը] LT',
      lastDay: '[երեկ] LT',
      nextWeek: function nextWeek() {
        return 'dddd [օրը ժամը] LT';
      },
      lastWeek: function lastWeek() {
        return '[անցած] dddd [օրը ժամը] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s հետո',
      past: '%s առաջ',
      s: 'մի քանի վայրկյան',
      ss: '%d վայրկյան',
      m: 'րոպե',
      mm: '%d րոպե',
      h: 'ժամ',
      hh: '%d ժամ',
      d: 'օր',
      dd: '%d օր',
      M: 'ամիս',
      MM: '%d ամիս',
      y: 'տարի',
      yy: '%d տարի'
    },
    meridiemParse: /գիշերվա|առավոտվա|ցերեկվա|երեկոյան/,
    isPM: function isPM(input) {
      return /^(ցերեկվա|երեկոյան)$/.test(input);
    },
    meridiem: function meridiem(hour) {
      if (hour < 4) {
        return 'գիշերվա';
      } else if (hour < 12) {
        return 'առավոտվա';
      } else if (hour < 17) {
        return 'ցերեկվա';
      } else {
        return 'երեկոյան';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}|\d{1,2}-(ին|րդ)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'DDD':
        case 'w':
        case 'W':
        case 'DDDo':
          if (number === 1) {
            return number + '-ին';
          }

          return number + '-րդ';

        default:
          return number;
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return hyAm;
});

/***/ }),

/***/ "1uSB":
/*!*************************************************************!*\
  !*** ./node_modules/@angular/compiler/fesm2015/compiler.js ***!
  \*************************************************************/
/*! exports provided: AST, ASTWithName, ASTWithSource, AbsoluteSourceSpan, AotCompiler, AotSummaryResolver, ArrayType, AssertNotNull, AstMemoryEfficientTransformer, AstPath, AstTransformer, AttrAst, Attribute, Binary, BinaryOperator, BinaryOperatorExpr, BindingPipe, BoundDirectivePropertyAst, BoundElementProperty, BoundElementPropertyAst, BoundEventAst, BoundTextAst, BuiltinMethod, BuiltinType, BuiltinTypeName, BuiltinVar, CONTENT_ATTR, CUSTOM_ELEMENTS_SCHEMA, CastExpr, Chain, ClassField, ClassMethod, ClassStmt, CommaExpr, Comment, CompileDirectiveMetadata, CompileMetadataResolver, CompileNgModuleMetadata, CompilePipeMetadata, CompileReflector, CompileShallowModuleMetadata, CompileStylesheetMetadata, CompileSummaryKind, CompileTemplateMetadata, CompiledStylesheet, CompilerConfig, Conditional, ConditionalExpr, ConstantPool, CssSelector, DEFAULT_INTERPOLATION_CONFIG, DYNAMIC_TYPE, DeclareFunctionStmt, DeclareVarStmt, DirectiveAst, DirectiveNormalizer, DirectiveResolver, DomElementSchemaRegistry, EOF, ERROR_COMPONENT_TYPE, Element, ElementAst, ElementSchemaRegistry, EmbeddedTemplateAst, EmitterVisitorContext, EmptyExpr, Expansion, ExpansionCase, Expression, ExpressionBinding, ExpressionStatement, ExpressionType, ExternalExpr, ExternalReference, Extractor, FunctionCall, FunctionExpr, GeneratedFile, HOST_ATTR, HtmlParser, HtmlTagDefinition, I18NHtmlParser, Identifiers, IfStmt, ImplicitReceiver, InstantiateExpr, Interpolation, InterpolationConfig, InvokeFunctionExpr, InvokeMethodExpr, IvyParser, JSDocComment, JitCompiler, JitEvaluator, JitSummaryResolver, KeyedRead, KeyedWrite, LeadingComment, Lexer, LiteralArray, LiteralArrayExpr, LiteralExpr, LiteralMap, LiteralMapExpr, LiteralPrimitive, LocalizedString, MapType, MessageBundle, MethodCall, NAMED_ENTITIES, NGSP_UNICODE, NONE_TYPE, NO_ERRORS_SCHEMA, NgContentAst, NgModuleCompiler, NgModuleResolver, NodeWithI18n, NonNullAssert, NotExpr, NullTemplateVisitor, ParseError, ParseErrorLevel, ParseLocation, ParseSourceFile, ParseSourceSpan, ParseSpan, ParseTreeResult, ParsedEvent, ParsedProperty, ParsedPropertyType, ParsedVariable, Parser, ParserError, PipeResolver, PrefixNot, PropertyRead, PropertyWrite, ProviderAst, ProviderAstType, ProviderMeta, Quote, R3BoundTarget, R3FactoryTarget, R3Identifiers, R3ResolvedDependencyType, R3TargetBinder, ReadKeyExpr, ReadPropExpr, ReadVarExpr, RecursiveAstVisitor, RecursiveTemplateAstVisitor, RecursiveVisitor, ReferenceAst, ResolvedStaticSymbol, ResourceLoader, ReturnStatement, STRING_TYPE, SafeMethodCall, SafePropertyRead, SelectorContext, SelectorListContext, SelectorMatcher, Serializer, SplitInterpolation, Statement, StaticReflector, StaticSymbol, StaticSymbolCache, StaticSymbolResolver, StmtModifier, StyleCompiler, StylesCompileDependency, SummaryResolver, TagContentType, TemplateBindingParseResult, TemplateParseError, TemplateParseResult, TemplateParser, Text, TextAst, ThrowStmt, TmplAstBoundAttribute, TmplAstBoundEvent, TmplAstBoundText, TmplAstContent, TmplAstElement, TmplAstRecursiveVisitor, TmplAstReference, TmplAstTemplate, TmplAstText, TmplAstTextAttribute, TmplAstVariable, Token, TokenType, TransitiveCompileNgModuleMetadata, TreeError, TryCatchStmt, Type, TypeScriptEmitter, TypeofExpr, Unary, UnaryOperator, UnaryOperatorExpr, UrlResolver, VERSION, VariableAst, VariableBinding, Version, ViewCompiler, WrappedNodeExpr, WriteKeyExpr, WritePropExpr, WriteVarExpr, Xliff, Xliff2, Xmb, XmlParser, Xtb, _ParseAST, analyzeAndValidateNgModules, analyzeFile, analyzeFileForInjectables, analyzeNgModules, collectExternalReferences, compileComponentFromMetadata, compileDirectiveFromMetadata, compileFactoryFunction, compileInjectable, compileInjector, compileNgModule, compilePipeFromMetadata, componentFactoryName, computeMsgId, core, createAotCompiler, createAotUrlResolver, createElementCssSelector, createLoweredSymbol, createOfflineCompileUrlResolver, createUrlResolverWithoutPackagePrefix, debugOutputAstAsTypeScript, findNode, flatten, formattedError, getHtmlTagDefinition, getNsPrefix, getParseErrors, getUrlScheme, hostViewClassName, identifierModuleUrl, identifierName, isEmptyExpression, isFormattedError, isIdentifier, isLoweredSymbol, isNgContainer, isNgContent, isNgTemplate, isQuote, isSyntaxError, jsDocComment, leadingComment, literalMap, makeBindingParser, mergeAnalyzedFiles, mergeNsAndName, ngModuleJitUrl, parseHostBindings, parseTemplate, preserveWhitespacesDefault, publishFacade, r3JitTypeSourceSpan, removeSummaryDuplicates, rendererTypeName, sanitizeIdentifier, sharedStylesheetJitUrl, splitClasses, splitNsName, syntaxError, templateJitUrl, templateSourceUrl, templateVisitAll, toTypeScript, tokenName, tokenReference, typeSourceSpan, unescapeIdentifier, unwrapResolvedMetadata, verifyHostBindings, viewClassName, visitAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AST", function() { return AST; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ASTWithName", function() { return ASTWithName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ASTWithSource", function() { return ASTWithSource; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AbsoluteSourceSpan", function() { return AbsoluteSourceSpan; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AotCompiler", function() { return AotCompiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AotSummaryResolver", function() { return AotSummaryResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ArrayType", function() { return ArrayType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AssertNotNull", function() { return AssertNotNull; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AstMemoryEfficientTransformer", function() { return AstMemoryEfficientTransformer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AstPath", function() { return AstPath; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AstTransformer", function() { return AstTransformer$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AttrAst", function() { return AttrAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Attribute", function() { return Attribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Binary", function() { return Binary; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BinaryOperator", function() { return BinaryOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BinaryOperatorExpr", function() { return BinaryOperatorExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BindingPipe", function() { return BindingPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BoundDirectivePropertyAst", function() { return BoundDirectivePropertyAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BoundElementProperty", function() { return BoundElementProperty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BoundElementPropertyAst", function() { return BoundElementPropertyAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BoundEventAst", function() { return BoundEventAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BoundTextAst", function() { return BoundTextAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BuiltinMethod", function() { return BuiltinMethod; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BuiltinType", function() { return BuiltinType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BuiltinTypeName", function() { return BuiltinTypeName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BuiltinVar", function() { return BuiltinVar; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CONTENT_ATTR", function() { return CONTENT_ATTR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CUSTOM_ELEMENTS_SCHEMA", function() { return CUSTOM_ELEMENTS_SCHEMA; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CastExpr", function() { return CastExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Chain", function() { return Chain; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ClassField", function() { return ClassField; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ClassMethod", function() { return ClassMethod; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ClassStmt", function() { return ClassStmt; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CommaExpr", function() { return CommaExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Comment", function() { return Comment; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileDirectiveMetadata", function() { return CompileDirectiveMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileMetadataResolver", function() { return CompileMetadataResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileNgModuleMetadata", function() { return CompileNgModuleMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompilePipeMetadata", function() { return CompilePipeMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileReflector", function() { return CompileReflector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileShallowModuleMetadata", function() { return CompileShallowModuleMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileStylesheetMetadata", function() { return CompileStylesheetMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileSummaryKind", function() { return CompileSummaryKind; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompileTemplateMetadata", function() { return CompileTemplateMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompiledStylesheet", function() { return CompiledStylesheet; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompilerConfig", function() { return CompilerConfig; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Conditional", function() { return Conditional; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ConditionalExpr", function() { return ConditionalExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ConstantPool", function() { return ConstantPool; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CssSelector", function() { return CssSelector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DEFAULT_INTERPOLATION_CONFIG", function() { return DEFAULT_INTERPOLATION_CONFIG; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DYNAMIC_TYPE", function() { return DYNAMIC_TYPE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DeclareFunctionStmt", function() { return DeclareFunctionStmt; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DeclareVarStmt", function() { return DeclareVarStmt; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DirectiveAst", function() { return DirectiveAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DirectiveNormalizer", function() { return DirectiveNormalizer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DirectiveResolver", function() { return DirectiveResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DomElementSchemaRegistry", function() { return DomElementSchemaRegistry; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EOF", function() { return EOF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ERROR_COMPONENT_TYPE", function() { return ERROR_COMPONENT_TYPE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Element", function() { return Element$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ElementAst", function() { return ElementAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ElementSchemaRegistry", function() { return ElementSchemaRegistry; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EmbeddedTemplateAst", function() { return EmbeddedTemplateAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EmitterVisitorContext", function() { return EmitterVisitorContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EmptyExpr", function() { return EmptyExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Expansion", function() { return Expansion; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExpansionCase", function() { return ExpansionCase; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Expression", function() { return Expression; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExpressionBinding", function() { return ExpressionBinding; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExpressionStatement", function() { return ExpressionStatement; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExpressionType", function() { return ExpressionType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExternalExpr", function() { return ExternalExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExternalReference", function() { return ExternalReference; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Extractor", function() { return Extractor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FunctionCall", function() { return FunctionCall; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FunctionExpr", function() { return FunctionExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "GeneratedFile", function() { return GeneratedFile; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HOST_ATTR", function() { return HOST_ATTR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HtmlParser", function() { return HtmlParser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HtmlTagDefinition", function() { return HtmlTagDefinition; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "I18NHtmlParser", function() { return I18NHtmlParser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Identifiers", function() { return Identifiers; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "IfStmt", function() { return IfStmt; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ImplicitReceiver", function() { return ImplicitReceiver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InstantiateExpr", function() { return InstantiateExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Interpolation", function() { return Interpolation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InterpolationConfig", function() { return InterpolationConfig; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InvokeFunctionExpr", function() { return InvokeFunctionExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InvokeMethodExpr", function() { return InvokeMethodExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "IvyParser", function() { return IvyParser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JSDocComment", function() { return JSDocComment; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JitCompiler", function() { return JitCompiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JitEvaluator", function() { return JitEvaluator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JitSummaryResolver", function() { return JitSummaryResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "KeyedRead", function() { return KeyedRead; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "KeyedWrite", function() { return KeyedWrite; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LeadingComment", function() { return LeadingComment; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Lexer", function() { return Lexer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LiteralArray", function() { return LiteralArray; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LiteralArrayExpr", function() { return LiteralArrayExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LiteralExpr", function() { return LiteralExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LiteralMap", function() { return LiteralMap; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LiteralMapExpr", function() { return LiteralMapExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LiteralPrimitive", function() { return LiteralPrimitive; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LocalizedString", function() { return LocalizedString; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MapType", function() { return MapType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MessageBundle", function() { return MessageBundle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MethodCall", function() { return MethodCall; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NAMED_ENTITIES", function() { return NAMED_ENTITIES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NGSP_UNICODE", function() { return NGSP_UNICODE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NONE_TYPE", function() { return NONE_TYPE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NO_ERRORS_SCHEMA", function() { return NO_ERRORS_SCHEMA; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgContentAst", function() { return NgContentAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModuleCompiler", function() { return NgModuleCompiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModuleResolver", function() { return NgModuleResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NodeWithI18n", function() { return NodeWithI18n; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NonNullAssert", function() { return NonNullAssert; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NotExpr", function() { return NotExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NullTemplateVisitor", function() { return NullTemplateVisitor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseError", function() { return ParseError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseErrorLevel", function() { return ParseErrorLevel; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseLocation", function() { return ParseLocation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseSourceFile", function() { return ParseSourceFile; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseSourceSpan", function() { return ParseSourceSpan; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseSpan", function() { return ParseSpan; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParseTreeResult", function() { return ParseTreeResult; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParsedEvent", function() { return ParsedEvent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParsedProperty", function() { return ParsedProperty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParsedPropertyType", function() { return ParsedPropertyType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParsedVariable", function() { return ParsedVariable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Parser", function() { return Parser$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ParserError", function() { return ParserError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PipeResolver", function() { return PipeResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PrefixNot", function() { return PrefixNot; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PropertyRead", function() { return PropertyRead; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PropertyWrite", function() { return PropertyWrite; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ProviderAst", function() { return ProviderAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ProviderAstType", function() { return ProviderAstType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ProviderMeta", function() { return ProviderMeta; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Quote", function() { return Quote; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "R3BoundTarget", function() { return R3BoundTarget; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "R3FactoryTarget", function() { return R3FactoryTarget; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "R3Identifiers", function() { return Identifiers$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "R3ResolvedDependencyType", function() { return R3ResolvedDependencyType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "R3TargetBinder", function() { return R3TargetBinder; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReadKeyExpr", function() { return ReadKeyExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReadPropExpr", function() { return ReadPropExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReadVarExpr", function() { return ReadVarExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RecursiveAstVisitor", function() { return RecursiveAstVisitor$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RecursiveTemplateAstVisitor", function() { return RecursiveTemplateAstVisitor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RecursiveVisitor", function() { return RecursiveVisitor$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReferenceAst", function() { return ReferenceAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ResolvedStaticSymbol", function() { return ResolvedStaticSymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ResourceLoader", function() { return ResourceLoader; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReturnStatement", function() { return ReturnStatement; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "STRING_TYPE", function() { return STRING_TYPE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SafeMethodCall", function() { return SafeMethodCall; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SafePropertyRead", function() { return SafePropertyRead; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SelectorContext", function() { return SelectorContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SelectorListContext", function() { return SelectorListContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SelectorMatcher", function() { return SelectorMatcher; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Serializer", function() { return Serializer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SplitInterpolation", function() { return SplitInterpolation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Statement", function() { return Statement; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StaticReflector", function() { return StaticReflector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StaticSymbol", function() { return StaticSymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StaticSymbolCache", function() { return StaticSymbolCache; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StaticSymbolResolver", function() { return StaticSymbolResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StmtModifier", function() { return StmtModifier; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StyleCompiler", function() { return StyleCompiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "StylesCompileDependency", function() { return StylesCompileDependency; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SummaryResolver", function() { return SummaryResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TagContentType", function() { return TagContentType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TemplateBindingParseResult", function() { return TemplateBindingParseResult; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TemplateParseError", function() { return TemplateParseError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TemplateParseResult", function() { return TemplateParseResult; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TemplateParser", function() { return TemplateParser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Text", function() { return Text$3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TextAst", function() { return TextAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ThrowStmt", function() { return ThrowStmt; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstBoundAttribute", function() { return BoundAttribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstBoundEvent", function() { return BoundEvent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstBoundText", function() { return BoundText; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstContent", function() { return Content; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstElement", function() { return Element; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstRecursiveVisitor", function() { return RecursiveVisitor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstReference", function() { return Reference; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstTemplate", function() { return Template; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstText", function() { return Text; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstTextAttribute", function() { return TextAttribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TmplAstVariable", function() { return Variable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Token", function() { return Token$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TokenType", function() { return TokenType$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TransitiveCompileNgModuleMetadata", function() { return TransitiveCompileNgModuleMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TreeError", function() { return TreeError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TryCatchStmt", function() { return TryCatchStmt; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Type", function() { return Type$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TypeScriptEmitter", function() { return TypeScriptEmitter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TypeofExpr", function() { return TypeofExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Unary", function() { return Unary; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UnaryOperator", function() { return UnaryOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UnaryOperatorExpr", function() { return UnaryOperatorExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UrlResolver", function() { return UrlResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VariableAst", function() { return VariableAst; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VariableBinding", function() { return VariableBinding; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Version", function() { return Version; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewCompiler", function() { return ViewCompiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "WrappedNodeExpr", function() { return WrappedNodeExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "WriteKeyExpr", function() { return WriteKeyExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "WritePropExpr", function() { return WritePropExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "WriteVarExpr", function() { return WriteVarExpr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Xliff", function() { return Xliff; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Xliff2", function() { return Xliff2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Xmb", function() { return Xmb; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "XmlParser", function() { return XmlParser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Xtb", function() { return Xtb; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "_ParseAST", function() { return _ParseAST; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "analyzeAndValidateNgModules", function() { return analyzeAndValidateNgModules; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "analyzeFile", function() { return analyzeFile; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "analyzeFileForInjectables", function() { return analyzeFileForInjectables; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "analyzeNgModules", function() { return analyzeNgModules; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "collectExternalReferences", function() { return collectExternalReferences; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compileComponentFromMetadata", function() { return compileComponentFromMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compileDirectiveFromMetadata", function() { return compileDirectiveFromMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compileFactoryFunction", function() { return compileFactoryFunction; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compileInjectable", function() { return _compileInjectable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compileInjector", function() { return _compileInjector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compileNgModule", function() { return _compileNgModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "compilePipeFromMetadata", function() { return compilePipeFromMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "componentFactoryName", function() { return componentFactoryName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "computeMsgId", function() { return computeMsgId; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "core", function() { return core; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createAotCompiler", function() { return createAotCompiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createAotUrlResolver", function() { return createAotUrlResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createElementCssSelector", function() { return createElementCssSelector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createLoweredSymbol", function() { return createLoweredSymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createOfflineCompileUrlResolver", function() { return createOfflineCompileUrlResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createUrlResolverWithoutPackagePrefix", function() { return createUrlResolverWithoutPackagePrefix; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "debugOutputAstAsTypeScript", function() { return debugOutputAstAsTypeScript; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "findNode", function() { return findNode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "flatten", function() { return flatten; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "formattedError", function() { return formattedError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getHtmlTagDefinition", function() { return getHtmlTagDefinition; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getNsPrefix", function() { return getNsPrefix; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getParseErrors", function() { return getParseErrors; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getUrlScheme", function() { return getUrlScheme; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "hostViewClassName", function() { return hostViewClassName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "identifierModuleUrl", function() { return identifierModuleUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "identifierName", function() { return identifierName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isEmptyExpression", function() { return isEmptyExpression; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isFormattedError", function() { return isFormattedError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isIdentifier", function() { return isIdentifier; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isLoweredSymbol", function() { return isLoweredSymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isNgContainer", function() { return isNgContainer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isNgContent", function() { return isNgContent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isNgTemplate", function() { return isNgTemplate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isQuote", function() { return isQuote; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isSyntaxError", function() { return isSyntaxError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "jsDocComment", function() { return jsDocComment; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "leadingComment", function() { return leadingComment; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "literalMap", function() { return literalMap; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "makeBindingParser", function() { return makeBindingParser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mergeAnalyzedFiles", function() { return mergeAnalyzedFiles; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mergeNsAndName", function() { return mergeNsAndName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ngModuleJitUrl", function() { return ngModuleJitUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "parseHostBindings", function() { return parseHostBindings; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "parseTemplate", function() { return parseTemplate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "preserveWhitespacesDefault", function() { return preserveWhitespacesDefault; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "publishFacade", function() { return publishFacade; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "r3JitTypeSourceSpan", function() { return r3JitTypeSourceSpan; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "removeSummaryDuplicates", function() { return removeSummaryDuplicates; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "rendererTypeName", function() { return rendererTypeName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "sanitizeIdentifier", function() { return sanitizeIdentifier; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "sharedStylesheetJitUrl", function() { return sharedStylesheetJitUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "splitClasses", function() { return splitClasses; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "splitNsName", function() { return splitNsName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "syntaxError", function() { return syntaxError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "templateJitUrl", function() { return templateJitUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "templateSourceUrl", function() { return templateSourceUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "templateVisitAll", function() { return templateVisitAll; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "toTypeScript", function() { return toTypeScript; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "tokenName", function() { return tokenName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "tokenReference", function() { return tokenReference; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "typeSourceSpan", function() { return typeSourceSpan; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "unescapeIdentifier", function() { return unescapeIdentifier; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "unwrapResolvedMetadata", function() { return unwrapResolvedMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "verifyHostBindings", function() { return verifyHostBindings; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "viewClassName", function() { return viewClassName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "visitAll", function() { return visitAll$1; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/defineProperty */ "rePB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn */ "md7G");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toArray */ "T5bk");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/construct */ "RHh3");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ "ODXe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createForOfIteratorHelper */ "uFwe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");















var _BoundPropertyMapping;

/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
var TagContentType;

(function (TagContentType) {
  TagContentType[TagContentType["RAW_TEXT"] = 0] = "RAW_TEXT";
  TagContentType[TagContentType["ESCAPABLE_RAW_TEXT"] = 1] = "ESCAPABLE_RAW_TEXT";
  TagContentType[TagContentType["PARSABLE_DATA"] = 2] = "PARSABLE_DATA";
})(TagContentType || (TagContentType = {}));

function splitNsName(elementName) {
  if (elementName[0] != ':') {
    return [null, elementName];
  }

  var colonIndex = elementName.indexOf(':', 1);

  if (colonIndex == -1) {
    throw new Error("Unsupported format \"".concat(elementName, "\" expecting \":namespace:name\""));
  }

  return [elementName.slice(1, colonIndex), elementName.slice(colonIndex + 1)];
} // `<ng-container>` tags work the same regardless the namespace


function isNgContainer(tagName) {
  return splitNsName(tagName)[1] === 'ng-container';
} // `<ng-content>` tags work the same regardless the namespace


function isNgContent(tagName) {
  return splitNsName(tagName)[1] === 'ng-content';
} // `<ng-template>` tags work the same regardless the namespace


function isNgTemplate(tagName) {
  return splitNsName(tagName)[1] === 'ng-template';
}

function getNsPrefix(fullName) {
  return fullName === null ? null : splitNsName(fullName)[0];
}

function mergeNsAndName(prefix, localName) {
  return prefix ? ":".concat(prefix, ":").concat(localName) : localName;
} // see http://www.w3.org/TR/html51/syntax.html#named-character-references
// see https://html.spec.whatwg.org/multipage/entities.json
// This list is not exhaustive to keep the compiler footprint low.
// The `&#123;` / `&#x1ab;` syntax should be used when the named character reference does not
// exist.


var NAMED_ENTITIES = {
  'Aacute': "\xC1",
  'aacute': "\xE1",
  'Acirc': "\xC2",
  'acirc': "\xE2",
  'acute': "\xB4",
  'AElig': "\xC6",
  'aelig': "\xE6",
  'Agrave': "\xC0",
  'agrave': "\xE0",
  'alefsym': "\u2135",
  'Alpha': "\u0391",
  'alpha': "\u03B1",
  'amp': '&',
  'and': "\u2227",
  'ang': "\u2220",
  'apos': "'",
  'Aring': "\xC5",
  'aring': "\xE5",
  'asymp': "\u2248",
  'Atilde': "\xC3",
  'atilde': "\xE3",
  'Auml': "\xC4",
  'auml': "\xE4",
  'bdquo': "\u201E",
  'Beta': "\u0392",
  'beta': "\u03B2",
  'brvbar': "\xA6",
  'bull': "\u2022",
  'cap': "\u2229",
  'Ccedil': "\xC7",
  'ccedil': "\xE7",
  'cedil': "\xB8",
  'cent': "\xA2",
  'Chi': "\u03A7",
  'chi': "\u03C7",
  'circ': "\u02C6",
  'clubs': "\u2663",
  'cong': "\u2245",
  'copy': "\xA9",
  'crarr': "\u21B5",
  'cup': "\u222A",
  'curren': "\xA4",
  'dagger': "\u2020",
  'Dagger': "\u2021",
  'darr': "\u2193",
  'dArr': "\u21D3",
  'deg': "\xB0",
  'Delta': "\u0394",
  'delta': "\u03B4",
  'diams': "\u2666",
  'divide': "\xF7",
  'Eacute': "\xC9",
  'eacute': "\xE9",
  'Ecirc': "\xCA",
  'ecirc': "\xEA",
  'Egrave': "\xC8",
  'egrave': "\xE8",
  'empty': "\u2205",
  'emsp': "\u2003",
  'ensp': "\u2002",
  'Epsilon': "\u0395",
  'epsilon': "\u03B5",
  'equiv': "\u2261",
  'Eta': "\u0397",
  'eta': "\u03B7",
  'ETH': "\xD0",
  'eth': "\xF0",
  'Euml': "\xCB",
  'euml': "\xEB",
  'euro': "\u20AC",
  'exist': "\u2203",
  'fnof': "\u0192",
  'forall': "\u2200",
  'frac12': "\xBD",
  'frac14': "\xBC",
  'frac34': "\xBE",
  'frasl': "\u2044",
  'Gamma': "\u0393",
  'gamma': "\u03B3",
  'ge': "\u2265",
  'gt': '>',
  'harr': "\u2194",
  'hArr': "\u21D4",
  'hearts': "\u2665",
  'hellip': "\u2026",
  'Iacute': "\xCD",
  'iacute': "\xED",
  'Icirc': "\xCE",
  'icirc': "\xEE",
  'iexcl': "\xA1",
  'Igrave': "\xCC",
  'igrave': "\xEC",
  'image': "\u2111",
  'infin': "\u221E",
  'int': "\u222B",
  'Iota': "\u0399",
  'iota': "\u03B9",
  'iquest': "\xBF",
  'isin': "\u2208",
  'Iuml': "\xCF",
  'iuml': "\xEF",
  'Kappa': "\u039A",
  'kappa': "\u03BA",
  'Lambda': "\u039B",
  'lambda': "\u03BB",
  'lang': "\u27E8",
  'laquo': "\xAB",
  'larr': "\u2190",
  'lArr': "\u21D0",
  'lceil': "\u2308",
  'ldquo': "\u201C",
  'le': "\u2264",
  'lfloor': "\u230A",
  'lowast': "\u2217",
  'loz': "\u25CA",
  'lrm': "\u200E",
  'lsaquo': "\u2039",
  'lsquo': "\u2018",
  'lt': '<',
  'macr': "\xAF",
  'mdash': "\u2014",
  'micro': "\xB5",
  'middot': "\xB7",
  'minus': "\u2212",
  'Mu': "\u039C",
  'mu': "\u03BC",
  'nabla': "\u2207",
  'nbsp': "\xA0",
  'ndash': "\u2013",
  'ne': "\u2260",
  'ni': "\u220B",
  'not': "\xAC",
  'notin': "\u2209",
  'nsub': "\u2284",
  'Ntilde': "\xD1",
  'ntilde': "\xF1",
  'Nu': "\u039D",
  'nu': "\u03BD",
  'Oacute': "\xD3",
  'oacute': "\xF3",
  'Ocirc': "\xD4",
  'ocirc': "\xF4",
  'OElig': "\u0152",
  'oelig': "\u0153",
  'Ograve': "\xD2",
  'ograve': "\xF2",
  'oline': "\u203E",
  'Omega': "\u03A9",
  'omega': "\u03C9",
  'Omicron': "\u039F",
  'omicron': "\u03BF",
  'oplus': "\u2295",
  'or': "\u2228",
  'ordf': "\xAA",
  'ordm': "\xBA",
  'Oslash': "\xD8",
  'oslash': "\xF8",
  'Otilde': "\xD5",
  'otilde': "\xF5",
  'otimes': "\u2297",
  'Ouml': "\xD6",
  'ouml': "\xF6",
  'para': "\xB6",
  'permil': "\u2030",
  'perp': "\u22A5",
  'Phi': "\u03A6",
  'phi': "\u03C6",
  'Pi': "\u03A0",
  'pi': "\u03C0",
  'piv': "\u03D6",
  'plusmn': "\xB1",
  'pound': "\xA3",
  'prime': "\u2032",
  'Prime': "\u2033",
  'prod': "\u220F",
  'prop': "\u221D",
  'Psi': "\u03A8",
  'psi': "\u03C8",
  'quot': "\"",
  'radic': "\u221A",
  'rang': "\u27E9",
  'raquo': "\xBB",
  'rarr': "\u2192",
  'rArr': "\u21D2",
  'rceil': "\u2309",
  'rdquo': "\u201D",
  'real': "\u211C",
  'reg': "\xAE",
  'rfloor': "\u230B",
  'Rho': "\u03A1",
  'rho': "\u03C1",
  'rlm': "\u200F",
  'rsaquo': "\u203A",
  'rsquo': "\u2019",
  'sbquo': "\u201A",
  'Scaron': "\u0160",
  'scaron': "\u0161",
  'sdot': "\u22C5",
  'sect': "\xA7",
  'shy': "\xAD",
  'Sigma': "\u03A3",
  'sigma': "\u03C3",
  'sigmaf': "\u03C2",
  'sim': "\u223C",
  'spades': "\u2660",
  'sub': "\u2282",
  'sube': "\u2286",
  'sum': "\u2211",
  'sup': "\u2283",
  'sup1': "\xB9",
  'sup2': "\xB2",
  'sup3': "\xB3",
  'supe': "\u2287",
  'szlig': "\xDF",
  'Tau': "\u03A4",
  'tau': "\u03C4",
  'there4': "\u2234",
  'Theta': "\u0398",
  'theta': "\u03B8",
  'thetasym': "\u03D1",
  'thinsp': "\u2009",
  'THORN': "\xDE",
  'thorn': "\xFE",
  'tilde': "\u02DC",
  'times': "\xD7",
  'trade': "\u2122",
  'Uacute': "\xDA",
  'uacute': "\xFA",
  'uarr': "\u2191",
  'uArr': "\u21D1",
  'Ucirc': "\xDB",
  'ucirc': "\xFB",
  'Ugrave': "\xD9",
  'ugrave': "\xF9",
  'uml': "\xA8",
  'upsih': "\u03D2",
  'Upsilon': "\u03A5",
  'upsilon': "\u03C5",
  'Uuml': "\xDC",
  'uuml': "\xFC",
  'weierp': "\u2118",
  'Xi': "\u039E",
  'xi': "\u03BE",
  'Yacute': "\xDD",
  'yacute': "\xFD",
  'yen': "\xA5",
  'yuml': "\xFF",
  'Yuml': "\u0178",
  'Zeta': "\u0396",
  'zeta': "\u03B6",
  'zwj': "\u200D",
  'zwnj': "\u200C"
}; // The &ngsp; pseudo-entity is denoting a space. see:
// https://github.com/dart-lang/angular/blob/0bb611387d29d65b5af7f9d2515ab571fd3fbee4/_tests/test/compiler/preserve_whitespace_test.dart

var NGSP_UNICODE = "\uE500";
NAMED_ENTITIES['ngsp'] = NGSP_UNICODE;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var HtmlTagDefinition = /*#__PURE__*/function () {
  function HtmlTagDefinition() {
    var _this = this;

    var _ref2 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        closedByChildren = _ref2.closedByChildren,
        implicitNamespacePrefix = _ref2.implicitNamespacePrefix,
        _ref2$contentType = _ref2.contentType,
        contentType = _ref2$contentType === void 0 ? TagContentType.PARSABLE_DATA : _ref2$contentType,
        _ref2$closedByParent = _ref2.closedByParent,
        closedByParent = _ref2$closedByParent === void 0 ? false : _ref2$closedByParent,
        _ref2$isVoid = _ref2.isVoid,
        isVoid = _ref2$isVoid === void 0 ? false : _ref2$isVoid,
        _ref2$ignoreFirstLf = _ref2.ignoreFirstLf,
        ignoreFirstLf = _ref2$ignoreFirstLf === void 0 ? false : _ref2$ignoreFirstLf,
        _ref2$preventNamespac = _ref2.preventNamespaceInheritance,
        preventNamespaceInheritance = _ref2$preventNamespac === void 0 ? false : _ref2$preventNamespac;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, HtmlTagDefinition);

    this.closedByChildren = {};
    this.closedByParent = false;
    this.canSelfClose = false;

    if (closedByChildren && closedByChildren.length > 0) {
      closedByChildren.forEach(function (tagName) {
        return _this.closedByChildren[tagName] = true;
      });
    }

    this.isVoid = isVoid;
    this.closedByParent = closedByParent || isVoid;
    this.implicitNamespacePrefix = implicitNamespacePrefix || null;
    this.contentType = contentType;
    this.ignoreFirstLf = ignoreFirstLf;
    this.preventNamespaceInheritance = preventNamespaceInheritance;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(HtmlTagDefinition, [{
    key: "isClosedByChild",
    value: function isClosedByChild(name) {
      return this.isVoid || name.toLowerCase() in this.closedByChildren;
    }
  }]);

  return HtmlTagDefinition;
}();

var _DEFAULT_TAG_DEFINITION; // see http://www.w3.org/TR/html51/syntax.html#optional-tags
// This implementation does not fully conform to the HTML5 spec.


var TAG_DEFINITIONS;

function getHtmlTagDefinition(tagName) {
  var _a, _b;

  if (!TAG_DEFINITIONS) {
    _DEFAULT_TAG_DEFINITION = new HtmlTagDefinition();
    TAG_DEFINITIONS = {
      'base': new HtmlTagDefinition({
        isVoid: true
      }),
      'meta': new HtmlTagDefinition({
        isVoid: true
      }),
      'area': new HtmlTagDefinition({
        isVoid: true
      }),
      'embed': new HtmlTagDefinition({
        isVoid: true
      }),
      'link': new HtmlTagDefinition({
        isVoid: true
      }),
      'img': new HtmlTagDefinition({
        isVoid: true
      }),
      'input': new HtmlTagDefinition({
        isVoid: true
      }),
      'param': new HtmlTagDefinition({
        isVoid: true
      }),
      'hr': new HtmlTagDefinition({
        isVoid: true
      }),
      'br': new HtmlTagDefinition({
        isVoid: true
      }),
      'source': new HtmlTagDefinition({
        isVoid: true
      }),
      'track': new HtmlTagDefinition({
        isVoid: true
      }),
      'wbr': new HtmlTagDefinition({
        isVoid: true
      }),
      'p': new HtmlTagDefinition({
        closedByChildren: ['address', 'article', 'aside', 'blockquote', 'div', 'dl', 'fieldset', 'footer', 'form', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'header', 'hgroup', 'hr', 'main', 'nav', 'ol', 'p', 'pre', 'section', 'table', 'ul'],
        closedByParent: true
      }),
      'thead': new HtmlTagDefinition({
        closedByChildren: ['tbody', 'tfoot']
      }),
      'tbody': new HtmlTagDefinition({
        closedByChildren: ['tbody', 'tfoot'],
        closedByParent: true
      }),
      'tfoot': new HtmlTagDefinition({
        closedByChildren: ['tbody'],
        closedByParent: true
      }),
      'tr': new HtmlTagDefinition({
        closedByChildren: ['tr'],
        closedByParent: true
      }),
      'td': new HtmlTagDefinition({
        closedByChildren: ['td', 'th'],
        closedByParent: true
      }),
      'th': new HtmlTagDefinition({
        closedByChildren: ['td', 'th'],
        closedByParent: true
      }),
      'col': new HtmlTagDefinition({
        isVoid: true
      }),
      'svg': new HtmlTagDefinition({
        implicitNamespacePrefix: 'svg'
      }),
      'foreignObject': new HtmlTagDefinition({
        // Usually the implicit namespace here would be redundant since it will be inherited from
        // the parent `svg`, but we have to do it for `foreignObject`, because the way the parser
        // works is that the parent node of an end tag is its own start tag which means that
        // the `preventNamespaceInheritance` on `foreignObject` would have it default to the
        // implicit namespace which is `html`, unless specified otherwise.
        implicitNamespacePrefix: 'svg',
        // We want to prevent children of foreignObject from inheriting its namespace, because
        // the point of the element is to allow nodes from other namespaces to be inserted.
        preventNamespaceInheritance: true
      }),
      'math': new HtmlTagDefinition({
        implicitNamespacePrefix: 'math'
      }),
      'li': new HtmlTagDefinition({
        closedByChildren: ['li'],
        closedByParent: true
      }),
      'dt': new HtmlTagDefinition({
        closedByChildren: ['dt', 'dd']
      }),
      'dd': new HtmlTagDefinition({
        closedByChildren: ['dt', 'dd'],
        closedByParent: true
      }),
      'rb': new HtmlTagDefinition({
        closedByChildren: ['rb', 'rt', 'rtc', 'rp'],
        closedByParent: true
      }),
      'rt': new HtmlTagDefinition({
        closedByChildren: ['rb', 'rt', 'rtc', 'rp'],
        closedByParent: true
      }),
      'rtc': new HtmlTagDefinition({
        closedByChildren: ['rb', 'rtc', 'rp'],
        closedByParent: true
      }),
      'rp': new HtmlTagDefinition({
        closedByChildren: ['rb', 'rt', 'rtc', 'rp'],
        closedByParent: true
      }),
      'optgroup': new HtmlTagDefinition({
        closedByChildren: ['optgroup'],
        closedByParent: true
      }),
      'option': new HtmlTagDefinition({
        closedByChildren: ['option', 'optgroup'],
        closedByParent: true
      }),
      'pre': new HtmlTagDefinition({
        ignoreFirstLf: true
      }),
      'listing': new HtmlTagDefinition({
        ignoreFirstLf: true
      }),
      'style': new HtmlTagDefinition({
        contentType: TagContentType.RAW_TEXT
      }),
      'script': new HtmlTagDefinition({
        contentType: TagContentType.RAW_TEXT
      }),
      'title': new HtmlTagDefinition({
        contentType: TagContentType.ESCAPABLE_RAW_TEXT
      }),
      'textarea': new HtmlTagDefinition({
        contentType: TagContentType.ESCAPABLE_RAW_TEXT,
        ignoreFirstLf: true
      })
    };
  } // We have to make both a case-sensitive and a case-insesitive lookup, because
  // HTML tag names are case insensitive, whereas some SVG tags are case sensitive.


  return (_b = (_a = TAG_DEFINITIONS[tagName]) !== null && _a !== void 0 ? _a : TAG_DEFINITIONS[tagName.toLowerCase()]) !== null && _b !== void 0 ? _b : _DEFAULT_TAG_DEFINITION;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _SELECTOR_REGEXP = new RegExp('(\\:not\\()|' + // 1: ":not("
'(([\\.\\#]?)[-\\w]+)|' + // 2: "tag"; 3: "."/"#";
// "-" should appear first in the regexp below as FF31 parses "[.-\w]" as a range
// 4: attribute; 5: attribute_string; 6: attribute_value
'(?:\\[([-.\\w*]+)(?:=([\"\']?)([^\\]\"\']*)\\5)?\\])|' + // "[name]", "[name=value]",
// "[name="value"]",
// "[name='value']"
'(\\))|' + // 7: ")"
'(\\s*,\\s*)', // 8: ","
'g');
/**
 * A css selector contains an element name,
 * css classes and attribute/value pairs with the purpose
 * of selecting subsets out of them.
 */


var CssSelector = /*#__PURE__*/function () {
  function CssSelector() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CssSelector);

    this.element = null;
    this.classNames = [];
    /**
     * The selectors are encoded in pairs where:
     * - even locations are attribute names
     * - odd locations are attribute values.
     *
     * Example:
     * Selector: `[key1=value1][key2]` would parse to:
     * ```
     * ['key1', 'value1', 'key2', '']
     * ```
     */

    this.attrs = [];
    this.notSelectors = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CssSelector, [{
    key: "isElementSelector",
    value: function isElementSelector() {
      return this.hasElementSelector() && this.classNames.length == 0 && this.attrs.length == 0 && this.notSelectors.length === 0;
    }
  }, {
    key: "hasElementSelector",
    value: function hasElementSelector() {
      return !!this.element;
    }
  }, {
    key: "setElement",
    value: function setElement() {
      var element = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      this.element = element;
    }
    /** Gets a template string for an element that matches the selector. */

  }, {
    key: "getMatchingElementTemplate",
    value: function getMatchingElementTemplate() {
      var tagName = this.element || 'div';
      var classAttr = this.classNames.length > 0 ? " class=\"".concat(this.classNames.join(' '), "\"") : '';
      var attrs = '';

      for (var i = 0; i < this.attrs.length; i += 2) {
        var attrName = this.attrs[i];
        var attrValue = this.attrs[i + 1] !== '' ? "=\"".concat(this.attrs[i + 1], "\"") : '';
        attrs += " ".concat(attrName).concat(attrValue);
      }

      return getHtmlTagDefinition(tagName).isVoid ? "<".concat(tagName).concat(classAttr).concat(attrs, "/>") : "<".concat(tagName).concat(classAttr).concat(attrs, "></").concat(tagName, ">");
    }
  }, {
    key: "getAttrs",
    value: function getAttrs() {
      var result = [];

      if (this.classNames.length > 0) {
        result.push('class', this.classNames.join(' '));
      }

      return result.concat(this.attrs);
    }
  }, {
    key: "addAttribute",
    value: function addAttribute(name) {
      var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      this.attrs.push(name, value && value.toLowerCase() || '');
    }
  }, {
    key: "addClassName",
    value: function addClassName(name) {
      this.classNames.push(name.toLowerCase());
    }
  }, {
    key: "toString",
    value: function toString() {
      var res = this.element || '';

      if (this.classNames) {
        this.classNames.forEach(function (klass) {
          return res += ".".concat(klass);
        });
      }

      if (this.attrs) {
        for (var i = 0; i < this.attrs.length; i += 2) {
          var name = this.attrs[i];
          var value = this.attrs[i + 1];
          res += "[".concat(name).concat(value ? '=' + value : '', "]");
        }
      }

      this.notSelectors.forEach(function (notSelector) {
        return res += ":not(".concat(notSelector, ")");
      });
      return res;
    }
  }], [{
    key: "parse",
    value: function parse(selector) {
      var results = [];

      var _addResult = function _addResult(res, cssSel) {
        if (cssSel.notSelectors.length > 0 && !cssSel.element && cssSel.classNames.length == 0 && cssSel.attrs.length == 0) {
          cssSel.element = '*';
        }

        res.push(cssSel);
      };

      var cssSelector = new CssSelector();
      var match;
      var current = cssSelector;
      var inNot = false;
      _SELECTOR_REGEXP.lastIndex = 0;

      while (match = _SELECTOR_REGEXP.exec(selector)) {
        if (match[1
        /* NOT */
        ]) {
          if (inNot) {
            throw new Error('Nesting :not in a selector is not allowed');
          }

          inNot = true;
          current = new CssSelector();
          cssSelector.notSelectors.push(current);
        }

        var tag = match[2
        /* TAG */
        ];

        if (tag) {
          var prefix = match[3
          /* PREFIX */
          ];

          if (prefix === '#') {
            // #hash
            current.addAttribute('id', tag.substr(1));
          } else if (prefix === '.') {
            // Class
            current.addClassName(tag.substr(1));
          } else {
            // Element
            current.setElement(tag);
          }
        }

        var attribute = match[4
        /* ATTRIBUTE */
        ];

        if (attribute) {
          current.addAttribute(attribute, match[6
          /* ATTRIBUTE_VALUE */
          ]);
        }

        if (match[7
        /* NOT_END */
        ]) {
          inNot = false;
          current = cssSelector;
        }

        if (match[8
        /* SEPARATOR */
        ]) {
          if (inNot) {
            throw new Error('Multiple selectors in :not are not supported');
          }

          _addResult(results, cssSelector);

          cssSelector = current = new CssSelector();
        }
      }

      _addResult(results, cssSelector);

      return results;
    }
  }]);

  return CssSelector;
}();
/**
 * Reads a list of CssSelectors and allows to calculate which ones
 * are contained in a given CssSelector.
 */


var SelectorMatcher = /*#__PURE__*/function () {
  function SelectorMatcher() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SelectorMatcher);

    this._elementMap = new Map();
    this._elementPartialMap = new Map();
    this._classMap = new Map();
    this._classPartialMap = new Map();
    this._attrValueMap = new Map();
    this._attrValuePartialMap = new Map();
    this._listContexts = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SelectorMatcher, [{
    key: "addSelectables",
    value: function addSelectables(cssSelectors, callbackCtxt) {
      var listContext = null;

      if (cssSelectors.length > 1) {
        listContext = new SelectorListContext(cssSelectors);

        this._listContexts.push(listContext);
      }

      for (var i = 0; i < cssSelectors.length; i++) {
        this._addSelectable(cssSelectors[i], callbackCtxt, listContext);
      }
    }
    /**
     * Add an object that can be found later on by calling `match`.
     * @param cssSelector A css selector
     * @param callbackCtxt An opaque object that will be given to the callback of the `match` function
     */

  }, {
    key: "_addSelectable",
    value: function _addSelectable(cssSelector, callbackCtxt, listContext) {
      var matcher = this;
      var element = cssSelector.element;
      var classNames = cssSelector.classNames;
      var attrs = cssSelector.attrs;
      var selectable = new SelectorContext(cssSelector, callbackCtxt, listContext);

      if (element) {
        var isTerminal = attrs.length === 0 && classNames.length === 0;

        if (isTerminal) {
          this._addTerminal(matcher._elementMap, element, selectable);
        } else {
          matcher = this._addPartial(matcher._elementPartialMap, element);
        }
      }

      if (classNames) {
        for (var i = 0; i < classNames.length; i++) {
          var _isTerminal = attrs.length === 0 && i === classNames.length - 1;

          var className = classNames[i];

          if (_isTerminal) {
            this._addTerminal(matcher._classMap, className, selectable);
          } else {
            matcher = this._addPartial(matcher._classPartialMap, className);
          }
        }
      }

      if (attrs) {
        for (var _i = 0; _i < attrs.length; _i += 2) {
          var _isTerminal2 = _i === attrs.length - 2;

          var name = attrs[_i];
          var value = attrs[_i + 1];

          if (_isTerminal2) {
            var terminalMap = matcher._attrValueMap;
            var terminalValuesMap = terminalMap.get(name);

            if (!terminalValuesMap) {
              terminalValuesMap = new Map();
              terminalMap.set(name, terminalValuesMap);
            }

            this._addTerminal(terminalValuesMap, value, selectable);
          } else {
            var partialMap = matcher._attrValuePartialMap;
            var partialValuesMap = partialMap.get(name);

            if (!partialValuesMap) {
              partialValuesMap = new Map();
              partialMap.set(name, partialValuesMap);
            }

            matcher = this._addPartial(partialValuesMap, value);
          }
        }
      }
    }
  }, {
    key: "_addTerminal",
    value: function _addTerminal(map, name, selectable) {
      var terminalList = map.get(name);

      if (!terminalList) {
        terminalList = [];
        map.set(name, terminalList);
      }

      terminalList.push(selectable);
    }
  }, {
    key: "_addPartial",
    value: function _addPartial(map, name) {
      var matcher = map.get(name);

      if (!matcher) {
        matcher = new SelectorMatcher();
        map.set(name, matcher);
      }

      return matcher;
    }
    /**
     * Find the objects that have been added via `addSelectable`
     * whose css selector is contained in the given css selector.
     * @param cssSelector A css selector
     * @param matchedCallback This callback will be called with the object handed into `addSelectable`
     * @return boolean true if a match was found
     */

  }, {
    key: "match",
    value: function match(cssSelector, matchedCallback) {
      var result = false;
      var element = cssSelector.element;
      var classNames = cssSelector.classNames;
      var attrs = cssSelector.attrs;

      for (var i = 0; i < this._listContexts.length; i++) {
        this._listContexts[i].alreadyMatched = false;
      }

      result = this._matchTerminal(this._elementMap, element, cssSelector, matchedCallback) || result;
      result = this._matchPartial(this._elementPartialMap, element, cssSelector, matchedCallback) || result;

      if (classNames) {
        for (var _i2 = 0; _i2 < classNames.length; _i2++) {
          var className = classNames[_i2];
          result = this._matchTerminal(this._classMap, className, cssSelector, matchedCallback) || result;
          result = this._matchPartial(this._classPartialMap, className, cssSelector, matchedCallback) || result;
        }
      }

      if (attrs) {
        for (var _i3 = 0; _i3 < attrs.length; _i3 += 2) {
          var name = attrs[_i3];
          var value = attrs[_i3 + 1];

          var terminalValuesMap = this._attrValueMap.get(name);

          if (value) {
            result = this._matchTerminal(terminalValuesMap, '', cssSelector, matchedCallback) || result;
          }

          result = this._matchTerminal(terminalValuesMap, value, cssSelector, matchedCallback) || result;

          var partialValuesMap = this._attrValuePartialMap.get(name);

          if (value) {
            result = this._matchPartial(partialValuesMap, '', cssSelector, matchedCallback) || result;
          }

          result = this._matchPartial(partialValuesMap, value, cssSelector, matchedCallback) || result;
        }
      }

      return result;
    }
    /** @internal */

  }, {
    key: "_matchTerminal",
    value: function _matchTerminal(map, name, cssSelector, matchedCallback) {
      if (!map || typeof name !== 'string') {
        return false;
      }

      var selectables = map.get(name) || [];
      var starSelectables = map.get('*');

      if (starSelectables) {
        selectables = selectables.concat(starSelectables);
      }

      if (selectables.length === 0) {
        return false;
      }

      var selectable;
      var result = false;

      for (var i = 0; i < selectables.length; i++) {
        selectable = selectables[i];
        result = selectable.finalize(cssSelector, matchedCallback) || result;
      }

      return result;
    }
    /** @internal */

  }, {
    key: "_matchPartial",
    value: function _matchPartial(map, name, cssSelector, matchedCallback) {
      if (!map || typeof name !== 'string') {
        return false;
      }

      var nestedSelector = map.get(name);

      if (!nestedSelector) {
        return false;
      } // TODO(perf): get rid of recursion and measure again
      // TODO(perf): don't pass the whole selector into the recursion,
      // but only the not processed parts


      return nestedSelector.match(cssSelector, matchedCallback);
    }
  }], [{
    key: "createNotMatcher",
    value: function createNotMatcher(notSelectors) {
      var notMatcher = new SelectorMatcher();
      notMatcher.addSelectables(notSelectors, null);
      return notMatcher;
    }
  }]);

  return SelectorMatcher;
}();

var SelectorListContext = function SelectorListContext(selectors) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SelectorListContext);

  this.selectors = selectors;
  this.alreadyMatched = false;
}; // Store context to pass back selector and context when a selector is matched


var SelectorContext = /*#__PURE__*/function () {
  function SelectorContext(selector, cbContext, listContext) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SelectorContext);

    this.selector = selector;
    this.cbContext = cbContext;
    this.listContext = listContext;
    this.notSelectors = selector.notSelectors;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SelectorContext, [{
    key: "finalize",
    value: function finalize(cssSelector, callback) {
      var result = true;

      if (this.notSelectors.length > 0 && (!this.listContext || !this.listContext.alreadyMatched)) {
        var notMatcher = SelectorMatcher.createNotMatcher(this.notSelectors);
        result = !notMatcher.match(cssSelector, null);
      }

      if (result && callback && (!this.listContext || !this.listContext.alreadyMatched)) {
        if (this.listContext) {
          this.listContext.alreadyMatched = true;
        }

        callback(this.selector, this.cbContext);
      }

      return result;
    }
  }]);

  return SelectorContext;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var createInject = makeMetadataFactory('Inject', function (token) {
  return {
    token: token
  };
});
var createInjectionToken = makeMetadataFactory('InjectionToken', function (desc) {
  return {
    _desc: desc,
    ɵprov: undefined
  };
});
var createAttribute = makeMetadataFactory('Attribute', function (attributeName) {
  return {
    attributeName: attributeName
  };
});
var createContentChildren = makeMetadataFactory('ContentChildren', function (selector) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return Object.assign({
    selector: selector,
    first: false,
    isViewQuery: false,
    descendants: false
  }, data);
});
var createContentChild = makeMetadataFactory('ContentChild', function (selector) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return Object.assign({
    selector: selector,
    first: true,
    isViewQuery: false,
    descendants: true
  }, data);
});
var createViewChildren = makeMetadataFactory('ViewChildren', function (selector) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return Object.assign({
    selector: selector,
    first: false,
    isViewQuery: true,
    descendants: true
  }, data);
});
var createViewChild = makeMetadataFactory('ViewChild', function (selector, data) {
  return Object.assign({
    selector: selector,
    first: true,
    isViewQuery: true,
    descendants: true
  }, data);
});
var createDirective = makeMetadataFactory('Directive', function () {
  var dir = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return dir;
});
var ViewEncapsulation;

(function (ViewEncapsulation) {
  ViewEncapsulation[ViewEncapsulation["Emulated"] = 0] = "Emulated";
  ViewEncapsulation[ViewEncapsulation["Native"] = 1] = "Native";
  ViewEncapsulation[ViewEncapsulation["None"] = 2] = "None";
  ViewEncapsulation[ViewEncapsulation["ShadowDom"] = 3] = "ShadowDom";
})(ViewEncapsulation || (ViewEncapsulation = {}));

var ChangeDetectionStrategy;

(function (ChangeDetectionStrategy) {
  ChangeDetectionStrategy[ChangeDetectionStrategy["OnPush"] = 0] = "OnPush";
  ChangeDetectionStrategy[ChangeDetectionStrategy["Default"] = 1] = "Default";
})(ChangeDetectionStrategy || (ChangeDetectionStrategy = {}));

var createComponent = makeMetadataFactory('Component', function () {
  var c = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return Object.assign({
    changeDetection: ChangeDetectionStrategy.Default
  }, c);
});
var createPipe = makeMetadataFactory('Pipe', function (p) {
  return Object.assign({
    pure: true
  }, p);
});
var createInput = makeMetadataFactory('Input', function (bindingPropertyName) {
  return {
    bindingPropertyName: bindingPropertyName
  };
});
var createOutput = makeMetadataFactory('Output', function (bindingPropertyName) {
  return {
    bindingPropertyName: bindingPropertyName
  };
});
var createHostBinding = makeMetadataFactory('HostBinding', function (hostPropertyName) {
  return {
    hostPropertyName: hostPropertyName
  };
});
var createHostListener = makeMetadataFactory('HostListener', function (eventName, args) {
  return {
    eventName: eventName,
    args: args
  };
});
var createNgModule = makeMetadataFactory('NgModule', function (ngModule) {
  return ngModule;
});
var createInjectable = makeMetadataFactory('Injectable', function () {
  var injectable = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return injectable;
});
var CUSTOM_ELEMENTS_SCHEMA = {
  name: 'custom-elements'
};
var NO_ERRORS_SCHEMA = {
  name: 'no-errors-schema'
};
var createOptional = makeMetadataFactory('Optional');
var createSelf = makeMetadataFactory('Self');
var createSkipSelf = makeMetadataFactory('SkipSelf');
var createHost = makeMetadataFactory('Host');
var Type = Function;
var SecurityContext;

(function (SecurityContext) {
  SecurityContext[SecurityContext["NONE"] = 0] = "NONE";
  SecurityContext[SecurityContext["HTML"] = 1] = "HTML";
  SecurityContext[SecurityContext["STYLE"] = 2] = "STYLE";
  SecurityContext[SecurityContext["SCRIPT"] = 3] = "SCRIPT";
  SecurityContext[SecurityContext["URL"] = 4] = "URL";
  SecurityContext[SecurityContext["RESOURCE_URL"] = 5] = "RESOURCE_URL";
})(SecurityContext || (SecurityContext = {}));

var MissingTranslationStrategy;

(function (MissingTranslationStrategy) {
  MissingTranslationStrategy[MissingTranslationStrategy["Error"] = 0] = "Error";
  MissingTranslationStrategy[MissingTranslationStrategy["Warning"] = 1] = "Warning";
  MissingTranslationStrategy[MissingTranslationStrategy["Ignore"] = 2] = "Ignore";
})(MissingTranslationStrategy || (MissingTranslationStrategy = {}));

function makeMetadataFactory(name, props) {
  // This must be declared as a function, not a fat arrow, so that ES2015 devmode produces code
  // that works with the static_reflector.ts in the ViewEngine compiler.
  // In particular, `_registerDecoratorOrConstructor` assumes that the value returned here can be
  // new'ed.
  function factory() {
    var values = props ? props.apply(void 0, arguments) : {};
    return Object.assign({
      ngMetadataName: name
    }, values);
  }

  factory.isTypeOf = function (obj) {
    return obj && obj.ngMetadataName === name;
  };

  factory.ngMetadataName = name;
  return factory;
}

function parserSelectorToSimpleSelector(selector) {
  var classes = selector.classNames && selector.classNames.length ? [8
  /* CLASS */
  ].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selector.classNames)) : [];
  var elementName = selector.element && selector.element !== '*' ? selector.element : '';
  return [elementName].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selector.attrs), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(classes));
}

function parserSelectorToNegativeSelector(selector) {
  var classes = selector.classNames && selector.classNames.length ? [8
  /* CLASS */
  ].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selector.classNames)) : [];

  if (selector.element) {
    return [1
    /* NOT */
    | 4
    /* ELEMENT */
    , selector.element].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selector.attrs), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(classes));
  } else if (selector.attrs.length) {
    return [1
    /* NOT */
    | 2
    /* ATTRIBUTE */
    ].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selector.attrs), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(classes));
  } else {
    return selector.classNames && selector.classNames.length ? [1
    /* NOT */
    | 8
    /* CLASS */
    ].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selector.classNames)) : [];
  }
}

function parserSelectorToR3Selector(selector) {
  var positive = parserSelectorToSimpleSelector(selector);
  var negative = selector.notSelectors && selector.notSelectors.length ? selector.notSelectors.map(function (notSelector) {
    return parserSelectorToNegativeSelector(notSelector);
  }) : [];
  return positive.concat.apply(positive, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(negative));
}

function parseSelectorToR3Selector(selector) {
  return selector ? CssSelector.parse(selector).map(parserSelectorToR3Selector) : [];
}

var core = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createInject: createInject,
  createInjectionToken: createInjectionToken,
  createAttribute: createAttribute,
  createContentChildren: createContentChildren,
  createContentChild: createContentChild,
  createViewChildren: createViewChildren,
  createViewChild: createViewChild,
  createDirective: createDirective,

  get ViewEncapsulation() {
    return ViewEncapsulation;
  },

  get ChangeDetectionStrategy() {
    return ChangeDetectionStrategy;
  },

  createComponent: createComponent,
  createPipe: createPipe,
  createInput: createInput,
  createOutput: createOutput,
  createHostBinding: createHostBinding,
  createHostListener: createHostListener,
  createNgModule: createNgModule,
  createInjectable: createInjectable,
  CUSTOM_ELEMENTS_SCHEMA: CUSTOM_ELEMENTS_SCHEMA,
  NO_ERRORS_SCHEMA: NO_ERRORS_SCHEMA,
  createOptional: createOptional,
  createSelf: createSelf,
  createSkipSelf: createSkipSelf,
  createHost: createHost,
  Type: Type,

  get SecurityContext() {
    return SecurityContext;
  },

  get MissingTranslationStrategy() {
    return MissingTranslationStrategy;
  },

  parseSelectorToR3Selector: parseSelectorToR3Selector
});
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
//// Types

var TypeModifier;

(function (TypeModifier) {
  TypeModifier[TypeModifier["Const"] = 0] = "Const";
})(TypeModifier || (TypeModifier = {}));

var Type$1 = /*#__PURE__*/function () {
  function Type$1() {
    var modifiers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Type$1);

    this.modifiers = modifiers;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Type$1, [{
    key: "hasModifier",
    value: function hasModifier(modifier) {
      return this.modifiers.indexOf(modifier) !== -1;
    }
  }]);

  return Type$1;
}();

var BuiltinTypeName;

(function (BuiltinTypeName) {
  BuiltinTypeName[BuiltinTypeName["Dynamic"] = 0] = "Dynamic";
  BuiltinTypeName[BuiltinTypeName["Bool"] = 1] = "Bool";
  BuiltinTypeName[BuiltinTypeName["String"] = 2] = "String";
  BuiltinTypeName[BuiltinTypeName["Int"] = 3] = "Int";
  BuiltinTypeName[BuiltinTypeName["Number"] = 4] = "Number";
  BuiltinTypeName[BuiltinTypeName["Function"] = 5] = "Function";
  BuiltinTypeName[BuiltinTypeName["Inferred"] = 6] = "Inferred";
  BuiltinTypeName[BuiltinTypeName["None"] = 7] = "None";
})(BuiltinTypeName || (BuiltinTypeName = {}));

var BuiltinType = /*#__PURE__*/function (_Type$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(BuiltinType, _Type$);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(BuiltinType);

  function BuiltinType(name, modifiers) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BuiltinType);

    _this2 = _super.call(this, modifiers);
    _this2.name = name;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BuiltinType, [{
    key: "visitType",
    value: function visitType(visitor, context) {
      return visitor.visitBuiltinType(this, context);
    }
  }]);

  return BuiltinType;
}(Type$1);

var ExpressionType = /*#__PURE__*/function (_Type$2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ExpressionType, _Type$2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ExpressionType);

  function ExpressionType(value, modifiers) {
    var _this3;

    var typeParams = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExpressionType);

    _this3 = _super2.call(this, modifiers);
    _this3.value = value;
    _this3.typeParams = typeParams;
    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ExpressionType, [{
    key: "visitType",
    value: function visitType(visitor, context) {
      return visitor.visitExpressionType(this, context);
    }
  }]);

  return ExpressionType;
}(Type$1);

var ArrayType = /*#__PURE__*/function (_Type$3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ArrayType, _Type$3);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ArrayType);

  function ArrayType(of, modifiers) {
    var _this4;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ArrayType);

    _this4 = _super3.call(this, modifiers);
    _this4.of = of;
    return _this4;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ArrayType, [{
    key: "visitType",
    value: function visitType(visitor, context) {
      return visitor.visitArrayType(this, context);
    }
  }]);

  return ArrayType;
}(Type$1);

var MapType = /*#__PURE__*/function (_Type$4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(MapType, _Type$4);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(MapType);

  function MapType(valueType, modifiers) {
    var _this5;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, MapType);

    _this5 = _super4.call(this, modifiers);
    _this5.valueType = valueType || null;
    return _this5;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(MapType, [{
    key: "visitType",
    value: function visitType(visitor, context) {
      return visitor.visitMapType(this, context);
    }
  }]);

  return MapType;
}(Type$1);

var DYNAMIC_TYPE = new BuiltinType(BuiltinTypeName.Dynamic);
var INFERRED_TYPE = new BuiltinType(BuiltinTypeName.Inferred);
var BOOL_TYPE = new BuiltinType(BuiltinTypeName.Bool);
var INT_TYPE = new BuiltinType(BuiltinTypeName.Int);
var NUMBER_TYPE = new BuiltinType(BuiltinTypeName.Number);
var STRING_TYPE = new BuiltinType(BuiltinTypeName.String);
var FUNCTION_TYPE = new BuiltinType(BuiltinTypeName.Function);
var NONE_TYPE = new BuiltinType(BuiltinTypeName.None); ///// Expressions

var UnaryOperator;

(function (UnaryOperator) {
  UnaryOperator[UnaryOperator["Minus"] = 0] = "Minus";
  UnaryOperator[UnaryOperator["Plus"] = 1] = "Plus";
})(UnaryOperator || (UnaryOperator = {}));

var BinaryOperator;

(function (BinaryOperator) {
  BinaryOperator[BinaryOperator["Equals"] = 0] = "Equals";
  BinaryOperator[BinaryOperator["NotEquals"] = 1] = "NotEquals";
  BinaryOperator[BinaryOperator["Identical"] = 2] = "Identical";
  BinaryOperator[BinaryOperator["NotIdentical"] = 3] = "NotIdentical";
  BinaryOperator[BinaryOperator["Minus"] = 4] = "Minus";
  BinaryOperator[BinaryOperator["Plus"] = 5] = "Plus";
  BinaryOperator[BinaryOperator["Divide"] = 6] = "Divide";
  BinaryOperator[BinaryOperator["Multiply"] = 7] = "Multiply";
  BinaryOperator[BinaryOperator["Modulo"] = 8] = "Modulo";
  BinaryOperator[BinaryOperator["And"] = 9] = "And";
  BinaryOperator[BinaryOperator["Or"] = 10] = "Or";
  BinaryOperator[BinaryOperator["BitwiseAnd"] = 11] = "BitwiseAnd";
  BinaryOperator[BinaryOperator["Lower"] = 12] = "Lower";
  BinaryOperator[BinaryOperator["LowerEquals"] = 13] = "LowerEquals";
  BinaryOperator[BinaryOperator["Bigger"] = 14] = "Bigger";
  BinaryOperator[BinaryOperator["BiggerEquals"] = 15] = "BiggerEquals";
})(BinaryOperator || (BinaryOperator = {}));

function nullSafeIsEquivalent(base, other) {
  if (base == null || other == null) {
    return base == other;
  }

  return base.isEquivalent(other);
}

function areAllEquivalent(base, other) {
  var len = base.length;

  if (len !== other.length) {
    return false;
  }

  for (var i = 0; i < len; i++) {
    if (!base[i].isEquivalent(other[i])) {
      return false;
    }
  }

  return true;
}

var Expression = /*#__PURE__*/function () {
  function Expression(type, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Expression);

    this.type = type || null;
    this.sourceSpan = sourceSpan || null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Expression, [{
    key: "prop",
    value: function prop(name, sourceSpan) {
      return new ReadPropExpr(this, name, null, sourceSpan);
    }
  }, {
    key: "key",
    value: function key(index, type, sourceSpan) {
      return new ReadKeyExpr(this, index, type, sourceSpan);
    }
  }, {
    key: "callMethod",
    value: function callMethod(name, params, sourceSpan) {
      return new InvokeMethodExpr(this, name, params, null, sourceSpan);
    }
  }, {
    key: "callFn",
    value: function callFn(params, sourceSpan, pure) {
      return new InvokeFunctionExpr(this, params, null, sourceSpan, pure);
    }
  }, {
    key: "instantiate",
    value: function instantiate(params, type, sourceSpan) {
      return new InstantiateExpr(this, params, type, sourceSpan);
    }
  }, {
    key: "conditional",
    value: function conditional(trueCase) {
      var falseCase = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      var sourceSpan = arguments.length > 2 ? arguments[2] : undefined;
      return new ConditionalExpr(this, trueCase, falseCase, null, sourceSpan);
    }
  }, {
    key: "equals",
    value: function equals(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Equals, this, rhs, null, sourceSpan);
    }
  }, {
    key: "notEquals",
    value: function notEquals(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.NotEquals, this, rhs, null, sourceSpan);
    }
  }, {
    key: "identical",
    value: function identical(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Identical, this, rhs, null, sourceSpan);
    }
  }, {
    key: "notIdentical",
    value: function notIdentical(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.NotIdentical, this, rhs, null, sourceSpan);
    }
  }, {
    key: "minus",
    value: function minus(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Minus, this, rhs, null, sourceSpan);
    }
  }, {
    key: "plus",
    value: function plus(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Plus, this, rhs, null, sourceSpan);
    }
  }, {
    key: "divide",
    value: function divide(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Divide, this, rhs, null, sourceSpan);
    }
  }, {
    key: "multiply",
    value: function multiply(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Multiply, this, rhs, null, sourceSpan);
    }
  }, {
    key: "modulo",
    value: function modulo(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Modulo, this, rhs, null, sourceSpan);
    }
  }, {
    key: "and",
    value: function and(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.And, this, rhs, null, sourceSpan);
    }
  }, {
    key: "bitwiseAnd",
    value: function bitwiseAnd(rhs, sourceSpan) {
      var parens = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
      return new BinaryOperatorExpr(BinaryOperator.BitwiseAnd, this, rhs, null, sourceSpan, parens);
    }
  }, {
    key: "or",
    value: function or(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Or, this, rhs, null, sourceSpan);
    }
  }, {
    key: "lower",
    value: function lower(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Lower, this, rhs, null, sourceSpan);
    }
  }, {
    key: "lowerEquals",
    value: function lowerEquals(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.LowerEquals, this, rhs, null, sourceSpan);
    }
  }, {
    key: "bigger",
    value: function bigger(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.Bigger, this, rhs, null, sourceSpan);
    }
  }, {
    key: "biggerEquals",
    value: function biggerEquals(rhs, sourceSpan) {
      return new BinaryOperatorExpr(BinaryOperator.BiggerEquals, this, rhs, null, sourceSpan);
    }
  }, {
    key: "isBlank",
    value: function isBlank(sourceSpan) {
      // Note: We use equals by purpose here to compare to null and undefined in JS.
      // We use the typed null to allow strictNullChecks to narrow types.
      return this.equals(TYPED_NULL_EXPR, sourceSpan);
    }
  }, {
    key: "cast",
    value: function cast(type, sourceSpan) {
      return new CastExpr(this, type, sourceSpan);
    }
  }, {
    key: "toStmt",
    value: function toStmt() {
      return new ExpressionStatement(this, null);
    }
  }]);

  return Expression;
}();

var BuiltinVar;

(function (BuiltinVar) {
  BuiltinVar[BuiltinVar["This"] = 0] = "This";
  BuiltinVar[BuiltinVar["Super"] = 1] = "Super";
  BuiltinVar[BuiltinVar["CatchError"] = 2] = "CatchError";
  BuiltinVar[BuiltinVar["CatchStack"] = 3] = "CatchStack";
})(BuiltinVar || (BuiltinVar = {}));

var ReadVarExpr = /*#__PURE__*/function (_Expression) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ReadVarExpr, _Expression);

  var _super5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ReadVarExpr);

  function ReadVarExpr(name, type, sourceSpan) {
    var _this6;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReadVarExpr);

    _this6 = _super5.call(this, type, sourceSpan);

    if (typeof name === 'string') {
      _this6.name = name;
      _this6.builtin = null;
    } else {
      _this6.name = null;
      _this6.builtin = name;
    }

    return _this6;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ReadVarExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof ReadVarExpr && this.name === e.name && this.builtin === e.builtin;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitReadVarExpr(this, context);
    }
  }, {
    key: "set",
    value: function set(value) {
      if (!this.name) {
        throw new Error("Built in variable ".concat(this.builtin, " can not be assigned to."));
      }

      return new WriteVarExpr(this.name, value, null, this.sourceSpan);
    }
  }]);

  return ReadVarExpr;
}(Expression);

var TypeofExpr = /*#__PURE__*/function (_Expression2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(TypeofExpr, _Expression2);

  var _super6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(TypeofExpr);

  function TypeofExpr(expr, type, sourceSpan) {
    var _this7;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TypeofExpr);

    _this7 = _super6.call(this, type, sourceSpan);
    _this7.expr = expr;
    return _this7;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TypeofExpr, [{
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitTypeofExpr(this, context);
    }
  }, {
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof TypeofExpr && e.expr.isEquivalent(this.expr);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return this.expr.isConstant();
    }
  }]);

  return TypeofExpr;
}(Expression);

var WrappedNodeExpr = /*#__PURE__*/function (_Expression3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(WrappedNodeExpr, _Expression3);

  var _super7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(WrappedNodeExpr);

  function WrappedNodeExpr(node, type, sourceSpan) {
    var _this8;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, WrappedNodeExpr);

    _this8 = _super7.call(this, type, sourceSpan);
    _this8.node = node;
    return _this8;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(WrappedNodeExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof WrappedNodeExpr && this.node === e.node;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitWrappedNodeExpr(this, context);
    }
  }]);

  return WrappedNodeExpr;
}(Expression);

var WriteVarExpr = /*#__PURE__*/function (_Expression4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(WriteVarExpr, _Expression4);

  var _super8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(WriteVarExpr);

  function WriteVarExpr(name, value, type, sourceSpan) {
    var _this9;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, WriteVarExpr);

    _this9 = _super8.call(this, type || value.type, sourceSpan);
    _this9.name = name;
    _this9.value = value;
    return _this9;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(WriteVarExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof WriteVarExpr && this.name === e.name && this.value.isEquivalent(e.value);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitWriteVarExpr(this, context);
    }
  }, {
    key: "toDeclStmt",
    value: function toDeclStmt(type, modifiers) {
      return new DeclareVarStmt(this.name, this.value, type, modifiers, this.sourceSpan);
    }
  }, {
    key: "toConstDecl",
    value: function toConstDecl() {
      return this.toDeclStmt(INFERRED_TYPE, [StmtModifier.Final]);
    }
  }]);

  return WriteVarExpr;
}(Expression);

var WriteKeyExpr = /*#__PURE__*/function (_Expression5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(WriteKeyExpr, _Expression5);

  var _super9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(WriteKeyExpr);

  function WriteKeyExpr(receiver, index, value, type, sourceSpan) {
    var _this10;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, WriteKeyExpr);

    _this10 = _super9.call(this, type || value.type, sourceSpan);
    _this10.receiver = receiver;
    _this10.index = index;
    _this10.value = value;
    return _this10;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(WriteKeyExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof WriteKeyExpr && this.receiver.isEquivalent(e.receiver) && this.index.isEquivalent(e.index) && this.value.isEquivalent(e.value);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitWriteKeyExpr(this, context);
    }
  }]);

  return WriteKeyExpr;
}(Expression);

var WritePropExpr = /*#__PURE__*/function (_Expression6) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(WritePropExpr, _Expression6);

  var _super10 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(WritePropExpr);

  function WritePropExpr(receiver, name, value, type, sourceSpan) {
    var _this11;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, WritePropExpr);

    _this11 = _super10.call(this, type || value.type, sourceSpan);
    _this11.receiver = receiver;
    _this11.name = name;
    _this11.value = value;
    return _this11;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(WritePropExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof WritePropExpr && this.receiver.isEquivalent(e.receiver) && this.name === e.name && this.value.isEquivalent(e.value);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitWritePropExpr(this, context);
    }
  }]);

  return WritePropExpr;
}(Expression);

var BuiltinMethod;

(function (BuiltinMethod) {
  BuiltinMethod[BuiltinMethod["ConcatArray"] = 0] = "ConcatArray";
  BuiltinMethod[BuiltinMethod["SubscribeObservable"] = 1] = "SubscribeObservable";
  BuiltinMethod[BuiltinMethod["Bind"] = 2] = "Bind";
})(BuiltinMethod || (BuiltinMethod = {}));

var InvokeMethodExpr = /*#__PURE__*/function (_Expression7) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(InvokeMethodExpr, _Expression7);

  var _super11 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(InvokeMethodExpr);

  function InvokeMethodExpr(receiver, method, args, type, sourceSpan) {
    var _this12;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, InvokeMethodExpr);

    _this12 = _super11.call(this, type, sourceSpan);
    _this12.receiver = receiver;
    _this12.args = args;

    if (typeof method === 'string') {
      _this12.name = method;
      _this12.builtin = null;
    } else {
      _this12.name = null;
      _this12.builtin = method;
    }

    return _this12;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(InvokeMethodExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof InvokeMethodExpr && this.receiver.isEquivalent(e.receiver) && this.name === e.name && this.builtin === e.builtin && areAllEquivalent(this.args, e.args);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitInvokeMethodExpr(this, context);
    }
  }]);

  return InvokeMethodExpr;
}(Expression);

var InvokeFunctionExpr = /*#__PURE__*/function (_Expression8) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(InvokeFunctionExpr, _Expression8);

  var _super12 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(InvokeFunctionExpr);

  function InvokeFunctionExpr(fn, args, type, sourceSpan) {
    var _this13;

    var pure = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, InvokeFunctionExpr);

    _this13 = _super12.call(this, type, sourceSpan);
    _this13.fn = fn;
    _this13.args = args;
    _this13.pure = pure;
    return _this13;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(InvokeFunctionExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof InvokeFunctionExpr && this.fn.isEquivalent(e.fn) && areAllEquivalent(this.args, e.args) && this.pure === e.pure;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitInvokeFunctionExpr(this, context);
    }
  }]);

  return InvokeFunctionExpr;
}(Expression);

var InstantiateExpr = /*#__PURE__*/function (_Expression9) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(InstantiateExpr, _Expression9);

  var _super13 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(InstantiateExpr);

  function InstantiateExpr(classExpr, args, type, sourceSpan) {
    var _this14;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, InstantiateExpr);

    _this14 = _super13.call(this, type, sourceSpan);
    _this14.classExpr = classExpr;
    _this14.args = args;
    return _this14;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(InstantiateExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof InstantiateExpr && this.classExpr.isEquivalent(e.classExpr) && areAllEquivalent(this.args, e.args);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitInstantiateExpr(this, context);
    }
  }]);

  return InstantiateExpr;
}(Expression);

var LiteralExpr = /*#__PURE__*/function (_Expression10) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralExpr, _Expression10);

  var _super14 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralExpr);

  function LiteralExpr(value, type, sourceSpan) {
    var _this15;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralExpr);

    _this15 = _super14.call(this, type, sourceSpan);
    _this15.value = value;
    return _this15;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof LiteralExpr && this.value === e.value;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return true;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitLiteralExpr(this, context);
    }
  }]);

  return LiteralExpr;
}(Expression);

var MessagePiece = function MessagePiece(text, sourceSpan) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, MessagePiece);

  this.text = text;
  this.sourceSpan = sourceSpan;
};

var LiteralPiece = /*#__PURE__*/function (_MessagePiece) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralPiece, _MessagePiece);

  var _super15 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralPiece);

  function LiteralPiece() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralPiece);

    return _super15.apply(this, arguments);
  }

  return LiteralPiece;
}(MessagePiece);

var PlaceholderPiece = /*#__PURE__*/function (_MessagePiece2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(PlaceholderPiece, _MessagePiece2);

  var _super16 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(PlaceholderPiece);

  function PlaceholderPiece() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PlaceholderPiece);

    return _super16.apply(this, arguments);
  }

  return PlaceholderPiece;
}(MessagePiece);

var LocalizedString = /*#__PURE__*/function (_Expression11) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LocalizedString, _Expression11);

  var _super17 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LocalizedString);

  function LocalizedString(metaBlock, messageParts, placeHolderNames, expressions, sourceSpan) {
    var _this16;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LocalizedString);

    _this16 = _super17.call(this, STRING_TYPE, sourceSpan);
    _this16.metaBlock = metaBlock;
    _this16.messageParts = messageParts;
    _this16.placeHolderNames = placeHolderNames;
    _this16.expressions = expressions;
    return _this16;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LocalizedString, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      // return e instanceof LocalizedString && this.message === e.message;
      return false;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitLocalizedString(this, context);
    }
    /**
     * Serialize the given `meta` and `messagePart` into "cooked" and "raw" strings that can be used
     * in a `$localize` tagged string. The format of the metadata is the same as that parsed by
     * `parseI18nMeta()`.
     *
     * @param meta The metadata to serialize
     * @param messagePart The first part of the tagged string
     */

  }, {
    key: "serializeI18nHead",
    value: function serializeI18nHead() {
      var MEANING_SEPARATOR = '|';
      var ID_SEPARATOR = '@@';
      var LEGACY_ID_INDICATOR = '␟';
      var metaBlock = this.metaBlock.description || '';

      if (this.metaBlock.meaning) {
        metaBlock = "".concat(this.metaBlock.meaning).concat(MEANING_SEPARATOR).concat(metaBlock);
      }

      if (this.metaBlock.customId) {
        metaBlock = "".concat(metaBlock).concat(ID_SEPARATOR).concat(this.metaBlock.customId);
      }

      if (this.metaBlock.legacyIds) {
        this.metaBlock.legacyIds.forEach(function (legacyId) {
          metaBlock = "".concat(metaBlock).concat(LEGACY_ID_INDICATOR).concat(legacyId);
        });
      }

      return createCookedRawString(metaBlock, this.messageParts[0].text);
    }
  }, {
    key: "getMessagePartSourceSpan",
    value: function getMessagePartSourceSpan(i) {
      var _a, _b;

      return (_b = (_a = this.messageParts[i]) === null || _a === void 0 ? void 0 : _a.sourceSpan) !== null && _b !== void 0 ? _b : this.sourceSpan;
    }
  }, {
    key: "getPlaceholderSourceSpan",
    value: function getPlaceholderSourceSpan(i) {
      var _a, _b, _c, _d;

      return (_d = (_b = (_a = this.placeHolderNames[i]) === null || _a === void 0 ? void 0 : _a.sourceSpan) !== null && _b !== void 0 ? _b : (_c = this.expressions[i]) === null || _c === void 0 ? void 0 : _c.sourceSpan) !== null && _d !== void 0 ? _d : this.sourceSpan;
    }
    /**
     * Serialize the given `placeholderName` and `messagePart` into "cooked" and "raw" strings that
     * can be used in a `$localize` tagged string.
     *
     * @param placeholderName The placeholder name to serialize
     * @param messagePart The following message string after this placeholder
     */

  }, {
    key: "serializeI18nTemplatePart",
    value: function serializeI18nTemplatePart(partIndex) {
      var placeholderName = this.placeHolderNames[partIndex - 1].text;
      var messagePart = this.messageParts[partIndex];
      return createCookedRawString(placeholderName, messagePart.text);
    }
  }]);

  return LocalizedString;
}(Expression);

var escapeSlashes = function escapeSlashes(str) {
  return str.replace(/\\/g, '\\\\');
};

var escapeStartingColon = function escapeStartingColon(str) {
  return str.replace(/^:/, '\\:');
};

var escapeColons = function escapeColons(str) {
  return str.replace(/:/g, '\\:');
};

var escapeForMessagePart = function escapeForMessagePart(str) {
  return str.replace(/`/g, '\\`').replace(/\${/g, '$\\{');
};
/**
 * Creates a `{cooked, raw}` object from the `metaBlock` and `messagePart`.
 *
 * The `raw` text must have various character sequences escaped:
 * * "\" would otherwise indicate that the next character is a control character.
 * * "`" and "${" are template string control sequences that would otherwise prematurely indicate
 *   the end of a message part.
 * * ":" inside a metablock would prematurely indicate the end of the metablock.
 * * ":" at the start of a messagePart with no metablock would erroneously indicate the start of a
 *   metablock.
 *
 * @param metaBlock Any metadata that should be prepended to the string
 * @param messagePart The message part of the string
 */


function createCookedRawString(metaBlock, messagePart) {
  if (metaBlock === '') {
    return {
      cooked: messagePart,
      raw: escapeForMessagePart(escapeStartingColon(escapeSlashes(messagePart)))
    };
  } else {
    return {
      cooked: ":".concat(metaBlock, ":").concat(messagePart),
      raw: escapeForMessagePart(":".concat(escapeColons(escapeSlashes(metaBlock)), ":").concat(escapeSlashes(messagePart)))
    };
  }
}

var ExternalExpr = /*#__PURE__*/function (_Expression12) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ExternalExpr, _Expression12);

  var _super18 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ExternalExpr);

  function ExternalExpr(value, type) {
    var _this17;

    var typeParams = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
    var sourceSpan = arguments.length > 3 ? arguments[3] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExternalExpr);

    _this17 = _super18.call(this, type, sourceSpan);
    _this17.value = value;
    _this17.typeParams = typeParams;
    return _this17;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ExternalExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof ExternalExpr && this.value.name === e.value.name && this.value.moduleName === e.value.moduleName && this.value.runtime === e.value.runtime;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitExternalExpr(this, context);
    }
  }]);

  return ExternalExpr;
}(Expression);

var ExternalReference = function ExternalReference(moduleName, name, runtime) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExternalReference);

  this.moduleName = moduleName;
  this.name = name;
  this.runtime = runtime;
};

var ConditionalExpr = /*#__PURE__*/function (_Expression13) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ConditionalExpr, _Expression13);

  var _super19 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ConditionalExpr);

  function ConditionalExpr(condition, trueCase) {
    var _this18;

    var falseCase = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
    var type = arguments.length > 3 ? arguments[3] : undefined;
    var sourceSpan = arguments.length > 4 ? arguments[4] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ConditionalExpr);

    _this18 = _super19.call(this, type || trueCase.type, sourceSpan);
    _this18.condition = condition;
    _this18.falseCase = falseCase;
    _this18.trueCase = trueCase;
    return _this18;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ConditionalExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof ConditionalExpr && this.condition.isEquivalent(e.condition) && this.trueCase.isEquivalent(e.trueCase) && nullSafeIsEquivalent(this.falseCase, e.falseCase);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitConditionalExpr(this, context);
    }
  }]);

  return ConditionalExpr;
}(Expression);

var NotExpr = /*#__PURE__*/function (_Expression14) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(NotExpr, _Expression14);

  var _super20 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(NotExpr);

  function NotExpr(condition, sourceSpan) {
    var _this19;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NotExpr);

    _this19 = _super20.call(this, BOOL_TYPE, sourceSpan);
    _this19.condition = condition;
    return _this19;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NotExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof NotExpr && this.condition.isEquivalent(e.condition);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitNotExpr(this, context);
    }
  }]);

  return NotExpr;
}(Expression);

var AssertNotNull = /*#__PURE__*/function (_Expression15) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(AssertNotNull, _Expression15);

  var _super21 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(AssertNotNull);

  function AssertNotNull(condition, sourceSpan) {
    var _this20;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AssertNotNull);

    _this20 = _super21.call(this, condition.type, sourceSpan);
    _this20.condition = condition;
    return _this20;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AssertNotNull, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof AssertNotNull && this.condition.isEquivalent(e.condition);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitAssertNotNullExpr(this, context);
    }
  }]);

  return AssertNotNull;
}(Expression);

var CastExpr = /*#__PURE__*/function (_Expression16) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(CastExpr, _Expression16);

  var _super22 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(CastExpr);

  function CastExpr(value, type, sourceSpan) {
    var _this21;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CastExpr);

    _this21 = _super22.call(this, type, sourceSpan);
    _this21.value = value;
    return _this21;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CastExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof CastExpr && this.value.isEquivalent(e.value);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitCastExpr(this, context);
    }
  }]);

  return CastExpr;
}(Expression);

var FnParam = /*#__PURE__*/function () {
  function FnParam(name) {
    var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, FnParam);

    this.name = name;
    this.type = type;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(FnParam, [{
    key: "isEquivalent",
    value: function isEquivalent(param) {
      return this.name === param.name;
    }
  }]);

  return FnParam;
}();

var FunctionExpr = /*#__PURE__*/function (_Expression17) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(FunctionExpr, _Expression17);

  var _super23 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(FunctionExpr);

  function FunctionExpr(params, statements, type, sourceSpan, name) {
    var _this22;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, FunctionExpr);

    _this22 = _super23.call(this, type, sourceSpan);
    _this22.params = params;
    _this22.statements = statements;
    _this22.name = name;
    return _this22;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(FunctionExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof FunctionExpr && areAllEquivalent(this.params, e.params) && areAllEquivalent(this.statements, e.statements);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitFunctionExpr(this, context);
    }
  }, {
    key: "toDeclStmt",
    value: function toDeclStmt(name, modifiers) {
      return new DeclareFunctionStmt(name, this.params, this.statements, this.type, modifiers, this.sourceSpan);
    }
  }]);

  return FunctionExpr;
}(Expression);

var UnaryOperatorExpr = /*#__PURE__*/function (_Expression18) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(UnaryOperatorExpr, _Expression18);

  var _super24 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(UnaryOperatorExpr);

  function UnaryOperatorExpr(operator, expr, type, sourceSpan) {
    var _this23;

    var parens = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : true;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, UnaryOperatorExpr);

    _this23 = _super24.call(this, type || NUMBER_TYPE, sourceSpan);
    _this23.operator = operator;
    _this23.expr = expr;
    _this23.parens = parens;
    return _this23;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(UnaryOperatorExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof UnaryOperatorExpr && this.operator === e.operator && this.expr.isEquivalent(e.expr);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitUnaryOperatorExpr(this, context);
    }
  }]);

  return UnaryOperatorExpr;
}(Expression);

var BinaryOperatorExpr = /*#__PURE__*/function (_Expression19) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(BinaryOperatorExpr, _Expression19);

  var _super25 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(BinaryOperatorExpr);

  function BinaryOperatorExpr(operator, lhs, rhs, type, sourceSpan) {
    var _this24;

    var parens = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : true;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BinaryOperatorExpr);

    _this24 = _super25.call(this, type || lhs.type, sourceSpan);
    _this24.operator = operator;
    _this24.rhs = rhs;
    _this24.parens = parens;
    _this24.lhs = lhs;
    return _this24;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BinaryOperatorExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof BinaryOperatorExpr && this.operator === e.operator && this.lhs.isEquivalent(e.lhs) && this.rhs.isEquivalent(e.rhs);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitBinaryOperatorExpr(this, context);
    }
  }]);

  return BinaryOperatorExpr;
}(Expression);

var ReadPropExpr = /*#__PURE__*/function (_Expression20) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ReadPropExpr, _Expression20);

  var _super26 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ReadPropExpr);

  function ReadPropExpr(receiver, name, type, sourceSpan) {
    var _this25;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReadPropExpr);

    _this25 = _super26.call(this, type, sourceSpan);
    _this25.receiver = receiver;
    _this25.name = name;
    return _this25;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ReadPropExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof ReadPropExpr && this.receiver.isEquivalent(e.receiver) && this.name === e.name;
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitReadPropExpr(this, context);
    }
  }, {
    key: "set",
    value: function set(value) {
      return new WritePropExpr(this.receiver, this.name, value, null, this.sourceSpan);
    }
  }]);

  return ReadPropExpr;
}(Expression);

var ReadKeyExpr = /*#__PURE__*/function (_Expression21) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ReadKeyExpr, _Expression21);

  var _super27 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ReadKeyExpr);

  function ReadKeyExpr(receiver, index, type, sourceSpan) {
    var _this26;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReadKeyExpr);

    _this26 = _super27.call(this, type, sourceSpan);
    _this26.receiver = receiver;
    _this26.index = index;
    return _this26;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ReadKeyExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof ReadKeyExpr && this.receiver.isEquivalent(e.receiver) && this.index.isEquivalent(e.index);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitReadKeyExpr(this, context);
    }
  }, {
    key: "set",
    value: function set(value) {
      return new WriteKeyExpr(this.receiver, this.index, value, null, this.sourceSpan);
    }
  }]);

  return ReadKeyExpr;
}(Expression);

var LiteralArrayExpr = /*#__PURE__*/function (_Expression22) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralArrayExpr, _Expression22);

  var _super28 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralArrayExpr);

  function LiteralArrayExpr(entries, type, sourceSpan) {
    var _this27;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralArrayExpr);

    _this27 = _super28.call(this, type, sourceSpan);
    _this27.entries = entries;
    return _this27;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralArrayExpr, [{
    key: "isConstant",
    value: function isConstant() {
      return this.entries.every(function (e) {
        return e.isConstant();
      });
    }
  }, {
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof LiteralArrayExpr && areAllEquivalent(this.entries, e.entries);
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitLiteralArrayExpr(this, context);
    }
  }]);

  return LiteralArrayExpr;
}(Expression);

var LiteralMapEntry = /*#__PURE__*/function () {
  function LiteralMapEntry(key, value, quoted) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralMapEntry);

    this.key = key;
    this.value = value;
    this.quoted = quoted;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralMapEntry, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return this.key === e.key && this.value.isEquivalent(e.value);
    }
  }]);

  return LiteralMapEntry;
}();

var LiteralMapExpr = /*#__PURE__*/function (_Expression23) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralMapExpr, _Expression23);

  var _super29 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralMapExpr);

  function LiteralMapExpr(entries, type, sourceSpan) {
    var _this28;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralMapExpr);

    _this28 = _super29.call(this, type, sourceSpan);
    _this28.entries = entries;
    _this28.valueType = null;

    if (type) {
      _this28.valueType = type.valueType;
    }

    return _this28;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralMapExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof LiteralMapExpr && areAllEquivalent(this.entries, e.entries);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return this.entries.every(function (e) {
        return e.value.isConstant();
      });
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitLiteralMapExpr(this, context);
    }
  }]);

  return LiteralMapExpr;
}(Expression);

var CommaExpr = /*#__PURE__*/function (_Expression24) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(CommaExpr, _Expression24);

  var _super30 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(CommaExpr);

  function CommaExpr(parts, sourceSpan) {
    var _this29;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CommaExpr);

    _this29 = _super30.call(this, parts[parts.length - 1].type, sourceSpan);
    _this29.parts = parts;
    return _this29;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CommaExpr, [{
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof CommaExpr && areAllEquivalent(this.parts, e.parts);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return false;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      return visitor.visitCommaExpr(this, context);
    }
  }]);

  return CommaExpr;
}(Expression);

var THIS_EXPR = new ReadVarExpr(BuiltinVar.This, null, null);
var SUPER_EXPR = new ReadVarExpr(BuiltinVar.Super, null, null);
var CATCH_ERROR_VAR = new ReadVarExpr(BuiltinVar.CatchError, null, null);
var CATCH_STACK_VAR = new ReadVarExpr(BuiltinVar.CatchStack, null, null);
var NULL_EXPR = new LiteralExpr(null, null, null);
var TYPED_NULL_EXPR = new LiteralExpr(null, INFERRED_TYPE, null); //// Statements

var StmtModifier;

(function (StmtModifier) {
  StmtModifier[StmtModifier["Final"] = 0] = "Final";
  StmtModifier[StmtModifier["Private"] = 1] = "Private";
  StmtModifier[StmtModifier["Exported"] = 2] = "Exported";
  StmtModifier[StmtModifier["Static"] = 3] = "Static";
})(StmtModifier || (StmtModifier = {}));

var LeadingComment = /*#__PURE__*/function () {
  function LeadingComment(text, multiline, trailingNewline) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LeadingComment);

    this.text = text;
    this.multiline = multiline;
    this.trailingNewline = trailingNewline;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LeadingComment, [{
    key: "toString",
    value: function toString() {
      return this.multiline ? " ".concat(this.text, " ") : this.text;
    }
  }]);

  return LeadingComment;
}();

var JSDocComment = /*#__PURE__*/function (_LeadingComment) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(JSDocComment, _LeadingComment);

  var _super31 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(JSDocComment);

  function JSDocComment(tags) {
    var _this30;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, JSDocComment);

    _this30 = _super31.call(this, '',
    /* multiline */
    true,
    /* trailingNewline */
    true);
    _this30.tags = tags;
    return _this30;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(JSDocComment, [{
    key: "toString",
    value: function toString() {
      return serializeTags(this.tags);
    }
  }]);

  return JSDocComment;
}(LeadingComment);

var Statement = /*#__PURE__*/function () {
  function Statement() {
    var modifiers = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var sourceSpan = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    var leadingComments = arguments.length > 2 ? arguments[2] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Statement);

    this.modifiers = modifiers;
    this.sourceSpan = sourceSpan;
    this.leadingComments = leadingComments;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Statement, [{
    key: "hasModifier",
    value: function hasModifier(modifier) {
      return this.modifiers.indexOf(modifier) !== -1;
    }
  }, {
    key: "addLeadingComment",
    value: function addLeadingComment(leadingComment) {
      var _a;

      this.leadingComments = (_a = this.leadingComments) !== null && _a !== void 0 ? _a : [];
      this.leadingComments.push(leadingComment);
    }
  }]);

  return Statement;
}();

var DeclareVarStmt = /*#__PURE__*/function (_Statement) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(DeclareVarStmt, _Statement);

  var _super32 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(DeclareVarStmt);

  function DeclareVarStmt(name, value, type, modifiers, sourceSpan, leadingComments) {
    var _this31;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DeclareVarStmt);

    _this31 = _super32.call(this, modifiers, sourceSpan, leadingComments);
    _this31.name = name;
    _this31.value = value;
    _this31.type = type || value && value.type || null;
    return _this31;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DeclareVarStmt, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof DeclareVarStmt && this.name === stmt.name && (this.value ? !!stmt.value && this.value.isEquivalent(stmt.value) : !stmt.value);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitDeclareVarStmt(this, context);
    }
  }]);

  return DeclareVarStmt;
}(Statement);

var DeclareFunctionStmt = /*#__PURE__*/function (_Statement2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(DeclareFunctionStmt, _Statement2);

  var _super33 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(DeclareFunctionStmt);

  function DeclareFunctionStmt(name, params, statements, type, modifiers, sourceSpan, leadingComments) {
    var _this32;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DeclareFunctionStmt);

    _this32 = _super33.call(this, modifiers, sourceSpan, leadingComments);
    _this32.name = name;
    _this32.params = params;
    _this32.statements = statements;
    _this32.type = type || null;
    return _this32;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DeclareFunctionStmt, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof DeclareFunctionStmt && areAllEquivalent(this.params, stmt.params) && areAllEquivalent(this.statements, stmt.statements);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitDeclareFunctionStmt(this, context);
    }
  }]);

  return DeclareFunctionStmt;
}(Statement);

var ExpressionStatement = /*#__PURE__*/function (_Statement3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ExpressionStatement, _Statement3);

  var _super34 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ExpressionStatement);

  function ExpressionStatement(expr, sourceSpan, leadingComments) {
    var _this33;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExpressionStatement);

    _this33 = _super34.call(this, [], sourceSpan, leadingComments);
    _this33.expr = expr;
    return _this33;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ExpressionStatement, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof ExpressionStatement && this.expr.isEquivalent(stmt.expr);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitExpressionStmt(this, context);
    }
  }]);

  return ExpressionStatement;
}(Statement);

var ReturnStatement = /*#__PURE__*/function (_Statement4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ReturnStatement, _Statement4);

  var _super35 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ReturnStatement);

  function ReturnStatement(value) {
    var _this34;

    var sourceSpan = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    var leadingComments = arguments.length > 2 ? arguments[2] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReturnStatement);

    _this34 = _super35.call(this, [], sourceSpan, leadingComments);
    _this34.value = value;
    return _this34;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ReturnStatement, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof ReturnStatement && this.value.isEquivalent(stmt.value);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitReturnStmt(this, context);
    }
  }]);

  return ReturnStatement;
}(Statement);

var AbstractClassPart = /*#__PURE__*/function () {
  function AbstractClassPart() {
    var type = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
    var modifiers = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AbstractClassPart);

    this.type = type;
    this.modifiers = modifiers;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AbstractClassPart, [{
    key: "hasModifier",
    value: function hasModifier(modifier) {
      return this.modifiers.indexOf(modifier) !== -1;
    }
  }]);

  return AbstractClassPart;
}();

var ClassField = /*#__PURE__*/function (_AbstractClassPart) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ClassField, _AbstractClassPart);

  var _super36 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ClassField);

  function ClassField(name, type, modifiers, initializer) {
    var _this35;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ClassField);

    _this35 = _super36.call(this, type, modifiers);
    _this35.name = name;
    _this35.initializer = initializer;
    return _this35;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ClassField, [{
    key: "isEquivalent",
    value: function isEquivalent(f) {
      return this.name === f.name;
    }
  }]);

  return ClassField;
}(AbstractClassPart);

var ClassMethod = /*#__PURE__*/function (_AbstractClassPart2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ClassMethod, _AbstractClassPart2);

  var _super37 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ClassMethod);

  function ClassMethod(name, params, body, type, modifiers) {
    var _this36;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ClassMethod);

    _this36 = _super37.call(this, type, modifiers);
    _this36.name = name;
    _this36.params = params;
    _this36.body = body;
    return _this36;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ClassMethod, [{
    key: "isEquivalent",
    value: function isEquivalent(m) {
      return this.name === m.name && areAllEquivalent(this.body, m.body);
    }
  }]);

  return ClassMethod;
}(AbstractClassPart);

var ClassGetter = /*#__PURE__*/function (_AbstractClassPart3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ClassGetter, _AbstractClassPart3);

  var _super38 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ClassGetter);

  function ClassGetter(name, body, type, modifiers) {
    var _this37;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ClassGetter);

    _this37 = _super38.call(this, type, modifiers);
    _this37.name = name;
    _this37.body = body;
    return _this37;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ClassGetter, [{
    key: "isEquivalent",
    value: function isEquivalent(m) {
      return this.name === m.name && areAllEquivalent(this.body, m.body);
    }
  }]);

  return ClassGetter;
}(AbstractClassPart);

var ClassStmt = /*#__PURE__*/function (_Statement5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ClassStmt, _Statement5);

  var _super39 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ClassStmt);

  function ClassStmt(name, parent, fields, getters, constructorMethod, methods, modifiers, sourceSpan, leadingComments) {
    var _this38;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ClassStmt);

    _this38 = _super39.call(this, modifiers, sourceSpan, leadingComments);
    _this38.name = name;
    _this38.parent = parent;
    _this38.fields = fields;
    _this38.getters = getters;
    _this38.constructorMethod = constructorMethod;
    _this38.methods = methods;
    return _this38;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ClassStmt, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof ClassStmt && this.name === stmt.name && nullSafeIsEquivalent(this.parent, stmt.parent) && areAllEquivalent(this.fields, stmt.fields) && areAllEquivalent(this.getters, stmt.getters) && this.constructorMethod.isEquivalent(stmt.constructorMethod) && areAllEquivalent(this.methods, stmt.methods);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitDeclareClassStmt(this, context);
    }
  }]);

  return ClassStmt;
}(Statement);

var IfStmt = /*#__PURE__*/function (_Statement6) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(IfStmt, _Statement6);

  var _super40 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(IfStmt);

  function IfStmt(condition, trueCase) {
    var _this39;

    var falseCase = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
    var sourceSpan = arguments.length > 3 ? arguments[3] : undefined;
    var leadingComments = arguments.length > 4 ? arguments[4] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, IfStmt);

    _this39 = _super40.call(this, [], sourceSpan, leadingComments);
    _this39.condition = condition;
    _this39.trueCase = trueCase;
    _this39.falseCase = falseCase;
    return _this39;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(IfStmt, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof IfStmt && this.condition.isEquivalent(stmt.condition) && areAllEquivalent(this.trueCase, stmt.trueCase) && areAllEquivalent(this.falseCase, stmt.falseCase);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitIfStmt(this, context);
    }
  }]);

  return IfStmt;
}(Statement);

var TryCatchStmt = /*#__PURE__*/function (_Statement7) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(TryCatchStmt, _Statement7);

  var _super41 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(TryCatchStmt);

  function TryCatchStmt(bodyStmts, catchStmts) {
    var _this40;

    var sourceSpan = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
    var leadingComments = arguments.length > 3 ? arguments[3] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TryCatchStmt);

    _this40 = _super41.call(this, [], sourceSpan, leadingComments);
    _this40.bodyStmts = bodyStmts;
    _this40.catchStmts = catchStmts;
    return _this40;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TryCatchStmt, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof TryCatchStmt && areAllEquivalent(this.bodyStmts, stmt.bodyStmts) && areAllEquivalent(this.catchStmts, stmt.catchStmts);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitTryCatchStmt(this, context);
    }
  }]);

  return TryCatchStmt;
}(Statement);

var ThrowStmt = /*#__PURE__*/function (_Statement8) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ThrowStmt, _Statement8);

  var _super42 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ThrowStmt);

  function ThrowStmt(error) {
    var _this41;

    var sourceSpan = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    var leadingComments = arguments.length > 2 ? arguments[2] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ThrowStmt);

    _this41 = _super42.call(this, [], sourceSpan, leadingComments);
    _this41.error = error;
    return _this41;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ThrowStmt, [{
    key: "isEquivalent",
    value: function isEquivalent(stmt) {
      return stmt instanceof TryCatchStmt && this.error.isEquivalent(stmt.error);
    }
  }, {
    key: "visitStatement",
    value: function visitStatement(visitor, context) {
      return visitor.visitThrowStmt(this, context);
    }
  }]);

  return ThrowStmt;
}(Statement);

var AstTransformer = /*#__PURE__*/function () {
  function AstTransformer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AstTransformer);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AstTransformer, [{
    key: "transformExpr",
    value: function transformExpr(expr, context) {
      return expr;
    }
  }, {
    key: "transformStmt",
    value: function transformStmt(stmt, context) {
      return stmt;
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(ast, context) {
      return this.transformExpr(ast, context);
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, context) {
      return this.transformExpr(ast, context);
    }
  }, {
    key: "visitTypeofExpr",
    value: function visitTypeofExpr(expr, context) {
      return this.transformExpr(new TypeofExpr(expr.expr.visitExpression(this, context), expr.type, expr.sourceSpan), context);
    }
  }, {
    key: "visitWriteVarExpr",
    value: function visitWriteVarExpr(expr, context) {
      return this.transformExpr(new WriteVarExpr(expr.name, expr.value.visitExpression(this, context), expr.type, expr.sourceSpan), context);
    }
  }, {
    key: "visitWriteKeyExpr",
    value: function visitWriteKeyExpr(expr, context) {
      return this.transformExpr(new WriteKeyExpr(expr.receiver.visitExpression(this, context), expr.index.visitExpression(this, context), expr.value.visitExpression(this, context), expr.type, expr.sourceSpan), context);
    }
  }, {
    key: "visitWritePropExpr",
    value: function visitWritePropExpr(expr, context) {
      return this.transformExpr(new WritePropExpr(expr.receiver.visitExpression(this, context), expr.name, expr.value.visitExpression(this, context), expr.type, expr.sourceSpan), context);
    }
  }, {
    key: "visitInvokeMethodExpr",
    value: function visitInvokeMethodExpr(ast, context) {
      var method = ast.builtin || ast.name;
      return this.transformExpr(new InvokeMethodExpr(ast.receiver.visitExpression(this, context), method, this.visitAllExpressions(ast.args, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitInvokeFunctionExpr",
    value: function visitInvokeFunctionExpr(ast, context) {
      return this.transformExpr(new InvokeFunctionExpr(ast.fn.visitExpression(this, context), this.visitAllExpressions(ast.args, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitInstantiateExpr",
    value: function visitInstantiateExpr(ast, context) {
      return this.transformExpr(new InstantiateExpr(ast.classExpr.visitExpression(this, context), this.visitAllExpressions(ast.args, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitLiteralExpr",
    value: function visitLiteralExpr(ast, context) {
      return this.transformExpr(ast, context);
    }
  }, {
    key: "visitLocalizedString",
    value: function visitLocalizedString(ast, context) {
      return this.transformExpr(new LocalizedString(ast.metaBlock, ast.messageParts, ast.placeHolderNames, this.visitAllExpressions(ast.expressions, context), ast.sourceSpan), context);
    }
  }, {
    key: "visitExternalExpr",
    value: function visitExternalExpr(ast, context) {
      return this.transformExpr(ast, context);
    }
  }, {
    key: "visitConditionalExpr",
    value: function visitConditionalExpr(ast, context) {
      return this.transformExpr(new ConditionalExpr(ast.condition.visitExpression(this, context), ast.trueCase.visitExpression(this, context), ast.falseCase.visitExpression(this, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitNotExpr",
    value: function visitNotExpr(ast, context) {
      return this.transformExpr(new NotExpr(ast.condition.visitExpression(this, context), ast.sourceSpan), context);
    }
  }, {
    key: "visitAssertNotNullExpr",
    value: function visitAssertNotNullExpr(ast, context) {
      return this.transformExpr(new AssertNotNull(ast.condition.visitExpression(this, context), ast.sourceSpan), context);
    }
  }, {
    key: "visitCastExpr",
    value: function visitCastExpr(ast, context) {
      return this.transformExpr(new CastExpr(ast.value.visitExpression(this, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitFunctionExpr",
    value: function visitFunctionExpr(ast, context) {
      return this.transformExpr(new FunctionExpr(ast.params, this.visitAllStatements(ast.statements, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitUnaryOperatorExpr",
    value: function visitUnaryOperatorExpr(ast, context) {
      return this.transformExpr(new UnaryOperatorExpr(ast.operator, ast.expr.visitExpression(this, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitBinaryOperatorExpr",
    value: function visitBinaryOperatorExpr(ast, context) {
      return this.transformExpr(new BinaryOperatorExpr(ast.operator, ast.lhs.visitExpression(this, context), ast.rhs.visitExpression(this, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitReadPropExpr",
    value: function visitReadPropExpr(ast, context) {
      return this.transformExpr(new ReadPropExpr(ast.receiver.visitExpression(this, context), ast.name, ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitReadKeyExpr",
    value: function visitReadKeyExpr(ast, context) {
      return this.transformExpr(new ReadKeyExpr(ast.receiver.visitExpression(this, context), ast.index.visitExpression(this, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitLiteralArrayExpr",
    value: function visitLiteralArrayExpr(ast, context) {
      return this.transformExpr(new LiteralArrayExpr(this.visitAllExpressions(ast.entries, context), ast.type, ast.sourceSpan), context);
    }
  }, {
    key: "visitLiteralMapExpr",
    value: function visitLiteralMapExpr(ast, context) {
      var _this42 = this;

      var entries = ast.entries.map(function (entry) {
        return new LiteralMapEntry(entry.key, entry.value.visitExpression(_this42, context), entry.quoted);
      });
      var mapType = new MapType(ast.valueType);
      return this.transformExpr(new LiteralMapExpr(entries, mapType, ast.sourceSpan), context);
    }
  }, {
    key: "visitCommaExpr",
    value: function visitCommaExpr(ast, context) {
      return this.transformExpr(new CommaExpr(this.visitAllExpressions(ast.parts, context), ast.sourceSpan), context);
    }
  }, {
    key: "visitAllExpressions",
    value: function visitAllExpressions(exprs, context) {
      var _this43 = this;

      return exprs.map(function (expr) {
        return expr.visitExpression(_this43, context);
      });
    }
  }, {
    key: "visitDeclareVarStmt",
    value: function visitDeclareVarStmt(stmt, context) {
      var value = stmt.value && stmt.value.visitExpression(this, context);
      return this.transformStmt(new DeclareVarStmt(stmt.name, value, stmt.type, stmt.modifiers, stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, context) {
      return this.transformStmt(new DeclareFunctionStmt(stmt.name, stmt.params, this.visitAllStatements(stmt.statements, context), stmt.type, stmt.modifiers, stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitExpressionStmt",
    value: function visitExpressionStmt(stmt, context) {
      return this.transformStmt(new ExpressionStatement(stmt.expr.visitExpression(this, context), stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitReturnStmt",
    value: function visitReturnStmt(stmt, context) {
      return this.transformStmt(new ReturnStatement(stmt.value.visitExpression(this, context), stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, context) {
      var _this44 = this;

      var parent = stmt.parent.visitExpression(this, context);
      var getters = stmt.getters.map(function (getter) {
        return new ClassGetter(getter.name, _this44.visitAllStatements(getter.body, context), getter.type, getter.modifiers);
      });
      var ctorMethod = stmt.constructorMethod && new ClassMethod(stmt.constructorMethod.name, stmt.constructorMethod.params, this.visitAllStatements(stmt.constructorMethod.body, context), stmt.constructorMethod.type, stmt.constructorMethod.modifiers);
      var methods = stmt.methods.map(function (method) {
        return new ClassMethod(method.name, method.params, _this44.visitAllStatements(method.body, context), method.type, method.modifiers);
      });
      return this.transformStmt(new ClassStmt(stmt.name, parent, stmt.fields, getters, ctorMethod, methods, stmt.modifiers, stmt.sourceSpan), context);
    }
  }, {
    key: "visitIfStmt",
    value: function visitIfStmt(stmt, context) {
      return this.transformStmt(new IfStmt(stmt.condition.visitExpression(this, context), this.visitAllStatements(stmt.trueCase, context), this.visitAllStatements(stmt.falseCase, context), stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitTryCatchStmt",
    value: function visitTryCatchStmt(stmt, context) {
      return this.transformStmt(new TryCatchStmt(this.visitAllStatements(stmt.bodyStmts, context), this.visitAllStatements(stmt.catchStmts, context), stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitThrowStmt",
    value: function visitThrowStmt(stmt, context) {
      return this.transformStmt(new ThrowStmt(stmt.error.visitExpression(this, context), stmt.sourceSpan, stmt.leadingComments), context);
    }
  }, {
    key: "visitAllStatements",
    value: function visitAllStatements(stmts, context) {
      var _this45 = this;

      return stmts.map(function (stmt) {
        return stmt.visitStatement(_this45, context);
      });
    }
  }]);

  return AstTransformer;
}();

var RecursiveAstVisitor = /*#__PURE__*/function () {
  function RecursiveAstVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, RecursiveAstVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(RecursiveAstVisitor, [{
    key: "visitType",
    value: function visitType(ast, context) {
      return ast;
    }
  }, {
    key: "visitExpression",
    value: function visitExpression(ast, context) {
      if (ast.type) {
        ast.type.visitType(this, context);
      }

      return ast;
    }
  }, {
    key: "visitBuiltinType",
    value: function visitBuiltinType(type, context) {
      return this.visitType(type, context);
    }
  }, {
    key: "visitExpressionType",
    value: function visitExpressionType(type, context) {
      var _this46 = this;

      type.value.visitExpression(this, context);

      if (type.typeParams !== null) {
        type.typeParams.forEach(function (param) {
          return _this46.visitType(param, context);
        });
      }

      return this.visitType(type, context);
    }
  }, {
    key: "visitArrayType",
    value: function visitArrayType(type, context) {
      return this.visitType(type, context);
    }
  }, {
    key: "visitMapType",
    value: function visitMapType(type, context) {
      return this.visitType(type, context);
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, context) {
      return ast;
    }
  }, {
    key: "visitTypeofExpr",
    value: function visitTypeofExpr(ast, context) {
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(ast, context) {
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitWriteVarExpr",
    value: function visitWriteVarExpr(ast, context) {
      ast.value.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitWriteKeyExpr",
    value: function visitWriteKeyExpr(ast, context) {
      ast.receiver.visitExpression(this, context);
      ast.index.visitExpression(this, context);
      ast.value.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitWritePropExpr",
    value: function visitWritePropExpr(ast, context) {
      ast.receiver.visitExpression(this, context);
      ast.value.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitInvokeMethodExpr",
    value: function visitInvokeMethodExpr(ast, context) {
      ast.receiver.visitExpression(this, context);
      this.visitAllExpressions(ast.args, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitInvokeFunctionExpr",
    value: function visitInvokeFunctionExpr(ast, context) {
      ast.fn.visitExpression(this, context);
      this.visitAllExpressions(ast.args, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitInstantiateExpr",
    value: function visitInstantiateExpr(ast, context) {
      ast.classExpr.visitExpression(this, context);
      this.visitAllExpressions(ast.args, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitLiteralExpr",
    value: function visitLiteralExpr(ast, context) {
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitLocalizedString",
    value: function visitLocalizedString(ast, context) {
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitExternalExpr",
    value: function visitExternalExpr(ast, context) {
      var _this47 = this;

      if (ast.typeParams) {
        ast.typeParams.forEach(function (type) {
          return type.visitType(_this47, context);
        });
      }

      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitConditionalExpr",
    value: function visitConditionalExpr(ast, context) {
      ast.condition.visitExpression(this, context);
      ast.trueCase.visitExpression(this, context);
      ast.falseCase.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitNotExpr",
    value: function visitNotExpr(ast, context) {
      ast.condition.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitAssertNotNullExpr",
    value: function visitAssertNotNullExpr(ast, context) {
      ast.condition.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitCastExpr",
    value: function visitCastExpr(ast, context) {
      ast.value.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitFunctionExpr",
    value: function visitFunctionExpr(ast, context) {
      this.visitAllStatements(ast.statements, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitUnaryOperatorExpr",
    value: function visitUnaryOperatorExpr(ast, context) {
      ast.expr.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitBinaryOperatorExpr",
    value: function visitBinaryOperatorExpr(ast, context) {
      ast.lhs.visitExpression(this, context);
      ast.rhs.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitReadPropExpr",
    value: function visitReadPropExpr(ast, context) {
      ast.receiver.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitReadKeyExpr",
    value: function visitReadKeyExpr(ast, context) {
      ast.receiver.visitExpression(this, context);
      ast.index.visitExpression(this, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitLiteralArrayExpr",
    value: function visitLiteralArrayExpr(ast, context) {
      this.visitAllExpressions(ast.entries, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitLiteralMapExpr",
    value: function visitLiteralMapExpr(ast, context) {
      var _this48 = this;

      ast.entries.forEach(function (entry) {
        return entry.value.visitExpression(_this48, context);
      });
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitCommaExpr",
    value: function visitCommaExpr(ast, context) {
      this.visitAllExpressions(ast.parts, context);
      return this.visitExpression(ast, context);
    }
  }, {
    key: "visitAllExpressions",
    value: function visitAllExpressions(exprs, context) {
      var _this49 = this;

      exprs.forEach(function (expr) {
        return expr.visitExpression(_this49, context);
      });
    }
  }, {
    key: "visitDeclareVarStmt",
    value: function visitDeclareVarStmt(stmt, context) {
      if (stmt.value) {
        stmt.value.visitExpression(this, context);
      }

      if (stmt.type) {
        stmt.type.visitType(this, context);
      }

      return stmt;
    }
  }, {
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, context) {
      this.visitAllStatements(stmt.statements, context);

      if (stmt.type) {
        stmt.type.visitType(this, context);
      }

      return stmt;
    }
  }, {
    key: "visitExpressionStmt",
    value: function visitExpressionStmt(stmt, context) {
      stmt.expr.visitExpression(this, context);
      return stmt;
    }
  }, {
    key: "visitReturnStmt",
    value: function visitReturnStmt(stmt, context) {
      stmt.value.visitExpression(this, context);
      return stmt;
    }
  }, {
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, context) {
      var _this50 = this;

      stmt.parent.visitExpression(this, context);
      stmt.getters.forEach(function (getter) {
        return _this50.visitAllStatements(getter.body, context);
      });

      if (stmt.constructorMethod) {
        this.visitAllStatements(stmt.constructorMethod.body, context);
      }

      stmt.methods.forEach(function (method) {
        return _this50.visitAllStatements(method.body, context);
      });
      return stmt;
    }
  }, {
    key: "visitIfStmt",
    value: function visitIfStmt(stmt, context) {
      stmt.condition.visitExpression(this, context);
      this.visitAllStatements(stmt.trueCase, context);
      this.visitAllStatements(stmt.falseCase, context);
      return stmt;
    }
  }, {
    key: "visitTryCatchStmt",
    value: function visitTryCatchStmt(stmt, context) {
      this.visitAllStatements(stmt.bodyStmts, context);
      this.visitAllStatements(stmt.catchStmts, context);
      return stmt;
    }
  }, {
    key: "visitThrowStmt",
    value: function visitThrowStmt(stmt, context) {
      stmt.error.visitExpression(this, context);
      return stmt;
    }
  }, {
    key: "visitAllStatements",
    value: function visitAllStatements(stmts, context) {
      var _this51 = this;

      stmts.forEach(function (stmt) {
        return stmt.visitStatement(_this51, context);
      });
    }
  }]);

  return RecursiveAstVisitor;
}();

function findReadVarNames(stmts) {
  var visitor = new _ReadVarVisitor();
  visitor.visitAllStatements(stmts, null);
  return visitor.varNames;
}

var _ReadVarVisitor = /*#__PURE__*/function (_RecursiveAstVisitor) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_ReadVarVisitor, _RecursiveAstVisitor);

  var _super43 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_ReadVarVisitor);

  function _ReadVarVisitor() {
    var _this52;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _ReadVarVisitor);

    _this52 = _super43.apply(this, arguments);
    _this52.varNames = new Set();
    return _this52;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_ReadVarVisitor, [{
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, context) {
      // Don't descend into nested functions
      return stmt;
    }
  }, {
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, context) {
      // Don't descend into nested classes
      return stmt;
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(ast, context) {
      if (ast.name) {
        this.varNames.add(ast.name);
      }

      return null;
    }
  }]);

  return _ReadVarVisitor;
}(RecursiveAstVisitor);

function collectExternalReferences(stmts) {
  var visitor = new _FindExternalReferencesVisitor();
  visitor.visitAllStatements(stmts, null);
  return visitor.externalReferences;
}

var _FindExternalReferencesVisitor = /*#__PURE__*/function (_RecursiveAstVisitor2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_FindExternalReferencesVisitor, _RecursiveAstVisitor2);

  var _super44 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_FindExternalReferencesVisitor);

  function _FindExternalReferencesVisitor() {
    var _this53;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _FindExternalReferencesVisitor);

    _this53 = _super44.apply(this, arguments);
    _this53.externalReferences = [];
    return _this53;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_FindExternalReferencesVisitor, [{
    key: "visitExternalExpr",
    value: function visitExternalExpr(e, context) {
      this.externalReferences.push(e.value);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(_FindExternalReferencesVisitor.prototype), "visitExternalExpr", this).call(this, e, context);
    }
  }]);

  return _FindExternalReferencesVisitor;
}(RecursiveAstVisitor);

function applySourceSpanToStatementIfNeeded(stmt, sourceSpan) {
  if (!sourceSpan) {
    return stmt;
  }

  var transformer = new _ApplySourceSpanTransformer(sourceSpan);
  return stmt.visitStatement(transformer, null);
}

function applySourceSpanToExpressionIfNeeded(expr, sourceSpan) {
  if (!sourceSpan) {
    return expr;
  }

  var transformer = new _ApplySourceSpanTransformer(sourceSpan);
  return expr.visitExpression(transformer, null);
}

var _ApplySourceSpanTransformer = /*#__PURE__*/function (_AstTransformer) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_ApplySourceSpanTransformer, _AstTransformer);

  var _super45 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_ApplySourceSpanTransformer);

  function _ApplySourceSpanTransformer(sourceSpan) {
    var _this54;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _ApplySourceSpanTransformer);

    _this54 = _super45.call(this);
    _this54.sourceSpan = sourceSpan;
    return _this54;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_ApplySourceSpanTransformer, [{
    key: "_clone",
    value: function _clone(obj) {
      var clone = Object.create(obj.constructor.prototype);

      for (var _i4 = 0, _Object$keys = Object.keys(obj); _i4 < _Object$keys.length; _i4++) {
        var prop = _Object$keys[_i4];
        clone[prop] = obj[prop];
      }

      return clone;
    }
  }, {
    key: "transformExpr",
    value: function transformExpr(expr, context) {
      if (!expr.sourceSpan) {
        expr = this._clone(expr);
        expr.sourceSpan = this.sourceSpan;
      }

      return expr;
    }
  }, {
    key: "transformStmt",
    value: function transformStmt(stmt, context) {
      if (!stmt.sourceSpan) {
        stmt = this._clone(stmt);
        stmt.sourceSpan = this.sourceSpan;
      }

      return stmt;
    }
  }]);

  return _ApplySourceSpanTransformer;
}(AstTransformer);

function leadingComment(text) {
  var multiline = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var trailingNewline = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  return new LeadingComment(text, multiline, trailingNewline);
}

function jsDocComment() {
  var tags = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return new JSDocComment(tags);
}

function variable(name, type, sourceSpan) {
  return new ReadVarExpr(name, type, sourceSpan);
}

function importExpr(id) {
  var typeParams = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var sourceSpan = arguments.length > 2 ? arguments[2] : undefined;
  return new ExternalExpr(id, null, typeParams, sourceSpan);
}

function importType(id, typeParams, typeModifiers) {
  return id != null ? expressionType(importExpr(id, typeParams, null), typeModifiers) : null;
}

function expressionType(expr, typeModifiers, typeParams) {
  return new ExpressionType(expr, typeModifiers, typeParams);
}

function typeofExpr(expr) {
  return new TypeofExpr(expr);
}

function literalArr(values, type, sourceSpan) {
  return new LiteralArrayExpr(values, type, sourceSpan);
}

function literalMap(values) {
  var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  return new LiteralMapExpr(values.map(function (e) {
    return new LiteralMapEntry(e.key, e.value, e.quoted);
  }), type, null);
}

function unary(operator, expr, type, sourceSpan) {
  return new UnaryOperatorExpr(operator, expr, type, sourceSpan);
}

function not(expr, sourceSpan) {
  return new NotExpr(expr, sourceSpan);
}

function assertNotNull(expr, sourceSpan) {
  return new AssertNotNull(expr, sourceSpan);
}

function fn(params, body, type, sourceSpan, name) {
  return new FunctionExpr(params, body, type, sourceSpan, name);
}

function ifStmt(condition, thenClause, elseClause, sourceSpan, leadingComments) {
  return new IfStmt(condition, thenClause, elseClause, sourceSpan, leadingComments);
}

function literal(value, type, sourceSpan) {
  return new LiteralExpr(value, type, sourceSpan);
}

function localizedString(metaBlock, messageParts, placeholderNames, expressions, sourceSpan) {
  return new LocalizedString(metaBlock, messageParts, placeholderNames, expressions, sourceSpan);
}

function isNull(exp) {
  return exp instanceof LiteralExpr && exp.value === null;
}
/*
 * Serializes a `Tag` into a string.
 * Returns a string like " @foo {bar} baz" (note the leading whitespace before `@foo`).
 */


function tagToString(tag) {
  var out = '';

  if (tag.tagName) {
    out += " @".concat(tag.tagName);
  }

  if (tag.text) {
    if (tag.text.match(/\/\*|\*\//)) {
      throw new Error('JSDoc text cannot contain "/*" and "*/"');
    }

    out += ' ' + tag.text.replace(/@/g, '\\@');
  }

  return out;
}

function serializeTags(tags) {
  if (tags.length === 0) return '';

  if (tags.length === 1 && tags[0].tagName && !tags[0].text) {
    // The JSDOC comment is a single simple tag: e.g `/** @tagname */`.
    return "*".concat(tagToString(tags[0]), " ");
  }

  var out = '*\n';

  var _iterator = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(tags),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var tag = _step.value;
      out += ' *'; // If the tagToString is multi-line, insert " * " prefixes on lines.

      out += tagToString(tag).replace(/\n/g, '\n * ');
      out += '\n';
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  out += ' ';
  return out;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var DASH_CASE_REGEXP = /-+([a-z0-9])/g;

function dashCaseToCamelCase(input) {
  return input.replace(DASH_CASE_REGEXP, function () {
    for (var _len = arguments.length, m = new Array(_len), _key = 0; _key < _len; _key++) {
      m[_key] = arguments[_key];
    }

    return m[1].toUpperCase();
  });
}

function splitAtColon(input, defaultValues) {
  return _splitAt(input, ':', defaultValues);
}

function splitAtPeriod(input, defaultValues) {
  return _splitAt(input, '.', defaultValues);
}

function _splitAt(input, character, defaultValues) {
  var characterIndex = input.indexOf(character);
  if (characterIndex == -1) return defaultValues;
  return [input.slice(0, characterIndex).trim(), input.slice(characterIndex + 1).trim()];
}

function visitValue(value, visitor, context) {
  if (Array.isArray(value)) {
    return visitor.visitArray(value, context);
  }

  if (isStrictStringMap(value)) {
    return visitor.visitStringMap(value, context);
  }

  if (value == null || typeof value == 'string' || typeof value == 'number' || typeof value == 'boolean') {
    return visitor.visitPrimitive(value, context);
  }

  return visitor.visitOther(value, context);
}

function isDefined(val) {
  return val !== null && val !== undefined;
}

function noUndefined(val) {
  return val === undefined ? null : val;
}

var ValueTransformer = /*#__PURE__*/function () {
  function ValueTransformer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ValueTransformer);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ValueTransformer, [{
    key: "visitArray",
    value: function visitArray(arr, context) {
      var _this55 = this;

      return arr.map(function (value) {
        return visitValue(value, _this55, context);
      });
    }
  }, {
    key: "visitStringMap",
    value: function visitStringMap(map, context) {
      var _this56 = this;

      var result = {};
      Object.keys(map).forEach(function (key) {
        result[key] = visitValue(map[key], _this56, context);
      });
      return result;
    }
  }, {
    key: "visitPrimitive",
    value: function visitPrimitive(value, context) {
      return value;
    }
  }, {
    key: "visitOther",
    value: function visitOther(value, context) {
      return value;
    }
  }]);

  return ValueTransformer;
}();

var SyncAsync = {
  assertSync: function assertSync(value) {
    if (isPromise(value)) {
      throw new Error("Illegal state: value cannot be a promise");
    }

    return value;
  },
  then: function then(value, cb) {
    return isPromise(value) ? value.then(cb) : cb(value);
  },
  all: function all(syncAsyncValues) {
    return syncAsyncValues.some(isPromise) ? Promise.all(syncAsyncValues) : syncAsyncValues;
  }
};

function error(msg) {
  throw new Error("Internal Error: ".concat(msg));
}

function syntaxError(msg, parseErrors) {
  var error = Error(msg);
  error[ERROR_SYNTAX_ERROR] = true;
  if (parseErrors) error[ERROR_PARSE_ERRORS] = parseErrors;
  return error;
}

var ERROR_SYNTAX_ERROR = 'ngSyntaxError';
var ERROR_PARSE_ERRORS = 'ngParseErrors';

function isSyntaxError(error) {
  return error[ERROR_SYNTAX_ERROR];
}

function getParseErrors(error) {
  return error[ERROR_PARSE_ERRORS] || [];
} // Escape characters that have a special meaning in Regular Expressions


function escapeRegExp(s) {
  return s.replace(/([.*+?^=!:${}()|[\]\/\\])/g, '\\$1');
}

var STRING_MAP_PROTO = Object.getPrototypeOf({});

function isStrictStringMap(obj) {
  return typeof obj === 'object' && obj !== null && Object.getPrototypeOf(obj) === STRING_MAP_PROTO;
}

function utf8Encode(str) {
  var encoded = '';

  for (var index = 0; index < str.length; index++) {
    var codePoint = str.charCodeAt(index); // decode surrogate
    // see https://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae

    if (codePoint >= 0xd800 && codePoint <= 0xdbff && str.length > index + 1) {
      var low = str.charCodeAt(index + 1);

      if (low >= 0xdc00 && low <= 0xdfff) {
        index++;
        codePoint = (codePoint - 0xd800 << 10) + low - 0xdc00 + 0x10000;
      }
    }

    if (codePoint <= 0x7f) {
      encoded += String.fromCharCode(codePoint);
    } else if (codePoint <= 0x7ff) {
      encoded += String.fromCharCode(codePoint >> 6 & 0x1F | 0xc0, codePoint & 0x3f | 0x80);
    } else if (codePoint <= 0xffff) {
      encoded += String.fromCharCode(codePoint >> 12 | 0xe0, codePoint >> 6 & 0x3f | 0x80, codePoint & 0x3f | 0x80);
    } else if (codePoint <= 0x1fffff) {
      encoded += String.fromCharCode(codePoint >> 18 & 0x07 | 0xf0, codePoint >> 12 & 0x3f | 0x80, codePoint >> 6 & 0x3f | 0x80, codePoint & 0x3f | 0x80);
    }
  }

  return encoded;
}

function stringify(token) {
  if (typeof token === 'string') {
    return token;
  }

  if (Array.isArray(token)) {
    return '[' + token.map(stringify).join(', ') + ']';
  }

  if (token == null) {
    return '' + token;
  }

  if (token.overriddenName) {
    return "".concat(token.overriddenName);
  }

  if (token.name) {
    return "".concat(token.name);
  }

  if (!token.toString) {
    return 'object';
  } // WARNING: do not try to `JSON.stringify(token)` here
  // see https://github.com/angular/angular/issues/23440


  var res = token.toString();

  if (res == null) {
    return '' + res;
  }

  var newLineIndex = res.indexOf('\n');
  return newLineIndex === -1 ? res : res.substring(0, newLineIndex);
}
/**
 * Lazily retrieves the reference value from a forwardRef.
 */


function resolveForwardRef(type) {
  if (typeof type === 'function' && type.hasOwnProperty('__forward_ref__')) {
    return type();
  } else {
    return type;
  }
}
/**
 * Determine if the argument is shaped like a Promise
 */


function isPromise(obj) {
  // allow any Promise/A+ compliant thenable.
  // It's up to the caller to ensure that obj.then conforms to the spec
  return !!obj && typeof obj.then === 'function';
}

var Version = function Version(full) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Version);

  this.full = full;
  var splits = full.split('.');
  this.major = splits[0];
  this.minor = splits[1];
  this.patch = splits.slice(2).join('.');
};

var __window = typeof window !== 'undefined' && window;

var __self = typeof self !== 'undefined' && typeof WorkerGlobalScope !== 'undefined' && self instanceof WorkerGlobalScope && self;

var __global = typeof global !== 'undefined' && global; // Check __global first, because in Node tests both __global and __window may be defined and _global
// should be __global in that case.


var _global = __global || __window || __self;

function newArray(size, value) {
  var list = [];

  for (var i = 0; i < size; i++) {
    list.push(value);
  }

  return list;
}
/**
 * Partitions a given array into 2 arrays, based on a boolean value returned by the condition
 * function.
 *
 * @param arr Input array that should be partitioned
 * @param conditionFn Condition function that is called for each item in a given array and returns a
 * boolean value.
 */


function partitionArray(arr, conditionFn) {
  var truthy = [];
  var falsy = [];
  arr.forEach(function (item) {
    (conditionFn(item) ? truthy : falsy).push(item);
  });
  return [truthy, falsy];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CONSTANT_PREFIX = '_c';
/**
 * `ConstantPool` tries to reuse literal factories when two or more literals are identical.
 * We determine whether literals are identical by creating a key out of their AST using the
 * `KeyVisitor`. This constant is used to replace dynamic expressions which can't be safely
 * converted into a key. E.g. given an expression `{foo: bar()}`, since we don't know what
 * the result of `bar` will be, we create a key that looks like `{foo: <unknown>}`. Note
 * that we use a variable, rather than something like `null` in order to avoid collisions.
 */

var UNKNOWN_VALUE_KEY = variable('<unknown>');
/**
 * Context to use when producing a key.
 *
 * This ensures we see the constant not the reference variable when producing
 * a key.
 */

var KEY_CONTEXT = {};
/**
 * Generally all primitive values are excluded from the `ConstantPool`, but there is an exclusion
 * for strings that reach a certain length threshold. This constant defines the length threshold for
 * strings.
 */

var POOL_INCLUSION_LENGTH_THRESHOLD_FOR_STRINGS = 50;
/**
 * A node that is a place-holder that allows the node to be replaced when the actual
 * node is known.
 *
 * This allows the constant pool to change an expression from a direct reference to
 * a constant to a shared constant. It returns a fix-up node that is later allowed to
 * change the referenced expression.
 */

var FixupExpression = /*#__PURE__*/function (_Expression25) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(FixupExpression, _Expression25);

  var _super46 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(FixupExpression);

  function FixupExpression(resolved) {
    var _this57;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, FixupExpression);

    _this57 = _super46.call(this, resolved.type);
    _this57.resolved = resolved;
    _this57.original = resolved;
    return _this57;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(FixupExpression, [{
    key: "visitExpression",
    value: function visitExpression(visitor, context) {
      if (context === KEY_CONTEXT) {
        // When producing a key we want to traverse the constant not the
        // variable used to refer to it.
        return this.original.visitExpression(visitor, context);
      } else {
        return this.resolved.visitExpression(visitor, context);
      }
    }
  }, {
    key: "isEquivalent",
    value: function isEquivalent(e) {
      return e instanceof FixupExpression && this.resolved.isEquivalent(e.resolved);
    }
  }, {
    key: "isConstant",
    value: function isConstant() {
      return true;
    }
  }, {
    key: "fixup",
    value: function fixup(expression) {
      this.resolved = expression;
      this.shared = true;
    }
  }]);

  return FixupExpression;
}(Expression);
/**
 * A constant pool allows a code emitter to share constant in an output context.
 *
 * The constant pool also supports sharing access to ivy definitions references.
 */


var ConstantPool = /*#__PURE__*/function () {
  function ConstantPool() {
    var isClosureCompilerEnabled = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ConstantPool);

    this.isClosureCompilerEnabled = isClosureCompilerEnabled;
    this.statements = [];
    this.literals = new Map();
    this.literalFactories = new Map();
    this.injectorDefinitions = new Map();
    this.directiveDefinitions = new Map();
    this.componentDefinitions = new Map();
    this.pipeDefinitions = new Map();
    this.nextNameIndex = 0;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ConstantPool, [{
    key: "getConstLiteral",
    value: function getConstLiteral(literal, forceShared) {
      if (literal instanceof LiteralExpr && !isLongStringLiteral(literal) || literal instanceof FixupExpression) {
        // Do no put simple literals into the constant pool or try to produce a constant for a
        // reference to a constant.
        return literal;
      }

      var key = this.keyOf(literal);
      var fixup = this.literals.get(key);
      var newValue = false;

      if (!fixup) {
        fixup = new FixupExpression(literal);
        this.literals.set(key, fixup);
        newValue = true;
      }

      if (!newValue && !fixup.shared || newValue && forceShared) {
        // Replace the expression with a variable
        var name = this.freshName();
        var definition;
        var usage;

        if (this.isClosureCompilerEnabled && isLongStringLiteral(literal)) {
          // For string literals, Closure will **always** inline the string at
          // **all** usages, duplicating it each time. For large strings, this
          // unnecessarily bloats bundle size. To work around this restriction, we
          // wrap the string in a function, and call that function for each usage.
          // This tricks Closure into using inline logic for functions instead of
          // string literals. Function calls are only inlined if the body is small
          // enough to be worth it. By doing this, very large strings will be
          // shared across multiple usages, rather than duplicating the string at
          // each usage site.
          //
          // const myStr = function() { return "very very very long string"; };
          // const usage1 = myStr();
          // const usage2 = myStr();
          definition = variable(name).set(new FunctionExpr([], // Params.
          [// Statements.
          new ReturnStatement(literal)]));
          usage = variable(name).callFn([]);
        } else {
          // Just declare and use the variable directly, without a function call
          // indirection. This saves a few bytes and avoids an unncessary call.
          definition = variable(name).set(literal);
          usage = variable(name);
        }

        this.statements.push(definition.toDeclStmt(INFERRED_TYPE, [StmtModifier.Final]));
        fixup.fixup(usage);
      }

      return fixup;
    }
  }, {
    key: "getDefinition",
    value: function getDefinition(type, kind, ctx) {
      var forceShared = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
      var definitions = this.definitionsOf(kind);
      var fixup = definitions.get(type);
      var newValue = false;

      if (!fixup) {
        var property = this.propertyNameOf(kind);
        fixup = new FixupExpression(ctx.importExpr(type).prop(property));
        definitions.set(type, fixup);
        newValue = true;
      }

      if (!newValue && !fixup.shared || newValue && forceShared) {
        var name = this.freshName();
        this.statements.push(variable(name).set(fixup.resolved).toDeclStmt(INFERRED_TYPE, [StmtModifier.Final]));
        fixup.fixup(variable(name));
      }

      return fixup;
    }
  }, {
    key: "getLiteralFactory",
    value: function getLiteralFactory(literal) {
      // Create a pure function that builds an array of a mix of constant and variable expressions
      if (literal instanceof LiteralArrayExpr) {
        var argumentsForKey = literal.entries.map(function (e) {
          return e.isConstant() ? e : UNKNOWN_VALUE_KEY;
        });
        var key = this.keyOf(literalArr(argumentsForKey));
        return this._getLiteralFactory(key, literal.entries, function (entries) {
          return literalArr(entries);
        });
      } else {
        var expressionForKey = literalMap(literal.entries.map(function (e) {
          return {
            key: e.key,
            value: e.value.isConstant() ? e.value : UNKNOWN_VALUE_KEY,
            quoted: e.quoted
          };
        }));

        var _key2 = this.keyOf(expressionForKey);

        return this._getLiteralFactory(_key2, literal.entries.map(function (e) {
          return e.value;
        }), function (entries) {
          return literalMap(entries.map(function (value, index) {
            return {
              key: literal.entries[index].key,
              value: value,
              quoted: literal.entries[index].quoted
            };
          }));
        });
      }
    }
  }, {
    key: "_getLiteralFactory",
    value: function _getLiteralFactory(key, values, resultMap) {
      var _this58 = this;

      var literalFactory = this.literalFactories.get(key);
      var literalFactoryArguments = values.filter(function (e) {
        return !e.isConstant();
      });

      if (!literalFactory) {
        var resultExpressions = values.map(function (e, index) {
          return e.isConstant() ? _this58.getConstLiteral(e, true) : variable("a".concat(index));
        });
        var parameters = resultExpressions.filter(isVariable).map(function (e) {
          return new FnParam(e.name, DYNAMIC_TYPE);
        });
        var pureFunctionDeclaration = fn(parameters, [new ReturnStatement(resultMap(resultExpressions))], INFERRED_TYPE);
        var name = this.freshName();
        this.statements.push(variable(name).set(pureFunctionDeclaration).toDeclStmt(INFERRED_TYPE, [StmtModifier.Final]));
        literalFactory = variable(name);
        this.literalFactories.set(key, literalFactory);
      }

      return {
        literalFactory: literalFactory,
        literalFactoryArguments: literalFactoryArguments
      };
    }
    /**
     * Produce a unique name.
     *
     * The name might be unique among different prefixes if any of the prefixes end in
     * a digit so the prefix should be a constant string (not based on user input) and
     * must not end in a digit.
     */

  }, {
    key: "uniqueName",
    value: function uniqueName(prefix) {
      return "".concat(prefix).concat(this.nextNameIndex++);
    }
  }, {
    key: "definitionsOf",
    value: function definitionsOf(kind) {
      switch (kind) {
        case 2
        /* Component */
        :
          return this.componentDefinitions;

        case 1
        /* Directive */
        :
          return this.directiveDefinitions;

        case 0
        /* Injector */
        :
          return this.injectorDefinitions;

        case 3
        /* Pipe */
        :
          return this.pipeDefinitions;
      }

      error("Unknown definition kind ".concat(kind));
      return this.componentDefinitions;
    }
  }, {
    key: "propertyNameOf",
    value: function propertyNameOf(kind) {
      switch (kind) {
        case 2
        /* Component */
        :
          return 'ɵcmp';

        case 1
        /* Directive */
        :
          return 'ɵdir';

        case 0
        /* Injector */
        :
          return 'ɵinj';

        case 3
        /* Pipe */
        :
          return 'ɵpipe';
      }

      error("Unknown definition kind ".concat(kind));
      return '<unknown>';
    }
  }, {
    key: "freshName",
    value: function freshName() {
      return this.uniqueName(CONSTANT_PREFIX);
    }
  }, {
    key: "keyOf",
    value: function keyOf(expression) {
      return expression.visitExpression(new KeyVisitor(), KEY_CONTEXT);
    }
  }]);

  return ConstantPool;
}();
/**
 * Visitor used to determine if 2 expressions are equivalent and can be shared in the
 * `ConstantPool`.
 *
 * When the id (string) generated by the visitor is equal, expressions are considered equivalent.
 */


var KeyVisitor = /*#__PURE__*/function () {
  function KeyVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, KeyVisitor);

    this.visitWrappedNodeExpr = invalid;
    this.visitWriteVarExpr = invalid;
    this.visitWriteKeyExpr = invalid;
    this.visitWritePropExpr = invalid;
    this.visitInvokeMethodExpr = invalid;
    this.visitInvokeFunctionExpr = invalid;
    this.visitInstantiateExpr = invalid;
    this.visitConditionalExpr = invalid;
    this.visitNotExpr = invalid;
    this.visitAssertNotNullExpr = invalid;
    this.visitCastExpr = invalid;
    this.visitFunctionExpr = invalid;
    this.visitUnaryOperatorExpr = invalid;
    this.visitBinaryOperatorExpr = invalid;
    this.visitReadPropExpr = invalid;
    this.visitReadKeyExpr = invalid;
    this.visitCommaExpr = invalid;
    this.visitLocalizedString = invalid;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(KeyVisitor, [{
    key: "visitLiteralExpr",
    value: function visitLiteralExpr(ast) {
      return "".concat(typeof ast.value === 'string' ? '"' + ast.value + '"' : ast.value);
    }
  }, {
    key: "visitLiteralArrayExpr",
    value: function visitLiteralArrayExpr(ast, context) {
      var _this59 = this;

      return "[".concat(ast.entries.map(function (entry) {
        return entry.visitExpression(_this59, context);
      }).join(','), "]");
    }
  }, {
    key: "visitLiteralMapExpr",
    value: function visitLiteralMapExpr(ast, context) {
      var _this60 = this;

      var mapKey = function mapKey(entry) {
        var quote = entry.quoted ? '"' : '';
        return "".concat(quote).concat(entry.key).concat(quote);
      };

      var mapEntry = function mapEntry(entry) {
        return "".concat(mapKey(entry), ":").concat(entry.value.visitExpression(_this60, context));
      };

      return "{".concat(ast.entries.map(mapEntry).join(','));
    }
  }, {
    key: "visitExternalExpr",
    value: function visitExternalExpr(ast) {
      return ast.value.moduleName ? "EX:".concat(ast.value.moduleName, ":").concat(ast.value.name) : "EX:".concat(ast.value.runtime.name);
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(node) {
      return "VAR:".concat(node.name);
    }
  }, {
    key: "visitTypeofExpr",
    value: function visitTypeofExpr(node, context) {
      return "TYPEOF:".concat(node.expr.visitExpression(this, context));
    }
  }]);

  return KeyVisitor;
}();

function invalid(arg) {
  throw new Error("Invalid state: Visitor ".concat(this.constructor.name, " doesn't handle ").concat(arg.constructor.name));
}

function isVariable(e) {
  return e instanceof ReadVarExpr;
}

function isLongStringLiteral(expr) {
  return expr instanceof LiteralExpr && typeof expr.value === 'string' && expr.value.length >= POOL_INCLUSION_LENGTH_THRESHOLD_FOR_STRINGS;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CORE = '@angular/core';

var Identifiers = function Identifiers() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Identifiers);
};

Identifiers.ANALYZE_FOR_ENTRY_COMPONENTS = {
  name: 'ANALYZE_FOR_ENTRY_COMPONENTS',
  moduleName: CORE
};
Identifiers.ElementRef = {
  name: 'ElementRef',
  moduleName: CORE
};
Identifiers.NgModuleRef = {
  name: 'NgModuleRef',
  moduleName: CORE
};
Identifiers.ViewContainerRef = {
  name: 'ViewContainerRef',
  moduleName: CORE
};
Identifiers.ChangeDetectorRef = {
  name: 'ChangeDetectorRef',
  moduleName: CORE
};
Identifiers.QueryList = {
  name: 'QueryList',
  moduleName: CORE
};
Identifiers.TemplateRef = {
  name: 'TemplateRef',
  moduleName: CORE
};
Identifiers.Renderer2 = {
  name: 'Renderer2',
  moduleName: CORE
};
Identifiers.CodegenComponentFactoryResolver = {
  name: 'ɵCodegenComponentFactoryResolver',
  moduleName: CORE
};
Identifiers.ComponentFactoryResolver = {
  name: 'ComponentFactoryResolver',
  moduleName: CORE
};
Identifiers.ComponentFactory = {
  name: 'ComponentFactory',
  moduleName: CORE
};
Identifiers.ComponentRef = {
  name: 'ComponentRef',
  moduleName: CORE
};
Identifiers.NgModuleFactory = {
  name: 'NgModuleFactory',
  moduleName: CORE
};
Identifiers.createModuleFactory = {
  name: 'ɵcmf',
  moduleName: CORE
};
Identifiers.moduleDef = {
  name: 'ɵmod',
  moduleName: CORE
};
Identifiers.moduleProviderDef = {
  name: 'ɵmpd',
  moduleName: CORE
};
Identifiers.RegisterModuleFactoryFn = {
  name: 'ɵregisterModuleFactory',
  moduleName: CORE
};
Identifiers.inject = {
  name: 'ɵɵinject',
  moduleName: CORE
};
Identifiers.directiveInject = {
  name: 'ɵɵdirectiveInject',
  moduleName: CORE
};
Identifiers.INJECTOR = {
  name: 'INJECTOR',
  moduleName: CORE
};
Identifiers.Injector = {
  name: 'Injector',
  moduleName: CORE
};
Identifiers.ɵɵdefineInjectable = {
  name: 'ɵɵdefineInjectable',
  moduleName: CORE
};
Identifiers.InjectableDef = {
  name: 'ɵɵInjectableDef',
  moduleName: CORE
};
Identifiers.ViewEncapsulation = {
  name: 'ViewEncapsulation',
  moduleName: CORE
};
Identifiers.ChangeDetectionStrategy = {
  name: 'ChangeDetectionStrategy',
  moduleName: CORE
};
Identifiers.SecurityContext = {
  name: 'SecurityContext',
  moduleName: CORE
};
Identifiers.LOCALE_ID = {
  name: 'LOCALE_ID',
  moduleName: CORE
};
Identifiers.TRANSLATIONS_FORMAT = {
  name: 'TRANSLATIONS_FORMAT',
  moduleName: CORE
};
Identifiers.inlineInterpolate = {
  name: 'ɵinlineInterpolate',
  moduleName: CORE
};
Identifiers.interpolate = {
  name: 'ɵinterpolate',
  moduleName: CORE
};
Identifiers.EMPTY_ARRAY = {
  name: 'ɵEMPTY_ARRAY',
  moduleName: CORE
};
Identifiers.EMPTY_MAP = {
  name: 'ɵEMPTY_MAP',
  moduleName: CORE
};
Identifiers.Renderer = {
  name: 'Renderer',
  moduleName: CORE
};
Identifiers.viewDef = {
  name: 'ɵvid',
  moduleName: CORE
};
Identifiers.elementDef = {
  name: 'ɵeld',
  moduleName: CORE
};
Identifiers.anchorDef = {
  name: 'ɵand',
  moduleName: CORE
};
Identifiers.textDef = {
  name: 'ɵted',
  moduleName: CORE
};
Identifiers.directiveDef = {
  name: 'ɵdid',
  moduleName: CORE
};
Identifiers.providerDef = {
  name: 'ɵprd',
  moduleName: CORE
};
Identifiers.queryDef = {
  name: 'ɵqud',
  moduleName: CORE
};
Identifiers.pureArrayDef = {
  name: 'ɵpad',
  moduleName: CORE
};
Identifiers.pureObjectDef = {
  name: 'ɵpod',
  moduleName: CORE
};
Identifiers.purePipeDef = {
  name: 'ɵppd',
  moduleName: CORE
};
Identifiers.pipeDef = {
  name: 'ɵpid',
  moduleName: CORE
};
Identifiers.nodeValue = {
  name: 'ɵnov',
  moduleName: CORE
};
Identifiers.ngContentDef = {
  name: 'ɵncd',
  moduleName: CORE
};
Identifiers.unwrapValue = {
  name: 'ɵunv',
  moduleName: CORE
};
Identifiers.createRendererType2 = {
  name: 'ɵcrt',
  moduleName: CORE
}; // type only

Identifiers.RendererType2 = {
  name: 'RendererType2',
  moduleName: CORE
}; // type only

Identifiers.ViewDefinition = {
  name: 'ɵViewDefinition',
  moduleName: CORE
};
Identifiers.createComponentFactory = {
  name: 'ɵccf',
  moduleName: CORE
};
Identifiers.setClassMetadata = {
  name: 'ɵsetClassMetadata',
  moduleName: CORE
};

function createTokenForReference(reference) {
  return {
    identifier: {
      reference: reference
    }
  };
}

function createTokenForExternalReference(reflector, reference) {
  return createTokenForReference(reflector.resolveExternalReference(reference));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A token representing the a reference to a static type.
 *
 * This token is unique for a filePath and name and can be used as a hash table key.
 */


var StaticSymbol = /*#__PURE__*/function () {
  function StaticSymbol(filePath, name, members) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StaticSymbol);

    this.filePath = filePath;
    this.name = name;
    this.members = members;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StaticSymbol, [{
    key: "assertNoMembers",
    value: function assertNoMembers() {
      if (this.members.length) {
        throw new Error("Illegal state: symbol without members expected, but got ".concat(JSON.stringify(this), "."));
      }
    }
  }]);

  return StaticSymbol;
}();
/**
 * A cache of static symbol used by the StaticReflector to return the same symbol for the
 * same symbol values.
 */


var StaticSymbolCache = /*#__PURE__*/function () {
  function StaticSymbolCache() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StaticSymbolCache);

    this.cache = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StaticSymbolCache, [{
    key: "get",
    value: function get(declarationFile, name, members) {
      members = members || [];
      var memberSuffix = members.length ? ".".concat(members.join('.')) : '';
      var key = "\"".concat(declarationFile, "\".").concat(name).concat(memberSuffix);
      var result = this.cache.get(key);

      if (!result) {
        result = new StaticSymbol(declarationFile, name, members);
        this.cache.set(key, result);
      }

      return result;
    }
  }]);

  return StaticSymbolCache;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// group 0: "[prop] or (event) or @trigger"
// group 1: "prop" from "[prop]"
// group 2: "event" from "(event)"
// group 3: "@trigger" from "@trigger"


var HOST_REG_EXP = /^(?:(?:\[([^\]]+)\])|(?:\(([^\)]+)\)))|(\@[-\w]+)$/;

function sanitizeIdentifier(name) {
  return name.replace(/\W/g, '_');
}

var _anonymousTypeIndex = 0;

function identifierName(compileIdentifier) {
  if (!compileIdentifier || !compileIdentifier.reference) {
    return null;
  }

  var ref = compileIdentifier.reference;

  if (ref instanceof StaticSymbol) {
    return ref.name;
  }

  if (ref['__anonymousType']) {
    return ref['__anonymousType'];
  }

  var identifier = stringify(ref);

  if (identifier.indexOf('(') >= 0) {
    // case: anonymous functions!
    identifier = "anonymous_".concat(_anonymousTypeIndex++);
    ref['__anonymousType'] = identifier;
  } else {
    identifier = sanitizeIdentifier(identifier);
  }

  return identifier;
}

function identifierModuleUrl(compileIdentifier) {
  var ref = compileIdentifier.reference;

  if (ref instanceof StaticSymbol) {
    return ref.filePath;
  } // Runtime type


  return "./".concat(stringify(ref));
}

function viewClassName(compType, embeddedTemplateIndex) {
  return "View_".concat(identifierName({
    reference: compType
  }), "_").concat(embeddedTemplateIndex);
}

function rendererTypeName(compType) {
  return "RenderType_".concat(identifierName({
    reference: compType
  }));
}

function hostViewClassName(compType) {
  return "HostView_".concat(identifierName({
    reference: compType
  }));
}

function componentFactoryName(compType) {
  return "".concat(identifierName({
    reference: compType
  }), "NgFactory");
}

var CompileSummaryKind;

(function (CompileSummaryKind) {
  CompileSummaryKind[CompileSummaryKind["Pipe"] = 0] = "Pipe";
  CompileSummaryKind[CompileSummaryKind["Directive"] = 1] = "Directive";
  CompileSummaryKind[CompileSummaryKind["NgModule"] = 2] = "NgModule";
  CompileSummaryKind[CompileSummaryKind["Injectable"] = 3] = "Injectable";
})(CompileSummaryKind || (CompileSummaryKind = {}));

function tokenName(token) {
  return token.value != null ? sanitizeIdentifier(token.value) : identifierName(token.identifier);
}

function tokenReference(token) {
  if (token.identifier != null) {
    return token.identifier.reference;
  } else {
    return token.value;
  }
}
/**
 * Metadata about a stylesheet
 */


var CompileStylesheetMetadata = function CompileStylesheetMetadata() {
  var _ref3 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      moduleUrl = _ref3.moduleUrl,
      styles = _ref3.styles,
      styleUrls = _ref3.styleUrls;

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileStylesheetMetadata);

  this.moduleUrl = moduleUrl || null;
  this.styles = _normalizeArray(styles);
  this.styleUrls = _normalizeArray(styleUrls);
};
/**
 * Metadata regarding compilation of a template.
 */


var CompileTemplateMetadata = /*#__PURE__*/function () {
  function CompileTemplateMetadata(_ref4) {
    var encapsulation = _ref4.encapsulation,
        template = _ref4.template,
        templateUrl = _ref4.templateUrl,
        htmlAst = _ref4.htmlAst,
        styles = _ref4.styles,
        styleUrls = _ref4.styleUrls,
        externalStylesheets = _ref4.externalStylesheets,
        animations = _ref4.animations,
        ngContentSelectors = _ref4.ngContentSelectors,
        interpolation = _ref4.interpolation,
        isInline = _ref4.isInline,
        preserveWhitespaces = _ref4.preserveWhitespaces;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileTemplateMetadata);

    this.encapsulation = encapsulation;
    this.template = template;
    this.templateUrl = templateUrl;
    this.htmlAst = htmlAst;
    this.styles = _normalizeArray(styles);
    this.styleUrls = _normalizeArray(styleUrls);
    this.externalStylesheets = _normalizeArray(externalStylesheets);
    this.animations = animations ? flatten(animations) : [];
    this.ngContentSelectors = ngContentSelectors || [];

    if (interpolation && interpolation.length != 2) {
      throw new Error("'interpolation' should have a start and an end symbol.");
    }

    this.interpolation = interpolation;
    this.isInline = isInline;
    this.preserveWhitespaces = preserveWhitespaces;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompileTemplateMetadata, [{
    key: "toSummary",
    value: function toSummary() {
      return {
        ngContentSelectors: this.ngContentSelectors,
        encapsulation: this.encapsulation,
        styles: this.styles,
        animations: this.animations
      };
    }
  }]);

  return CompileTemplateMetadata;
}();
/**
 * Metadata regarding compilation of a directive.
 */


var CompileDirectiveMetadata = /*#__PURE__*/function () {
  function CompileDirectiveMetadata(_ref5) {
    var isHost = _ref5.isHost,
        type = _ref5.type,
        isComponent = _ref5.isComponent,
        selector = _ref5.selector,
        exportAs = _ref5.exportAs,
        changeDetection = _ref5.changeDetection,
        inputs = _ref5.inputs,
        outputs = _ref5.outputs,
        hostListeners = _ref5.hostListeners,
        hostProperties = _ref5.hostProperties,
        hostAttributes = _ref5.hostAttributes,
        providers = _ref5.providers,
        viewProviders = _ref5.viewProviders,
        queries = _ref5.queries,
        guards = _ref5.guards,
        viewQueries = _ref5.viewQueries,
        entryComponents = _ref5.entryComponents,
        template = _ref5.template,
        componentViewType = _ref5.componentViewType,
        rendererType = _ref5.rendererType,
        componentFactory = _ref5.componentFactory;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileDirectiveMetadata);

    this.isHost = !!isHost;
    this.type = type;
    this.isComponent = isComponent;
    this.selector = selector;
    this.exportAs = exportAs;
    this.changeDetection = changeDetection;
    this.inputs = inputs;
    this.outputs = outputs;
    this.hostListeners = hostListeners;
    this.hostProperties = hostProperties;
    this.hostAttributes = hostAttributes;
    this.providers = _normalizeArray(providers);
    this.viewProviders = _normalizeArray(viewProviders);
    this.queries = _normalizeArray(queries);
    this.guards = guards;
    this.viewQueries = _normalizeArray(viewQueries);
    this.entryComponents = _normalizeArray(entryComponents);
    this.template = template;
    this.componentViewType = componentViewType;
    this.rendererType = rendererType;
    this.componentFactory = componentFactory;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompileDirectiveMetadata, [{
    key: "toSummary",
    value: function toSummary() {
      return {
        summaryKind: CompileSummaryKind.Directive,
        type: this.type,
        isComponent: this.isComponent,
        selector: this.selector,
        exportAs: this.exportAs,
        inputs: this.inputs,
        outputs: this.outputs,
        hostListeners: this.hostListeners,
        hostProperties: this.hostProperties,
        hostAttributes: this.hostAttributes,
        providers: this.providers,
        viewProviders: this.viewProviders,
        queries: this.queries,
        guards: this.guards,
        viewQueries: this.viewQueries,
        entryComponents: this.entryComponents,
        changeDetection: this.changeDetection,
        template: this.template && this.template.toSummary(),
        componentViewType: this.componentViewType,
        rendererType: this.rendererType,
        componentFactory: this.componentFactory
      };
    }
  }], [{
    key: "create",
    value: function create(_ref6) {
      var isHost = _ref6.isHost,
          type = _ref6.type,
          isComponent = _ref6.isComponent,
          selector = _ref6.selector,
          exportAs = _ref6.exportAs,
          changeDetection = _ref6.changeDetection,
          inputs = _ref6.inputs,
          outputs = _ref6.outputs,
          host = _ref6.host,
          providers = _ref6.providers,
          viewProviders = _ref6.viewProviders,
          queries = _ref6.queries,
          guards = _ref6.guards,
          viewQueries = _ref6.viewQueries,
          entryComponents = _ref6.entryComponents,
          template = _ref6.template,
          componentViewType = _ref6.componentViewType,
          rendererType = _ref6.rendererType,
          componentFactory = _ref6.componentFactory;
      var hostListeners = {};
      var hostProperties = {};
      var hostAttributes = {};

      if (host != null) {
        Object.keys(host).forEach(function (key) {
          var value = host[key];
          var matches = key.match(HOST_REG_EXP);

          if (matches === null) {
            hostAttributes[key] = value;
          } else if (matches[1] != null) {
            hostProperties[matches[1]] = value;
          } else if (matches[2] != null) {
            hostListeners[matches[2]] = value;
          }
        });
      }

      var inputsMap = {};

      if (inputs != null) {
        inputs.forEach(function (bindConfig) {
          // canonical syntax: `dirProp: elProp`
          // if there is no `:`, use dirProp = elProp
          var parts = splitAtColon(bindConfig, [bindConfig, bindConfig]);
          inputsMap[parts[0]] = parts[1];
        });
      }

      var outputsMap = {};

      if (outputs != null) {
        outputs.forEach(function (bindConfig) {
          // canonical syntax: `dirProp: elProp`
          // if there is no `:`, use dirProp = elProp
          var parts = splitAtColon(bindConfig, [bindConfig, bindConfig]);
          outputsMap[parts[0]] = parts[1];
        });
      }

      return new CompileDirectiveMetadata({
        isHost: isHost,
        type: type,
        isComponent: !!isComponent,
        selector: selector,
        exportAs: exportAs,
        changeDetection: changeDetection,
        inputs: inputsMap,
        outputs: outputsMap,
        hostListeners: hostListeners,
        hostProperties: hostProperties,
        hostAttributes: hostAttributes,
        providers: providers,
        viewProviders: viewProviders,
        queries: queries,
        guards: guards,
        viewQueries: viewQueries,
        entryComponents: entryComponents,
        template: template,
        componentViewType: componentViewType,
        rendererType: rendererType,
        componentFactory: componentFactory
      });
    }
  }]);

  return CompileDirectiveMetadata;
}();

var CompilePipeMetadata = /*#__PURE__*/function () {
  function CompilePipeMetadata(_ref7) {
    var type = _ref7.type,
        name = _ref7.name,
        pure = _ref7.pure;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompilePipeMetadata);

    this.type = type;
    this.name = name;
    this.pure = !!pure;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompilePipeMetadata, [{
    key: "toSummary",
    value: function toSummary() {
      return {
        summaryKind: CompileSummaryKind.Pipe,
        type: this.type,
        name: this.name,
        pure: this.pure
      };
    }
  }]);

  return CompilePipeMetadata;
}();

var CompileShallowModuleMetadata = function CompileShallowModuleMetadata() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileShallowModuleMetadata);
};
/**
 * Metadata regarding compilation of a module.
 */


var CompileNgModuleMetadata = /*#__PURE__*/function () {
  function CompileNgModuleMetadata(_ref8) {
    var type = _ref8.type,
        providers = _ref8.providers,
        declaredDirectives = _ref8.declaredDirectives,
        exportedDirectives = _ref8.exportedDirectives,
        declaredPipes = _ref8.declaredPipes,
        exportedPipes = _ref8.exportedPipes,
        entryComponents = _ref8.entryComponents,
        bootstrapComponents = _ref8.bootstrapComponents,
        importedModules = _ref8.importedModules,
        exportedModules = _ref8.exportedModules,
        schemas = _ref8.schemas,
        transitiveModule = _ref8.transitiveModule,
        id = _ref8.id;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileNgModuleMetadata);

    this.type = type || null;
    this.declaredDirectives = _normalizeArray(declaredDirectives);
    this.exportedDirectives = _normalizeArray(exportedDirectives);
    this.declaredPipes = _normalizeArray(declaredPipes);
    this.exportedPipes = _normalizeArray(exportedPipes);
    this.providers = _normalizeArray(providers);
    this.entryComponents = _normalizeArray(entryComponents);
    this.bootstrapComponents = _normalizeArray(bootstrapComponents);
    this.importedModules = _normalizeArray(importedModules);
    this.exportedModules = _normalizeArray(exportedModules);
    this.schemas = _normalizeArray(schemas);
    this.id = id || null;
    this.transitiveModule = transitiveModule || null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompileNgModuleMetadata, [{
    key: "toSummary",
    value: function toSummary() {
      var module = this.transitiveModule;
      return {
        summaryKind: CompileSummaryKind.NgModule,
        type: this.type,
        entryComponents: module.entryComponents,
        providers: module.providers,
        modules: module.modules,
        exportedDirectives: module.exportedDirectives,
        exportedPipes: module.exportedPipes
      };
    }
  }]);

  return CompileNgModuleMetadata;
}();

var TransitiveCompileNgModuleMetadata = /*#__PURE__*/function () {
  function TransitiveCompileNgModuleMetadata() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TransitiveCompileNgModuleMetadata);

    this.directivesSet = new Set();
    this.directives = [];
    this.exportedDirectivesSet = new Set();
    this.exportedDirectives = [];
    this.pipesSet = new Set();
    this.pipes = [];
    this.exportedPipesSet = new Set();
    this.exportedPipes = [];
    this.modulesSet = new Set();
    this.modules = [];
    this.entryComponentsSet = new Set();
    this.entryComponents = [];
    this.providers = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TransitiveCompileNgModuleMetadata, [{
    key: "addProvider",
    value: function addProvider(provider, module) {
      this.providers.push({
        provider: provider,
        module: module
      });
    }
  }, {
    key: "addDirective",
    value: function addDirective(id) {
      if (!this.directivesSet.has(id.reference)) {
        this.directivesSet.add(id.reference);
        this.directives.push(id);
      }
    }
  }, {
    key: "addExportedDirective",
    value: function addExportedDirective(id) {
      if (!this.exportedDirectivesSet.has(id.reference)) {
        this.exportedDirectivesSet.add(id.reference);
        this.exportedDirectives.push(id);
      }
    }
  }, {
    key: "addPipe",
    value: function addPipe(id) {
      if (!this.pipesSet.has(id.reference)) {
        this.pipesSet.add(id.reference);
        this.pipes.push(id);
      }
    }
  }, {
    key: "addExportedPipe",
    value: function addExportedPipe(id) {
      if (!this.exportedPipesSet.has(id.reference)) {
        this.exportedPipesSet.add(id.reference);
        this.exportedPipes.push(id);
      }
    }
  }, {
    key: "addModule",
    value: function addModule(id) {
      if (!this.modulesSet.has(id.reference)) {
        this.modulesSet.add(id.reference);
        this.modules.push(id);
      }
    }
  }, {
    key: "addEntryComponent",
    value: function addEntryComponent(ec) {
      if (!this.entryComponentsSet.has(ec.componentType)) {
        this.entryComponentsSet.add(ec.componentType);
        this.entryComponents.push(ec);
      }
    }
  }]);

  return TransitiveCompileNgModuleMetadata;
}();

function _normalizeArray(obj) {
  return obj || [];
}

var ProviderMeta = function ProviderMeta(token, _ref9) {
  var useClass = _ref9.useClass,
      useValue = _ref9.useValue,
      useExisting = _ref9.useExisting,
      useFactory = _ref9.useFactory,
      deps = _ref9.deps,
      multi = _ref9.multi;

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ProviderMeta);

  this.token = token;
  this.useClass = useClass || null;
  this.useValue = useValue;
  this.useExisting = useExisting;
  this.useFactory = useFactory || null;
  this.dependencies = deps || null;
  this.multi = !!multi;
};

function flatten(list) {
  return list.reduce(function (flat, item) {
    var flatItem = Array.isArray(item) ? flatten(item) : item;
    return flat.concat(flatItem);
  }, []);
}

function jitSourceUrl(url) {
  // Note: We need 3 "/" so that ng shows up as a separate domain
  // in the chrome dev tools.
  return url.replace(/(\w+:\/\/[\w:-]+)?(\/+)?/, 'ng:///');
}

function templateSourceUrl(ngModuleType, compMeta, templateMeta) {
  var url;

  if (templateMeta.isInline) {
    if (compMeta.type.reference instanceof StaticSymbol) {
      // Note: a .ts file might contain multiple components with inline templates,
      // so we need to give them unique urls, as these will be used for sourcemaps.
      url = "".concat(compMeta.type.reference.filePath, ".").concat(compMeta.type.reference.name, ".html");
    } else {
      url = "".concat(identifierName(ngModuleType), "/").concat(identifierName(compMeta.type), ".html");
    }
  } else {
    url = templateMeta.templateUrl;
  }

  return compMeta.type.reference instanceof StaticSymbol ? url : jitSourceUrl(url);
}

function sharedStylesheetJitUrl(meta, id) {
  var pathParts = meta.moduleUrl.split(/\/\\/g);
  var baseName = pathParts[pathParts.length - 1];
  return jitSourceUrl("css/".concat(id).concat(baseName, ".ngstyle.js"));
}

function ngModuleJitUrl(moduleMeta) {
  return jitSourceUrl("".concat(identifierName(moduleMeta.type), "/module.ngfactory.js"));
}

function templateJitUrl(ngModuleType, compMeta) {
  return jitSourceUrl("".concat(identifierName(ngModuleType), "/").concat(identifierName(compMeta.type), ".ngfactory.js"));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CORE$1 = '@angular/core';

var Identifiers$1 = function Identifiers$1() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Identifiers$1);
};
/* Methods */


Identifiers$1.NEW_METHOD = 'factory';
Identifiers$1.TRANSFORM_METHOD = 'transform';
Identifiers$1.PATCH_DEPS = 'patchedDeps';
/* Instructions */

Identifiers$1.namespaceHTML = {
  name: 'ɵɵnamespaceHTML',
  moduleName: CORE$1
};
Identifiers$1.namespaceMathML = {
  name: 'ɵɵnamespaceMathML',
  moduleName: CORE$1
};
Identifiers$1.namespaceSVG = {
  name: 'ɵɵnamespaceSVG',
  moduleName: CORE$1
};
Identifiers$1.element = {
  name: 'ɵɵelement',
  moduleName: CORE$1
};
Identifiers$1.elementStart = {
  name: 'ɵɵelementStart',
  moduleName: CORE$1
};
Identifiers$1.elementEnd = {
  name: 'ɵɵelementEnd',
  moduleName: CORE$1
};
Identifiers$1.advance = {
  name: 'ɵɵadvance',
  moduleName: CORE$1
};
Identifiers$1.syntheticHostProperty = {
  name: 'ɵɵsyntheticHostProperty',
  moduleName: CORE$1
};
Identifiers$1.syntheticHostListener = {
  name: 'ɵɵsyntheticHostListener',
  moduleName: CORE$1
};
Identifiers$1.attribute = {
  name: 'ɵɵattribute',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate1 = {
  name: 'ɵɵattributeInterpolate1',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate2 = {
  name: 'ɵɵattributeInterpolate2',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate3 = {
  name: 'ɵɵattributeInterpolate3',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate4 = {
  name: 'ɵɵattributeInterpolate4',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate5 = {
  name: 'ɵɵattributeInterpolate5',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate6 = {
  name: 'ɵɵattributeInterpolate6',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate7 = {
  name: 'ɵɵattributeInterpolate7',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolate8 = {
  name: 'ɵɵattributeInterpolate8',
  moduleName: CORE$1
};
Identifiers$1.attributeInterpolateV = {
  name: 'ɵɵattributeInterpolateV',
  moduleName: CORE$1
};
Identifiers$1.classProp = {
  name: 'ɵɵclassProp',
  moduleName: CORE$1
};
Identifiers$1.elementContainerStart = {
  name: 'ɵɵelementContainerStart',
  moduleName: CORE$1
};
Identifiers$1.elementContainerEnd = {
  name: 'ɵɵelementContainerEnd',
  moduleName: CORE$1
};
Identifiers$1.elementContainer = {
  name: 'ɵɵelementContainer',
  moduleName: CORE$1
};
Identifiers$1.styleMap = {
  name: 'ɵɵstyleMap',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate1 = {
  name: 'ɵɵstyleMapInterpolate1',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate2 = {
  name: 'ɵɵstyleMapInterpolate2',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate3 = {
  name: 'ɵɵstyleMapInterpolate3',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate4 = {
  name: 'ɵɵstyleMapInterpolate4',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate5 = {
  name: 'ɵɵstyleMapInterpolate5',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate6 = {
  name: 'ɵɵstyleMapInterpolate6',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate7 = {
  name: 'ɵɵstyleMapInterpolate7',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolate8 = {
  name: 'ɵɵstyleMapInterpolate8',
  moduleName: CORE$1
};
Identifiers$1.styleMapInterpolateV = {
  name: 'ɵɵstyleMapInterpolateV',
  moduleName: CORE$1
};
Identifiers$1.classMap = {
  name: 'ɵɵclassMap',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate1 = {
  name: 'ɵɵclassMapInterpolate1',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate2 = {
  name: 'ɵɵclassMapInterpolate2',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate3 = {
  name: 'ɵɵclassMapInterpolate3',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate4 = {
  name: 'ɵɵclassMapInterpolate4',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate5 = {
  name: 'ɵɵclassMapInterpolate5',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate6 = {
  name: 'ɵɵclassMapInterpolate6',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate7 = {
  name: 'ɵɵclassMapInterpolate7',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolate8 = {
  name: 'ɵɵclassMapInterpolate8',
  moduleName: CORE$1
};
Identifiers$1.classMapInterpolateV = {
  name: 'ɵɵclassMapInterpolateV',
  moduleName: CORE$1
};
Identifiers$1.styleProp = {
  name: 'ɵɵstyleProp',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate1 = {
  name: 'ɵɵstylePropInterpolate1',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate2 = {
  name: 'ɵɵstylePropInterpolate2',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate3 = {
  name: 'ɵɵstylePropInterpolate3',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate4 = {
  name: 'ɵɵstylePropInterpolate4',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate5 = {
  name: 'ɵɵstylePropInterpolate5',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate6 = {
  name: 'ɵɵstylePropInterpolate6',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate7 = {
  name: 'ɵɵstylePropInterpolate7',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolate8 = {
  name: 'ɵɵstylePropInterpolate8',
  moduleName: CORE$1
};
Identifiers$1.stylePropInterpolateV = {
  name: 'ɵɵstylePropInterpolateV',
  moduleName: CORE$1
};
Identifiers$1.nextContext = {
  name: 'ɵɵnextContext',
  moduleName: CORE$1
};
Identifiers$1.templateCreate = {
  name: 'ɵɵtemplate',
  moduleName: CORE$1
};
Identifiers$1.text = {
  name: 'ɵɵtext',
  moduleName: CORE$1
};
Identifiers$1.enableBindings = {
  name: 'ɵɵenableBindings',
  moduleName: CORE$1
};
Identifiers$1.disableBindings = {
  name: 'ɵɵdisableBindings',
  moduleName: CORE$1
};
Identifiers$1.getCurrentView = {
  name: 'ɵɵgetCurrentView',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate = {
  name: 'ɵɵtextInterpolate',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate1 = {
  name: 'ɵɵtextInterpolate1',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate2 = {
  name: 'ɵɵtextInterpolate2',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate3 = {
  name: 'ɵɵtextInterpolate3',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate4 = {
  name: 'ɵɵtextInterpolate4',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate5 = {
  name: 'ɵɵtextInterpolate5',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate6 = {
  name: 'ɵɵtextInterpolate6',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate7 = {
  name: 'ɵɵtextInterpolate7',
  moduleName: CORE$1
};
Identifiers$1.textInterpolate8 = {
  name: 'ɵɵtextInterpolate8',
  moduleName: CORE$1
};
Identifiers$1.textInterpolateV = {
  name: 'ɵɵtextInterpolateV',
  moduleName: CORE$1
};
Identifiers$1.restoreView = {
  name: 'ɵɵrestoreView',
  moduleName: CORE$1
};
Identifiers$1.pureFunction0 = {
  name: 'ɵɵpureFunction0',
  moduleName: CORE$1
};
Identifiers$1.pureFunction1 = {
  name: 'ɵɵpureFunction1',
  moduleName: CORE$1
};
Identifiers$1.pureFunction2 = {
  name: 'ɵɵpureFunction2',
  moduleName: CORE$1
};
Identifiers$1.pureFunction3 = {
  name: 'ɵɵpureFunction3',
  moduleName: CORE$1
};
Identifiers$1.pureFunction4 = {
  name: 'ɵɵpureFunction4',
  moduleName: CORE$1
};
Identifiers$1.pureFunction5 = {
  name: 'ɵɵpureFunction5',
  moduleName: CORE$1
};
Identifiers$1.pureFunction6 = {
  name: 'ɵɵpureFunction6',
  moduleName: CORE$1
};
Identifiers$1.pureFunction7 = {
  name: 'ɵɵpureFunction7',
  moduleName: CORE$1
};
Identifiers$1.pureFunction8 = {
  name: 'ɵɵpureFunction8',
  moduleName: CORE$1
};
Identifiers$1.pureFunctionV = {
  name: 'ɵɵpureFunctionV',
  moduleName: CORE$1
};
Identifiers$1.pipeBind1 = {
  name: 'ɵɵpipeBind1',
  moduleName: CORE$1
};
Identifiers$1.pipeBind2 = {
  name: 'ɵɵpipeBind2',
  moduleName: CORE$1
};
Identifiers$1.pipeBind3 = {
  name: 'ɵɵpipeBind3',
  moduleName: CORE$1
};
Identifiers$1.pipeBind4 = {
  name: 'ɵɵpipeBind4',
  moduleName: CORE$1
};
Identifiers$1.pipeBindV = {
  name: 'ɵɵpipeBindV',
  moduleName: CORE$1
};
Identifiers$1.hostProperty = {
  name: 'ɵɵhostProperty',
  moduleName: CORE$1
};
Identifiers$1.property = {
  name: 'ɵɵproperty',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate = {
  name: 'ɵɵpropertyInterpolate',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate1 = {
  name: 'ɵɵpropertyInterpolate1',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate2 = {
  name: 'ɵɵpropertyInterpolate2',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate3 = {
  name: 'ɵɵpropertyInterpolate3',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate4 = {
  name: 'ɵɵpropertyInterpolate4',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate5 = {
  name: 'ɵɵpropertyInterpolate5',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate6 = {
  name: 'ɵɵpropertyInterpolate6',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate7 = {
  name: 'ɵɵpropertyInterpolate7',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolate8 = {
  name: 'ɵɵpropertyInterpolate8',
  moduleName: CORE$1
};
Identifiers$1.propertyInterpolateV = {
  name: 'ɵɵpropertyInterpolateV',
  moduleName: CORE$1
};
Identifiers$1.i18n = {
  name: 'ɵɵi18n',
  moduleName: CORE$1
};
Identifiers$1.i18nAttributes = {
  name: 'ɵɵi18nAttributes',
  moduleName: CORE$1
};
Identifiers$1.i18nExp = {
  name: 'ɵɵi18nExp',
  moduleName: CORE$1
};
Identifiers$1.i18nStart = {
  name: 'ɵɵi18nStart',
  moduleName: CORE$1
};
Identifiers$1.i18nEnd = {
  name: 'ɵɵi18nEnd',
  moduleName: CORE$1
};
Identifiers$1.i18nApply = {
  name: 'ɵɵi18nApply',
  moduleName: CORE$1
};
Identifiers$1.i18nPostprocess = {
  name: 'ɵɵi18nPostprocess',
  moduleName: CORE$1
};
Identifiers$1.pipe = {
  name: 'ɵɵpipe',
  moduleName: CORE$1
};
Identifiers$1.projection = {
  name: 'ɵɵprojection',
  moduleName: CORE$1
};
Identifiers$1.projectionDef = {
  name: 'ɵɵprojectionDef',
  moduleName: CORE$1
};
Identifiers$1.reference = {
  name: 'ɵɵreference',
  moduleName: CORE$1
};
Identifiers$1.inject = {
  name: 'ɵɵinject',
  moduleName: CORE$1
};
Identifiers$1.injectAttribute = {
  name: 'ɵɵinjectAttribute',
  moduleName: CORE$1
};
Identifiers$1.injectPipeChangeDetectorRef = {
  name: 'ɵɵinjectPipeChangeDetectorRef',
  moduleName: CORE$1
};
Identifiers$1.directiveInject = {
  name: 'ɵɵdirectiveInject',
  moduleName: CORE$1
};
Identifiers$1.invalidFactory = {
  name: 'ɵɵinvalidFactory',
  moduleName: CORE$1
};
Identifiers$1.invalidFactoryDep = {
  name: 'ɵɵinvalidFactoryDep',
  moduleName: CORE$1
};
Identifiers$1.templateRefExtractor = {
  name: 'ɵɵtemplateRefExtractor',
  moduleName: CORE$1
};
Identifiers$1.resolveWindow = {
  name: 'ɵɵresolveWindow',
  moduleName: CORE$1
};
Identifiers$1.resolveDocument = {
  name: 'ɵɵresolveDocument',
  moduleName: CORE$1
};
Identifiers$1.resolveBody = {
  name: 'ɵɵresolveBody',
  moduleName: CORE$1
};
Identifiers$1.defineComponent = {
  name: 'ɵɵdefineComponent',
  moduleName: CORE$1
};
Identifiers$1.setComponentScope = {
  name: 'ɵɵsetComponentScope',
  moduleName: CORE$1
};
Identifiers$1.ComponentDefWithMeta = {
  name: 'ɵɵComponentDefWithMeta',
  moduleName: CORE$1
};
Identifiers$1.FactoryDef = {
  name: 'ɵɵFactoryDef',
  moduleName: CORE$1
};
Identifiers$1.defineDirective = {
  name: 'ɵɵdefineDirective',
  moduleName: CORE$1
};
Identifiers$1.DirectiveDefWithMeta = {
  name: 'ɵɵDirectiveDefWithMeta',
  moduleName: CORE$1
};
Identifiers$1.InjectorDef = {
  name: 'ɵɵInjectorDef',
  moduleName: CORE$1
};
Identifiers$1.defineInjector = {
  name: 'ɵɵdefineInjector',
  moduleName: CORE$1
};
Identifiers$1.NgModuleDefWithMeta = {
  name: 'ɵɵNgModuleDefWithMeta',
  moduleName: CORE$1
};
Identifiers$1.ModuleWithProviders = {
  name: 'ModuleWithProviders',
  moduleName: CORE$1
};
Identifiers$1.defineNgModule = {
  name: 'ɵɵdefineNgModule',
  moduleName: CORE$1
};
Identifiers$1.setNgModuleScope = {
  name: 'ɵɵsetNgModuleScope',
  moduleName: CORE$1
};
Identifiers$1.PipeDefWithMeta = {
  name: 'ɵɵPipeDefWithMeta',
  moduleName: CORE$1
};
Identifiers$1.definePipe = {
  name: 'ɵɵdefinePipe',
  moduleName: CORE$1
};
Identifiers$1.queryRefresh = {
  name: 'ɵɵqueryRefresh',
  moduleName: CORE$1
};
Identifiers$1.viewQuery = {
  name: 'ɵɵviewQuery',
  moduleName: CORE$1
};
Identifiers$1.staticViewQuery = {
  name: 'ɵɵstaticViewQuery',
  moduleName: CORE$1
};
Identifiers$1.staticContentQuery = {
  name: 'ɵɵstaticContentQuery',
  moduleName: CORE$1
};
Identifiers$1.loadQuery = {
  name: 'ɵɵloadQuery',
  moduleName: CORE$1
};
Identifiers$1.contentQuery = {
  name: 'ɵɵcontentQuery',
  moduleName: CORE$1
};
Identifiers$1.NgOnChangesFeature = {
  name: 'ɵɵNgOnChangesFeature',
  moduleName: CORE$1
};
Identifiers$1.InheritDefinitionFeature = {
  name: 'ɵɵInheritDefinitionFeature',
  moduleName: CORE$1
};
Identifiers$1.CopyDefinitionFeature = {
  name: 'ɵɵCopyDefinitionFeature',
  moduleName: CORE$1
};
Identifiers$1.ProvidersFeature = {
  name: 'ɵɵProvidersFeature',
  moduleName: CORE$1
};
Identifiers$1.listener = {
  name: 'ɵɵlistener',
  moduleName: CORE$1
};
Identifiers$1.getFactoryOf = {
  name: 'ɵɵgetFactoryOf',
  moduleName: CORE$1
};
Identifiers$1.getInheritedFactory = {
  name: 'ɵɵgetInheritedFactory',
  moduleName: CORE$1
}; // sanitization-related functions

Identifiers$1.sanitizeHtml = {
  name: 'ɵɵsanitizeHtml',
  moduleName: CORE$1
};
Identifiers$1.sanitizeStyle = {
  name: 'ɵɵsanitizeStyle',
  moduleName: CORE$1
};
Identifiers$1.sanitizeResourceUrl = {
  name: 'ɵɵsanitizeResourceUrl',
  moduleName: CORE$1
};
Identifiers$1.sanitizeScript = {
  name: 'ɵɵsanitizeScript',
  moduleName: CORE$1
};
Identifiers$1.sanitizeUrl = {
  name: 'ɵɵsanitizeUrl',
  moduleName: CORE$1
};
Identifiers$1.sanitizeUrlOrResourceUrl = {
  name: 'ɵɵsanitizeUrlOrResourceUrl',
  moduleName: CORE$1
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Convert an object map with `Expression` values into a `LiteralMapExpr`.
 */

function mapToMapExpression(map) {
  var result = Object.keys(map).map(function (key) {
    return {
      key: key,
      // The assertion here is because really TypeScript doesn't allow us to express that if the
      // key is present, it will have a value, but this is true in reality.
      value: map[key],
      quoted: false
    };
  });
  return literalMap(result);
}
/**
 * Convert metadata into an `Expression` in the given `OutputContext`.
 *
 * This operation will handle arrays, references to symbols, or literal `null` or `undefined`.
 */


function convertMetaToOutput(meta, ctx) {
  if (Array.isArray(meta)) {
    return literalArr(meta.map(function (entry) {
      return convertMetaToOutput(entry, ctx);
    }));
  }

  if (meta instanceof StaticSymbol) {
    return ctx.importExpr(meta);
  }

  if (meta == null) {
    return literal(meta);
  }

  throw new Error("Internal error: Unsupported or unknown metadata: ".concat(meta));
}

function typeWithParameters(type, numParams) {
  if (numParams === 0) {
    return expressionType(type);
  }

  var params = [];

  for (var i = 0; i < numParams; i++) {
    params.push(DYNAMIC_TYPE);
  }

  return expressionType(type, undefined, params);
}

var ANIMATE_SYMBOL_PREFIX = '@';

function prepareSyntheticPropertyName(name) {
  return "".concat(ANIMATE_SYMBOL_PREFIX).concat(name);
}

function prepareSyntheticListenerName(name, phase) {
  return "".concat(ANIMATE_SYMBOL_PREFIX).concat(name, ".").concat(phase);
}

function isSyntheticPropertyOrListener(name) {
  return name.charAt(0) == ANIMATE_SYMBOL_PREFIX;
}

function getSyntheticPropertyName(name) {
  // this will strip out listener phase values...
  // @foo.start => @foo
  var i = name.indexOf('.');
  name = i > 0 ? name.substring(0, i) : name;

  if (name.charAt(0) !== ANIMATE_SYMBOL_PREFIX) {
    name = ANIMATE_SYMBOL_PREFIX + name;
  }

  return name;
}

function prepareSyntheticListenerFunctionName(name, phase) {
  return "animation_".concat(name, "_").concat(phase);
}

function jitOnlyGuardedExpression(expr) {
  var ngJitMode = new ExternalExpr({
    name: 'ngJitMode',
    moduleName: null
  });
  var jitFlagNotDefined = new BinaryOperatorExpr(BinaryOperator.Identical, new TypeofExpr(ngJitMode), literal('undefined'));
  var jitFlagUndefinedOrTrue = new BinaryOperatorExpr(BinaryOperator.Or, jitFlagNotDefined, ngJitMode,
  /* type */
  undefined,
  /* sourceSpan */
  undefined, true);
  return new BinaryOperatorExpr(BinaryOperator.And, jitFlagUndefinedOrTrue, expr);
}

function wrapReference(value) {
  var wrapped = new WrappedNodeExpr(value);
  return {
    value: wrapped,
    type: wrapped
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var $EOF = 0;
var $BSPACE = 8;
var $TAB = 9;
var $LF = 10;
var $VTAB = 11;
var $FF = 12;
var $CR = 13;
var $SPACE = 32;
var $BANG = 33;
var $DQ = 34;
var $HASH = 35;
var $$ = 36;
var $PERCENT = 37;
var $AMPERSAND = 38;
var $SQ = 39;
var $LPAREN = 40;
var $RPAREN = 41;
var $STAR = 42;
var $PLUS = 43;
var $COMMA = 44;
var $MINUS = 45;
var $PERIOD = 46;
var $SLASH = 47;
var $COLON = 58;
var $SEMICOLON = 59;
var $LT = 60;
var $EQ = 61;
var $GT = 62;
var $QUESTION = 63;
var $0 = 48;
var $7 = 55;
var $9 = 57;
var $A = 65;
var $E = 69;
var $F = 70;
var $X = 88;
var $Z = 90;
var $LBRACKET = 91;
var $BACKSLASH = 92;
var $RBRACKET = 93;
var $CARET = 94;
var $_ = 95;
var $a = 97;
var $b = 98;
var $e = 101;
var $f = 102;
var $n = 110;
var $r = 114;
var $t = 116;
var $u = 117;
var $v = 118;
var $x = 120;
var $z = 122;
var $LBRACE = 123;
var $BAR = 124;
var $RBRACE = 125;
var $NBSP = 160;
var $PIPE = 124;
var $TILDA = 126;
var $AT = 64;
var $BT = 96;

function isWhitespace(code) {
  return code >= $TAB && code <= $SPACE || code == $NBSP;
}

function isDigit(code) {
  return $0 <= code && code <= $9;
}

function isAsciiLetter(code) {
  return code >= $a && code <= $z || code >= $A && code <= $Z;
}

function isAsciiHexDigit(code) {
  return code >= $a && code <= $f || code >= $A && code <= $F || isDigit(code);
}

function isNewLine(code) {
  return code === $LF || code === $CR;
}

function isOctalDigit(code) {
  return $0 <= code && code <= $7;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ParseLocation = /*#__PURE__*/function () {
  function ParseLocation(file, offset, line, col) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParseLocation);

    this.file = file;
    this.offset = offset;
    this.line = line;
    this.col = col;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ParseLocation, [{
    key: "toString",
    value: function toString() {
      return this.offset != null ? "".concat(this.file.url, "@").concat(this.line, ":").concat(this.col) : this.file.url;
    }
  }, {
    key: "moveBy",
    value: function moveBy(delta) {
      var source = this.file.content;
      var len = source.length;
      var offset = this.offset;
      var line = this.line;
      var col = this.col;

      while (offset > 0 && delta < 0) {
        offset--;
        delta++;
        var ch = source.charCodeAt(offset);

        if (ch == $LF) {
          line--;
          var priorLine = source.substr(0, offset - 1).lastIndexOf(String.fromCharCode($LF));
          col = priorLine > 0 ? offset - priorLine : offset;
        } else {
          col--;
        }
      }

      while (offset < len && delta > 0) {
        var _ch = source.charCodeAt(offset);

        offset++;
        delta--;

        if (_ch == $LF) {
          line++;
          col = 0;
        } else {
          col++;
        }
      }

      return new ParseLocation(this.file, offset, line, col);
    } // Return the source around the location
    // Up to `maxChars` or `maxLines` on each side of the location

  }, {
    key: "getContext",
    value: function getContext(maxChars, maxLines) {
      var content = this.file.content;
      var startOffset = this.offset;

      if (startOffset != null) {
        if (startOffset > content.length - 1) {
          startOffset = content.length - 1;
        }

        var endOffset = startOffset;
        var ctxChars = 0;
        var ctxLines = 0;

        while (ctxChars < maxChars && startOffset > 0) {
          startOffset--;
          ctxChars++;

          if (content[startOffset] == '\n') {
            if (++ctxLines == maxLines) {
              break;
            }
          }
        }

        ctxChars = 0;
        ctxLines = 0;

        while (ctxChars < maxChars && endOffset < content.length - 1) {
          endOffset++;
          ctxChars++;

          if (content[endOffset] == '\n') {
            if (++ctxLines == maxLines) {
              break;
            }
          }
        }

        return {
          before: content.substring(startOffset, this.offset),
          after: content.substring(this.offset, endOffset + 1)
        };
      }

      return null;
    }
  }]);

  return ParseLocation;
}();

var ParseSourceFile = function ParseSourceFile(content, url) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParseSourceFile);

  this.content = content;
  this.url = url;
};

var ParseSourceSpan = /*#__PURE__*/function () {
  function ParseSourceSpan(start, end) {
    var details = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParseSourceSpan);

    this.start = start;
    this.end = end;
    this.details = details;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ParseSourceSpan, [{
    key: "toString",
    value: function toString() {
      return this.start.file.content.substring(this.start.offset, this.end.offset);
    }
  }]);

  return ParseSourceSpan;
}();

var ParseErrorLevel;

(function (ParseErrorLevel) {
  ParseErrorLevel[ParseErrorLevel["WARNING"] = 0] = "WARNING";
  ParseErrorLevel[ParseErrorLevel["ERROR"] = 1] = "ERROR";
})(ParseErrorLevel || (ParseErrorLevel = {}));

var ParseError = /*#__PURE__*/function () {
  function ParseError(span, msg) {
    var level = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : ParseErrorLevel.ERROR;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParseError);

    this.span = span;
    this.msg = msg;
    this.level = level;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ParseError, [{
    key: "contextualMessage",
    value: function contextualMessage() {
      var ctx = this.span.start.getContext(100, 3);
      return ctx ? "".concat(this.msg, " (\"").concat(ctx.before, "[").concat(ParseErrorLevel[this.level], " ->]").concat(ctx.after, "\")") : this.msg;
    }
  }, {
    key: "toString",
    value: function toString() {
      var details = this.span.details ? ", ".concat(this.span.details) : '';
      return "".concat(this.contextualMessage(), ": ").concat(this.span.start).concat(details);
    }
  }]);

  return ParseError;
}();

function typeSourceSpan(kind, type) {
  var moduleUrl = identifierModuleUrl(type);
  var sourceFileName = moduleUrl != null ? "in ".concat(kind, " ").concat(identifierName(type), " in ").concat(moduleUrl) : "in ".concat(kind, " ").concat(identifierName(type));
  var sourceFile = new ParseSourceFile('', sourceFileName);
  return new ParseSourceSpan(new ParseLocation(sourceFile, -1, -1, -1), new ParseLocation(sourceFile, -1, -1, -1));
}
/**
 * Generates Source Span object for a given R3 Type for JIT mode.
 *
 * @param kind Component or Directive.
 * @param typeName name of the Component or Directive.
 * @param sourceUrl reference to Component or Directive source.
 * @returns instance of ParseSourceSpan that represent a given Component or Directive.
 */


function r3JitTypeSourceSpan(kind, typeName, sourceUrl) {
  var sourceFileName = "in ".concat(kind, " ").concat(typeName, " in ").concat(sourceUrl);
  var sourceFile = new ParseSourceFile('', sourceFileName);
  return new ParseSourceSpan(new ParseLocation(sourceFile, -1, -1, -1), new ParseLocation(sourceFile, -1, -1, -1));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var Text = /*#__PURE__*/function () {
  function Text(value, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Text);

    this.value = value;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Text, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitText(this);
    }
  }]);

  return Text;
}();

var BoundText = /*#__PURE__*/function () {
  function BoundText(value, sourceSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundText);

    this.value = value;
    this.sourceSpan = sourceSpan;
    this.i18n = i18n;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundText, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitBoundText(this);
    }
  }]);

  return BoundText;
}();

var TextAttribute = /*#__PURE__*/function () {
  function TextAttribute(name, value, sourceSpan, valueSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TextAttribute);

    this.name = name;
    this.value = value;
    this.sourceSpan = sourceSpan;
    this.valueSpan = valueSpan;
    this.i18n = i18n;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TextAttribute, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitTextAttribute(this);
    }
  }]);

  return TextAttribute;
}();

var BoundAttribute = /*#__PURE__*/function () {
  function BoundAttribute(name, type, securityContext, value, unit, sourceSpan, valueSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundAttribute);

    this.name = name;
    this.type = type;
    this.securityContext = securityContext;
    this.value = value;
    this.unit = unit;
    this.sourceSpan = sourceSpan;
    this.valueSpan = valueSpan;
    this.i18n = i18n;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundAttribute, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitBoundAttribute(this);
    }
  }], [{
    key: "fromBoundElementProperty",
    value: function fromBoundElementProperty(prop, i18n) {
      return new BoundAttribute(prop.name, prop.type, prop.securityContext, prop.value, prop.unit, prop.sourceSpan, prop.valueSpan, i18n);
    }
  }]);

  return BoundAttribute;
}();

var BoundEvent = /*#__PURE__*/function () {
  function BoundEvent(name, type, handler, target, phase, sourceSpan, handlerSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundEvent);

    this.name = name;
    this.type = type;
    this.handler = handler;
    this.target = target;
    this.phase = phase;
    this.sourceSpan = sourceSpan;
    this.handlerSpan = handlerSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundEvent, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitBoundEvent(this);
    }
  }], [{
    key: "fromParsedEvent",
    value: function fromParsedEvent(event) {
      var target = event.type === 0
      /* Regular */
      ? event.targetOrPhase : null;
      var phase = event.type === 1
      /* Animation */
      ? event.targetOrPhase : null;
      return new BoundEvent(event.name, event.type, event.handler, target, phase, event.sourceSpan, event.handlerSpan);
    }
  }]);

  return BoundEvent;
}();

var Element = /*#__PURE__*/function () {
  function Element(name, attributes, inputs, outputs, children, references, sourceSpan, startSourceSpan, endSourceSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Element);

    this.name = name;
    this.attributes = attributes;
    this.inputs = inputs;
    this.outputs = outputs;
    this.children = children;
    this.references = references;
    this.sourceSpan = sourceSpan;
    this.startSourceSpan = startSourceSpan;
    this.endSourceSpan = endSourceSpan;
    this.i18n = i18n; // If the element is empty then the source span should include any closing tag

    if (children.length === 0 && startSourceSpan && endSourceSpan) {
      this.sourceSpan = new ParseSourceSpan(sourceSpan.start, endSourceSpan.end);
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Element, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitElement(this);
    }
  }]);

  return Element;
}();

var Template = /*#__PURE__*/function () {
  function Template(tagName, attributes, inputs, outputs, templateAttrs, children, references, variables, sourceSpan, startSourceSpan, endSourceSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Template);

    this.tagName = tagName;
    this.attributes = attributes;
    this.inputs = inputs;
    this.outputs = outputs;
    this.templateAttrs = templateAttrs;
    this.children = children;
    this.references = references;
    this.variables = variables;
    this.sourceSpan = sourceSpan;
    this.startSourceSpan = startSourceSpan;
    this.endSourceSpan = endSourceSpan;
    this.i18n = i18n;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Template, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitTemplate(this);
    }
  }]);

  return Template;
}();

var Content = /*#__PURE__*/function () {
  function Content(selector, attributes, sourceSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Content);

    this.selector = selector;
    this.attributes = attributes;
    this.sourceSpan = sourceSpan;
    this.i18n = i18n;
    this.name = 'ng-content';
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Content, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitContent(this);
    }
  }]);

  return Content;
}();

var Variable = /*#__PURE__*/function () {
  function Variable(name, value, sourceSpan, valueSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Variable);

    this.name = name;
    this.value = value;
    this.sourceSpan = sourceSpan;
    this.valueSpan = valueSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Variable, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitVariable(this);
    }
  }]);

  return Variable;
}();

var Reference = /*#__PURE__*/function () {
  function Reference(name, value, sourceSpan, valueSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Reference);

    this.name = name;
    this.value = value;
    this.sourceSpan = sourceSpan;
    this.valueSpan = valueSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Reference, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitReference(this);
    }
  }]);

  return Reference;
}();

var Icu = /*#__PURE__*/function () {
  function Icu(vars, placeholders, sourceSpan, i18n) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Icu);

    this.vars = vars;
    this.placeholders = placeholders;
    this.sourceSpan = sourceSpan;
    this.i18n = i18n;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Icu, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitIcu(this);
    }
  }]);

  return Icu;
}();

var NullVisitor = /*#__PURE__*/function () {
  function NullVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NullVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NullVisitor, [{
    key: "visitElement",
    value: function visitElement(element) {}
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {}
  }, {
    key: "visitContent",
    value: function visitContent(content) {}
  }, {
    key: "visitVariable",
    value: function visitVariable(variable) {}
  }, {
    key: "visitReference",
    value: function visitReference(reference) {}
  }, {
    key: "visitTextAttribute",
    value: function visitTextAttribute(attribute) {}
  }, {
    key: "visitBoundAttribute",
    value: function visitBoundAttribute(attribute) {}
  }, {
    key: "visitBoundEvent",
    value: function visitBoundEvent(attribute) {}
  }, {
    key: "visitText",
    value: function visitText(text) {}
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {}
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {}
  }]);

  return NullVisitor;
}();

var RecursiveVisitor = /*#__PURE__*/function () {
  function RecursiveVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, RecursiveVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(RecursiveVisitor, [{
    key: "visitElement",
    value: function visitElement(element) {
      visitAll(this, element.attributes);
      visitAll(this, element.children);
      visitAll(this, element.references);
    }
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {
      visitAll(this, template.attributes);
      visitAll(this, template.children);
      visitAll(this, template.references);
      visitAll(this, template.variables);
    }
  }, {
    key: "visitContent",
    value: function visitContent(content) {}
  }, {
    key: "visitVariable",
    value: function visitVariable(variable) {}
  }, {
    key: "visitReference",
    value: function visitReference(reference) {}
  }, {
    key: "visitTextAttribute",
    value: function visitTextAttribute(attribute) {}
  }, {
    key: "visitBoundAttribute",
    value: function visitBoundAttribute(attribute) {}
  }, {
    key: "visitBoundEvent",
    value: function visitBoundEvent(attribute) {}
  }, {
    key: "visitText",
    value: function visitText(text) {}
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {}
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {}
  }]);

  return RecursiveVisitor;
}();

var TransformVisitor = /*#__PURE__*/function () {
  function TransformVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TransformVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TransformVisitor, [{
    key: "visitElement",
    value: function visitElement(element) {
      var newAttributes = transformAll(this, element.attributes);
      var newInputs = transformAll(this, element.inputs);
      var newOutputs = transformAll(this, element.outputs);
      var newChildren = transformAll(this, element.children);
      var newReferences = transformAll(this, element.references);

      if (newAttributes != element.attributes || newInputs != element.inputs || newOutputs != element.outputs || newChildren != element.children || newReferences != element.references) {
        return new Element(element.name, newAttributes, newInputs, newOutputs, newChildren, newReferences, element.sourceSpan, element.startSourceSpan, element.endSourceSpan);
      }

      return element;
    }
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {
      var newAttributes = transformAll(this, template.attributes);
      var newInputs = transformAll(this, template.inputs);
      var newOutputs = transformAll(this, template.outputs);
      var newTemplateAttrs = transformAll(this, template.templateAttrs);
      var newChildren = transformAll(this, template.children);
      var newReferences = transformAll(this, template.references);
      var newVariables = transformAll(this, template.variables);

      if (newAttributes != template.attributes || newInputs != template.inputs || newOutputs != template.outputs || newTemplateAttrs != template.templateAttrs || newChildren != template.children || newReferences != template.references || newVariables != template.variables) {
        return new Template(template.tagName, newAttributes, newInputs, newOutputs, newTemplateAttrs, newChildren, newReferences, newVariables, template.sourceSpan, template.startSourceSpan, template.endSourceSpan);
      }

      return template;
    }
  }, {
    key: "visitContent",
    value: function visitContent(content) {
      return content;
    }
  }, {
    key: "visitVariable",
    value: function visitVariable(variable) {
      return variable;
    }
  }, {
    key: "visitReference",
    value: function visitReference(reference) {
      return reference;
    }
  }, {
    key: "visitTextAttribute",
    value: function visitTextAttribute(attribute) {
      return attribute;
    }
  }, {
    key: "visitBoundAttribute",
    value: function visitBoundAttribute(attribute) {
      return attribute;
    }
  }, {
    key: "visitBoundEvent",
    value: function visitBoundEvent(attribute) {
      return attribute;
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      return text;
    }
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {
      return text;
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {
      return icu;
    }
  }]);

  return TransformVisitor;
}();

function visitAll(visitor, nodes) {
  var result = [];

  if (visitor.visit) {
    var _iterator2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(nodes),
        _step2;

    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var node = _step2.value;
        var newNode = visitor.visit(node) || node.visit(visitor);
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
  } else {
    var _iterator3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(nodes),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var _node = _step3.value;

        var _newNode = _node.visit(visitor);

        if (_newNode) {
          result.push(_newNode);
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }
  }

  return result;
}

function transformAll(visitor, nodes) {
  var result = [];
  var changed = false;

  var _iterator4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(nodes),
      _step4;

  try {
    for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
      var node = _step4.value;
      var newNode = node.visit(visitor);

      if (newNode) {
        result.push(newNode);
      }

      changed = changed || newNode != node;
    }
  } catch (err) {
    _iterator4.e(err);
  } finally {
    _iterator4.f();
  }

  return changed ? result : nodes;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var Message =
/**
 * @param nodes message AST
 * @param placeholders maps placeholder names to static content
 * @param placeholderToMessage maps placeholder names to messages (used for nested ICU messages)
 * @param meaning
 * @param description
 * @param customId
 */
function Message(nodes, placeholders, placeholderToMessage, meaning, description, customId) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Message);

  this.nodes = nodes;
  this.placeholders = placeholders;
  this.placeholderToMessage = placeholderToMessage;
  this.meaning = meaning;
  this.description = description;
  this.customId = customId;
  this.id = this.customId;
  /** The ids to use if there are no custom id and if `i18nLegacyMessageIdFormat` is not empty */

  this.legacyIds = [];

  if (nodes.length) {
    this.sources = [{
      filePath: nodes[0].sourceSpan.start.file.url,
      startLine: nodes[0].sourceSpan.start.line + 1,
      startCol: nodes[0].sourceSpan.start.col + 1,
      endLine: nodes[nodes.length - 1].sourceSpan.end.line + 1,
      endCol: nodes[0].sourceSpan.start.col + 1
    }];
  } else {
    this.sources = [];
  }
};

var Text$1 = /*#__PURE__*/function () {
  function Text$1(value, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Text$1);

    this.value = value;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Text$1, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitText(this, context);
    }
  }]);

  return Text$1;
}(); // TODO(vicb): do we really need this node (vs an array) ?


var Container = /*#__PURE__*/function () {
  function Container(children, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Container);

    this.children = children;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Container, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitContainer(this, context);
    }
  }]);

  return Container;
}();

var Icu$1 = /*#__PURE__*/function () {
  function Icu$1(expression, type, cases, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Icu$1);

    this.expression = expression;
    this.type = type;
    this.cases = cases;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Icu$1, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitIcu(this, context);
    }
  }]);

  return Icu$1;
}();

var TagPlaceholder = /*#__PURE__*/function () {
  function TagPlaceholder(tag, attrs, startName, closeName, children, isVoid, // TODO sourceSpan should cover all (we need a startSourceSpan and endSourceSpan)
  sourceSpan, startSourceSpan, endSourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TagPlaceholder);

    this.tag = tag;
    this.attrs = attrs;
    this.startName = startName;
    this.closeName = closeName;
    this.children = children;
    this.isVoid = isVoid;
    this.sourceSpan = sourceSpan;
    this.startSourceSpan = startSourceSpan;
    this.endSourceSpan = endSourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TagPlaceholder, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitTagPlaceholder(this, context);
    }
  }]);

  return TagPlaceholder;
}();

var Placeholder = /*#__PURE__*/function () {
  function Placeholder(value, name, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Placeholder);

    this.value = value;
    this.name = name;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Placeholder, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitPlaceholder(this, context);
    }
  }]);

  return Placeholder;
}();

var IcuPlaceholder = /*#__PURE__*/function () {
  function IcuPlaceholder(value, name, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, IcuPlaceholder);

    this.value = value;
    this.name = name;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(IcuPlaceholder, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitIcuPlaceholder(this, context);
    }
  }]);

  return IcuPlaceholder;
}(); // Clone the AST


var CloneVisitor = /*#__PURE__*/function () {
  function CloneVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CloneVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CloneVisitor, [{
    key: "visitText",
    value: function visitText(text, context) {
      return new Text$1(text.value, text.sourceSpan);
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this61 = this;

      var children = container.children.map(function (n) {
        return n.visit(_this61, context);
      });
      return new Container(children, container.sourceSpan);
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this62 = this;

      var cases = {};
      Object.keys(icu.cases).forEach(function (key) {
        return cases[key] = icu.cases[key].visit(_this62, context);
      });
      var msg = new Icu$1(icu.expression, icu.type, cases, icu.sourceSpan);
      msg.expressionPlaceholder = icu.expressionPlaceholder;
      return msg;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var _this63 = this;

      var children = ph.children.map(function (n) {
        return n.visit(_this63, context);
      });
      return new TagPlaceholder(ph.tag, ph.attrs, ph.startName, ph.closeName, children, ph.isVoid, ph.sourceSpan, ph.startSourceSpan, ph.endSourceSpan);
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      return new Placeholder(ph.value, ph.name, ph.sourceSpan);
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      return new IcuPlaceholder(ph.value, ph.name, ph.sourceSpan);
    }
  }]);

  return CloneVisitor;
}(); // Visit all the nodes recursively


var RecurseVisitor = /*#__PURE__*/function () {
  function RecurseVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, RecurseVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(RecurseVisitor, [{
    key: "visitText",
    value: function visitText(text, context) {}
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this64 = this;

      container.children.forEach(function (child) {
        return child.visit(_this64);
      });
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this65 = this;

      Object.keys(icu.cases).forEach(function (k) {
        icu.cases[k].visit(_this65);
      });
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var _this66 = this;

      ph.children.forEach(function (child) {
        return child.visit(_this66);
      });
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {}
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {}
  }]);

  return RecurseVisitor;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Return the message id or compute it using the XLIFF1 digest.
 */


function _digest2(message) {
  return message.id || computeDigest(message);
}
/**
 * Compute the message id using the XLIFF1 digest.
 */


function computeDigest(message) {
  return sha1(serializeNodes(message.nodes).join('') + "[".concat(message.meaning, "]"));
}
/**
 * Return the message id or compute it using the XLIFF2/XMB/$localize digest.
 */


function decimalDigest(message) {
  return message.id || computeDecimalDigest(message);
}
/**
 * Compute the message id using the XLIFF2/XMB/$localize digest.
 */


function computeDecimalDigest(message) {
  var visitor = new _SerializerIgnoreIcuExpVisitor();
  var parts = message.nodes.map(function (a) {
    return a.visit(visitor, null);
  });
  return computeMsgId(parts.join(''), message.meaning);
}
/**
 * Serialize the i18n ast to something xml-like in order to generate an UID.
 *
 * The visitor is also used in the i18n parser tests
 *
 * @internal
 */


var _SerializerVisitor = /*#__PURE__*/function () {
  function _SerializerVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _SerializerVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_SerializerVisitor, [{
    key: "visitText",
    value: function visitText(text, context) {
      return text.value;
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this67 = this;

      return "[".concat(container.children.map(function (child) {
        return child.visit(_this67);
      }).join(', '), "]");
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this68 = this;

      var strCases = Object.keys(icu.cases).map(function (k) {
        return "".concat(k, " {").concat(icu.cases[k].visit(_this68), "}");
      });
      return "{".concat(icu.expression, ", ").concat(icu.type, ", ").concat(strCases.join(', '), "}");
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var _this69 = this;

      return ph.isVoid ? "<ph tag name=\"".concat(ph.startName, "\"/>") : "<ph tag name=\"".concat(ph.startName, "\">").concat(ph.children.map(function (child) {
        return child.visit(_this69);
      }).join(', '), "</ph name=\"").concat(ph.closeName, "\">");
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      return ph.value ? "<ph name=\"".concat(ph.name, "\">").concat(ph.value, "</ph>") : "<ph name=\"".concat(ph.name, "\"/>");
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      return "<ph icu name=\"".concat(ph.name, "\">").concat(ph.value.visit(this), "</ph>");
    }
  }]);

  return _SerializerVisitor;
}();

var serializerVisitor = new _SerializerVisitor();

function serializeNodes(nodes) {
  return nodes.map(function (a) {
    return a.visit(serializerVisitor, null);
  });
}
/**
 * Serialize the i18n ast to something xml-like in order to generate an UID.
 *
 * Ignore the ICU expressions so that message IDs stays identical if only the expression changes.
 *
 * @internal
 */


var _SerializerIgnoreIcuExpVisitor = /*#__PURE__*/function (_SerializerVisitor2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_SerializerIgnoreIcuExpVisitor, _SerializerVisitor2);

  var _super47 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_SerializerIgnoreIcuExpVisitor);

  function _SerializerIgnoreIcuExpVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _SerializerIgnoreIcuExpVisitor);

    return _super47.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_SerializerIgnoreIcuExpVisitor, [{
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this70 = this;

      var strCases = Object.keys(icu.cases).map(function (k) {
        return "".concat(k, " {").concat(icu.cases[k].visit(_this70), "}");
      }); // Do not take the expression into account

      return "{".concat(icu.type, ", ").concat(strCases.join(', '), "}");
    }
  }]);

  return _SerializerIgnoreIcuExpVisitor;
}(_SerializerVisitor);
/**
 * Compute the SHA1 of the given string
 *
 * see http://csrc.nist.gov/publications/fips/fips180-4/fips-180-4.pdf
 *
 * WARNING: this function has not been designed not tested with security in mind.
 *          DO NOT USE IT IN A SECURITY SENSITIVE CONTEXT.
 */


function sha1(str) {
  var utf8 = utf8Encode(str);
  var words32 = stringToWords32(utf8, Endian.Big);
  var len = utf8.length * 8;
  var w = newArray(80);
  var a = 0x67452301,
      b = 0xefcdab89,
      c = 0x98badcfe,
      d = 0x10325476,
      e = 0xc3d2e1f0;
  words32[len >> 5] |= 0x80 << 24 - len % 32;
  words32[(len + 64 >> 9 << 4) + 15] = len;

  for (var i = 0; i < words32.length; i += 16) {
    var h0 = a,
        h1 = b,
        h2 = c,
        h3 = d,
        h4 = e;

    for (var j = 0; j < 80; j++) {
      if (j < 16) {
        w[j] = words32[i + j];
      } else {
        w[j] = rol32(w[j - 3] ^ w[j - 8] ^ w[j - 14] ^ w[j - 16], 1);
      }

      var fkVal = fk(j, b, c, d);
      var f = fkVal[0];
      var k = fkVal[1];
      var temp = [rol32(a, 5), f, e, k, w[j]].reduce(add32);
      e = d;
      d = c;
      c = rol32(b, 30);
      b = a;
      a = temp;
    }

    a = add32(a, h0);
    b = add32(b, h1);
    c = add32(c, h2);
    d = add32(d, h3);
    e = add32(e, h4);
  }

  return byteStringToHexString(words32ToByteString([a, b, c, d, e]));
}

function fk(index, b, c, d) {
  if (index < 20) {
    return [b & c | ~b & d, 0x5a827999];
  }

  if (index < 40) {
    return [b ^ c ^ d, 0x6ed9eba1];
  }

  if (index < 60) {
    return [b & c | b & d | c & d, 0x8f1bbcdc];
  }

  return [b ^ c ^ d, 0xca62c1d6];
}
/**
 * Compute the fingerprint of the given string
 *
 * The output is 64 bit number encoded as a decimal string
 *
 * based on:
 * https://github.com/google/closure-compiler/blob/master/src/com/google/javascript/jscomp/GoogleJsMessageIdGenerator.java
 */


function fingerprint(str) {
  var utf8 = utf8Encode(str);
  var hi = hash32(utf8, 0);
  var lo = hash32(utf8, 102072);

  if (hi == 0 && (lo == 0 || lo == 1)) {
    hi = hi ^ 0x130f9bef;
    lo = lo ^ -0x6b5f56d8;
  }

  return [hi, lo];
}

function computeMsgId(msg) {
  var meaning = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var msgFingerprint = fingerprint(msg);

  if (meaning) {
    var meaningFingerprint = fingerprint(meaning);
    msgFingerprint = add64(rol64(msgFingerprint, 1), meaningFingerprint);
  }

  var hi = msgFingerprint[0];
  var lo = msgFingerprint[1];
  return byteStringToDecString(words32ToByteString([hi & 0x7fffffff, lo]));
}

function hash32(str, c) {
  var a = 0x9e3779b9,
      b = 0x9e3779b9;
  var i;
  var len = str.length;

  for (i = 0; i + 12 <= len; i += 12) {
    a = add32(a, wordAt(str, i, Endian.Little));
    b = add32(b, wordAt(str, i + 4, Endian.Little));
    c = add32(c, wordAt(str, i + 8, Endian.Little));
    var res = mix(a, b, c);
    a = res[0], b = res[1], c = res[2];
  }

  a = add32(a, wordAt(str, i, Endian.Little));
  b = add32(b, wordAt(str, i + 4, Endian.Little)); // the first byte of c is reserved for the length

  c = add32(c, len);
  c = add32(c, wordAt(str, i + 8, Endian.Little) << 8);
  return mix(a, b, c)[2];
} // clang-format off


function mix(a, b, c) {
  a = sub32(a, b);
  a = sub32(a, c);
  a ^= c >>> 13;
  b = sub32(b, c);
  b = sub32(b, a);
  b ^= a << 8;
  c = sub32(c, a);
  c = sub32(c, b);
  c ^= b >>> 13;
  a = sub32(a, b);
  a = sub32(a, c);
  a ^= c >>> 12;
  b = sub32(b, c);
  b = sub32(b, a);
  b ^= a << 16;
  c = sub32(c, a);
  c = sub32(c, b);
  c ^= b >>> 5;
  a = sub32(a, b);
  a = sub32(a, c);
  a ^= c >>> 3;
  b = sub32(b, c);
  b = sub32(b, a);
  b ^= a << 10;
  c = sub32(c, a);
  c = sub32(c, b);
  c ^= b >>> 15;
  return [a, b, c];
} // clang-format on
// Utils


var Endian;

(function (Endian) {
  Endian[Endian["Little"] = 0] = "Little";
  Endian[Endian["Big"] = 1] = "Big";
})(Endian || (Endian = {}));

function add32(a, b) {
  return add32to64(a, b)[1];
}

function add32to64(a, b) {
  var low = (a & 0xffff) + (b & 0xffff);
  var high = (a >>> 16) + (b >>> 16) + (low >>> 16);
  return [high >>> 16, high << 16 | low & 0xffff];
}

function add64(a, b) {
  var ah = a[0],
      al = a[1];
  var bh = b[0],
      bl = b[1];
  var result = add32to64(al, bl);
  var carry = result[0];
  var l = result[1];
  var h = add32(add32(ah, bh), carry);
  return [h, l];
}

function sub32(a, b) {
  var low = (a & 0xffff) - (b & 0xffff);
  var high = (a >> 16) - (b >> 16) + (low >> 16);
  return high << 16 | low & 0xffff;
} // Rotate a 32b number left `count` position


function rol32(a, count) {
  return a << count | a >>> 32 - count;
} // Rotate a 64b number left `count` position


function rol64(num, count) {
  var hi = num[0],
      lo = num[1];
  var h = hi << count | lo >>> 32 - count;
  var l = lo << count | hi >>> 32 - count;
  return [h, l];
}

function stringToWords32(str, endian) {
  var size = str.length + 3 >>> 2;
  var words32 = [];

  for (var i = 0; i < size; i++) {
    words32[i] = wordAt(str, i * 4, endian);
  }

  return words32;
}

function byteAt(str, index) {
  return index >= str.length ? 0 : str.charCodeAt(index) & 0xff;
}

function wordAt(str, index, endian) {
  var word = 0;

  if (endian === Endian.Big) {
    for (var i = 0; i < 4; i++) {
      word += byteAt(str, index + i) << 24 - 8 * i;
    }
  } else {
    for (var _i5 = 0; _i5 < 4; _i5++) {
      word += byteAt(str, index + _i5) << 8 * _i5;
    }
  }

  return word;
}

function words32ToByteString(words32) {
  return words32.reduce(function (str, word) {
    return str + word32ToByteString(word);
  }, '');
}

function word32ToByteString(word) {
  var str = '';

  for (var i = 0; i < 4; i++) {
    str += String.fromCharCode(word >>> 8 * (3 - i) & 0xff);
  }

  return str;
}

function byteStringToHexString(str) {
  var hex = '';

  for (var i = 0; i < str.length; i++) {
    var b = byteAt(str, i);
    hex += (b >>> 4).toString(16) + (b & 0x0f).toString(16);
  }

  return hex.toLowerCase();
} // based on http://www.danvk.org/hex2dec.html (JS can not handle more than 56b)


function byteStringToDecString(str) {
  var decimal = '';
  var toThePower = '1';

  for (var i = str.length - 1; i >= 0; i--) {
    decimal = addBigInt(decimal, numberTimesBigInt(byteAt(str, i), toThePower));
    toThePower = numberTimesBigInt(256, toThePower);
  }

  return decimal.split('').reverse().join('');
} // x and y decimal, lowest significant digit first


function addBigInt(x, y) {
  var sum = '';
  var len = Math.max(x.length, y.length);

  for (var i = 0, carry = 0; i < len || carry; i++) {
    var tmpSum = carry + +(x[i] || 0) + +(y[i] || 0);

    if (tmpSum >= 10) {
      carry = 1;
      sum += tmpSum - 10;
    } else {
      carry = 0;
      sum += tmpSum;
    }
  }

  return sum;
}

function numberTimesBigInt(num, b) {
  var product = '';
  var bToThePower = b;

  for (; num !== 0; num = num >>> 1) {
    if (num & 1) product = addBigInt(product, bToThePower);
    bToThePower = addBigInt(bToThePower, bToThePower);
  }

  return product;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var Serializer = /*#__PURE__*/function () {
  function Serializer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Serializer);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Serializer, [{
    key: "createNameMapper",
    // Creates a name mapper, see `PlaceholderMapper`
    // Returning `null` means that no name mapping is used.
    value: function createNameMapper(message) {
      return null;
    }
  }]);

  return Serializer;
}();
/**
 * A simple mapper that take a function to transform an internal name to a public name
 */


var SimplePlaceholderMapper = /*#__PURE__*/function (_RecurseVisitor) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(SimplePlaceholderMapper, _RecurseVisitor);

  var _super48 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(SimplePlaceholderMapper);

  // create a mapping from the message
  function SimplePlaceholderMapper(message, mapName) {
    var _this71;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SimplePlaceholderMapper);

    _this71 = _super48.call(this);
    _this71.mapName = mapName;
    _this71.internalToPublic = {};
    _this71.publicToNextId = {};
    _this71.publicToInternal = {};
    message.nodes.forEach(function (node) {
      return node.visit(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this71));
    });
    return _this71;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SimplePlaceholderMapper, [{
    key: "toPublicName",
    value: function toPublicName(internalName) {
      return this.internalToPublic.hasOwnProperty(internalName) ? this.internalToPublic[internalName] : null;
    }
  }, {
    key: "toInternalName",
    value: function toInternalName(publicName) {
      return this.publicToInternal.hasOwnProperty(publicName) ? this.publicToInternal[publicName] : null;
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      return null;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      this.visitPlaceholderName(ph.startName);

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(SimplePlaceholderMapper.prototype), "visitTagPlaceholder", this).call(this, ph, context);

      this.visitPlaceholderName(ph.closeName);
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      this.visitPlaceholderName(ph.name);
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      this.visitPlaceholderName(ph.name);
    } // XMB placeholders could only contains A-Z, 0-9 and _

  }, {
    key: "visitPlaceholderName",
    value: function visitPlaceholderName(internalName) {
      if (!internalName || this.internalToPublic.hasOwnProperty(internalName)) {
        return;
      }

      var publicName = this.mapName(internalName);

      if (this.publicToInternal.hasOwnProperty(publicName)) {
        // Create a new XMB when it has already been used
        var nextId = this.publicToNextId[publicName];
        this.publicToNextId[publicName] = nextId + 1;
        publicName = "".concat(publicName, "_").concat(nextId);
      } else {
        this.publicToNextId[publicName] = 1;
      }

      this.internalToPublic[internalName] = publicName;
      this.publicToInternal[publicName] = internalName;
    }
  }]);

  return SimplePlaceholderMapper;
}(RecurseVisitor);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _Visitor = /*#__PURE__*/function () {
  function _Visitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _Visitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_Visitor, [{
    key: "visitTag",
    value: function visitTag(tag) {
      var _this72 = this;

      var strAttrs = this._serializeAttributes(tag.attrs);

      if (tag.children.length == 0) {
        return "<".concat(tag.name).concat(strAttrs, "/>");
      }

      var strChildren = tag.children.map(function (node) {
        return node.visit(_this72);
      });
      return "<".concat(tag.name).concat(strAttrs, ">").concat(strChildren.join(''), "</").concat(tag.name, ">");
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      return text.value;
    }
  }, {
    key: "visitDeclaration",
    value: function visitDeclaration(decl) {
      return "<?xml".concat(this._serializeAttributes(decl.attrs), " ?>");
    }
  }, {
    key: "_serializeAttributes",
    value: function _serializeAttributes(attrs) {
      var strAttrs = Object.keys(attrs).map(function (name) {
        return "".concat(name, "=\"").concat(attrs[name], "\"");
      }).join(' ');
      return strAttrs.length > 0 ? ' ' + strAttrs : '';
    }
  }, {
    key: "visitDoctype",
    value: function visitDoctype(doctype) {
      return "<!DOCTYPE ".concat(doctype.rootTag, " [\n").concat(doctype.dtd, "\n]>");
    }
  }]);

  return _Visitor;
}();

var _visitor = new _Visitor();

function serialize(nodes) {
  return nodes.map(function (node) {
    return node.visit(_visitor);
  }).join('');
}

var Declaration = /*#__PURE__*/function () {
  function Declaration(unescapedAttrs) {
    var _this73 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Declaration);

    this.attrs = {};
    Object.keys(unescapedAttrs).forEach(function (k) {
      _this73.attrs[k] = escapeXml(unescapedAttrs[k]);
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Declaration, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitDeclaration(this);
    }
  }]);

  return Declaration;
}();

var Doctype = /*#__PURE__*/function () {
  function Doctype(rootTag, dtd) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Doctype);

    this.rootTag = rootTag;
    this.dtd = dtd;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Doctype, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitDoctype(this);
    }
  }]);

  return Doctype;
}();

var Tag = /*#__PURE__*/function () {
  function Tag(name) {
    var _this74 = this;

    var unescapedAttrs = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var children = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Tag);

    this.name = name;
    this.children = children;
    this.attrs = {};
    Object.keys(unescapedAttrs).forEach(function (k) {
      _this74.attrs[k] = escapeXml(unescapedAttrs[k]);
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Tag, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitTag(this);
    }
  }]);

  return Tag;
}();

var Text$2 = /*#__PURE__*/function () {
  function Text$2(unescapedValue) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Text$2);

    this.value = escapeXml(unescapedValue);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Text$2, [{
    key: "visit",
    value: function visit(visitor) {
      return visitor.visitText(this);
    }
  }]);

  return Text$2;
}();

var CR = /*#__PURE__*/function (_Text$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(CR, _Text$);

  var _super49 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(CR);

  function CR() {
    var ws = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CR);

    return _super49.call(this, "\n".concat(new Array(ws + 1).join(' ')));
  }

  return CR;
}(Text$2);

var _ESCAPED_CHARS = [[/&/g, '&amp;'], [/"/g, '&quot;'], [/'/g, '&apos;'], [/</g, '&lt;'], [/>/g, '&gt;']]; // Escape `_ESCAPED_CHARS` characters in the given text with encoded entities

function escapeXml(text) {
  return _ESCAPED_CHARS.reduce(function (text, entry) {
    return text.replace(entry[0], entry[1]);
  }, text);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _MESSAGES_TAG = 'messagebundle';
var _MESSAGE_TAG = 'msg';
var _PLACEHOLDER_TAG = 'ph';
var _EXAMPLE_TAG = 'ex';
var _SOURCE_TAG = 'source';
var _DOCTYPE = "<!ELEMENT messagebundle (msg)*>\n<!ATTLIST messagebundle class CDATA #IMPLIED>\n\n<!ELEMENT msg (#PCDATA|ph|source)*>\n<!ATTLIST msg id CDATA #IMPLIED>\n<!ATTLIST msg seq CDATA #IMPLIED>\n<!ATTLIST msg name CDATA #IMPLIED>\n<!ATTLIST msg desc CDATA #IMPLIED>\n<!ATTLIST msg meaning CDATA #IMPLIED>\n<!ATTLIST msg obsolete (obsolete) #IMPLIED>\n<!ATTLIST msg xml:space (default|preserve) \"default\">\n<!ATTLIST msg is_hidden CDATA #IMPLIED>\n\n<!ELEMENT source (#PCDATA)>\n\n<!ELEMENT ph (#PCDATA|ex)*>\n<!ATTLIST ph name CDATA #REQUIRED>\n\n<!ELEMENT ex (#PCDATA)>";

var Xmb = /*#__PURE__*/function (_Serializer) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Xmb, _Serializer);

  var _super50 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Xmb);

  function Xmb() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Xmb);

    return _super50.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Xmb, [{
    key: "write",
    value: function write(messages, locale) {
      var exampleVisitor = new ExampleVisitor();
      var visitor = new _Visitor$1();
      var rootNode = new Tag(_MESSAGES_TAG);
      messages.forEach(function (message) {
        var attrs = {
          id: message.id
        };

        if (message.description) {
          attrs['desc'] = message.description;
        }

        if (message.meaning) {
          attrs['meaning'] = message.meaning;
        }

        var sourceTags = [];
        message.sources.forEach(function (source) {
          sourceTags.push(new Tag(_SOURCE_TAG, {}, [new Text$2("".concat(source.filePath, ":").concat(source.startLine).concat(source.endLine !== source.startLine ? ',' + source.endLine : ''))]));
        });
        rootNode.children.push(new CR(2), new Tag(_MESSAGE_TAG, attrs, [].concat(sourceTags, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitor.serialize(message.nodes)))));
      });
      rootNode.children.push(new CR());
      return serialize([new Declaration({
        version: '1.0',
        encoding: 'UTF-8'
      }), new CR(), new Doctype(_MESSAGES_TAG, _DOCTYPE), new CR(), exampleVisitor.addDefaultExamples(rootNode), new CR()]);
    }
  }, {
    key: "load",
    value: function load(content, url) {
      throw new Error('Unsupported');
    }
  }, {
    key: "digest",
    value: function digest(message) {
      return digest$1(message);
    }
  }, {
    key: "createNameMapper",
    value: function createNameMapper(message) {
      return new SimplePlaceholderMapper(message, toPublicName);
    }
  }]);

  return Xmb;
}(Serializer);

var _Visitor$1 = /*#__PURE__*/function () {
  function _Visitor$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _Visitor$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_Visitor$1, [{
    key: "visitText",
    value: function visitText(text, context) {
      return [new Text$2(text.value)];
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this75 = this;

      var nodes = [];
      container.children.forEach(function (node) {
        return nodes.push.apply(nodes, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(node.visit(_this75)));
      });
      return nodes;
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this76 = this;

      var nodes = [new Text$2("{".concat(icu.expressionPlaceholder, ", ").concat(icu.type, ", "))];
      Object.keys(icu.cases).forEach(function (c) {
        nodes.push.apply(nodes, [new Text$2("".concat(c, " {"))].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(icu.cases[c].visit(_this76)), [new Text$2("} ")]));
      });
      nodes.push(new Text$2("}"));
      return nodes;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var startTagAsText = new Text$2("<".concat(ph.tag, ">"));
      var startEx = new Tag(_EXAMPLE_TAG, {}, [startTagAsText]); // TC requires PH to have a non empty EX, and uses the text node to show the "original" value.

      var startTagPh = new Tag(_PLACEHOLDER_TAG, {
        name: ph.startName
      }, [startEx, startTagAsText]);

      if (ph.isVoid) {
        // void tags have no children nor closing tags
        return [startTagPh];
      }

      var closeTagAsText = new Text$2("</".concat(ph.tag, ">"));
      var closeEx = new Tag(_EXAMPLE_TAG, {}, [closeTagAsText]); // TC requires PH to have a non empty EX, and uses the text node to show the "original" value.

      var closeTagPh = new Tag(_PLACEHOLDER_TAG, {
        name: ph.closeName
      }, [closeEx, closeTagAsText]);
      return [startTagPh].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this.serialize(ph.children)), [closeTagPh]);
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      var interpolationAsText = new Text$2("{{".concat(ph.value, "}}")); // Example tag needs to be not-empty for TC.

      var exTag = new Tag(_EXAMPLE_TAG, {}, [interpolationAsText]);
      return [// TC requires PH to have a non empty EX, and uses the text node to show the "original" value.
      new Tag(_PLACEHOLDER_TAG, {
        name: ph.name
      }, [exTag, interpolationAsText])];
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      var icuExpression = ph.value.expression;
      var icuType = ph.value.type;
      var icuCases = Object.keys(ph.value.cases).map(function (value) {
        return value + ' {...}';
      }).join(' ');
      var icuAsText = new Text$2("{".concat(icuExpression, ", ").concat(icuType, ", ").concat(icuCases, "}"));
      var exTag = new Tag(_EXAMPLE_TAG, {}, [icuAsText]);
      return [// TC requires PH to have a non empty EX, and uses the text node to show the "original" value.
      new Tag(_PLACEHOLDER_TAG, {
        name: ph.name
      }, [exTag, icuAsText])];
    }
  }, {
    key: "serialize",
    value: function serialize(nodes) {
      var _ref10,
          _this77 = this;

      return (_ref10 = []).concat.apply(_ref10, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(nodes.map(function (node) {
        return node.visit(_this77);
      })));
    }
  }]);

  return _Visitor$1;
}();

function digest$1(message) {
  return decimalDigest(message);
} // TC requires at least one non-empty example on placeholders


var ExampleVisitor = /*#__PURE__*/function () {
  function ExampleVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExampleVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ExampleVisitor, [{
    key: "addDefaultExamples",
    value: function addDefaultExamples(node) {
      node.visit(this);
      return node;
    }
  }, {
    key: "visitTag",
    value: function visitTag(tag) {
      var _this78 = this;

      if (tag.name === _PLACEHOLDER_TAG) {
        if (!tag.children || tag.children.length == 0) {
          var exText = new Text$2(tag.attrs['name'] || '...');
          tag.children = [new Tag(_EXAMPLE_TAG, {}, [exText])];
        }
      } else if (tag.children) {
        tag.children.forEach(function (node) {
          return node.visit(_this78);
        });
      }
    }
  }, {
    key: "visitText",
    value: function visitText(text) {}
  }, {
    key: "visitDeclaration",
    value: function visitDeclaration(decl) {}
  }, {
    key: "visitDoctype",
    value: function visitDoctype(doctype) {}
  }]);

  return ExampleVisitor;
}(); // XMB/XTB placeholders can only contain A-Z, 0-9 and _


function toPublicName(internalName) {
  return internalName.toUpperCase().replace(/[^A-Z0-9_]/g, '_');
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/* Closure variables holding messages must be named `MSG_[A-Z0-9]+` */


var CLOSURE_TRANSLATION_VAR_PREFIX = 'MSG_';
/**
 * Prefix for non-`goog.getMsg` i18n-related vars.
 * Note: the prefix uses lowercase characters intentionally due to a Closure behavior that
 * considers variables like `I18N_0` as constants and throws an error when their value changes.
 */

var TRANSLATION_VAR_PREFIX = 'i18n_';
/** Name of the i18n attributes **/

var I18N_ATTR = 'i18n';
var I18N_ATTR_PREFIX = 'i18n-';
/** Prefix of var expressions used in ICUs */

var I18N_ICU_VAR_PREFIX = 'VAR_';
/** Prefix of ICU expressions for post processing */

var I18N_ICU_MAPPING_PREFIX = 'I18N_EXP_';
/** Placeholder wrapper for i18n expressions **/

var I18N_PLACEHOLDER_SYMBOL = '�';

function isI18nAttribute(name) {
  return name === I18N_ATTR || name.startsWith(I18N_ATTR_PREFIX);
}

function isI18nRootNode(meta) {
  return meta instanceof Message;
}

function isSingleI18nIcu(meta) {
  return isI18nRootNode(meta) && meta.nodes.length === 1 && meta.nodes[0] instanceof Icu$1;
}

function hasI18nMeta(node) {
  return !!node.i18n;
}

function hasI18nAttrs(element) {
  return element.attrs.some(function (attr) {
    return isI18nAttribute(attr.name);
  });
}

function icuFromI18nMessage(message) {
  return message.nodes[0];
}

function wrapI18nPlaceholder(content) {
  var contextId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var blockId = contextId > 0 ? ":".concat(contextId) : '';
  return "".concat(I18N_PLACEHOLDER_SYMBOL).concat(content).concat(blockId).concat(I18N_PLACEHOLDER_SYMBOL);
}

function assembleI18nBoundString(strings) {
  var bindingStartIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var contextId = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  if (!strings.length) return '';
  var acc = '';
  var lastIdx = strings.length - 1;

  for (var i = 0; i < lastIdx; i++) {
    acc += "".concat(strings[i]).concat(wrapI18nPlaceholder(bindingStartIndex + i, contextId));
  }

  acc += strings[lastIdx];
  return acc;
}

function getSeqNumberGenerator() {
  var startsAt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var current = startsAt;
  return function () {
    return current++;
  };
}

function placeholdersToParams(placeholders) {
  var params = {};
  placeholders.forEach(function (values, key) {
    params[key] = literal(values.length > 1 ? "[".concat(values.join('|'), "]") : values[0]);
  });
  return params;
}

function updatePlaceholderMap(map, name) {
  var current = map.get(name) || [];

  for (var _len2 = arguments.length, values = new Array(_len2 > 2 ? _len2 - 2 : 0), _key3 = 2; _key3 < _len2; _key3++) {
    values[_key3 - 2] = arguments[_key3];
  }

  current.push.apply(current, values);
  map.set(name, current);
}

function assembleBoundTextPlaceholders(meta) {
  var bindingStartIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var contextId = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var startIdx = bindingStartIndex;
  var placeholders = new Map();
  var node = meta instanceof Message ? meta.nodes.find(function (node) {
    return node instanceof Container;
  }) : meta;

  if (node) {
    node.children.filter(function (child) {
      return child instanceof Placeholder;
    }).forEach(function (child, idx) {
      var content = wrapI18nPlaceholder(startIdx + idx, contextId);
      updatePlaceholderMap(placeholders, child.name, content);
    });
  }

  return placeholders;
}
/**
 * Format the placeholder names in a map of placeholders to expressions.
 *
 * The placeholder names are converted from "internal" format (e.g. `START_TAG_DIV_1`) to "external"
 * format (e.g. `startTagDiv_1`).
 *
 * @param params A map of placeholder names to expressions.
 * @param useCamelCase whether to camelCase the placeholder name when formatting.
 * @returns A new map of formatted placeholder names to expressions.
 */


function i18nFormatPlaceholderNames() {
  var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var useCamelCase = arguments.length > 1 ? arguments[1] : undefined;
  var _params = {};

  if (params && Object.keys(params).length) {
    Object.keys(params).forEach(function (key) {
      return _params[formatI18nPlaceholderName(key, useCamelCase)] = params[key];
    });
  }

  return _params;
}
/**
 * Converts internal placeholder names to public-facing format
 * (for example to use in goog.getMsg call).
 * Example: `START_TAG_DIV_1` is converted to `startTagDiv_1`.
 *
 * @param name The placeholder name that should be formatted
 * @returns Formatted placeholder name
 */


function formatI18nPlaceholderName(name) {
  var useCamelCase = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  var publicName = toPublicName(name);

  if (!useCamelCase) {
    return publicName;
  }

  var chunks = publicName.split('_');

  if (chunks.length === 1) {
    // if no "_" found - just lowercase the value
    return name.toLowerCase();
  }

  var postfix; // eject last element if it's a number

  if (/^\d+$/.test(chunks[chunks.length - 1])) {
    postfix = chunks.pop();
  }

  var raw = chunks.shift().toLowerCase();

  if (chunks.length) {
    raw += chunks.map(function (c) {
      return c.charAt(0).toUpperCase() + c.slice(1).toLowerCase();
    }).join('');
  }

  return postfix ? "".concat(raw, "_").concat(postfix) : raw;
}
/**
 * Generates a prefix for translation const name.
 *
 * @param extra Additional local prefix that should be injected into translation var name
 * @returns Complete translation const prefix
 */


function getTranslationConstPrefix(extra) {
  return "".concat(CLOSURE_TRANSLATION_VAR_PREFIX).concat(extra).toUpperCase();
}
/**
 * Generate AST to declare a variable. E.g. `var I18N_1;`.
 * @param variable the name of the variable to declare.
 */


function declareI18nVariable(variable) {
  return new DeclareVarStmt(variable.name, undefined, INFERRED_TYPE, undefined, variable.sourceSpan);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Checks whether an object key contains potentially unsafe chars, thus the key should be wrapped in
 * quotes. Note: we do not wrap all keys into quotes, as it may have impact on minification and may
 * bot work in some cases when object keys are mangled by minifier.
 *
 * TODO(FW-1136): this is a temporary solution, we need to come up with a better way of working with
 * inputs that contain potentially unsafe chars.
 */


var UNSAFE_OBJECT_KEY_NAME_REGEXP = /[-.]/;
/** Name of the temporary to use during data binding */

var TEMPORARY_NAME = '_t';
/** Name of the context parameter passed into a template function */

var CONTEXT_NAME = 'ctx';
/** Name of the RenderFlag passed into a template function */

var RENDER_FLAGS = 'rf';
/** The prefix reference variables */

var REFERENCE_PREFIX = '_r';
/** The name of the implicit context reference */

var IMPLICIT_REFERENCE = '$implicit';
/** Non bindable attribute name **/

var NON_BINDABLE_ATTR = 'ngNonBindable';
/**
 * Creates an allocator for a temporary variable.
 *
 * A variable declaration is added to the statements the first time the allocator is invoked.
 */

function temporaryAllocator(statements, name) {
  var temp = null;
  return function () {
    if (!temp) {
      statements.push(new DeclareVarStmt(TEMPORARY_NAME, undefined, DYNAMIC_TYPE));
      temp = variable(name);
    }

    return temp;
  };
}

function unsupported(feature) {
  if (this) {
    throw new Error("Builder ".concat(this.constructor.name, " doesn't support ").concat(feature, " yet"));
  }

  throw new Error("Feature ".concat(feature, " is not supported yet"));
}

function invalid$1(arg) {
  throw new Error("Invalid state: Visitor ".concat(this.constructor.name, " doesn't handle ").concat(arg.constructor.name));
}

function asLiteral(value) {
  if (Array.isArray(value)) {
    return literalArr(value.map(asLiteral));
  }

  return literal(value, INFERRED_TYPE);
}

function conditionallyCreateMapObjectLiteral(keys, keepDeclared) {
  if (Object.getOwnPropertyNames(keys).length > 0) {
    return mapToExpression(keys, keepDeclared);
  }

  return null;
}

function mapToExpression(map, keepDeclared) {
  return literalMap(Object.getOwnPropertyNames(map).map(function (key) {
    // canonical syntax: `dirProp: publicProp`
    // if there is no `:`, use dirProp = elProp
    var value = map[key];
    var declaredName;
    var publicName;
    var minifiedName;

    if (Array.isArray(value)) {
      var _value = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(value, 2);

      publicName = _value[0];
      declaredName = _value[1];
    } else {
      var _splitAtColon = splitAtColon(key, [key, value]);

      var _splitAtColon2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_splitAtColon, 2);

      declaredName = _splitAtColon2[0];
      publicName = _splitAtColon2[1];
    }

    minifiedName = declaredName;
    return {
      key: minifiedName,
      // put quotes around keys that contain potentially unsafe characters
      quoted: UNSAFE_OBJECT_KEY_NAME_REGEXP.test(minifiedName),
      value: keepDeclared && publicName !== declaredName ? literalArr([asLiteral(publicName), asLiteral(declaredName)]) : asLiteral(publicName)
    };
  }));
}
/**
 *  Remove trailing null nodes as they are implied.
 */


function trimTrailingNulls(parameters) {
  while (isNull(parameters[parameters.length - 1])) {
    parameters.pop();
  }

  return parameters;
}

function getQueryPredicate(query, constantPool) {
  if (Array.isArray(query.predicate)) {
    var predicate = [];
    query.predicate.forEach(function (selector) {
      // Each item in predicates array may contain strings with comma-separated refs
      // (for ex. 'ref, ref1, ..., refN'), thus we extract individual refs and store them
      // as separate array entities
      var selectors = selector.split(',').map(function (token) {
        return literal(token.trim());
      });
      predicate.push.apply(predicate, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(selectors));
    });
    return constantPool.getConstLiteral(literalArr(predicate), true);
  } else {
    return query.predicate;
  }
}

function noop() {}

var DefinitionMap = /*#__PURE__*/function () {
  function DefinitionMap() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DefinitionMap);

    this.values = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DefinitionMap, [{
    key: "set",
    value: function set(key, value) {
      if (value) {
        this.values.push({
          key: key,
          value: value,
          quoted: false
        });
      }
    }
  }, {
    key: "toLiteralMap",
    value: function toLiteralMap() {
      return literalMap(this.values);
    }
  }]);

  return DefinitionMap;
}();
/**
 * Extract a map of properties to values for a given element or template node, which can be used
 * by the directive matching machinery.
 *
 * @param elOrTpl the element or template in question
 * @return an object set up for directive matching. For attributes on the element/template, this
 * object maps a property name to its (static) value. For any bindings, this map simply maps the
 * property name to an empty string.
 */


function getAttrsForDirectiveMatching(elOrTpl) {
  var attributesMap = {};

  if (elOrTpl instanceof Template && elOrTpl.tagName !== 'ng-template') {
    elOrTpl.templateAttrs.forEach(function (a) {
      return attributesMap[a.name] = '';
    });
  } else {
    elOrTpl.attributes.forEach(function (a) {
      if (!isI18nAttribute(a.name)) {
        attributesMap[a.name] = a.value;
      }
    });
    elOrTpl.inputs.forEach(function (i) {
      attributesMap[i.name] = '';
    });
    elOrTpl.outputs.forEach(function (o) {
      attributesMap[o.name] = '';
    });
  }

  return attributesMap;
}
/** Returns a call expression to a chained instruction, e.g. `property(params[0])(params[1])`. */


function chainedInstruction(reference, calls, span) {
  var expression = importExpr(reference, null, span);

  if (calls.length > 0) {
    for (var i = 0; i < calls.length; i++) {
      expression = expression.callFn(calls[i], span);
    }
  } else {
    // Add a blank invocation, in case the `calls` array is empty.
    expression = expression.callFn([], span);
  }

  return expression;
}
/**
 * Gets the number of arguments expected to be passed to a generated instruction in the case of
 * interpolation instructions.
 * @param interpolation An interpolation ast
 */


function getInterpolationArgsLength(interpolation) {
  var expressions = interpolation.expressions,
      strings = interpolation.strings;

  if (expressions.length === 1 && strings.length === 2 && strings[0] === '' && strings[1] === '') {
    // If the interpolation has one interpolated value, but the prefix and suffix are both empty
    // strings, we only pass one argument, to a special instruction like `propertyInterpolate` or
    // `textInterpolate`.
    return 1;
  } else {
    return expressions.length + strings.length;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var R3FactoryDelegateType;

(function (R3FactoryDelegateType) {
  R3FactoryDelegateType[R3FactoryDelegateType["Class"] = 0] = "Class";
  R3FactoryDelegateType[R3FactoryDelegateType["Function"] = 1] = "Function";
  R3FactoryDelegateType[R3FactoryDelegateType["Factory"] = 2] = "Factory";
})(R3FactoryDelegateType || (R3FactoryDelegateType = {}));

var R3FactoryTarget;

(function (R3FactoryTarget) {
  R3FactoryTarget[R3FactoryTarget["Directive"] = 0] = "Directive";
  R3FactoryTarget[R3FactoryTarget["Component"] = 1] = "Component";
  R3FactoryTarget[R3FactoryTarget["Injectable"] = 2] = "Injectable";
  R3FactoryTarget[R3FactoryTarget["Pipe"] = 3] = "Pipe";
  R3FactoryTarget[R3FactoryTarget["NgModule"] = 4] = "NgModule";
})(R3FactoryTarget || (R3FactoryTarget = {}));
/**
 * Resolved type of a dependency.
 *
 * Occasionally, dependencies will have special significance which is known statically. In that
 * case the `R3ResolvedDependencyType` informs the factory generator that a particular dependency
 * should be generated specially (usually by calling a special injection function instead of the
 * standard one).
 */


var R3ResolvedDependencyType;

(function (R3ResolvedDependencyType) {
  /**
   * A normal token dependency.
   */
  R3ResolvedDependencyType[R3ResolvedDependencyType["Token"] = 0] = "Token";
  /**
   * The dependency is for an attribute.
   *
   * The token expression is a string representing the attribute name.
   */

  R3ResolvedDependencyType[R3ResolvedDependencyType["Attribute"] = 1] = "Attribute";
  /**
   * Injecting the `ChangeDetectorRef` token. Needs special handling when injected into a pipe.
   */

  R3ResolvedDependencyType[R3ResolvedDependencyType["ChangeDetectorRef"] = 2] = "ChangeDetectorRef";
  /**
   * An invalid dependency (no token could be determined). An error should be thrown at runtime.
   */

  R3ResolvedDependencyType[R3ResolvedDependencyType["Invalid"] = 3] = "Invalid";
})(R3ResolvedDependencyType || (R3ResolvedDependencyType = {}));
/**
 * Construct a factory function expression for the given `R3FactoryMetadata`.
 */


function compileFactoryFunction(meta) {
  var t = variable('t');
  var statements = [];
  var ctorDepsType = NONE_TYPE; // The type to instantiate via constructor invocation. If there is no delegated factory, meaning
  // this type is always created by constructor invocation, then this is the type-to-create
  // parameter provided by the user (t) if specified, or the current type if not. If there is a
  // delegated factory (which is used to create the current type) then this is only the type-to-
  // create parameter (t).

  var typeForCtor = !isDelegatedMetadata(meta) ? new BinaryOperatorExpr(BinaryOperator.Or, t, meta.internalType) : t;
  var ctorExpr = null;

  if (meta.deps !== null) {
    // There is a constructor (either explicitly or implicitly defined).
    if (meta.deps !== 'invalid') {
      ctorExpr = new InstantiateExpr(typeForCtor, injectDependencies(meta.deps, meta.injectFn, meta.target === R3FactoryTarget.Pipe));
      ctorDepsType = createCtorDepsType(meta.deps);
    }
  } else {
    var baseFactory = variable("\u0275".concat(meta.name, "_BaseFactory"));
    var getInheritedFactory = importExpr(Identifiers$1.getInheritedFactory);
    var baseFactoryStmt = baseFactory.set(getInheritedFactory.callFn([meta.internalType],
    /* sourceSpan */
    undefined,
    /* pure */
    true)).toDeclStmt(INFERRED_TYPE, [StmtModifier.Exported, StmtModifier.Final]);
    statements.push(baseFactoryStmt); // There is no constructor, use the base class' factory to construct typeForCtor.

    ctorExpr = baseFactory.callFn([typeForCtor]);
  }

  var ctorExprFinal = ctorExpr;
  var body = [];
  var retExpr = null;

  function makeConditionalFactory(nonCtorExpr) {
    var r = variable('r');
    body.push(r.set(NULL_EXPR).toDeclStmt());
    var ctorStmt = null;

    if (ctorExprFinal !== null) {
      ctorStmt = r.set(ctorExprFinal).toStmt();
    } else {
      ctorStmt = importExpr(Identifiers$1.invalidFactory).callFn([]).toStmt();
    }

    body.push(ifStmt(t, [ctorStmt], [r.set(nonCtorExpr).toStmt()]));
    return r;
  }

  if (isDelegatedMetadata(meta) && meta.delegateType === R3FactoryDelegateType.Factory) {
    var delegateFactory = variable("\u0275".concat(meta.name, "_BaseFactory"));
    var getFactoryOf = importExpr(Identifiers$1.getFactoryOf);

    if (meta.delegate.isEquivalent(meta.internalType)) {
      throw new Error("Illegal state: compiling factory that delegates to itself");
    }

    var delegateFactoryStmt = delegateFactory.set(getFactoryOf.callFn([meta.delegate])).toDeclStmt(INFERRED_TYPE, [StmtModifier.Exported, StmtModifier.Final]);
    statements.push(delegateFactoryStmt);
    retExpr = makeConditionalFactory(delegateFactory.callFn([]));
  } else if (isDelegatedMetadata(meta)) {
    // This type is created with a delegated factory. If a type parameter is not specified, call
    // the factory instead.
    var delegateArgs = injectDependencies(meta.delegateDeps, meta.injectFn, meta.target === R3FactoryTarget.Pipe); // Either call `new delegate(...)` or `delegate(...)` depending on meta.delegateType.

    var factoryExpr = new (meta.delegateType === R3FactoryDelegateType.Class ? InstantiateExpr : InvokeFunctionExpr)(meta.delegate, delegateArgs);
    retExpr = makeConditionalFactory(factoryExpr);
  } else if (isExpressionFactoryMetadata(meta)) {
    // TODO(alxhub): decide whether to lower the value here or in the caller
    retExpr = makeConditionalFactory(meta.expression);
  } else {
    retExpr = ctorExpr;
  }

  if (retExpr !== null) {
    body.push(new ReturnStatement(retExpr));
  } else {
    body.push(importExpr(Identifiers$1.invalidFactory).callFn([]).toStmt());
  }

  return {
    factory: fn([new FnParam('t', DYNAMIC_TYPE)], body, INFERRED_TYPE, undefined, "".concat(meta.name, "_Factory")),
    statements: statements,
    type: expressionType(importExpr(Identifiers$1.FactoryDef, [typeWithParameters(meta.type.type, meta.typeArgumentCount), ctorDepsType]))
  };
}

function injectDependencies(deps, injectFn, isPipe) {
  return deps.map(function (dep, index) {
    return compileInjectDependency(dep, injectFn, isPipe, index);
  });
}

function compileInjectDependency(dep, injectFn, isPipe, index) {
  // Interpret the dependency according to its resolved type.
  switch (dep.resolved) {
    case R3ResolvedDependencyType.Token:
    case R3ResolvedDependencyType.ChangeDetectorRef:
      // Build up the injection flags according to the metadata.
      var flags = 0
      /* Default */
      | (dep.self ? 2
      /* Self */
      : 0) | (dep.skipSelf ? 4
      /* SkipSelf */
      : 0) | (dep.host ? 1
      /* Host */
      : 0) | (dep.optional ? 8
      /* Optional */
      : 0); // If this dependency is optional or otherwise has non-default flags, then additional
      // parameters describing how to inject the dependency must be passed to the inject function
      // that's being used.

      var flagsParam = flags !== 0
      /* Default */
      || dep.optional ? literal(flags) : null; // We have a separate instruction for injecting ChangeDetectorRef into a pipe.

      if (isPipe && dep.resolved === R3ResolvedDependencyType.ChangeDetectorRef) {
        return importExpr(Identifiers$1.injectPipeChangeDetectorRef).callFn(flagsParam ? [flagsParam] : []);
      } // Build up the arguments to the injectFn call.


      var injectArgs = [dep.token];

      if (flagsParam) {
        injectArgs.push(flagsParam);
      }

      return importExpr(injectFn).callFn(injectArgs);

    case R3ResolvedDependencyType.Attribute:
      // In the case of attributes, the attribute name in question is given as the token.
      return importExpr(Identifiers$1.injectAttribute).callFn([dep.token]);

    case R3ResolvedDependencyType.Invalid:
      return importExpr(Identifiers$1.invalidFactoryDep).callFn([literal(index)]);

    default:
      return unsupported("Unknown R3ResolvedDependencyType: ".concat(R3ResolvedDependencyType[dep.resolved]));
  }
}

function createCtorDepsType(deps) {
  var hasTypes = false;
  var attributeTypes = deps.map(function (dep) {
    var type = createCtorDepType(dep);

    if (type !== null) {
      hasTypes = true;
      return type;
    } else {
      return literal(null);
    }
  });

  if (hasTypes) {
    return expressionType(literalArr(attributeTypes));
  } else {
    return NONE_TYPE;
  }
}

function createCtorDepType(dep) {
  var entries = [];

  if (dep.resolved === R3ResolvedDependencyType.Attribute) {
    if (dep.attribute !== null) {
      entries.push({
        key: 'attribute',
        value: dep.attribute,
        quoted: false
      });
    }
  }

  if (dep.optional) {
    entries.push({
      key: 'optional',
      value: literal(true),
      quoted: false
    });
  }

  if (dep.host) {
    entries.push({
      key: 'host',
      value: literal(true),
      quoted: false
    });
  }

  if (dep.self) {
    entries.push({
      key: 'self',
      value: literal(true),
      quoted: false
    });
  }

  if (dep.skipSelf) {
    entries.push({
      key: 'skipSelf',
      value: literal(true),
      quoted: false
    });
  }

  return entries.length > 0 ? literalMap(entries) : null;
}
/**
 * A helper function useful for extracting `R3DependencyMetadata` from a Render2
 * `CompileTypeMetadata` instance.
 */


function dependenciesFromGlobalMetadata(type, outputCtx, reflector) {
  // Use the `CompileReflector` to look up references to some well-known Angular types. These will
  // be compared with the token to statically determine whether the token has significance to
  // Angular, and set the correct `R3ResolvedDependencyType` as a result.
  var injectorRef = reflector.resolveExternalReference(Identifiers.Injector); // Iterate through the type's DI dependencies and produce `R3DependencyMetadata` for each of them.

  var deps = [];

  var _iterator5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(type.diDeps),
      _step5;

  try {
    for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
      var dependency = _step5.value;

      if (dependency.token) {
        var tokenRef = tokenReference(dependency.token);
        var resolved = dependency.isAttribute ? R3ResolvedDependencyType.Attribute : R3ResolvedDependencyType.Token; // In the case of most dependencies, the token will be a reference to a type. Sometimes,
        // however, it can be a string, in the case of older Angular code or @Attribute injection.

        var token = tokenRef instanceof StaticSymbol ? outputCtx.importExpr(tokenRef) : literal(tokenRef); // Construct the dependency.

        deps.push({
          token: token,
          attribute: null,
          resolved: resolved,
          host: !!dependency.isHost,
          optional: !!dependency.isOptional,
          self: !!dependency.isSelf,
          skipSelf: !!dependency.isSkipSelf
        });
      } else {
        unsupported('dependency without a token');
      }
    }
  } catch (err) {
    _iterator5.e(err);
  } finally {
    _iterator5.f();
  }

  return deps;
}

function isDelegatedMetadata(meta) {
  return meta.delegateType !== undefined;
}

function isExpressionFactoryMetadata(meta) {
  return meta.expression !== undefined;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function _compileInjectable(meta) {
  var result = null;
  var factoryMeta = {
    name: meta.name,
    type: meta.type,
    internalType: meta.internalType,
    typeArgumentCount: meta.typeArgumentCount,
    deps: [],
    injectFn: Identifiers.inject,
    target: R3FactoryTarget.Injectable
  };

  if (meta.useClass !== undefined) {
    // meta.useClass has two modes of operation. Either deps are specified, in which case `new` is
    // used to instantiate the class with dependencies injected, or deps are not specified and
    // the factory of the class is used to instantiate it.
    //
    // A special case exists for useClass: Type where Type is the injectable type itself and no
    // deps are specified, in which case 'useClass' is effectively ignored.
    var useClassOnSelf = meta.useClass.isEquivalent(meta.internalType);
    var deps = undefined;

    if (meta.userDeps !== undefined) {
      deps = meta.userDeps;
    }

    if (deps !== undefined) {
      // factory: () => new meta.useClass(...deps)
      result = compileFactoryFunction(Object.assign(Object.assign({}, factoryMeta), {
        delegate: meta.useClass,
        delegateDeps: deps,
        delegateType: R3FactoryDelegateType.Class
      }));
    } else if (useClassOnSelf) {
      result = compileFactoryFunction(factoryMeta);
    } else {
      result = delegateToFactory(meta.type.value, meta.useClass);
    }
  } else if (meta.useFactory !== undefined) {
    if (meta.userDeps !== undefined) {
      result = compileFactoryFunction(Object.assign(Object.assign({}, factoryMeta), {
        delegate: meta.useFactory,
        delegateDeps: meta.userDeps || [],
        delegateType: R3FactoryDelegateType.Function
      }));
    } else {
      result = {
        statements: [],
        factory: fn([], [new ReturnStatement(meta.useFactory.callFn([]))])
      };
    }
  } else if (meta.useValue !== undefined) {
    // Note: it's safe to use `meta.useValue` instead of the `USE_VALUE in meta` check used for
    // client code because meta.useValue is an Expression which will be defined even if the actual
    // value is undefined.
    result = compileFactoryFunction(Object.assign(Object.assign({}, factoryMeta), {
      expression: meta.useValue
    }));
  } else if (meta.useExisting !== undefined) {
    // useExisting is an `inject` call on the existing token.
    result = compileFactoryFunction(Object.assign(Object.assign({}, factoryMeta), {
      expression: importExpr(Identifiers.inject).callFn([meta.useExisting])
    }));
  } else {
    result = delegateToFactory(meta.type.value, meta.internalType);
  }

  var token = meta.internalType;
  var injectableProps = {
    token: token,
    factory: result.factory
  }; // Only generate providedIn property if it has a non-null value

  if (meta.providedIn.value !== null) {
    injectableProps.providedIn = meta.providedIn;
  }

  var expression = importExpr(Identifiers.ɵɵdefineInjectable).callFn([mapToMapExpression(injectableProps)]);
  var type = new ExpressionType(importExpr(Identifiers.InjectableDef, [typeWithParameters(meta.type.type, meta.typeArgumentCount)]));
  return {
    expression: expression,
    type: type,
    statements: result.statements
  };
}

function delegateToFactory(type, internalType) {
  return {
    statements: [],
    // If types are the same, we can generate `factory: type.ɵfac`
    // If types are different, we have to generate a wrapper function to ensure
    // the internal type has been resolved (`factory: function(t) { return type.ɵfac(t); }`)
    factory: type.node === internalType.node ? internalType.prop('ɵfac') : fn([new FnParam('t', DYNAMIC_TYPE)], [new ReturnStatement(internalType.callMethod('ɵfac', [variable('t')]))])
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function assertArrayOfStrings(identifier, value) {
  if (value == null) {
    return;
  }

  if (!Array.isArray(value)) {
    throw new Error("Expected '".concat(identifier, "' to be an array of strings."));
  }

  for (var i = 0; i < value.length; i += 1) {
    if (typeof value[i] !== 'string') {
      throw new Error("Expected '".concat(identifier, "' to be an array of strings."));
    }
  }
}

var UNUSABLE_INTERPOLATION_REGEXPS = [/^\s*$/, /[<>]/, /^[{}]$/, /&(#|[a-z])/i, /^\/\//];

function assertInterpolationSymbols(identifier, value) {
  if (value != null && !(Array.isArray(value) && value.length == 2)) {
    throw new Error("Expected '".concat(identifier, "' to be an array, [start, end]."));
  } else if (value != null) {
    var start = value[0];
    var end = value[1]; // Check for unusable interpolation symbols

    UNUSABLE_INTERPOLATION_REGEXPS.forEach(function (regexp) {
      if (regexp.test(start) || regexp.test(end)) {
        throw new Error("['".concat(start, "', '").concat(end, "'] contains unusable interpolation symbol."));
      }
    });
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var InterpolationConfig = /*#__PURE__*/function () {
  function InterpolationConfig(start, end) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, InterpolationConfig);

    this.start = start;
    this.end = end;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(InterpolationConfig, null, [{
    key: "fromArray",
    value: function fromArray(markers) {
      if (!markers) {
        return DEFAULT_INTERPOLATION_CONFIG;
      }

      assertInterpolationSymbols('interpolation', markers);
      return new InterpolationConfig(markers[0], markers[1]);
    }
  }]);

  return InterpolationConfig;
}();

var DEFAULT_INTERPOLATION_CONFIG = new InterpolationConfig('{{', '}}');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit

var VERSION = 3;
var JS_B64_PREFIX = '# sourceMappingURL=data:application/json;base64,';

var SourceMapGenerator = /*#__PURE__*/function () {
  function SourceMapGenerator() {
    var file = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SourceMapGenerator);

    this.file = file;
    this.sourcesContent = new Map();
    this.lines = [];
    this.lastCol0 = 0;
    this.hasMappings = false;
  } // The content is `null` when the content is expected to be loaded using the URL


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SourceMapGenerator, [{
    key: "addSource",
    value: function addSource(url) {
      var content = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      if (!this.sourcesContent.has(url)) {
        this.sourcesContent.set(url, content);
      }

      return this;
    }
  }, {
    key: "addLine",
    value: function addLine() {
      this.lines.push([]);
      this.lastCol0 = 0;
      return this;
    }
  }, {
    key: "addMapping",
    value: function addMapping(col0, sourceUrl, sourceLine0, sourceCol0) {
      if (!this.currentLine) {
        throw new Error("A line must be added before mappings can be added");
      }

      if (sourceUrl != null && !this.sourcesContent.has(sourceUrl)) {
        throw new Error("Unknown source file \"".concat(sourceUrl, "\""));
      }

      if (col0 == null) {
        throw new Error("The column in the generated code must be provided");
      }

      if (col0 < this.lastCol0) {
        throw new Error("Mapping should be added in output order");
      }

      if (sourceUrl && (sourceLine0 == null || sourceCol0 == null)) {
        throw new Error("The source location must be provided when a source url is provided");
      }

      this.hasMappings = true;
      this.lastCol0 = col0;
      this.currentLine.push({
        col0: col0,
        sourceUrl: sourceUrl,
        sourceLine0: sourceLine0,
        sourceCol0: sourceCol0
      });
      return this;
    }
    /**
     * @internal strip this from published d.ts files due to
     * https://github.com/microsoft/TypeScript/issues/36216
     */

  }, {
    key: "toJSON",
    value: function toJSON() {
      var _this79 = this;

      if (!this.hasMappings) {
        return null;
      }

      var sourcesIndex = new Map();
      var sources = [];
      var sourcesContent = [];
      Array.from(this.sourcesContent.keys()).forEach(function (url, i) {
        sourcesIndex.set(url, i);
        sources.push(url);
        sourcesContent.push(_this79.sourcesContent.get(url) || null);
      });
      var mappings = '';
      var lastCol0 = 0;
      var lastSourceIndex = 0;
      var lastSourceLine0 = 0;
      var lastSourceCol0 = 0;
      this.lines.forEach(function (segments) {
        lastCol0 = 0;
        mappings += segments.map(function (segment) {
          // zero-based starting column of the line in the generated code
          var segAsStr = toBase64VLQ(segment.col0 - lastCol0);
          lastCol0 = segment.col0;

          if (segment.sourceUrl != null) {
            // zero-based index into the “sources” list
            segAsStr += toBase64VLQ(sourcesIndex.get(segment.sourceUrl) - lastSourceIndex);
            lastSourceIndex = sourcesIndex.get(segment.sourceUrl); // the zero-based starting line in the original source

            segAsStr += toBase64VLQ(segment.sourceLine0 - lastSourceLine0);
            lastSourceLine0 = segment.sourceLine0; // the zero-based starting column in the original source

            segAsStr += toBase64VLQ(segment.sourceCol0 - lastSourceCol0);
            lastSourceCol0 = segment.sourceCol0;
          }

          return segAsStr;
        }).join(',');
        mappings += ';';
      });
      mappings = mappings.slice(0, -1);
      return {
        'file': this.file || '',
        'version': VERSION,
        'sourceRoot': '',
        'sources': sources,
        'sourcesContent': sourcesContent,
        'mappings': mappings
      };
    }
  }, {
    key: "toJsComment",
    value: function toJsComment() {
      return this.hasMappings ? '//' + JS_B64_PREFIX + toBase64String(JSON.stringify(this, null, 0)) : '';
    }
  }, {
    key: "currentLine",
    get: function get() {
      return this.lines.slice(-1)[0];
    }
  }]);

  return SourceMapGenerator;
}();

function toBase64String(value) {
  var b64 = '';
  value = utf8Encode(value);

  for (var i = 0; i < value.length;) {
    var i1 = value.charCodeAt(i++);
    var i2 = value.charCodeAt(i++);
    var i3 = value.charCodeAt(i++);
    b64 += toBase64Digit(i1 >> 2);
    b64 += toBase64Digit((i1 & 3) << 4 | (isNaN(i2) ? 0 : i2 >> 4));
    b64 += isNaN(i2) ? '=' : toBase64Digit((i2 & 15) << 2 | i3 >> 6);
    b64 += isNaN(i2) || isNaN(i3) ? '=' : toBase64Digit(i3 & 63);
  }

  return b64;
}

function toBase64VLQ(value) {
  value = value < 0 ? (-value << 1) + 1 : value << 1;
  var out = '';

  do {
    var digit = value & 31;
    value = value >> 5;

    if (value > 0) {
      digit = digit | 32;
    }

    out += toBase64Digit(digit);
  } while (value > 0);

  return out;
}

var B64_DIGITS = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

function toBase64Digit(value) {
  if (value < 0 || value >= 64) {
    throw new Error("Can only encode value in the range [0, 63]");
  }

  return B64_DIGITS[value];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _SINGLE_QUOTE_ESCAPE_STRING_RE = /'|\\|\n|\r|\$/g;
var _LEGAL_IDENTIFIER_RE = /^[$A-Z_][0-9A-Z_$]*$/i;
var _INDENT_WITH = '  ';
var CATCH_ERROR_VAR$1 = variable('error', null, null);
var CATCH_STACK_VAR$1 = variable('stack', null, null);

var _EmittedLine = function _EmittedLine(indent) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _EmittedLine);

  this.indent = indent;
  this.partsLength = 0;
  this.parts = [];
  this.srcSpans = [];
};

var EmitterVisitorContext = /*#__PURE__*/function () {
  function EmitterVisitorContext(_indent) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, EmitterVisitorContext);

    this._indent = _indent;
    this._classes = [];
    this._preambleLineCount = 0;
    this._lines = [new _EmittedLine(_indent)];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(EmitterVisitorContext, [{
    key: "println",
    value: function println(from) {
      var lastPart = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      this.print(from || null, lastPart, true);
    }
  }, {
    key: "lineIsEmpty",
    value: function lineIsEmpty() {
      return this._currentLine.parts.length === 0;
    }
  }, {
    key: "lineLength",
    value: function lineLength() {
      return this._currentLine.indent * _INDENT_WITH.length + this._currentLine.partsLength;
    }
  }, {
    key: "print",
    value: function print(from, part) {
      var newLine = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

      if (part.length > 0) {
        this._currentLine.parts.push(part);

        this._currentLine.partsLength += part.length;

        this._currentLine.srcSpans.push(from && from.sourceSpan || null);
      }

      if (newLine) {
        this._lines.push(new _EmittedLine(this._indent));
      }
    }
  }, {
    key: "removeEmptyLastLine",
    value: function removeEmptyLastLine() {
      if (this.lineIsEmpty()) {
        this._lines.pop();
      }
    }
  }, {
    key: "incIndent",
    value: function incIndent() {
      this._indent++;

      if (this.lineIsEmpty()) {
        this._currentLine.indent = this._indent;
      }
    }
  }, {
    key: "decIndent",
    value: function decIndent() {
      this._indent--;

      if (this.lineIsEmpty()) {
        this._currentLine.indent = this._indent;
      }
    }
  }, {
    key: "pushClass",
    value: function pushClass(clazz) {
      this._classes.push(clazz);
    }
  }, {
    key: "popClass",
    value: function popClass() {
      return this._classes.pop();
    }
  }, {
    key: "toSource",
    value: function toSource() {
      return this.sourceLines.map(function (l) {
        return l.parts.length > 0 ? _createIndent(l.indent) + l.parts.join('') : '';
      }).join('\n');
    }
  }, {
    key: "toSourceMapGenerator",
    value: function toSourceMapGenerator(genFilePath) {
      var startsAtLine = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var map = new SourceMapGenerator(genFilePath);
      var firstOffsetMapped = false;

      var mapFirstOffsetIfNeeded = function mapFirstOffsetIfNeeded() {
        if (!firstOffsetMapped) {
          // Add a single space so that tools won't try to load the file from disk.
          // Note: We are using virtual urls like `ng:///`, so we have to
          // provide a content here.
          map.addSource(genFilePath, ' ').addMapping(0, genFilePath, 0, 0);
          firstOffsetMapped = true;
        }
      };

      for (var i = 0; i < startsAtLine; i++) {
        map.addLine();
        mapFirstOffsetIfNeeded();
      }

      this.sourceLines.forEach(function (line, lineIdx) {
        map.addLine();
        var spans = line.srcSpans;
        var parts = line.parts;
        var col0 = line.indent * _INDENT_WITH.length;
        var spanIdx = 0; // skip leading parts without source spans

        while (spanIdx < spans.length && !spans[spanIdx]) {
          col0 += parts[spanIdx].length;
          spanIdx++;
        }

        if (spanIdx < spans.length && lineIdx === 0 && col0 === 0) {
          firstOffsetMapped = true;
        } else {
          mapFirstOffsetIfNeeded();
        }

        while (spanIdx < spans.length) {
          var span = spans[spanIdx];
          var source = span.start.file;
          var sourceLine = span.start.line;
          var sourceCol = span.start.col;
          map.addSource(source.url, source.content).addMapping(col0, source.url, sourceLine, sourceCol);
          col0 += parts[spanIdx].length;
          spanIdx++; // assign parts without span or the same span to the previous segment

          while (spanIdx < spans.length && (span === spans[spanIdx] || !spans[spanIdx])) {
            col0 += parts[spanIdx].length;
            spanIdx++;
          }
        }
      });
      return map;
    }
  }, {
    key: "setPreambleLineCount",
    value: function setPreambleLineCount(count) {
      return this._preambleLineCount = count;
    }
  }, {
    key: "spanOf",
    value: function spanOf(line, column) {
      var emittedLine = this._lines[line - this._preambleLineCount];

      if (emittedLine) {
        var columnsLeft = column - _createIndent(emittedLine.indent).length;

        for (var partIndex = 0; partIndex < emittedLine.parts.length; partIndex++) {
          var part = emittedLine.parts[partIndex];

          if (part.length > columnsLeft) {
            return emittedLine.srcSpans[partIndex];
          }

          columnsLeft -= part.length;
        }
      }

      return null;
    }
    /**
     * @internal strip this from published d.ts files due to
     * https://github.com/microsoft/TypeScript/issues/36216
     */

  }, {
    key: "_currentLine",

    /**
     * @internal strip this from published d.ts files due to
     * https://github.com/microsoft/TypeScript/issues/36216
     */
    get: function get() {
      return this._lines[this._lines.length - 1];
    }
  }, {
    key: "currentClass",
    get: function get() {
      return this._classes.length > 0 ? this._classes[this._classes.length - 1] : null;
    }
  }, {
    key: "sourceLines",
    get: function get() {
      if (this._lines.length && this._lines[this._lines.length - 1].parts.length === 0) {
        return this._lines.slice(0, -1);
      }

      return this._lines;
    }
  }], [{
    key: "createRoot",
    value: function createRoot() {
      return new EmitterVisitorContext(0);
    }
  }]);

  return EmitterVisitorContext;
}();

var AbstractEmitterVisitor = /*#__PURE__*/function () {
  function AbstractEmitterVisitor(_escapeDollarInStrings) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AbstractEmitterVisitor);

    this._escapeDollarInStrings = _escapeDollarInStrings;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AbstractEmitterVisitor, [{
    key: "printLeadingComments",
    value: function printLeadingComments(stmt, ctx) {
      if (stmt.leadingComments === undefined) {
        return;
      }

      var _iterator6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(stmt.leadingComments),
          _step6;

      try {
        for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
          var comment = _step6.value;

          if (comment instanceof JSDocComment) {
            ctx.print(stmt, "/*".concat(comment.toString(), "*/"), comment.trailingNewline);
          } else {
            if (comment.multiline) {
              ctx.print(stmt, "/* ".concat(comment.text, " */"), comment.trailingNewline);
            } else {
              comment.text.split('\n').forEach(function (line) {
                ctx.println(stmt, "// ".concat(line));
              });
            }
          }
        }
      } catch (err) {
        _iterator6.e(err);
      } finally {
        _iterator6.f();
      }
    }
  }, {
    key: "visitExpressionStmt",
    value: function visitExpressionStmt(stmt, ctx) {
      this.printLeadingComments(stmt, ctx);
      stmt.expr.visitExpression(this, ctx);
      ctx.println(stmt, ';');
      return null;
    }
  }, {
    key: "visitReturnStmt",
    value: function visitReturnStmt(stmt, ctx) {
      this.printLeadingComments(stmt, ctx);
      ctx.print(stmt, "return ");
      stmt.value.visitExpression(this, ctx);
      ctx.println(stmt, ';');
      return null;
    }
  }, {
    key: "visitIfStmt",
    value: function visitIfStmt(stmt, ctx) {
      this.printLeadingComments(stmt, ctx);
      ctx.print(stmt, "if (");
      stmt.condition.visitExpression(this, ctx);
      ctx.print(stmt, ") {");
      var hasElseCase = stmt.falseCase != null && stmt.falseCase.length > 0;

      if (stmt.trueCase.length <= 1 && !hasElseCase) {
        ctx.print(stmt, " ");
        this.visitAllStatements(stmt.trueCase, ctx);
        ctx.removeEmptyLastLine();
        ctx.print(stmt, " ");
      } else {
        ctx.println();
        ctx.incIndent();
        this.visitAllStatements(stmt.trueCase, ctx);
        ctx.decIndent();

        if (hasElseCase) {
          ctx.println(stmt, "} else {");
          ctx.incIndent();
          this.visitAllStatements(stmt.falseCase, ctx);
          ctx.decIndent();
        }
      }

      ctx.println(stmt, "}");
      return null;
    }
  }, {
    key: "visitThrowStmt",
    value: function visitThrowStmt(stmt, ctx) {
      this.printLeadingComments(stmt, ctx);
      ctx.print(stmt, "throw ");
      stmt.error.visitExpression(this, ctx);
      ctx.println(stmt, ";");
      return null;
    }
  }, {
    key: "visitWriteVarExpr",
    value: function visitWriteVarExpr(expr, ctx) {
      var lineWasEmpty = ctx.lineIsEmpty();

      if (!lineWasEmpty) {
        ctx.print(expr, '(');
      }

      ctx.print(expr, "".concat(expr.name, " = "));
      expr.value.visitExpression(this, ctx);

      if (!lineWasEmpty) {
        ctx.print(expr, ')');
      }

      return null;
    }
  }, {
    key: "visitWriteKeyExpr",
    value: function visitWriteKeyExpr(expr, ctx) {
      var lineWasEmpty = ctx.lineIsEmpty();

      if (!lineWasEmpty) {
        ctx.print(expr, '(');
      }

      expr.receiver.visitExpression(this, ctx);
      ctx.print(expr, "[");
      expr.index.visitExpression(this, ctx);
      ctx.print(expr, "] = ");
      expr.value.visitExpression(this, ctx);

      if (!lineWasEmpty) {
        ctx.print(expr, ')');
      }

      return null;
    }
  }, {
    key: "visitWritePropExpr",
    value: function visitWritePropExpr(expr, ctx) {
      var lineWasEmpty = ctx.lineIsEmpty();

      if (!lineWasEmpty) {
        ctx.print(expr, '(');
      }

      expr.receiver.visitExpression(this, ctx);
      ctx.print(expr, ".".concat(expr.name, " = "));
      expr.value.visitExpression(this, ctx);

      if (!lineWasEmpty) {
        ctx.print(expr, ')');
      }

      return null;
    }
  }, {
    key: "visitInvokeMethodExpr",
    value: function visitInvokeMethodExpr(expr, ctx) {
      expr.receiver.visitExpression(this, ctx);
      var name = expr.name;

      if (expr.builtin != null) {
        name = this.getBuiltinMethodName(expr.builtin);

        if (name == null) {
          // some builtins just mean to skip the call.
          return null;
        }
      }

      ctx.print(expr, ".".concat(name, "("));
      this.visitAllExpressions(expr.args, ctx, ",");
      ctx.print(expr, ")");
      return null;
    }
  }, {
    key: "visitInvokeFunctionExpr",
    value: function visitInvokeFunctionExpr(expr, ctx) {
      expr.fn.visitExpression(this, ctx);
      ctx.print(expr, "(");
      this.visitAllExpressions(expr.args, ctx, ',');
      ctx.print(expr, ")");
      return null;
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, ctx) {
      throw new Error('Abstract emitter cannot visit WrappedNodeExpr.');
    }
  }, {
    key: "visitTypeofExpr",
    value: function visitTypeofExpr(expr, ctx) {
      ctx.print(expr, 'typeof ');
      expr.expr.visitExpression(this, ctx);
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(ast, ctx) {
      var varName = ast.name;

      if (ast.builtin != null) {
        switch (ast.builtin) {
          case BuiltinVar.Super:
            varName = 'super';
            break;

          case BuiltinVar.This:
            varName = 'this';
            break;

          case BuiltinVar.CatchError:
            varName = CATCH_ERROR_VAR$1.name;
            break;

          case BuiltinVar.CatchStack:
            varName = CATCH_STACK_VAR$1.name;
            break;

          default:
            throw new Error("Unknown builtin variable ".concat(ast.builtin));
        }
      }

      ctx.print(ast, varName);
      return null;
    }
  }, {
    key: "visitInstantiateExpr",
    value: function visitInstantiateExpr(ast, ctx) {
      ctx.print(ast, "new ");
      ast.classExpr.visitExpression(this, ctx);
      ctx.print(ast, "(");
      this.visitAllExpressions(ast.args, ctx, ',');
      ctx.print(ast, ")");
      return null;
    }
  }, {
    key: "visitLiteralExpr",
    value: function visitLiteralExpr(ast, ctx) {
      var value = ast.value;

      if (typeof value === 'string') {
        ctx.print(ast, escapeIdentifier(value, this._escapeDollarInStrings));
      } else {
        ctx.print(ast, "".concat(value));
      }

      return null;
    }
  }, {
    key: "visitLocalizedString",
    value: function visitLocalizedString(ast, ctx) {
      var head = ast.serializeI18nHead();
      ctx.print(ast, '$localize `' + head.raw);

      for (var i = 1; i < ast.messageParts.length; i++) {
        ctx.print(ast, '${');
        ast.expressions[i - 1].visitExpression(this, ctx);
        ctx.print(ast, "}".concat(ast.serializeI18nTemplatePart(i).raw));
      }

      ctx.print(ast, '`');
      return null;
    }
  }, {
    key: "visitConditionalExpr",
    value: function visitConditionalExpr(ast, ctx) {
      ctx.print(ast, "(");
      ast.condition.visitExpression(this, ctx);
      ctx.print(ast, '? ');
      ast.trueCase.visitExpression(this, ctx);
      ctx.print(ast, ': ');
      ast.falseCase.visitExpression(this, ctx);
      ctx.print(ast, ")");
      return null;
    }
  }, {
    key: "visitNotExpr",
    value: function visitNotExpr(ast, ctx) {
      ctx.print(ast, '!');
      ast.condition.visitExpression(this, ctx);
      return null;
    }
  }, {
    key: "visitAssertNotNullExpr",
    value: function visitAssertNotNullExpr(ast, ctx) {
      ast.condition.visitExpression(this, ctx);
      return null;
    }
  }, {
    key: "visitUnaryOperatorExpr",
    value: function visitUnaryOperatorExpr(ast, ctx) {
      var opStr;

      switch (ast.operator) {
        case UnaryOperator.Plus:
          opStr = '+';
          break;

        case UnaryOperator.Minus:
          opStr = '-';
          break;

        default:
          throw new Error("Unknown operator ".concat(ast.operator));
      }

      if (ast.parens) ctx.print(ast, "(");
      ctx.print(ast, opStr);
      ast.expr.visitExpression(this, ctx);
      if (ast.parens) ctx.print(ast, ")");
      return null;
    }
  }, {
    key: "visitBinaryOperatorExpr",
    value: function visitBinaryOperatorExpr(ast, ctx) {
      var opStr;

      switch (ast.operator) {
        case BinaryOperator.Equals:
          opStr = '==';
          break;

        case BinaryOperator.Identical:
          opStr = '===';
          break;

        case BinaryOperator.NotEquals:
          opStr = '!=';
          break;

        case BinaryOperator.NotIdentical:
          opStr = '!==';
          break;

        case BinaryOperator.And:
          opStr = '&&';
          break;

        case BinaryOperator.BitwiseAnd:
          opStr = '&';
          break;

        case BinaryOperator.Or:
          opStr = '||';
          break;

        case BinaryOperator.Plus:
          opStr = '+';
          break;

        case BinaryOperator.Minus:
          opStr = '-';
          break;

        case BinaryOperator.Divide:
          opStr = '/';
          break;

        case BinaryOperator.Multiply:
          opStr = '*';
          break;

        case BinaryOperator.Modulo:
          opStr = '%';
          break;

        case BinaryOperator.Lower:
          opStr = '<';
          break;

        case BinaryOperator.LowerEquals:
          opStr = '<=';
          break;

        case BinaryOperator.Bigger:
          opStr = '>';
          break;

        case BinaryOperator.BiggerEquals:
          opStr = '>=';
          break;

        default:
          throw new Error("Unknown operator ".concat(ast.operator));
      }

      if (ast.parens) ctx.print(ast, "(");
      ast.lhs.visitExpression(this, ctx);
      ctx.print(ast, " ".concat(opStr, " "));
      ast.rhs.visitExpression(this, ctx);
      if (ast.parens) ctx.print(ast, ")");
      return null;
    }
  }, {
    key: "visitReadPropExpr",
    value: function visitReadPropExpr(ast, ctx) {
      ast.receiver.visitExpression(this, ctx);
      ctx.print(ast, ".");
      ctx.print(ast, ast.name);
      return null;
    }
  }, {
    key: "visitReadKeyExpr",
    value: function visitReadKeyExpr(ast, ctx) {
      ast.receiver.visitExpression(this, ctx);
      ctx.print(ast, "[");
      ast.index.visitExpression(this, ctx);
      ctx.print(ast, "]");
      return null;
    }
  }, {
    key: "visitLiteralArrayExpr",
    value: function visitLiteralArrayExpr(ast, ctx) {
      ctx.print(ast, "[");
      this.visitAllExpressions(ast.entries, ctx, ',');
      ctx.print(ast, "]");
      return null;
    }
  }, {
    key: "visitLiteralMapExpr",
    value: function visitLiteralMapExpr(ast, ctx) {
      var _this80 = this;

      ctx.print(ast, "{");
      this.visitAllObjects(function (entry) {
        ctx.print(ast, "".concat(escapeIdentifier(entry.key, _this80._escapeDollarInStrings, entry.quoted), ":"));
        entry.value.visitExpression(_this80, ctx);
      }, ast.entries, ctx, ',');
      ctx.print(ast, "}");
      return null;
    }
  }, {
    key: "visitCommaExpr",
    value: function visitCommaExpr(ast, ctx) {
      ctx.print(ast, '(');
      this.visitAllExpressions(ast.parts, ctx, ',');
      ctx.print(ast, ')');
      return null;
    }
  }, {
    key: "visitAllExpressions",
    value: function visitAllExpressions(expressions, ctx, separator) {
      var _this81 = this;

      this.visitAllObjects(function (expr) {
        return expr.visitExpression(_this81, ctx);
      }, expressions, ctx, separator);
    }
  }, {
    key: "visitAllObjects",
    value: function visitAllObjects(handler, expressions, ctx, separator) {
      var incrementedIndent = false;

      for (var i = 0; i < expressions.length; i++) {
        if (i > 0) {
          if (ctx.lineLength() > 80) {
            ctx.print(null, separator, true);

            if (!incrementedIndent) {
              // continuation are marked with double indent.
              ctx.incIndent();
              ctx.incIndent();
              incrementedIndent = true;
            }
          } else {
            ctx.print(null, separator, false);
          }
        }

        handler(expressions[i]);
      }

      if (incrementedIndent) {
        // continuation are marked with double indent.
        ctx.decIndent();
        ctx.decIndent();
      }
    }
  }, {
    key: "visitAllStatements",
    value: function visitAllStatements(statements, ctx) {
      var _this82 = this;

      statements.forEach(function (stmt) {
        return stmt.visitStatement(_this82, ctx);
      });
    }
  }]);

  return AbstractEmitterVisitor;
}();

function escapeIdentifier(input, escapeDollar) {
  var alwaysQuote = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

  if (input == null) {
    return null;
  }

  var body = input.replace(_SINGLE_QUOTE_ESCAPE_STRING_RE, function () {
    if ((arguments.length <= 0 ? undefined : arguments[0]) == '$') {
      return escapeDollar ? '\\$' : '$';
    } else if ((arguments.length <= 0 ? undefined : arguments[0]) == '\n') {
      return '\\n';
    } else if ((arguments.length <= 0 ? undefined : arguments[0]) == '\r') {
      return '\\r';
    } else {
      return "\\".concat(arguments.length <= 0 ? undefined : arguments[0]);
    }
  });
  var requiresQuotes = alwaysQuote || !_LEGAL_IDENTIFIER_RE.test(body);
  return requiresQuotes ? "'".concat(body, "'") : body;
}

function _createIndent(count) {
  var res = '';

  for (var i = 0; i < count; i++) {
    res += _INDENT_WITH;
  }

  return res;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var AbstractJsEmitterVisitor = /*#__PURE__*/function (_AbstractEmitterVisit) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(AbstractJsEmitterVisitor, _AbstractEmitterVisit);

  var _super51 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(AbstractJsEmitterVisitor);

  function AbstractJsEmitterVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AbstractJsEmitterVisitor);

    return _super51.call(this, false);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AbstractJsEmitterVisitor, [{
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, ctx) {
      var _this83 = this;

      ctx.pushClass(stmt);

      this._visitClassConstructor(stmt, ctx);

      if (stmt.parent != null) {
        ctx.print(stmt, "".concat(stmt.name, ".prototype = Object.create("));
        stmt.parent.visitExpression(this, ctx);
        ctx.println(stmt, ".prototype);");
      }

      stmt.getters.forEach(function (getter) {
        return _this83._visitClassGetter(stmt, getter, ctx);
      });
      stmt.methods.forEach(function (method) {
        return _this83._visitClassMethod(stmt, method, ctx);
      });
      ctx.popClass();
      return null;
    }
  }, {
    key: "_visitClassConstructor",
    value: function _visitClassConstructor(stmt, ctx) {
      ctx.print(stmt, "function ".concat(stmt.name, "("));

      if (stmt.constructorMethod != null) {
        this._visitParams(stmt.constructorMethod.params, ctx);
      }

      ctx.println(stmt, ") {");
      ctx.incIndent();

      if (stmt.constructorMethod != null) {
        if (stmt.constructorMethod.body.length > 0) {
          ctx.println(stmt, "var self = this;");
          this.visitAllStatements(stmt.constructorMethod.body, ctx);
        }
      }

      ctx.decIndent();
      ctx.println(stmt, "}");
    }
  }, {
    key: "_visitClassGetter",
    value: function _visitClassGetter(stmt, getter, ctx) {
      ctx.println(stmt, "Object.defineProperty(".concat(stmt.name, ".prototype, '").concat(getter.name, "', { get: function() {"));
      ctx.incIndent();

      if (getter.body.length > 0) {
        ctx.println(stmt, "var self = this;");
        this.visitAllStatements(getter.body, ctx);
      }

      ctx.decIndent();
      ctx.println(stmt, "}});");
    }
  }, {
    key: "_visitClassMethod",
    value: function _visitClassMethod(stmt, method, ctx) {
      ctx.print(stmt, "".concat(stmt.name, ".prototype.").concat(method.name, " = function("));

      this._visitParams(method.params, ctx);

      ctx.println(stmt, ") {");
      ctx.incIndent();

      if (method.body.length > 0) {
        ctx.println(stmt, "var self = this;");
        this.visitAllStatements(method.body, ctx);
      }

      ctx.decIndent();
      ctx.println(stmt, "};");
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, ctx) {
      throw new Error('Cannot emit a WrappedNodeExpr in Javascript.');
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(ast, ctx) {
      if (ast.builtin === BuiltinVar.This) {
        ctx.print(ast, 'self');
      } else if (ast.builtin === BuiltinVar.Super) {
        throw new Error("'super' needs to be handled at a parent ast node, not at the variable level!");
      } else {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(AbstractJsEmitterVisitor.prototype), "visitReadVarExpr", this).call(this, ast, ctx);
      }

      return null;
    }
  }, {
    key: "visitDeclareVarStmt",
    value: function visitDeclareVarStmt(stmt, ctx) {
      ctx.print(stmt, "var ".concat(stmt.name));

      if (stmt.value) {
        ctx.print(stmt, ' = ');
        stmt.value.visitExpression(this, ctx);
      }

      ctx.println(stmt, ";");
      return null;
    }
  }, {
    key: "visitCastExpr",
    value: function visitCastExpr(ast, ctx) {
      ast.value.visitExpression(this, ctx);
      return null;
    }
  }, {
    key: "visitInvokeFunctionExpr",
    value: function visitInvokeFunctionExpr(expr, ctx) {
      var fnExpr = expr.fn;

      if (fnExpr instanceof ReadVarExpr && fnExpr.builtin === BuiltinVar.Super) {
        ctx.currentClass.parent.visitExpression(this, ctx);
        ctx.print(expr, ".call(this");

        if (expr.args.length > 0) {
          ctx.print(expr, ", ");
          this.visitAllExpressions(expr.args, ctx, ',');
        }

        ctx.print(expr, ")");
      } else {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(AbstractJsEmitterVisitor.prototype), "visitInvokeFunctionExpr", this).call(this, expr, ctx);
      }

      return null;
    }
  }, {
    key: "visitFunctionExpr",
    value: function visitFunctionExpr(ast, ctx) {
      ctx.print(ast, "function".concat(ast.name ? ' ' + ast.name : '', "("));

      this._visitParams(ast.params, ctx);

      ctx.println(ast, ") {");
      ctx.incIndent();
      this.visitAllStatements(ast.statements, ctx);
      ctx.decIndent();
      ctx.print(ast, "}");
      return null;
    }
  }, {
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, ctx) {
      ctx.print(stmt, "function ".concat(stmt.name, "("));

      this._visitParams(stmt.params, ctx);

      ctx.println(stmt, ") {");
      ctx.incIndent();
      this.visitAllStatements(stmt.statements, ctx);
      ctx.decIndent();
      ctx.println(stmt, "}");
      return null;
    }
  }, {
    key: "visitTryCatchStmt",
    value: function visitTryCatchStmt(stmt, ctx) {
      ctx.println(stmt, "try {");
      ctx.incIndent();
      this.visitAllStatements(stmt.bodyStmts, ctx);
      ctx.decIndent();
      ctx.println(stmt, "} catch (".concat(CATCH_ERROR_VAR$1.name, ") {"));
      ctx.incIndent();
      var catchStmts = [CATCH_STACK_VAR$1.set(CATCH_ERROR_VAR$1.prop('stack')).toDeclStmt(null, [StmtModifier.Final])].concat(stmt.catchStmts);
      this.visitAllStatements(catchStmts, ctx);
      ctx.decIndent();
      ctx.println(stmt, "}");
      return null;
    }
  }, {
    key: "visitLocalizedString",
    value: function visitLocalizedString(ast, ctx) {
      var _this84 = this;

      // The following convoluted piece of code is effectively the downlevelled equivalent of
      // ```
      // $localize `...`
      // ```
      // which is effectively like:
      // ```
      // $localize(__makeTemplateObject(cooked, raw), expression1, expression2, ...);
      // ```
      //
      // The `$localize` function expects a "template object", which is an array of "cooked" strings
      // plus a `raw` property that contains an array of "raw" strings.
      //
      // In some environments a helper function called `__makeTemplateObject(cooked, raw)` might be
      // available, in which case we use that. Otherwise we must create our own helper function
      // inline.
      //
      // In the inline function, if `Object.defineProperty` is available we use that to attach the
      // `raw` array.
      ctx.print(ast, '$localize((this&&this.__makeTemplateObject||function(e,t){return Object.defineProperty?Object.defineProperty(e,"raw",{value:t}):e.raw=t,e})(');
      var parts = [ast.serializeI18nHead()];

      for (var i = 1; i < ast.messageParts.length; i++) {
        parts.push(ast.serializeI18nTemplatePart(i));
      }

      ctx.print(ast, "[".concat(parts.map(function (part) {
        return escapeIdentifier(part.cooked, false);
      }).join(', '), "], "));
      ctx.print(ast, "[".concat(parts.map(function (part) {
        return escapeIdentifier(part.raw, false);
      }).join(', '), "])"));
      ast.expressions.forEach(function (expression) {
        ctx.print(ast, ', ');
        expression.visitExpression(_this84, ctx);
      });
      ctx.print(ast, ')');
      return null;
    }
  }, {
    key: "_visitParams",
    value: function _visitParams(params, ctx) {
      this.visitAllObjects(function (param) {
        return ctx.print(null, param.name);
      }, params, ctx, ',');
    }
  }, {
    key: "getBuiltinMethodName",
    value: function getBuiltinMethodName(method) {
      var name;

      switch (method) {
        case BuiltinMethod.ConcatArray:
          name = 'concat';
          break;

        case BuiltinMethod.SubscribeObservable:
          name = 'subscribe';
          break;

        case BuiltinMethod.Bind:
          name = 'bind';
          break;

        default:
          throw new Error("Unknown builtin method: ".concat(method));
      }

      return name;
    }
  }]);

  return AbstractJsEmitterVisitor;
}(AbstractEmitterVisitor);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A helper class to manage the evaluation of JIT generated code.
 */


var JitEvaluator = /*#__PURE__*/function () {
  function JitEvaluator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, JitEvaluator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(JitEvaluator, [{
    key: "evaluateStatements",

    /**
     *
     * @param sourceUrl The URL of the generated code.
     * @param statements An array of Angular statement AST nodes to be evaluated.
     * @param reflector A helper used when converting the statements to executable code.
     * @param createSourceMaps If true then create a source-map for the generated code and include it
     * inline as a source-map comment.
     * @returns A map of all the variables in the generated code.
     */
    value: function evaluateStatements(sourceUrl, statements, reflector, createSourceMaps) {
      var converter = new JitEmitterVisitor(reflector);
      var ctx = EmitterVisitorContext.createRoot(); // Ensure generated code is in strict mode

      if (statements.length > 0 && !isUseStrictStatement(statements[0])) {
        statements = [literal('use strict').toStmt()].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(statements));
      }

      converter.visitAllStatements(statements, ctx);
      converter.createReturnStmt(ctx);
      return this.evaluateCode(sourceUrl, ctx, converter.getArgs(), createSourceMaps);
    }
    /**
     * Evaluate a piece of JIT generated code.
     * @param sourceUrl The URL of this generated code.
     * @param ctx A context object that contains an AST of the code to be evaluated.
     * @param vars A map containing the names and values of variables that the evaluated code might
     * reference.
     * @param createSourceMap If true then create a source-map for the generated code and include it
     * inline as a source-map comment.
     * @returns The result of evaluating the code.
     */

  }, {
    key: "evaluateCode",
    value: function evaluateCode(sourceUrl, ctx, vars, createSourceMap) {
      var fnBody = "\"use strict\";".concat(ctx.toSource(), "\n//# sourceURL=").concat(sourceUrl);
      var fnArgNames = [];
      var fnArgValues = [];

      for (var argName in vars) {
        fnArgValues.push(vars[argName]);
        fnArgNames.push(argName);
      }

      if (createSourceMap) {
        // using `new Function(...)` generates a header, 1 line of no arguments, 2 lines otherwise
        // E.g. ```
        // function anonymous(a,b,c
        // /**/) { ... }```
        // We don't want to hard code this fact, so we auto detect it via an empty function first.
        var emptyFn = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_3__["default"])(Function, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(fnArgNames.concat('return null;'))).toString();

        var headerLines = emptyFn.slice(0, emptyFn.indexOf('return null;')).split('\n').length - 1;
        fnBody += "\n".concat(ctx.toSourceMapGenerator(sourceUrl, headerLines).toJsComment());
      }

      var fn = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_3__["default"])(Function, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(fnArgNames.concat(fnBody)));

      return this.executeFunction(fn, fnArgValues);
    }
    /**
     * Execute a JIT generated function by calling it.
     *
     * This method can be overridden in tests to capture the functions that are generated
     * by this `JitEvaluator` class.
     *
     * @param fn A function to execute.
     * @param args The arguments to pass to the function being executed.
     * @returns The return value of the executed function.
     */

  }, {
    key: "executeFunction",
    value: function executeFunction(fn, args) {
      return fn.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(args));
    }
  }]);

  return JitEvaluator;
}();
/**
 * An Angular AST visitor that converts AST nodes into executable JavaScript code.
 */


var JitEmitterVisitor = /*#__PURE__*/function (_AbstractJsEmitterVis) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(JitEmitterVisitor, _AbstractJsEmitterVis);

  var _super52 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(JitEmitterVisitor);

  function JitEmitterVisitor(reflector) {
    var _this85;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, JitEmitterVisitor);

    _this85 = _super52.call(this);
    _this85.reflector = reflector;
    _this85._evalArgNames = [];
    _this85._evalArgValues = [];
    _this85._evalExportedVars = [];
    return _this85;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(JitEmitterVisitor, [{
    key: "createReturnStmt",
    value: function createReturnStmt(ctx) {
      var stmt = new ReturnStatement(new LiteralMapExpr(this._evalExportedVars.map(function (resultVar) {
        return new LiteralMapEntry(resultVar, variable(resultVar), false);
      })));
      stmt.visitStatement(this, ctx);
    }
  }, {
    key: "getArgs",
    value: function getArgs() {
      var result = {};

      for (var i = 0; i < this._evalArgNames.length; i++) {
        result[this._evalArgNames[i]] = this._evalArgValues[i];
      }

      return result;
    }
  }, {
    key: "visitExternalExpr",
    value: function visitExternalExpr(ast, ctx) {
      this._emitReferenceToExternal(ast, this.reflector.resolveExternalReference(ast.value), ctx);

      return null;
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, ctx) {
      this._emitReferenceToExternal(ast, ast.node, ctx);

      return null;
    }
  }, {
    key: "visitDeclareVarStmt",
    value: function visitDeclareVarStmt(stmt, ctx) {
      if (stmt.hasModifier(StmtModifier.Exported)) {
        this._evalExportedVars.push(stmt.name);
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(JitEmitterVisitor.prototype), "visitDeclareVarStmt", this).call(this, stmt, ctx);
    }
  }, {
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, ctx) {
      if (stmt.hasModifier(StmtModifier.Exported)) {
        this._evalExportedVars.push(stmt.name);
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(JitEmitterVisitor.prototype), "visitDeclareFunctionStmt", this).call(this, stmt, ctx);
    }
  }, {
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, ctx) {
      if (stmt.hasModifier(StmtModifier.Exported)) {
        this._evalExportedVars.push(stmt.name);
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(JitEmitterVisitor.prototype), "visitDeclareClassStmt", this).call(this, stmt, ctx);
    }
  }, {
    key: "_emitReferenceToExternal",
    value: function _emitReferenceToExternal(ast, value, ctx) {
      var id = this._evalArgValues.indexOf(value);

      if (id === -1) {
        id = this._evalArgValues.length;

        this._evalArgValues.push(value);

        var name = identifierName({
          reference: value
        }) || 'val';

        this._evalArgNames.push("jit_".concat(name, "_").concat(id));
      }

      ctx.print(ast, this._evalArgNames[id]);
    }
  }]);

  return JitEmitterVisitor;
}(AbstractJsEmitterVisitor);

function isUseStrictStatement(statement) {
  return statement.isEquivalent(literal('use strict').toStmt());
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Implementation of `CompileReflector` which resolves references to @angular/core
 * symbols at runtime, according to a consumer-provided mapping.
 *
 * Only supports `resolveExternalReference`, all other methods throw.
 */


var R3JitReflector = /*#__PURE__*/function () {
  function R3JitReflector(context) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, R3JitReflector);

    this.context = context;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(R3JitReflector, [{
    key: "resolveExternalReference",
    value: function resolveExternalReference(ref) {
      // This reflector only handles @angular/core imports.
      if (ref.moduleName !== '@angular/core') {
        throw new Error("Cannot resolve external reference to ".concat(ref.moduleName, ", only references to @angular/core are supported."));
      }

      if (!this.context.hasOwnProperty(ref.name)) {
        throw new Error("No value provided for @angular/core symbol '".concat(ref.name, "'."));
      }

      return this.context[ref.name];
    }
  }, {
    key: "parameters",
    value: function parameters(typeOrFunc) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "annotations",
    value: function annotations(typeOrFunc) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "shallowAnnotations",
    value: function shallowAnnotations(typeOrFunc) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "tryAnnotations",
    value: function tryAnnotations(typeOrFunc) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "propMetadata",
    value: function propMetadata(typeOrFunc) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "hasLifecycleHook",
    value: function hasLifecycleHook(type, lcProperty) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "guards",
    value: function guards(typeOrFunc) {
      throw new Error('Not implemented.');
    }
  }, {
    key: "componentModuleUrl",
    value: function componentModuleUrl(type, cmpMetadata) {
      throw new Error('Not implemented.');
    }
  }]);

  return R3JitReflector;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function mapEntry(key, value) {
  return {
    key: key,
    value: value,
    quoted: false
  };
}

function mapLiteral(obj) {
  var quoted = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  return literalMap(Object.keys(obj).map(function (key) {
    return {
      key: key,
      quoted: quoted,
      value: obj[key]
    };
  }));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Construct an `R3NgModuleDef` for the given `R3NgModuleMetadata`.
 */


function _compileNgModule(meta) {
  var internalType = meta.internalType,
      moduleType = meta.type,
      bootstrap = meta.bootstrap,
      declarations = meta.declarations,
      imports = meta.imports,
      exports = meta.exports,
      schemas = meta.schemas,
      containsForwardDecls = meta.containsForwardDecls,
      emitInline = meta.emitInline,
      id = meta.id;
  var additionalStatements = [];
  var definitionMap = {
    type: internalType
  }; // Only generate the keys in the metadata if the arrays have values.

  if (bootstrap.length) {
    definitionMap.bootstrap = refsToArray(bootstrap, containsForwardDecls);
  } // If requested to emit scope information inline, pass the declarations, imports and exports to
  // the `ɵɵdefineNgModule` call. The JIT compilation uses this.


  if (emitInline) {
    if (declarations.length) {
      definitionMap.declarations = refsToArray(declarations, containsForwardDecls);
    }

    if (imports.length) {
      definitionMap.imports = refsToArray(imports, containsForwardDecls);
    }

    if (exports.length) {
      definitionMap.exports = refsToArray(exports, containsForwardDecls);
    }
  } // If not emitting inline, the scope information is not passed into `ɵɵdefineNgModule` as it would
  // prevent tree-shaking of the declarations, imports and exports references.
  else {
      var setNgModuleScopeCall = generateSetNgModuleScopeCall(meta);

      if (setNgModuleScopeCall !== null) {
        additionalStatements.push(setNgModuleScopeCall);
      }
    }

  if (schemas && schemas.length) {
    definitionMap.schemas = literalArr(schemas.map(function (ref) {
      return ref.value;
    }));
  }

  if (id) {
    definitionMap.id = id;
  }

  var expression = importExpr(Identifiers$1.defineNgModule).callFn([mapToMapExpression(definitionMap)]);
  var type = new ExpressionType(importExpr(Identifiers$1.NgModuleDefWithMeta, [new ExpressionType(moduleType.type), tupleTypeOf(declarations), tupleTypeOf(imports), tupleTypeOf(exports)]));
  return {
    expression: expression,
    type: type,
    additionalStatements: additionalStatements
  };
}
/**
 * Generates a function call to `ɵɵsetNgModuleScope` with all necessary information so that the
 * transitive module scope can be computed during runtime in JIT mode. This call is marked pure
 * such that the references to declarations, imports and exports may be elided causing these
 * symbols to become tree-shakeable.
 */


function generateSetNgModuleScopeCall(meta) {
  var moduleType = meta.adjacentType,
      declarations = meta.declarations,
      imports = meta.imports,
      exports = meta.exports,
      containsForwardDecls = meta.containsForwardDecls;
  var scopeMap = {};

  if (declarations.length) {
    scopeMap.declarations = refsToArray(declarations, containsForwardDecls);
  }

  if (imports.length) {
    scopeMap.imports = refsToArray(imports, containsForwardDecls);
  }

  if (exports.length) {
    scopeMap.exports = refsToArray(exports, containsForwardDecls);
  }

  if (Object.keys(scopeMap).length === 0) {
    return null;
  } // setNgModuleScope(...)


  var fnCall = new InvokeFunctionExpr(
  /* fn */
  importExpr(Identifiers$1.setNgModuleScope),
  /* args */
  [moduleType, mapToMapExpression(scopeMap)]); // (ngJitMode guard) && setNgModuleScope(...)

  var guardedCall = jitOnlyGuardedExpression(fnCall); // function() { (ngJitMode guard) && setNgModuleScope(...); }

  var iife = new FunctionExpr(
  /* params */
  [],
  /* statements */
  [guardedCall.toStmt()]); // (function() { (ngJitMode guard) && setNgModuleScope(...); })()

  var iifeCall = new InvokeFunctionExpr(
  /* fn */
  iife,
  /* args */
  []);
  return iifeCall.toStmt();
}

function _compileInjector(meta) {
  var result = compileFactoryFunction({
    name: meta.name,
    type: meta.type,
    internalType: meta.internalType,
    typeArgumentCount: 0,
    deps: meta.deps,
    injectFn: Identifiers$1.inject,
    target: R3FactoryTarget.NgModule
  });
  var definitionMap = {
    factory: result.factory
  };

  if (meta.providers !== null) {
    definitionMap.providers = meta.providers;
  }

  if (meta.imports.length > 0) {
    definitionMap.imports = literalArr(meta.imports);
  }

  var expression = importExpr(Identifiers$1.defineInjector).callFn([mapToMapExpression(definitionMap)]);
  var type = new ExpressionType(importExpr(Identifiers$1.InjectorDef, [new ExpressionType(meta.type.type)]));
  return {
    expression: expression,
    type: type,
    statements: result.statements
  };
} // TODO(alxhub): integrate this with `compileNgModule`. Currently the two are separate operations.


function compileNgModuleFromRender2(ctx, ngModule, injectableCompiler) {
  var className = identifierName(ngModule.type);
  var rawImports = ngModule.rawImports ? [ngModule.rawImports] : [];
  var rawExports = ngModule.rawExports ? [ngModule.rawExports] : [];
  var injectorDefArg = mapLiteral({
    'factory': injectableCompiler.factoryFor({
      type: ngModule.type,
      symbol: ngModule.type.reference
    }, ctx),
    'providers': convertMetaToOutput(ngModule.rawProviders, ctx),
    'imports': convertMetaToOutput([].concat(rawImports, rawExports), ctx)
  });
  var injectorDef = importExpr(Identifiers$1.defineInjector).callFn([injectorDefArg]);
  ctx.statements.push(new ClassStmt(
  /* name */
  className,
  /* parent */
  null,
  /* fields */
  [new ClassField(
  /* name */
  'ɵinj',
  /* type */
  INFERRED_TYPE,
  /* modifiers */
  [StmtModifier.Static],
  /* initializer */
  injectorDef)],
  /* getters */
  [],
  /* constructorMethod */
  new ClassMethod(null, [], []),
  /* methods */
  []));
}

function accessExportScope(module) {
  var selectorScope = new ReadPropExpr(module, 'ɵmod');
  return new ReadPropExpr(selectorScope, 'exported');
}

function tupleTypeOf(exp) {
  var types = exp.map(function (ref) {
    return typeofExpr(ref.type);
  });
  return exp.length > 0 ? expressionType(literalArr(types)) : NONE_TYPE;
}

function refsToArray(refs, shouldForwardDeclare) {
  var values = literalArr(refs.map(function (ref) {
    return ref.value;
  }));
  return shouldForwardDeclare ? fn([], [new ReturnStatement(values)]) : values;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function compilePipeFromMetadata(metadata) {
  var definitionMapValues = []; // e.g. `name: 'myPipe'`

  definitionMapValues.push({
    key: 'name',
    value: literal(metadata.pipeName),
    quoted: false
  }); // e.g. `type: MyPipe`

  definitionMapValues.push({
    key: 'type',
    value: metadata.type.value,
    quoted: false
  }); // e.g. `pure: true`

  definitionMapValues.push({
    key: 'pure',
    value: literal(metadata.pure),
    quoted: false
  });
  var expression = importExpr(Identifiers$1.definePipe).callFn([literalMap(definitionMapValues)]);
  var type = new ExpressionType(importExpr(Identifiers$1.PipeDefWithMeta, [typeWithParameters(metadata.type.type, metadata.typeArgumentCount), new ExpressionType(new LiteralExpr(metadata.pipeName))]));
  return {
    expression: expression,
    type: type
  };
}
/**
 * Write a pipe definition to the output context.
 */


function compilePipeFromRender2(outputCtx, pipe, reflector) {
  var name = identifierName(pipe.type);

  if (!name) {
    return error("Cannot resolve the name of ".concat(pipe.type));
  }

  var type = outputCtx.importExpr(pipe.type.reference);
  var metadata = {
    name: name,
    type: wrapReference(type),
    internalType: type,
    pipeName: pipe.name,
    typeArgumentCount: 0,
    deps: dependenciesFromGlobalMetadata(pipe.type, outputCtx, reflector),
    pure: pipe.pure
  };
  var res = compilePipeFromMetadata(metadata);
  var factoryRes = compileFactoryFunction(Object.assign(Object.assign({}, metadata), {
    injectFn: Identifiers$1.directiveInject,
    target: R3FactoryTarget.Pipe
  }));
  var definitionField = outputCtx.constantPool.propertyNameOf(3
  /* Pipe */
  );
  var ngFactoryDefStatement = new ClassStmt(
  /* name */
  name,
  /* parent */
  null,
  /* fields */
  [new ClassField(
  /* name */
  'ɵfac',
  /* type */
  INFERRED_TYPE,
  /* modifiers */
  [StmtModifier.Static],
  /* initializer */
  factoryRes.factory)],
  /* getters */
  [],
  /* constructorMethod */
  new ClassMethod(null, [], []),
  /* methods */
  []);
  var pipeDefStatement = new ClassStmt(
  /* name */
  name,
  /* parent */
  null,
  /* fields */
  [new ClassField(
  /* name */
  definitionField,
  /* type */
  INFERRED_TYPE,
  /* modifiers */
  [StmtModifier.Static],
  /* initializer */
  res.expression)],
  /* getters */
  [],
  /* constructorMethod */
  new ClassMethod(null, [], []),
  /* methods */
  []);
  outputCtx.statements.push(ngFactoryDefStatement, pipeDefStatement);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ParserError = function ParserError(message, input, errLocation, ctxLocation) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParserError);

  this.input = input;
  this.errLocation = errLocation;
  this.ctxLocation = ctxLocation;
  this.message = "Parser Error: ".concat(message, " ").concat(errLocation, " [").concat(input, "] in ").concat(ctxLocation);
};

var ParseSpan = /*#__PURE__*/function () {
  function ParseSpan(start, end) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParseSpan);

    this.start = start;
    this.end = end;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ParseSpan, [{
    key: "toAbsolute",
    value: function toAbsolute(absoluteOffset) {
      return new AbsoluteSourceSpan(absoluteOffset + this.start, absoluteOffset + this.end);
    }
  }]);

  return ParseSpan;
}();

var AST = /*#__PURE__*/function () {
  function AST(span,
  /**
   * Absolute location of the expression AST in a source code file.
   */
  sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AST);

    this.span = span;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AST, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return null;
    }
  }, {
    key: "toString",
    value: function toString() {
      return 'AST';
    }
  }]);

  return AST;
}();

var ASTWithName = /*#__PURE__*/function (_AST) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ASTWithName, _AST);

  var _super53 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ASTWithName);

  function ASTWithName(span, sourceSpan, nameSpan) {
    var _this86;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ASTWithName);

    _this86 = _super53.call(this, span, sourceSpan);
    _this86.nameSpan = nameSpan;
    return _this86;
  }

  return ASTWithName;
}(AST);
/**
 * Represents a quoted expression of the form:
 *
 * quote = prefix `:` uninterpretedExpression
 * prefix = identifier
 * uninterpretedExpression = arbitrary string
 *
 * A quoted expression is meant to be pre-processed by an AST transformer that
 * converts it into another AST that no longer contains quoted expressions.
 * It is meant to allow third-party developers to extend Angular template
 * expression language. The `uninterpretedExpression` part of the quote is
 * therefore not interpreted by the Angular's own expression parser.
 */


var Quote = /*#__PURE__*/function (_AST2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Quote, _AST2);

  var _super54 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Quote);

  function Quote(span, sourceSpan, prefix, uninterpretedExpression, location) {
    var _this87;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Quote);

    _this87 = _super54.call(this, span, sourceSpan);
    _this87.prefix = prefix;
    _this87.uninterpretedExpression = uninterpretedExpression;
    _this87.location = location;
    return _this87;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Quote, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitQuote(this, context);
    }
  }, {
    key: "toString",
    value: function toString() {
      return 'Quote';
    }
  }]);

  return Quote;
}(AST);

var EmptyExpr = /*#__PURE__*/function (_AST3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(EmptyExpr, _AST3);

  var _super55 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(EmptyExpr);

  function EmptyExpr() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, EmptyExpr);

    return _super55.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(EmptyExpr, [{
    key: "visit",
    value: function visit(visitor) {// do nothing

      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    }
  }]);

  return EmptyExpr;
}(AST);

var ImplicitReceiver = /*#__PURE__*/function (_AST4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ImplicitReceiver, _AST4);

  var _super56 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ImplicitReceiver);

  function ImplicitReceiver() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ImplicitReceiver);

    return _super56.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ImplicitReceiver, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitImplicitReceiver(this, context);
    }
  }]);

  return ImplicitReceiver;
}(AST);
/**
 * Multiple expressions separated by a semicolon.
 */


var Chain = /*#__PURE__*/function (_AST5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Chain, _AST5);

  var _super57 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Chain);

  function Chain(span, sourceSpan, expressions) {
    var _this88;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Chain);

    _this88 = _super57.call(this, span, sourceSpan);
    _this88.expressions = expressions;
    return _this88;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Chain, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitChain(this, context);
    }
  }]);

  return Chain;
}(AST);

var Conditional = /*#__PURE__*/function (_AST6) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Conditional, _AST6);

  var _super58 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Conditional);

  function Conditional(span, sourceSpan, condition, trueExp, falseExp) {
    var _this89;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Conditional);

    _this89 = _super58.call(this, span, sourceSpan);
    _this89.condition = condition;
    _this89.trueExp = trueExp;
    _this89.falseExp = falseExp;
    return _this89;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Conditional, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitConditional(this, context);
    }
  }]);

  return Conditional;
}(AST);

var PropertyRead = /*#__PURE__*/function (_ASTWithName) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(PropertyRead, _ASTWithName);

  var _super59 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(PropertyRead);

  function PropertyRead(span, sourceSpan, nameSpan, receiver, name) {
    var _this90;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PropertyRead);

    _this90 = _super59.call(this, span, sourceSpan, nameSpan);
    _this90.receiver = receiver;
    _this90.name = name;
    return _this90;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PropertyRead, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitPropertyRead(this, context);
    }
  }]);

  return PropertyRead;
}(ASTWithName);

var PropertyWrite = /*#__PURE__*/function (_ASTWithName2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(PropertyWrite, _ASTWithName2);

  var _super60 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(PropertyWrite);

  function PropertyWrite(span, sourceSpan, nameSpan, receiver, name, value) {
    var _this91;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PropertyWrite);

    _this91 = _super60.call(this, span, sourceSpan, nameSpan);
    _this91.receiver = receiver;
    _this91.name = name;
    _this91.value = value;
    return _this91;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PropertyWrite, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitPropertyWrite(this, context);
    }
  }]);

  return PropertyWrite;
}(ASTWithName);

var SafePropertyRead = /*#__PURE__*/function (_ASTWithName3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(SafePropertyRead, _ASTWithName3);

  var _super61 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(SafePropertyRead);

  function SafePropertyRead(span, sourceSpan, nameSpan, receiver, name) {
    var _this92;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SafePropertyRead);

    _this92 = _super61.call(this, span, sourceSpan, nameSpan);
    _this92.receiver = receiver;
    _this92.name = name;
    return _this92;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SafePropertyRead, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitSafePropertyRead(this, context);
    }
  }]);

  return SafePropertyRead;
}(ASTWithName);

var KeyedRead = /*#__PURE__*/function (_AST7) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(KeyedRead, _AST7);

  var _super62 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(KeyedRead);

  function KeyedRead(span, sourceSpan, obj, key) {
    var _this93;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, KeyedRead);

    _this93 = _super62.call(this, span, sourceSpan);
    _this93.obj = obj;
    _this93.key = key;
    return _this93;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(KeyedRead, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitKeyedRead(this, context);
    }
  }]);

  return KeyedRead;
}(AST);

var KeyedWrite = /*#__PURE__*/function (_AST8) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(KeyedWrite, _AST8);

  var _super63 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(KeyedWrite);

  function KeyedWrite(span, sourceSpan, obj, key, value) {
    var _this94;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, KeyedWrite);

    _this94 = _super63.call(this, span, sourceSpan);
    _this94.obj = obj;
    _this94.key = key;
    _this94.value = value;
    return _this94;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(KeyedWrite, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitKeyedWrite(this, context);
    }
  }]);

  return KeyedWrite;
}(AST);

var BindingPipe = /*#__PURE__*/function (_ASTWithName4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(BindingPipe, _ASTWithName4);

  var _super64 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(BindingPipe);

  function BindingPipe(span, sourceSpan, exp, name, args, nameSpan) {
    var _this95;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BindingPipe);

    _this95 = _super64.call(this, span, sourceSpan, nameSpan);
    _this95.exp = exp;
    _this95.name = name;
    _this95.args = args;
    return _this95;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BindingPipe, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitPipe(this, context);
    }
  }]);

  return BindingPipe;
}(ASTWithName);

var LiteralPrimitive = /*#__PURE__*/function (_AST9) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralPrimitive, _AST9);

  var _super65 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralPrimitive);

  function LiteralPrimitive(span, sourceSpan, value) {
    var _this96;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralPrimitive);

    _this96 = _super65.call(this, span, sourceSpan);
    _this96.value = value;
    return _this96;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralPrimitive, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitLiteralPrimitive(this, context);
    }
  }]);

  return LiteralPrimitive;
}(AST);

var LiteralArray = /*#__PURE__*/function (_AST10) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralArray, _AST10);

  var _super66 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralArray);

  function LiteralArray(span, sourceSpan, expressions) {
    var _this97;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralArray);

    _this97 = _super66.call(this, span, sourceSpan);
    _this97.expressions = expressions;
    return _this97;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralArray, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitLiteralArray(this, context);
    }
  }]);

  return LiteralArray;
}(AST);

var LiteralMap = /*#__PURE__*/function (_AST11) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(LiteralMap, _AST11);

  var _super67 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(LiteralMap);

  function LiteralMap(span, sourceSpan, keys, values) {
    var _this98;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LiteralMap);

    _this98 = _super67.call(this, span, sourceSpan);
    _this98.keys = keys;
    _this98.values = values;
    return _this98;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LiteralMap, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitLiteralMap(this, context);
    }
  }]);

  return LiteralMap;
}(AST);

var Interpolation = /*#__PURE__*/function (_AST12) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Interpolation, _AST12);

  var _super68 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Interpolation);

  function Interpolation(span, sourceSpan, strings, expressions) {
    var _this99;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Interpolation);

    _this99 = _super68.call(this, span, sourceSpan);
    _this99.strings = strings;
    _this99.expressions = expressions;
    return _this99;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Interpolation, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitInterpolation(this, context);
    }
  }]);

  return Interpolation;
}(AST);

var Binary = /*#__PURE__*/function (_AST13) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Binary, _AST13);

  var _super69 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Binary);

  function Binary(span, sourceSpan, operation, left, right) {
    var _this100;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Binary);

    _this100 = _super69.call(this, span, sourceSpan);
    _this100.operation = operation;
    _this100.left = left;
    _this100.right = right;
    return _this100;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Binary, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitBinary(this, context);
    }
  }]);

  return Binary;
}(AST);
/**
 * For backwards compatibility reasons, `Unary` inherits from `Binary` and mimics the binary AST
 * node that was originally used. This inheritance relation can be deleted in some future major,
 * after consumers have been given a chance to fully support Unary.
 */


var Unary = /*#__PURE__*/function (_Binary) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Unary, _Binary);

  var _super70 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Unary);

  /**
   * During the deprecation period this constructor is private, to avoid consumers from creating
   * a `Unary` with the fallback properties for `Binary`.
   */
  function Unary(span, sourceSpan, operator, expr, binaryOp, binaryLeft, binaryRight) {
    var _this101;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Unary);

    _this101 = _super70.call(this, span, sourceSpan, binaryOp, binaryLeft, binaryRight);
    _this101.operator = operator;
    _this101.expr = expr;
    return _this101;
  }
  /**
   * Creates a unary minus expression "-x", represented as `Binary` using "0 - x".
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Unary, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      if (visitor.visitUnary !== undefined) {
        return visitor.visitUnary(this, context);
      }

      return visitor.visitBinary(this, context);
    }
  }], [{
    key: "createMinus",
    value: function createMinus(span, sourceSpan, expr) {
      return new Unary(span, sourceSpan, '-', expr, '-', new LiteralPrimitive(span, sourceSpan, 0), expr);
    }
    /**
     * Creates a unary plus expression "+x", represented as `Binary` using "x - 0".
     */

  }, {
    key: "createPlus",
    value: function createPlus(span, sourceSpan, expr) {
      return new Unary(span, sourceSpan, '+', expr, '-', expr, new LiteralPrimitive(span, sourceSpan, 0));
    }
  }]);

  return Unary;
}(Binary);

var PrefixNot = /*#__PURE__*/function (_AST14) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(PrefixNot, _AST14);

  var _super71 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(PrefixNot);

  function PrefixNot(span, sourceSpan, expression) {
    var _this102;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PrefixNot);

    _this102 = _super71.call(this, span, sourceSpan);
    _this102.expression = expression;
    return _this102;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PrefixNot, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitPrefixNot(this, context);
    }
  }]);

  return PrefixNot;
}(AST);

var NonNullAssert = /*#__PURE__*/function (_AST15) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(NonNullAssert, _AST15);

  var _super72 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(NonNullAssert);

  function NonNullAssert(span, sourceSpan, expression) {
    var _this103;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NonNullAssert);

    _this103 = _super72.call(this, span, sourceSpan);
    _this103.expression = expression;
    return _this103;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NonNullAssert, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitNonNullAssert(this, context);
    }
  }]);

  return NonNullAssert;
}(AST);

var MethodCall = /*#__PURE__*/function (_ASTWithName5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(MethodCall, _ASTWithName5);

  var _super73 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(MethodCall);

  function MethodCall(span, sourceSpan, nameSpan, receiver, name, args) {
    var _this104;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, MethodCall);

    _this104 = _super73.call(this, span, sourceSpan, nameSpan);
    _this104.receiver = receiver;
    _this104.name = name;
    _this104.args = args;
    return _this104;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(MethodCall, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitMethodCall(this, context);
    }
  }]);

  return MethodCall;
}(ASTWithName);

var SafeMethodCall = /*#__PURE__*/function (_ASTWithName6) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(SafeMethodCall, _ASTWithName6);

  var _super74 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(SafeMethodCall);

  function SafeMethodCall(span, sourceSpan, nameSpan, receiver, name, args) {
    var _this105;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SafeMethodCall);

    _this105 = _super74.call(this, span, sourceSpan, nameSpan);
    _this105.receiver = receiver;
    _this105.name = name;
    _this105.args = args;
    return _this105;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SafeMethodCall, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitSafeMethodCall(this, context);
    }
  }]);

  return SafeMethodCall;
}(ASTWithName);

var FunctionCall = /*#__PURE__*/function (_AST16) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(FunctionCall, _AST16);

  var _super75 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(FunctionCall);

  function FunctionCall(span, sourceSpan, target, args) {
    var _this106;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, FunctionCall);

    _this106 = _super75.call(this, span, sourceSpan);
    _this106.target = target;
    _this106.args = args;
    return _this106;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(FunctionCall, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return visitor.visitFunctionCall(this, context);
    }
  }]);

  return FunctionCall;
}(AST);
/**
 * Records the absolute position of a text span in a source file, where `start` and `end` are the
 * starting and ending byte offsets, respectively, of the text span in a source file.
 */


var AbsoluteSourceSpan = function AbsoluteSourceSpan(start, end) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AbsoluteSourceSpan);

  this.start = start;
  this.end = end;
};

var ASTWithSource = /*#__PURE__*/function (_AST17) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ASTWithSource, _AST17);

  var _super76 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ASTWithSource);

  function ASTWithSource(ast, source, location, absoluteOffset, errors) {
    var _this107;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ASTWithSource);

    _this107 = _super76.call(this, new ParseSpan(0, source === null ? 0 : source.length), new AbsoluteSourceSpan(absoluteOffset, source === null ? absoluteOffset : absoluteOffset + source.length));
    _this107.ast = ast;
    _this107.source = source;
    _this107.location = location;
    _this107.errors = errors;
    return _this107;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ASTWithSource, [{
    key: "visit",
    value: function visit(visitor) {
      var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      if (visitor.visitASTWithSource) {
        return visitor.visitASTWithSource(this, context);
      }

      return this.ast.visit(visitor, context);
    }
  }, {
    key: "toString",
    value: function toString() {
      return "".concat(this.source, " in ").concat(this.location);
    }
  }]);

  return ASTWithSource;
}(AST);

var VariableBinding =
/**
 * @param sourceSpan entire span of the binding.
 * @param key name of the LHS along with its span.
 * @param value optional value for the RHS along with its span.
 */
function VariableBinding(sourceSpan, key, value) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, VariableBinding);

  this.sourceSpan = sourceSpan;
  this.key = key;
  this.value = value;
};

var ExpressionBinding =
/**
 * @param sourceSpan entire span of the binding.
 * @param key binding name, like ngForOf, ngForTrackBy, ngIf, along with its
 * span. Note that the length of the span may not be the same as
 * `key.source.length`. For example,
 * 1. key.source = ngFor, key.span is for "ngFor"
 * 2. key.source = ngForOf, key.span is for "of"
 * 3. key.source = ngForTrackBy, key.span is for "trackBy"
 * @param value optional expression for the RHS.
 */
function ExpressionBinding(sourceSpan, key, value) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExpressionBinding);

  this.sourceSpan = sourceSpan;
  this.key = key;
  this.value = value;
};

var RecursiveAstVisitor$1 = /*#__PURE__*/function () {
  function RecursiveAstVisitor$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, RecursiveAstVisitor$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(RecursiveAstVisitor$1, [{
    key: "visit",
    value: function visit(ast, context) {
      // The default implementation just visits every node.
      // Classes that extend RecursiveAstVisitor should override this function
      // to selectively visit the specified node.
      ast.visit(this, context);
    }
  }, {
    key: "visitUnary",
    value: function visitUnary(ast, context) {
      this.visit(ast.expr, context);
    }
  }, {
    key: "visitBinary",
    value: function visitBinary(ast, context) {
      this.visit(ast.left, context);
      this.visit(ast.right, context);
    }
  }, {
    key: "visitChain",
    value: function visitChain(ast, context) {
      this.visitAll(ast.expressions, context);
    }
  }, {
    key: "visitConditional",
    value: function visitConditional(ast, context) {
      this.visit(ast.condition, context);
      this.visit(ast.trueExp, context);
      this.visit(ast.falseExp, context);
    }
  }, {
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      this.visit(ast.exp, context);
      this.visitAll(ast.args, context);
    }
  }, {
    key: "visitFunctionCall",
    value: function visitFunctionCall(ast, context) {
      if (ast.target) {
        this.visit(ast.target, context);
      }

      this.visitAll(ast.args, context);
    }
  }, {
    key: "visitImplicitReceiver",
    value: function visitImplicitReceiver(ast, context) {}
  }, {
    key: "visitInterpolation",
    value: function visitInterpolation(ast, context) {
      this.visitAll(ast.expressions, context);
    }
  }, {
    key: "visitKeyedRead",
    value: function visitKeyedRead(ast, context) {
      this.visit(ast.obj, context);
      this.visit(ast.key, context);
    }
  }, {
    key: "visitKeyedWrite",
    value: function visitKeyedWrite(ast, context) {
      this.visit(ast.obj, context);
      this.visit(ast.key, context);
      this.visit(ast.value, context);
    }
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(ast, context) {
      this.visitAll(ast.expressions, context);
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(ast, context) {
      this.visitAll(ast.values, context);
    }
  }, {
    key: "visitLiteralPrimitive",
    value: function visitLiteralPrimitive(ast, context) {}
  }, {
    key: "visitMethodCall",
    value: function visitMethodCall(ast, context) {
      this.visit(ast.receiver, context);
      this.visitAll(ast.args, context);
    }
  }, {
    key: "visitPrefixNot",
    value: function visitPrefixNot(ast, context) {
      this.visit(ast.expression, context);
    }
  }, {
    key: "visitNonNullAssert",
    value: function visitNonNullAssert(ast, context) {
      this.visit(ast.expression, context);
    }
  }, {
    key: "visitPropertyRead",
    value: function visitPropertyRead(ast, context) {
      this.visit(ast.receiver, context);
    }
  }, {
    key: "visitPropertyWrite",
    value: function visitPropertyWrite(ast, context) {
      this.visit(ast.receiver, context);
      this.visit(ast.value, context);
    }
  }, {
    key: "visitSafePropertyRead",
    value: function visitSafePropertyRead(ast, context) {
      this.visit(ast.receiver, context);
    }
  }, {
    key: "visitSafeMethodCall",
    value: function visitSafeMethodCall(ast, context) {
      this.visit(ast.receiver, context);
      this.visitAll(ast.args, context);
    }
  }, {
    key: "visitQuote",
    value: function visitQuote(ast, context) {} // This is not part of the AstVisitor interface, just a helper method

  }, {
    key: "visitAll",
    value: function visitAll(asts, context) {
      var _iterator7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(asts),
          _step7;

      try {
        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
          var ast = _step7.value;
          this.visit(ast, context);
        }
      } catch (err) {
        _iterator7.e(err);
      } finally {
        _iterator7.f();
      }
    }
  }]);

  return RecursiveAstVisitor$1;
}();

var AstTransformer$1 = /*#__PURE__*/function () {
  function AstTransformer$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AstTransformer$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AstTransformer$1, [{
    key: "visitImplicitReceiver",
    value: function visitImplicitReceiver(ast, context) {
      return ast;
    }
  }, {
    key: "visitInterpolation",
    value: function visitInterpolation(ast, context) {
      return new Interpolation(ast.span, ast.sourceSpan, ast.strings, this.visitAll(ast.expressions));
    }
  }, {
    key: "visitLiteralPrimitive",
    value: function visitLiteralPrimitive(ast, context) {
      return new LiteralPrimitive(ast.span, ast.sourceSpan, ast.value);
    }
  }, {
    key: "visitPropertyRead",
    value: function visitPropertyRead(ast, context) {
      return new PropertyRead(ast.span, ast.sourceSpan, ast.nameSpan, ast.receiver.visit(this), ast.name);
    }
  }, {
    key: "visitPropertyWrite",
    value: function visitPropertyWrite(ast, context) {
      return new PropertyWrite(ast.span, ast.sourceSpan, ast.nameSpan, ast.receiver.visit(this), ast.name, ast.value.visit(this));
    }
  }, {
    key: "visitSafePropertyRead",
    value: function visitSafePropertyRead(ast, context) {
      return new SafePropertyRead(ast.span, ast.sourceSpan, ast.nameSpan, ast.receiver.visit(this), ast.name);
    }
  }, {
    key: "visitMethodCall",
    value: function visitMethodCall(ast, context) {
      return new MethodCall(ast.span, ast.sourceSpan, ast.nameSpan, ast.receiver.visit(this), ast.name, this.visitAll(ast.args));
    }
  }, {
    key: "visitSafeMethodCall",
    value: function visitSafeMethodCall(ast, context) {
      return new SafeMethodCall(ast.span, ast.sourceSpan, ast.nameSpan, ast.receiver.visit(this), ast.name, this.visitAll(ast.args));
    }
  }, {
    key: "visitFunctionCall",
    value: function visitFunctionCall(ast, context) {
      return new FunctionCall(ast.span, ast.sourceSpan, ast.target.visit(this), this.visitAll(ast.args));
    }
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(ast, context) {
      return new LiteralArray(ast.span, ast.sourceSpan, this.visitAll(ast.expressions));
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(ast, context) {
      return new LiteralMap(ast.span, ast.sourceSpan, ast.keys, this.visitAll(ast.values));
    }
  }, {
    key: "visitUnary",
    value: function visitUnary(ast, context) {
      switch (ast.operator) {
        case '+':
          return Unary.createPlus(ast.span, ast.sourceSpan, ast.expr.visit(this));

        case '-':
          return Unary.createMinus(ast.span, ast.sourceSpan, ast.expr.visit(this));

        default:
          throw new Error("Unknown unary operator ".concat(ast.operator));
      }
    }
  }, {
    key: "visitBinary",
    value: function visitBinary(ast, context) {
      return new Binary(ast.span, ast.sourceSpan, ast.operation, ast.left.visit(this), ast.right.visit(this));
    }
  }, {
    key: "visitPrefixNot",
    value: function visitPrefixNot(ast, context) {
      return new PrefixNot(ast.span, ast.sourceSpan, ast.expression.visit(this));
    }
  }, {
    key: "visitNonNullAssert",
    value: function visitNonNullAssert(ast, context) {
      return new NonNullAssert(ast.span, ast.sourceSpan, ast.expression.visit(this));
    }
  }, {
    key: "visitConditional",
    value: function visitConditional(ast, context) {
      return new Conditional(ast.span, ast.sourceSpan, ast.condition.visit(this), ast.trueExp.visit(this), ast.falseExp.visit(this));
    }
  }, {
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      return new BindingPipe(ast.span, ast.sourceSpan, ast.exp.visit(this), ast.name, this.visitAll(ast.args), ast.nameSpan);
    }
  }, {
    key: "visitKeyedRead",
    value: function visitKeyedRead(ast, context) {
      return new KeyedRead(ast.span, ast.sourceSpan, ast.obj.visit(this), ast.key.visit(this));
    }
  }, {
    key: "visitKeyedWrite",
    value: function visitKeyedWrite(ast, context) {
      return new KeyedWrite(ast.span, ast.sourceSpan, ast.obj.visit(this), ast.key.visit(this), ast.value.visit(this));
    }
  }, {
    key: "visitAll",
    value: function visitAll(asts) {
      var res = [];

      for (var i = 0; i < asts.length; ++i) {
        res[i] = asts[i].visit(this);
      }

      return res;
    }
  }, {
    key: "visitChain",
    value: function visitChain(ast, context) {
      return new Chain(ast.span, ast.sourceSpan, this.visitAll(ast.expressions));
    }
  }, {
    key: "visitQuote",
    value: function visitQuote(ast, context) {
      return new Quote(ast.span, ast.sourceSpan, ast.prefix, ast.uninterpretedExpression, ast.location);
    }
  }]);

  return AstTransformer$1;
}(); // A transformer that only creates new nodes if the transformer makes a change or
// a change is made a child node.


var AstMemoryEfficientTransformer = /*#__PURE__*/function () {
  function AstMemoryEfficientTransformer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AstMemoryEfficientTransformer);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AstMemoryEfficientTransformer, [{
    key: "visitImplicitReceiver",
    value: function visitImplicitReceiver(ast, context) {
      return ast;
    }
  }, {
    key: "visitInterpolation",
    value: function visitInterpolation(ast, context) {
      var expressions = this.visitAll(ast.expressions);
      if (expressions !== ast.expressions) return new Interpolation(ast.span, ast.sourceSpan, ast.strings, expressions);
      return ast;
    }
  }, {
    key: "visitLiteralPrimitive",
    value: function visitLiteralPrimitive(ast, context) {
      return ast;
    }
  }, {
    key: "visitPropertyRead",
    value: function visitPropertyRead(ast, context) {
      var receiver = ast.receiver.visit(this);

      if (receiver !== ast.receiver) {
        return new PropertyRead(ast.span, ast.sourceSpan, ast.nameSpan, receiver, ast.name);
      }

      return ast;
    }
  }, {
    key: "visitPropertyWrite",
    value: function visitPropertyWrite(ast, context) {
      var receiver = ast.receiver.visit(this);
      var value = ast.value.visit(this);

      if (receiver !== ast.receiver || value !== ast.value) {
        return new PropertyWrite(ast.span, ast.sourceSpan, ast.nameSpan, receiver, ast.name, value);
      }

      return ast;
    }
  }, {
    key: "visitSafePropertyRead",
    value: function visitSafePropertyRead(ast, context) {
      var receiver = ast.receiver.visit(this);

      if (receiver !== ast.receiver) {
        return new SafePropertyRead(ast.span, ast.sourceSpan, ast.nameSpan, receiver, ast.name);
      }

      return ast;
    }
  }, {
    key: "visitMethodCall",
    value: function visitMethodCall(ast, context) {
      var receiver = ast.receiver.visit(this);
      var args = this.visitAll(ast.args);

      if (receiver !== ast.receiver || args !== ast.args) {
        return new MethodCall(ast.span, ast.sourceSpan, ast.nameSpan, receiver, ast.name, args);
      }

      return ast;
    }
  }, {
    key: "visitSafeMethodCall",
    value: function visitSafeMethodCall(ast, context) {
      var receiver = ast.receiver.visit(this);
      var args = this.visitAll(ast.args);

      if (receiver !== ast.receiver || args !== ast.args) {
        return new SafeMethodCall(ast.span, ast.sourceSpan, ast.nameSpan, receiver, ast.name, args);
      }

      return ast;
    }
  }, {
    key: "visitFunctionCall",
    value: function visitFunctionCall(ast, context) {
      var target = ast.target && ast.target.visit(this);
      var args = this.visitAll(ast.args);

      if (target !== ast.target || args !== ast.args) {
        return new FunctionCall(ast.span, ast.sourceSpan, target, args);
      }

      return ast;
    }
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(ast, context) {
      var expressions = this.visitAll(ast.expressions);

      if (expressions !== ast.expressions) {
        return new LiteralArray(ast.span, ast.sourceSpan, expressions);
      }

      return ast;
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(ast, context) {
      var values = this.visitAll(ast.values);

      if (values !== ast.values) {
        return new LiteralMap(ast.span, ast.sourceSpan, ast.keys, values);
      }

      return ast;
    }
  }, {
    key: "visitUnary",
    value: function visitUnary(ast, context) {
      var expr = ast.expr.visit(this);

      if (expr !== ast.expr) {
        switch (ast.operator) {
          case '+':
            return Unary.createPlus(ast.span, ast.sourceSpan, expr);

          case '-':
            return Unary.createMinus(ast.span, ast.sourceSpan, expr);

          default:
            throw new Error("Unknown unary operator ".concat(ast.operator));
        }
      }

      return ast;
    }
  }, {
    key: "visitBinary",
    value: function visitBinary(ast, context) {
      var left = ast.left.visit(this);
      var right = ast.right.visit(this);

      if (left !== ast.left || right !== ast.right) {
        return new Binary(ast.span, ast.sourceSpan, ast.operation, left, right);
      }

      return ast;
    }
  }, {
    key: "visitPrefixNot",
    value: function visitPrefixNot(ast, context) {
      var expression = ast.expression.visit(this);

      if (expression !== ast.expression) {
        return new PrefixNot(ast.span, ast.sourceSpan, expression);
      }

      return ast;
    }
  }, {
    key: "visitNonNullAssert",
    value: function visitNonNullAssert(ast, context) {
      var expression = ast.expression.visit(this);

      if (expression !== ast.expression) {
        return new NonNullAssert(ast.span, ast.sourceSpan, expression);
      }

      return ast;
    }
  }, {
    key: "visitConditional",
    value: function visitConditional(ast, context) {
      var condition = ast.condition.visit(this);
      var trueExp = ast.trueExp.visit(this);
      var falseExp = ast.falseExp.visit(this);

      if (condition !== ast.condition || trueExp !== ast.trueExp || falseExp !== ast.falseExp) {
        return new Conditional(ast.span, ast.sourceSpan, condition, trueExp, falseExp);
      }

      return ast;
    }
  }, {
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      var exp = ast.exp.visit(this);
      var args = this.visitAll(ast.args);

      if (exp !== ast.exp || args !== ast.args) {
        return new BindingPipe(ast.span, ast.sourceSpan, exp, ast.name, args, ast.nameSpan);
      }

      return ast;
    }
  }, {
    key: "visitKeyedRead",
    value: function visitKeyedRead(ast, context) {
      var obj = ast.obj.visit(this);
      var key = ast.key.visit(this);

      if (obj !== ast.obj || key !== ast.key) {
        return new KeyedRead(ast.span, ast.sourceSpan, obj, key);
      }

      return ast;
    }
  }, {
    key: "visitKeyedWrite",
    value: function visitKeyedWrite(ast, context) {
      var obj = ast.obj.visit(this);
      var key = ast.key.visit(this);
      var value = ast.value.visit(this);

      if (obj !== ast.obj || key !== ast.key || value !== ast.value) {
        return new KeyedWrite(ast.span, ast.sourceSpan, obj, key, value);
      }

      return ast;
    }
  }, {
    key: "visitAll",
    value: function visitAll(asts) {
      var res = [];
      var modified = false;

      for (var i = 0; i < asts.length; ++i) {
        var original = asts[i];
        var value = original.visit(this);
        res[i] = value;
        modified = modified || value !== original;
      }

      return modified ? res : asts;
    }
  }, {
    key: "visitChain",
    value: function visitChain(ast, context) {
      var expressions = this.visitAll(ast.expressions);

      if (expressions !== ast.expressions) {
        return new Chain(ast.span, ast.sourceSpan, expressions);
      }

      return ast;
    }
  }, {
    key: "visitQuote",
    value: function visitQuote(ast, context) {
      return ast;
    }
  }]);

  return AstMemoryEfficientTransformer;
}(); // Bindings


var ParsedProperty = function ParsedProperty(name, expression, type, sourceSpan, valueSpan) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParsedProperty);

  this.name = name;
  this.expression = expression;
  this.type = type;
  this.sourceSpan = sourceSpan;
  this.valueSpan = valueSpan;
  this.isLiteral = this.type === ParsedPropertyType.LITERAL_ATTR;
  this.isAnimation = this.type === ParsedPropertyType.ANIMATION;
};

var ParsedPropertyType;

(function (ParsedPropertyType) {
  ParsedPropertyType[ParsedPropertyType["DEFAULT"] = 0] = "DEFAULT";
  ParsedPropertyType[ParsedPropertyType["LITERAL_ATTR"] = 1] = "LITERAL_ATTR";
  ParsedPropertyType[ParsedPropertyType["ANIMATION"] = 2] = "ANIMATION";
})(ParsedPropertyType || (ParsedPropertyType = {}));

var ParsedEvent = // Regular events have a target
// Animation events have a phase
function ParsedEvent(name, targetOrPhase, type, handler, sourceSpan, handlerSpan) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParsedEvent);

  this.name = name;
  this.targetOrPhase = targetOrPhase;
  this.type = type;
  this.handler = handler;
  this.sourceSpan = sourceSpan;
  this.handlerSpan = handlerSpan;
};
/**
 * ParsedVariable represents a variable declaration in a microsyntax expression.
 */


var ParsedVariable = function ParsedVariable(name, value, sourceSpan, keySpan, valueSpan) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParsedVariable);

  this.name = name;
  this.value = value;
  this.sourceSpan = sourceSpan;
  this.keySpan = keySpan;
  this.valueSpan = valueSpan;
};

var BoundElementProperty = function BoundElementProperty(name, type, securityContext, value, unit, sourceSpan, valueSpan) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundElementProperty);

  this.name = name;
  this.type = type;
  this.securityContext = securityContext;
  this.value = value;
  this.unit = unit;
  this.sourceSpan = sourceSpan;
  this.valueSpan = valueSpan;
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var EventHandlerVars = function EventHandlerVars() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, EventHandlerVars);
};

EventHandlerVars.event = variable('$event');

var ConvertActionBindingResult = function ConvertActionBindingResult(
/**
 * Render2 compatible statements,
 */
stmts,
/**
 * Variable name used with render2 compatible statements.
 */
allowDefault) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ConvertActionBindingResult);

  this.stmts = stmts;
  this.allowDefault = allowDefault;
  /**
   * This is bit of a hack. It converts statements which render2 expects to statements which are
   * expected by render3.
   *
   * Example: `<div click="doSomething($event)">` will generate:
   *
   * Render3:
   * ```
   * const pd_b:any = ((<any>ctx.doSomething($event)) !== false);
   * return pd_b;
   * ```
   *
   * but render2 expects:
   * ```
   * return ctx.doSomething($event);
   * ```
   */
  // TODO(misko): remove this hack once we no longer support ViewEngine.

  this.render3Stmts = stmts.map(function (statement) {
    if (statement instanceof DeclareVarStmt && statement.name == allowDefault.name && statement.value instanceof BinaryOperatorExpr) {
      var lhs = statement.value.lhs;
      return new ReturnStatement(lhs.value);
    }

    return statement;
  });
};
/**
 * Converts the given expression AST into an executable output AST, assuming the expression is
 * used in an action binding (e.g. an event handler).
 */


function convertActionBinding(localResolver, implicitReceiver, action, bindingId, interpolationFunction, baseSourceSpan, implicitReceiverAccesses) {
  if (!localResolver) {
    localResolver = new DefaultLocalResolver();
  }

  var actionWithoutBuiltins = convertPropertyBindingBuiltins({
    createLiteralArrayConverter: function createLiteralArrayConverter(argCount) {
      // Note: no caching for literal arrays in actions.
      return function (args) {
        return literalArr(args);
      };
    },
    createLiteralMapConverter: function createLiteralMapConverter(keys) {
      // Note: no caching for literal maps in actions.
      return function (values) {
        var entries = keys.map(function (k, i) {
          return {
            key: k.key,
            value: values[i],
            quoted: k.quoted
          };
        });
        return literalMap(entries);
      };
    },
    createPipeConverter: function createPipeConverter(name) {
      throw new Error("Illegal State: Actions are not allowed to contain pipes. Pipe: ".concat(name));
    }
  }, action);
  var visitor = new _AstToIrVisitor(localResolver, implicitReceiver, bindingId, interpolationFunction, baseSourceSpan, implicitReceiverAccesses);
  var actionStmts = [];
  flattenStatements(actionWithoutBuiltins.visit(visitor, _Mode.Statement), actionStmts);
  prependTemporaryDecls(visitor.temporaryCount, bindingId, actionStmts);

  if (visitor.usesImplicitReceiver) {
    localResolver.notifyImplicitReceiverUse();
  }

  var lastIndex = actionStmts.length - 1;
  var preventDefaultVar = null;

  if (lastIndex >= 0) {
    var lastStatement = actionStmts[lastIndex];
    var returnExpr = convertStmtIntoExpression(lastStatement);

    if (returnExpr) {
      // Note: We need to cast the result of the method call to dynamic,
      // as it might be a void method!
      preventDefaultVar = createPreventDefaultVar(bindingId);
      actionStmts[lastIndex] = preventDefaultVar.set(returnExpr.cast(DYNAMIC_TYPE).notIdentical(literal(false))).toDeclStmt(null, [StmtModifier.Final]);
    }
  }

  return new ConvertActionBindingResult(actionStmts, preventDefaultVar);
}

function convertPropertyBindingBuiltins(converterFactory, ast) {
  return convertBuiltins(converterFactory, ast);
}

var ConvertPropertyBindingResult = function ConvertPropertyBindingResult(stmts, currValExpr) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ConvertPropertyBindingResult);

  this.stmts = stmts;
  this.currValExpr = currValExpr;
};

var BindingForm;

(function (BindingForm) {
  // The general form of binding expression, supports all expressions.
  BindingForm[BindingForm["General"] = 0] = "General"; // Try to generate a simple binding (no temporaries or statements)
  // otherwise generate a general binding

  BindingForm[BindingForm["TrySimple"] = 1] = "TrySimple"; // Inlines assignment of temporaries into the generated expression. The result may still
  // have statements attached for declarations of temporary variables.
  // This is the only relevant form for Ivy, the other forms are only used in ViewEngine.

  BindingForm[BindingForm["Expression"] = 2] = "Expression";
})(BindingForm || (BindingForm = {}));
/**
 * Converts the given expression AST into an executable output AST, assuming the expression
 * is used in property binding. The expression has to be preprocessed via
 * `convertPropertyBindingBuiltins`.
 */


function _convertPropertyBinding(localResolver, implicitReceiver, expressionWithoutBuiltins, bindingId, form, interpolationFunction) {
  if (!localResolver) {
    localResolver = new DefaultLocalResolver();
  }

  var visitor = new _AstToIrVisitor(localResolver, implicitReceiver, bindingId, interpolationFunction);
  var outputExpr = expressionWithoutBuiltins.visit(visitor, _Mode.Expression);
  var stmts = getStatementsFromVisitor(visitor, bindingId);

  if (visitor.usesImplicitReceiver) {
    localResolver.notifyImplicitReceiverUse();
  }

  if (visitor.temporaryCount === 0 && form == BindingForm.TrySimple) {
    return new ConvertPropertyBindingResult([], outputExpr);
  } else if (form === BindingForm.Expression) {
    return new ConvertPropertyBindingResult(stmts, outputExpr);
  }

  var currValExpr = createCurrValueExpr(bindingId);
  stmts.push(currValExpr.set(outputExpr).toDeclStmt(DYNAMIC_TYPE, [StmtModifier.Final]));
  return new ConvertPropertyBindingResult(stmts, currValExpr);
}
/**
 * Given some expression, such as a binding or interpolation expression, and a context expression to
 * look values up on, visit each facet of the given expression resolving values from the context
 * expression such that a list of arguments can be derived from the found values that can be used as
 * arguments to an external update instruction.
 *
 * @param localResolver The resolver to use to look up expressions by name appropriately
 * @param contextVariableExpression The expression representing the context variable used to create
 * the final argument expressions
 * @param expressionWithArgumentsToExtract The expression to visit to figure out what values need to
 * be resolved and what arguments list to build.
 * @param bindingId A name prefix used to create temporary variable names if they're needed for the
 * arguments generated
 * @returns An array of expressions that can be passed as arguments to instruction expressions like
 * `o.importExpr(R3.propertyInterpolate).callFn(result)`
 */


function convertUpdateArguments(localResolver, contextVariableExpression, expressionWithArgumentsToExtract, bindingId) {
  var visitor = new _AstToIrVisitor(localResolver, contextVariableExpression, bindingId, undefined);
  var outputExpr = expressionWithArgumentsToExtract.visit(visitor, _Mode.Expression);

  if (visitor.usesImplicitReceiver) {
    localResolver.notifyImplicitReceiverUse();
  }

  var stmts = getStatementsFromVisitor(visitor, bindingId); // Removing the first argument, because it was a length for ViewEngine, not Ivy.

  var args = outputExpr.args.slice(1);

  if (expressionWithArgumentsToExtract instanceof Interpolation) {
    // If we're dealing with an interpolation of 1 value with an empty prefix and suffix, reduce the
    // args returned to just the value, because we're going to pass it to a special instruction.
    var strings = expressionWithArgumentsToExtract.strings;

    if (args.length === 3 && strings[0] === '' && strings[1] === '') {
      // Single argument interpolate instructions.
      args = [args[1]];
    } else if (args.length >= 19) {
      // 19 or more arguments must be passed to the `interpolateV`-style instructions, which accept
      // an array of arguments
      args = [literalArr(args)];
    }
  }

  return {
    stmts: stmts,
    args: args
  };
}

function getStatementsFromVisitor(visitor, bindingId) {
  var stmts = [];

  for (var i = 0; i < visitor.temporaryCount; i++) {
    stmts.push(temporaryDeclaration(bindingId, i));
  }

  return stmts;
}

function convertBuiltins(converterFactory, ast) {
  var visitor = new _BuiltinAstConverter(converterFactory);
  return ast.visit(visitor);
}

function temporaryName(bindingId, temporaryNumber) {
  return "tmp_".concat(bindingId, "_").concat(temporaryNumber);
}

function temporaryDeclaration(bindingId, temporaryNumber) {
  return new DeclareVarStmt(temporaryName(bindingId, temporaryNumber), NULL_EXPR);
}

function prependTemporaryDecls(temporaryCount, bindingId, statements) {
  for (var i = temporaryCount - 1; i >= 0; i--) {
    statements.unshift(temporaryDeclaration(bindingId, i));
  }
}

var _Mode;

(function (_Mode) {
  _Mode[_Mode["Statement"] = 0] = "Statement";
  _Mode[_Mode["Expression"] = 1] = "Expression";
})(_Mode || (_Mode = {}));

function ensureStatementMode(mode, ast) {
  if (mode !== _Mode.Statement) {
    throw new Error("Expected a statement, but saw ".concat(ast));
  }
}

function ensureExpressionMode(mode, ast) {
  if (mode !== _Mode.Expression) {
    throw new Error("Expected an expression, but saw ".concat(ast));
  }
}

function convertToStatementIfNeeded(mode, expr) {
  if (mode === _Mode.Statement) {
    return expr.toStmt();
  } else {
    return expr;
  }
}

var _BuiltinAstConverter = /*#__PURE__*/function (_AstTransformer$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_BuiltinAstConverter, _AstTransformer$);

  var _super77 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_BuiltinAstConverter);

  function _BuiltinAstConverter(_converterFactory) {
    var _this108;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _BuiltinAstConverter);

    _this108 = _super77.call(this);
    _this108._converterFactory = _converterFactory;
    return _this108;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_BuiltinAstConverter, [{
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      var _this109 = this;

      var args = [ast.exp].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ast.args)).map(function (ast) {
        return ast.visit(_this109, context);
      });
      return new BuiltinFunctionCall(ast.span, ast.sourceSpan, args, this._converterFactory.createPipeConverter(ast.name, args.length));
    }
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(ast, context) {
      var _this110 = this;

      var args = ast.expressions.map(function (ast) {
        return ast.visit(_this110, context);
      });
      return new BuiltinFunctionCall(ast.span, ast.sourceSpan, args, this._converterFactory.createLiteralArrayConverter(ast.expressions.length));
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(ast, context) {
      var _this111 = this;

      var args = ast.values.map(function (ast) {
        return ast.visit(_this111, context);
      });
      return new BuiltinFunctionCall(ast.span, ast.sourceSpan, args, this._converterFactory.createLiteralMapConverter(ast.keys));
    }
  }]);

  return _BuiltinAstConverter;
}(AstTransformer$1);

var _AstToIrVisitor = /*#__PURE__*/function () {
  function _AstToIrVisitor(_localResolver, _implicitReceiver, bindingId, interpolationFunction, baseSourceSpan, implicitReceiverAccesses) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _AstToIrVisitor);

    this._localResolver = _localResolver;
    this._implicitReceiver = _implicitReceiver;
    this.bindingId = bindingId;
    this.interpolationFunction = interpolationFunction;
    this.baseSourceSpan = baseSourceSpan;
    this.implicitReceiverAccesses = implicitReceiverAccesses;
    this._nodeMap = new Map();
    this._resultMap = new Map();
    this._currentTemporary = 0;
    this.temporaryCount = 0;
    this.usesImplicitReceiver = false;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_AstToIrVisitor, [{
    key: "visitUnary",
    value: function visitUnary(ast, mode) {
      var op;

      switch (ast.operator) {
        case '+':
          op = UnaryOperator.Plus;
          break;

        case '-':
          op = UnaryOperator.Minus;
          break;

        default:
          throw new Error("Unsupported operator ".concat(ast.operator));
      }

      return convertToStatementIfNeeded(mode, new UnaryOperatorExpr(op, this._visit(ast.expr, _Mode.Expression), undefined, this.convertSourceSpan(ast.span)));
    }
  }, {
    key: "visitBinary",
    value: function visitBinary(ast, mode) {
      var op;

      switch (ast.operation) {
        case '+':
          op = BinaryOperator.Plus;
          break;

        case '-':
          op = BinaryOperator.Minus;
          break;

        case '*':
          op = BinaryOperator.Multiply;
          break;

        case '/':
          op = BinaryOperator.Divide;
          break;

        case '%':
          op = BinaryOperator.Modulo;
          break;

        case '&&':
          op = BinaryOperator.And;
          break;

        case '||':
          op = BinaryOperator.Or;
          break;

        case '==':
          op = BinaryOperator.Equals;
          break;

        case '!=':
          op = BinaryOperator.NotEquals;
          break;

        case '===':
          op = BinaryOperator.Identical;
          break;

        case '!==':
          op = BinaryOperator.NotIdentical;
          break;

        case '<':
          op = BinaryOperator.Lower;
          break;

        case '>':
          op = BinaryOperator.Bigger;
          break;

        case '<=':
          op = BinaryOperator.LowerEquals;
          break;

        case '>=':
          op = BinaryOperator.BiggerEquals;
          break;

        default:
          throw new Error("Unsupported operation ".concat(ast.operation));
      }

      return convertToStatementIfNeeded(mode, new BinaryOperatorExpr(op, this._visit(ast.left, _Mode.Expression), this._visit(ast.right, _Mode.Expression), undefined, this.convertSourceSpan(ast.span)));
    }
  }, {
    key: "visitChain",
    value: function visitChain(ast, mode) {
      ensureStatementMode(mode, ast);
      return this.visitAll(ast.expressions, mode);
    }
  }, {
    key: "visitConditional",
    value: function visitConditional(ast, mode) {
      var value = this._visit(ast.condition, _Mode.Expression);

      return convertToStatementIfNeeded(mode, value.conditional(this._visit(ast.trueExp, _Mode.Expression), this._visit(ast.falseExp, _Mode.Expression), this.convertSourceSpan(ast.span)));
    }
  }, {
    key: "visitPipe",
    value: function visitPipe(ast, mode) {
      throw new Error("Illegal state: Pipes should have been converted into functions. Pipe: ".concat(ast.name));
    }
  }, {
    key: "visitFunctionCall",
    value: function visitFunctionCall(ast, mode) {
      var convertedArgs = this.visitAll(ast.args, _Mode.Expression);
      var fnResult;

      if (ast instanceof BuiltinFunctionCall) {
        fnResult = ast.converter(convertedArgs);
      } else {
        fnResult = this._visit(ast.target, _Mode.Expression).callFn(convertedArgs, this.convertSourceSpan(ast.span));
      }

      return convertToStatementIfNeeded(mode, fnResult);
    }
  }, {
    key: "visitImplicitReceiver",
    value: function visitImplicitReceiver(ast, mode) {
      ensureExpressionMode(mode, ast);
      this.usesImplicitReceiver = true;
      return this._implicitReceiver;
    }
  }, {
    key: "visitInterpolation",
    value: function visitInterpolation(ast, mode) {
      ensureExpressionMode(mode, ast);
      var args = [literal(ast.expressions.length)];

      for (var i = 0; i < ast.strings.length - 1; i++) {
        args.push(literal(ast.strings[i]));
        args.push(this._visit(ast.expressions[i], _Mode.Expression));
      }

      args.push(literal(ast.strings[ast.strings.length - 1]));

      if (this.interpolationFunction) {
        return this.interpolationFunction(args);
      }

      return ast.expressions.length <= 9 ? importExpr(Identifiers.inlineInterpolate).callFn(args) : importExpr(Identifiers.interpolate).callFn([args[0], literalArr(args.slice(1), undefined, this.convertSourceSpan(ast.span))]);
    }
  }, {
    key: "visitKeyedRead",
    value: function visitKeyedRead(ast, mode) {
      var leftMostSafe = this.leftMostSafeNode(ast);

      if (leftMostSafe) {
        return this.convertSafeAccess(ast, leftMostSafe, mode);
      } else {
        return convertToStatementIfNeeded(mode, this._visit(ast.obj, _Mode.Expression).key(this._visit(ast.key, _Mode.Expression)));
      }
    }
  }, {
    key: "visitKeyedWrite",
    value: function visitKeyedWrite(ast, mode) {
      var obj = this._visit(ast.obj, _Mode.Expression);

      var key = this._visit(ast.key, _Mode.Expression);

      var value = this._visit(ast.value, _Mode.Expression);

      return convertToStatementIfNeeded(mode, obj.key(key).set(value));
    }
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(ast, mode) {
      throw new Error("Illegal State: literal arrays should have been converted into functions");
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(ast, mode) {
      throw new Error("Illegal State: literal maps should have been converted into functions");
    }
  }, {
    key: "visitLiteralPrimitive",
    value: function visitLiteralPrimitive(ast, mode) {
      // For literal values of null, undefined, true, or false allow type interference
      // to infer the type.
      var type = ast.value === null || ast.value === undefined || ast.value === true || ast.value === true ? INFERRED_TYPE : undefined;
      return convertToStatementIfNeeded(mode, literal(ast.value, type, this.convertSourceSpan(ast.span)));
    }
  }, {
    key: "_getLocal",
    value: function _getLocal(name) {
      return this._localResolver.getLocal(name);
    }
  }, {
    key: "visitMethodCall",
    value: function visitMethodCall(ast, mode) {
      if (ast.receiver instanceof ImplicitReceiver && ast.name == '$any') {
        var args = this.visitAll(ast.args, _Mode.Expression);

        if (args.length != 1) {
          throw new Error("Invalid call to $any, expected 1 argument but received ".concat(args.length || 'none'));
        }

        return args[0].cast(DYNAMIC_TYPE, this.convertSourceSpan(ast.span));
      }

      var leftMostSafe = this.leftMostSafeNode(ast);

      if (leftMostSafe) {
        return this.convertSafeAccess(ast, leftMostSafe, mode);
      } else {
        var _args = this.visitAll(ast.args, _Mode.Expression);

        var prevUsesImplicitReceiver = this.usesImplicitReceiver;
        var result = null;

        var receiver = this._visit(ast.receiver, _Mode.Expression);

        if (receiver === this._implicitReceiver) {
          var varExpr = this._getLocal(ast.name);

          if (varExpr) {
            // Restore the previous "usesImplicitReceiver" state since the implicit
            // receiver has been replaced with a resolved local expression.
            this.usesImplicitReceiver = prevUsesImplicitReceiver;
            result = varExpr.callFn(_args);
          }

          this.addImplicitReceiverAccess(ast.name);
        }

        if (result == null) {
          result = receiver.callMethod(ast.name, _args, this.convertSourceSpan(ast.span));
        }

        return convertToStatementIfNeeded(mode, result);
      }
    }
  }, {
    key: "visitPrefixNot",
    value: function visitPrefixNot(ast, mode) {
      return convertToStatementIfNeeded(mode, not(this._visit(ast.expression, _Mode.Expression)));
    }
  }, {
    key: "visitNonNullAssert",
    value: function visitNonNullAssert(ast, mode) {
      return convertToStatementIfNeeded(mode, assertNotNull(this._visit(ast.expression, _Mode.Expression)));
    }
  }, {
    key: "visitPropertyRead",
    value: function visitPropertyRead(ast, mode) {
      var leftMostSafe = this.leftMostSafeNode(ast);

      if (leftMostSafe) {
        return this.convertSafeAccess(ast, leftMostSafe, mode);
      } else {
        var result = null;
        var prevUsesImplicitReceiver = this.usesImplicitReceiver;

        var receiver = this._visit(ast.receiver, _Mode.Expression);

        if (receiver === this._implicitReceiver) {
          result = this._getLocal(ast.name);

          if (result) {
            // Restore the previous "usesImplicitReceiver" state since the implicit
            // receiver has been replaced with a resolved local expression.
            this.usesImplicitReceiver = prevUsesImplicitReceiver;
          }

          this.addImplicitReceiverAccess(ast.name);
        }

        if (result == null) {
          result = receiver.prop(ast.name);
        }

        return convertToStatementIfNeeded(mode, result);
      }
    }
  }, {
    key: "visitPropertyWrite",
    value: function visitPropertyWrite(ast, mode) {
      var receiver = this._visit(ast.receiver, _Mode.Expression);

      var prevUsesImplicitReceiver = this.usesImplicitReceiver;
      var varExpr = null;

      if (receiver === this._implicitReceiver) {
        var localExpr = this._getLocal(ast.name);

        if (localExpr) {
          if (localExpr instanceof ReadPropExpr) {
            // If the local variable is a property read expression, it's a reference
            // to a 'context.property' value and will be used as the target of the
            // write expression.
            varExpr = localExpr; // Restore the previous "usesImplicitReceiver" state since the implicit
            // receiver has been replaced with a resolved local expression.

            this.usesImplicitReceiver = prevUsesImplicitReceiver;
            this.addImplicitReceiverAccess(ast.name);
          } else {
            // Otherwise it's an error.
            var _receiver = ast.name;
            var value = ast.value instanceof PropertyRead ? ast.value.name : undefined;
            throw new Error("Cannot assign value \"".concat(value, "\" to template variable \"").concat(_receiver, "\". Template variables are read-only."));
          }
        }
      } // If no local expression could be produced, use the original receiver's
      // property as the target.


      if (varExpr === null) {
        varExpr = receiver.prop(ast.name);
      }

      return convertToStatementIfNeeded(mode, varExpr.set(this._visit(ast.value, _Mode.Expression)));
    }
  }, {
    key: "visitSafePropertyRead",
    value: function visitSafePropertyRead(ast, mode) {
      return this.convertSafeAccess(ast, this.leftMostSafeNode(ast), mode);
    }
  }, {
    key: "visitSafeMethodCall",
    value: function visitSafeMethodCall(ast, mode) {
      return this.convertSafeAccess(ast, this.leftMostSafeNode(ast), mode);
    }
  }, {
    key: "visitAll",
    value: function visitAll(asts, mode) {
      var _this112 = this;

      return asts.map(function (ast) {
        return _this112._visit(ast, mode);
      });
    }
  }, {
    key: "visitQuote",
    value: function visitQuote(ast, mode) {
      throw new Error("Quotes are not supported for evaluation!\n        Statement: ".concat(ast.uninterpretedExpression, " located at ").concat(ast.location));
    }
  }, {
    key: "_visit",
    value: function _visit(ast, mode) {
      var result = this._resultMap.get(ast);

      if (result) return result;
      return (this._nodeMap.get(ast) || ast).visit(this, mode);
    }
  }, {
    key: "convertSafeAccess",
    value: function convertSafeAccess(ast, leftMostSafe, mode) {
      // If the expression contains a safe access node on the left it needs to be converted to
      // an expression that guards the access to the member by checking the receiver for blank. As
      // execution proceeds from left to right, the left most part of the expression must be guarded
      // first but, because member access is left associative, the right side of the expression is at
      // the top of the AST. The desired result requires lifting a copy of the left part of the
      // expression up to test it for blank before generating the unguarded version.
      // Consider, for example the following expression: a?.b.c?.d.e
      // This results in the ast:
      //         .
      //        / \
      //       ?.   e
      //      /  \
      //     .    d
      //    / \
      //   ?.  c
      //  /  \
      // a    b
      // The following tree should be generated:
      //
      //        /---- ? ----\
      //       /      |      \
      //     a   /--- ? ---\  null
      //        /     |     \
      //       .      .     null
      //      / \    / \
      //     .  c   .   e
      //    / \    / \
      //   a   b  .   d
      //         / \
      //        .   c
      //       / \
      //      a   b
      //
      // Notice that the first guard condition is the left hand of the left most safe access node
      // which comes in as leftMostSafe to this routine.
      var guardedExpression = this._visit(leftMostSafe.receiver, _Mode.Expression);

      var temporary = undefined;

      if (this.needsTemporary(leftMostSafe.receiver)) {
        // If the expression has method calls or pipes then we need to save the result into a
        // temporary variable to avoid calling stateful or impure code more than once.
        temporary = this.allocateTemporary(); // Preserve the result in the temporary variable

        guardedExpression = temporary.set(guardedExpression); // Ensure all further references to the guarded expression refer to the temporary instead.

        this._resultMap.set(leftMostSafe.receiver, temporary);
      }

      var condition = guardedExpression.isBlank(); // Convert the ast to an unguarded access to the receiver's member. The map will substitute
      // leftMostNode with its unguarded version in the call to `this.visit()`.

      if (leftMostSafe instanceof SafeMethodCall) {
        this._nodeMap.set(leftMostSafe, new MethodCall(leftMostSafe.span, leftMostSafe.sourceSpan, leftMostSafe.nameSpan, leftMostSafe.receiver, leftMostSafe.name, leftMostSafe.args));
      } else {
        this._nodeMap.set(leftMostSafe, new PropertyRead(leftMostSafe.span, leftMostSafe.sourceSpan, leftMostSafe.nameSpan, leftMostSafe.receiver, leftMostSafe.name));
      } // Recursively convert the node now without the guarded member access.


      var access = this._visit(ast, _Mode.Expression); // Remove the mapping. This is not strictly required as the converter only traverses each node
      // once but is safer if the conversion is changed to traverse the nodes more than once.


      this._nodeMap.delete(leftMostSafe); // If we allocated a temporary, release it.


      if (temporary) {
        this.releaseTemporary(temporary);
      } // Produce the conditional


      return convertToStatementIfNeeded(mode, condition.conditional(literal(null), access));
    } // Given an expression of the form a?.b.c?.d.e then the left most safe node is
    // the (a?.b). The . and ?. are left associative thus can be rewritten as:
    // ((((a?.c).b).c)?.d).e. This returns the most deeply nested safe read or
    // safe method call as this needs to be transformed initially to:
    //   a == null ? null : a.c.b.c?.d.e
    // then to:
    //   a == null ? null : a.b.c == null ? null : a.b.c.d.e

  }, {
    key: "leftMostSafeNode",
    value: function leftMostSafeNode(ast) {
      var _this113 = this;

      var visit = function visit(visitor, ast) {
        return (_this113._nodeMap.get(ast) || ast).visit(visitor);
      };

      return ast.visit({
        visitUnary: function visitUnary(ast) {
          return null;
        },
        visitBinary: function visitBinary(ast) {
          return null;
        },
        visitChain: function visitChain(ast) {
          return null;
        },
        visitConditional: function visitConditional(ast) {
          return null;
        },
        visitFunctionCall: function visitFunctionCall(ast) {
          return null;
        },
        visitImplicitReceiver: function visitImplicitReceiver(ast) {
          return null;
        },
        visitInterpolation: function visitInterpolation(ast) {
          return null;
        },
        visitKeyedRead: function visitKeyedRead(ast) {
          return visit(this, ast.obj);
        },
        visitKeyedWrite: function visitKeyedWrite(ast) {
          return null;
        },
        visitLiteralArray: function visitLiteralArray(ast) {
          return null;
        },
        visitLiteralMap: function visitLiteralMap(ast) {
          return null;
        },
        visitLiteralPrimitive: function visitLiteralPrimitive(ast) {
          return null;
        },
        visitMethodCall: function visitMethodCall(ast) {
          return visit(this, ast.receiver);
        },
        visitPipe: function visitPipe(ast) {
          return null;
        },
        visitPrefixNot: function visitPrefixNot(ast) {
          return null;
        },
        visitNonNullAssert: function visitNonNullAssert(ast) {
          return null;
        },
        visitPropertyRead: function visitPropertyRead(ast) {
          return visit(this, ast.receiver);
        },
        visitPropertyWrite: function visitPropertyWrite(ast) {
          return null;
        },
        visitQuote: function visitQuote(ast) {
          return null;
        },
        visitSafeMethodCall: function visitSafeMethodCall(ast) {
          return visit(this, ast.receiver) || ast;
        },
        visitSafePropertyRead: function visitSafePropertyRead(ast) {
          return visit(this, ast.receiver) || ast;
        }
      });
    } // Returns true of the AST includes a method or a pipe indicating that, if the
    // expression is used as the target of a safe property or method access then
    // the expression should be stored into a temporary variable.

  }, {
    key: "needsTemporary",
    value: function needsTemporary(ast) {
      var _this114 = this;

      var visit = function visit(visitor, ast) {
        return ast && (_this114._nodeMap.get(ast) || ast).visit(visitor);
      };

      var visitSome = function visitSome(visitor, ast) {
        return ast.some(function (ast) {
          return visit(visitor, ast);
        });
      };

      return ast.visit({
        visitUnary: function visitUnary(ast) {
          return visit(this, ast.expr);
        },
        visitBinary: function visitBinary(ast) {
          return visit(this, ast.left) || visit(this, ast.right);
        },
        visitChain: function visitChain(ast) {
          return false;
        },
        visitConditional: function visitConditional(ast) {
          return visit(this, ast.condition) || visit(this, ast.trueExp) || visit(this, ast.falseExp);
        },
        visitFunctionCall: function visitFunctionCall(ast) {
          return true;
        },
        visitImplicitReceiver: function visitImplicitReceiver(ast) {
          return false;
        },
        visitInterpolation: function visitInterpolation(ast) {
          return visitSome(this, ast.expressions);
        },
        visitKeyedRead: function visitKeyedRead(ast) {
          return false;
        },
        visitKeyedWrite: function visitKeyedWrite(ast) {
          return false;
        },
        visitLiteralArray: function visitLiteralArray(ast) {
          return true;
        },
        visitLiteralMap: function visitLiteralMap(ast) {
          return true;
        },
        visitLiteralPrimitive: function visitLiteralPrimitive(ast) {
          return false;
        },
        visitMethodCall: function visitMethodCall(ast) {
          return true;
        },
        visitPipe: function visitPipe(ast) {
          return true;
        },
        visitPrefixNot: function visitPrefixNot(ast) {
          return visit(this, ast.expression);
        },
        visitNonNullAssert: function visitNonNullAssert(ast) {
          return visit(this, ast.expression);
        },
        visitPropertyRead: function visitPropertyRead(ast) {
          return false;
        },
        visitPropertyWrite: function visitPropertyWrite(ast) {
          return false;
        },
        visitQuote: function visitQuote(ast) {
          return false;
        },
        visitSafeMethodCall: function visitSafeMethodCall(ast) {
          return true;
        },
        visitSafePropertyRead: function visitSafePropertyRead(ast) {
          return false;
        }
      });
    }
  }, {
    key: "allocateTemporary",
    value: function allocateTemporary() {
      var tempNumber = this._currentTemporary++;
      this.temporaryCount = Math.max(this._currentTemporary, this.temporaryCount);
      return new ReadVarExpr(temporaryName(this.bindingId, tempNumber));
    }
  }, {
    key: "releaseTemporary",
    value: function releaseTemporary(temporary) {
      this._currentTemporary--;

      if (temporary.name != temporaryName(this.bindingId, this._currentTemporary)) {
        throw new Error("Temporary ".concat(temporary.name, " released out of order"));
      }
    }
    /**
     * Creates an absolute `ParseSourceSpan` from the relative `ParseSpan`.
     *
     * `ParseSpan` objects are relative to the start of the expression.
     * This method converts these to full `ParseSourceSpan` objects that
     * show where the span is within the overall source file.
     *
     * @param span the relative span to convert.
     * @returns a `ParseSourceSpan` for the given span or null if no
     * `baseSourceSpan` was provided to this class.
     */

  }, {
    key: "convertSourceSpan",
    value: function convertSourceSpan(span) {
      if (this.baseSourceSpan) {
        var start = this.baseSourceSpan.start.moveBy(span.start);
        var end = this.baseSourceSpan.start.moveBy(span.end);
        return new ParseSourceSpan(start, end);
      } else {
        return null;
      }
    }
    /** Adds the name of an AST to the list of implicit receiver accesses. */

  }, {
    key: "addImplicitReceiverAccess",
    value: function addImplicitReceiverAccess(name) {
      if (this.implicitReceiverAccesses) {
        this.implicitReceiverAccesses.add(name);
      }
    }
  }]);

  return _AstToIrVisitor;
}();

function flattenStatements(arg, output) {
  if (Array.isArray(arg)) {
    arg.forEach(function (entry) {
      return flattenStatements(entry, output);
    });
  } else {
    output.push(arg);
  }
}

var DefaultLocalResolver = /*#__PURE__*/function () {
  function DefaultLocalResolver() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DefaultLocalResolver);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DefaultLocalResolver, [{
    key: "notifyImplicitReceiverUse",
    value: function notifyImplicitReceiverUse() {}
  }, {
    key: "getLocal",
    value: function getLocal(name) {
      if (name === EventHandlerVars.event.name) {
        return EventHandlerVars.event;
      }

      return null;
    }
  }]);

  return DefaultLocalResolver;
}();

function createCurrValueExpr(bindingId) {
  return variable("currVal_".concat(bindingId)); // fix syntax highlighting: `
}

function createPreventDefaultVar(bindingId) {
  return variable("pd_".concat(bindingId));
}

function convertStmtIntoExpression(stmt) {
  if (stmt instanceof ExpressionStatement) {
    return stmt.expr;
  } else if (stmt instanceof ReturnStatement) {
    return stmt.value;
  }

  return null;
}

var BuiltinFunctionCall = /*#__PURE__*/function (_FunctionCall) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(BuiltinFunctionCall, _FunctionCall);

  var _super78 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(BuiltinFunctionCall);

  function BuiltinFunctionCall(span, sourceSpan, args, converter) {
    var _this115;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BuiltinFunctionCall);

    _this115 = _super78.call(this, span, sourceSpan, null, args);
    _this115.args = args;
    _this115.converter = converter;
    return _this115;
  }

  return BuiltinFunctionCall;
}(FunctionCall);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This file is a port of shadowCSS from webcomponents.js to TypeScript.
 *
 * Please make sure to keep to edits in sync with the source file.
 *
 * Source:
 * https://github.com/webcomponents/webcomponentsjs/blob/4efecd7e0e/src/ShadowCSS/ShadowCSS.js
 *
 * The original file level comment is reproduced below
 */

/*
  This is a limited shim for ShadowDOM css styling.
  https://dvcs.w3.org/hg/webcomponents/raw-file/tip/spec/shadow/index.html#styles

  The intention here is to support only the styling features which can be
  relatively simply implemented. The goal is to allow users to avoid the
  most obvious pitfalls and do so without compromising performance significantly.
  For ShadowDOM styling that's not covered here, a set of best practices
  can be provided that should allow users to accomplish more complex styling.

  The following is a list of specific ShadowDOM styling features and a brief
  discussion of the approach used to shim.

  Shimmed features:

  * :host, :host-context: ShadowDOM allows styling of the shadowRoot's host
  element using the :host rule. To shim this feature, the :host styles are
  reformatted and prefixed with a given scope name and promoted to a
  document level stylesheet.
  For example, given a scope name of .foo, a rule like this:

    :host {
        background: red;
      }
    }

  becomes:

    .foo {
      background: red;
    }

  * encapsulation: Styles defined within ShadowDOM, apply only to
  dom inside the ShadowDOM. Polymer uses one of two techniques to implement
  this feature.

  By default, rules are prefixed with the host element tag name
  as a descendant selector. This ensures styling does not leak out of the 'top'
  of the element's ShadowDOM. For example,

  div {
      font-weight: bold;
    }

  becomes:

  x-foo div {
      font-weight: bold;
    }

  becomes:


  Alternatively, if WebComponents.ShadowCSS.strictStyling is set to true then
  selectors are scoped by adding an attribute selector suffix to each
  simple selector that contains the host element tag name. Each element
  in the element's ShadowDOM template is also given the scope attribute.
  Thus, these rules match only elements that have the scope attribute.
  For example, given a scope name of x-foo, a rule like this:

    div {
      font-weight: bold;
    }

  becomes:

    div[x-foo] {
      font-weight: bold;
    }

  Note that elements that are dynamically added to a scope must have the scope
  selector added to them manually.

  * upper/lower bound encapsulation: Styles which are defined outside a
  shadowRoot should not cross the ShadowDOM boundary and should not apply
  inside a shadowRoot.

  This styling behavior is not emulated. Some possible ways to do this that
  were rejected due to complexity and/or performance concerns include: (1) reset
  every possible property for every possible selector for a given scope name;
  (2) re-implement css in javascript.

  As an alternative, users should make sure to use selectors
  specific to the scope in which they are working.

  * ::distributed: This behavior is not emulated. It's often not necessary
  to style the contents of a specific insertion point and instead, descendants
  of the host element can be styled selectively. Users can also create an
  extra node around an insertion point and style that node's contents
  via descendent selectors. For example, with a shadowRoot like this:

    <style>
      ::content(div) {
        background: red;
      }
    </style>
    <content></content>

  could become:

    <style>
      / *@polyfill .content-container div * /
      ::content(div) {
        background: red;
      }
    </style>
    <div class="content-container">
      <content></content>
    </div>

  Note the use of @polyfill in the comment above a ShadowDOM specific style
  declaration. This is a directive to the styling shim to use the selector
  in comments in lieu of the next selector when running under polyfill.
*/


var ShadowCss = /*#__PURE__*/function () {
  function ShadowCss() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ShadowCss);

    this.strictStyling = true;
  }
  /*
   * Shim some cssText with the given selector. Returns cssText that can
   * be included in the document via WebComponents.ShadowCSS.addCssToDocument(css).
   *
   * When strictStyling is true:
   * - selector is the attribute added to all elements inside the host,
   * - hostSelector is the attribute added to the host itself.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ShadowCss, [{
    key: "shimCssText",
    value: function shimCssText(cssText, selector) {
      var hostSelector = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
      var commentsWithHash = extractCommentsWithHash(cssText);
      cssText = stripComments(cssText);
      cssText = this._insertDirectives(cssText);

      var scopedCssText = this._scopeCssText(cssText, selector, hostSelector);

      return [scopedCssText].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(commentsWithHash)).join('\n');
    }
  }, {
    key: "_insertDirectives",
    value: function _insertDirectives(cssText) {
      cssText = this._insertPolyfillDirectivesInCssText(cssText);
      return this._insertPolyfillRulesInCssText(cssText);
    }
    /*
     * Process styles to convert native ShadowDOM rules that will trip
     * up the css parser; we rely on decorating the stylesheet with inert rules.
     *
     * For example, we convert this rule:
     *
     * polyfill-next-selector { content: ':host menu-item'; }
     * ::content menu-item {
     *
     * to this:
     *
     * scopeName menu-item {
     *
     **/

  }, {
    key: "_insertPolyfillDirectivesInCssText",
    value: function _insertPolyfillDirectivesInCssText(cssText) {
      // Difference with webcomponents.js: does not handle comments
      return cssText.replace(_cssContentNextSelectorRe, function () {
        return (arguments.length <= 2 ? undefined : arguments[2]) + '{';
      });
    }
    /*
     * Process styles to add rules which will only apply under the polyfill
     *
     * For example, we convert this rule:
     *
     * polyfill-rule {
     *   content: ':host menu-item';
     * ...
     * }
     *
     * to this:
     *
     * scopeName menu-item {...}
     *
     **/

  }, {
    key: "_insertPolyfillRulesInCssText",
    value: function _insertPolyfillRulesInCssText(cssText) {
      // Difference with webcomponents.js: does not handle comments
      return cssText.replace(_cssContentRuleRe, function () {
        for (var _len3 = arguments.length, m = new Array(_len3), _key4 = 0; _key4 < _len3; _key4++) {
          m[_key4] = arguments[_key4];
        }

        var rule = m[0].replace(m[1], '').replace(m[2], '');
        return m[4] + rule;
      });
    }
    /* Ensure styles are scoped. Pseudo-scoping takes a rule like:
     *
     *  .foo {... }
     *
     *  and converts this to
     *
     *  scopeName .foo { ... }
     */

  }, {
    key: "_scopeCssText",
    value: function _scopeCssText(cssText, scopeSelector, hostSelector) {
      var unscopedRules = this._extractUnscopedRulesFromCssText(cssText); // replace :host and :host-context -shadowcsshost and -shadowcsshost respectively


      cssText = this._insertPolyfillHostInCssText(cssText);
      cssText = this._convertColonHost(cssText);
      cssText = this._convertColonHostContext(cssText);
      cssText = this._convertShadowDOMSelectors(cssText);

      if (scopeSelector) {
        cssText = this._scopeSelectors(cssText, scopeSelector, hostSelector);
      }

      cssText = cssText + '\n' + unscopedRules;
      return cssText.trim();
    }
    /*
     * Process styles to add rules which will only apply under the polyfill
     * and do not process via CSSOM. (CSSOM is destructive to rules on rare
     * occasions, e.g. -webkit-calc on Safari.)
     * For example, we convert this rule:
     *
     * @polyfill-unscoped-rule {
     *   content: 'menu-item';
     * ... }
     *
     * to this:
     *
     * menu-item {...}
     *
     **/

  }, {
    key: "_extractUnscopedRulesFromCssText",
    value: function _extractUnscopedRulesFromCssText(cssText) {
      // Difference with webcomponents.js: does not handle comments
      var r = '';
      var m;
      _cssContentUnscopedRuleRe.lastIndex = 0;

      while ((m = _cssContentUnscopedRuleRe.exec(cssText)) !== null) {
        var rule = m[0].replace(m[2], '').replace(m[1], m[4]);
        r += rule + '\n\n';
      }

      return r;
    }
    /*
     * convert a rule like :host(.foo) > .bar { }
     *
     * to
     *
     * .foo<scopeName> > .bar
     */

  }, {
    key: "_convertColonHost",
    value: function _convertColonHost(cssText) {
      return this._convertColonRule(cssText, _cssColonHostRe, this._colonHostPartReplacer);
    }
    /*
     * convert a rule like :host-context(.foo) > .bar { }
     *
     * to
     *
     * .foo<scopeName> > .bar, .foo scopeName > .bar { }
     *
     * and
     *
     * :host-context(.foo:host) .bar { ... }
     *
     * to
     *
     * .foo<scopeName> .bar { ... }
     */

  }, {
    key: "_convertColonHostContext",
    value: function _convertColonHostContext(cssText) {
      return this._convertColonRule(cssText, _cssColonHostContextRe, this._colonHostContextPartReplacer);
    }
  }, {
    key: "_convertColonRule",
    value: function _convertColonRule(cssText, regExp, partReplacer) {
      // m[1] = :host(-context), m[2] = contents of (), m[3] rest of rule
      return cssText.replace(regExp, function () {
        for (var _len4 = arguments.length, m = new Array(_len4), _key5 = 0; _key5 < _len4; _key5++) {
          m[_key5] = arguments[_key5];
        }

        if (m[2]) {
          var parts = m[2].split(',');
          var r = [];

          for (var i = 0; i < parts.length; i++) {
            var p = parts[i].trim();
            if (!p) break;
            r.push(partReplacer(_polyfillHostNoCombinator, p, m[3]));
          }

          return r.join(',');
        } else {
          return _polyfillHostNoCombinator + m[3];
        }
      });
    }
  }, {
    key: "_colonHostContextPartReplacer",
    value: function _colonHostContextPartReplacer(host, part, suffix) {
      if (part.indexOf(_polyfillHost) > -1) {
        return this._colonHostPartReplacer(host, part, suffix);
      } else {
        return host + part + suffix + ', ' + part + ' ' + host + suffix;
      }
    }
  }, {
    key: "_colonHostPartReplacer",
    value: function _colonHostPartReplacer(host, part, suffix) {
      return host + part.replace(_polyfillHost, '') + suffix;
    }
    /*
     * Convert combinators like ::shadow and pseudo-elements like ::content
     * by replacing with space.
     */

  }, {
    key: "_convertShadowDOMSelectors",
    value: function _convertShadowDOMSelectors(cssText) {
      return _shadowDOMSelectorsRe.reduce(function (result, pattern) {
        return result.replace(pattern, ' ');
      }, cssText);
    } // change a selector like 'div' to 'name div'

  }, {
    key: "_scopeSelectors",
    value: function _scopeSelectors(cssText, scopeSelector, hostSelector) {
      var _this116 = this;

      return processRules(cssText, function (rule) {
        var selector = rule.selector;
        var content = rule.content;

        if (rule.selector[0] != '@') {
          selector = _this116._scopeSelector(rule.selector, scopeSelector, hostSelector, _this116.strictStyling);
        } else if (rule.selector.startsWith('@media') || rule.selector.startsWith('@supports') || rule.selector.startsWith('@page') || rule.selector.startsWith('@document')) {
          content = _this116._scopeSelectors(rule.content, scopeSelector, hostSelector);
        }

        return new CssRule(selector, content);
      });
    }
  }, {
    key: "_scopeSelector",
    value: function _scopeSelector(selector, scopeSelector, hostSelector, strict) {
      var _this117 = this;

      return selector.split(',').map(function (part) {
        return part.trim().split(_shadowDeepSelectors);
      }).map(function (deepParts) {
        var _deepParts = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toArray__WEBPACK_IMPORTED_MODULE_2__["default"])(deepParts),
            shallowPart = _deepParts[0],
            otherParts = _deepParts.slice(1);

        var applyScope = function applyScope(shallowPart) {
          if (_this117._selectorNeedsScoping(shallowPart, scopeSelector)) {
            return strict ? _this117._applyStrictSelectorScope(shallowPart, scopeSelector, hostSelector) : _this117._applySelectorScope(shallowPart, scopeSelector, hostSelector);
          } else {
            return shallowPart;
          }
        };

        return [applyScope(shallowPart)].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(otherParts)).join(' ');
      }).join(', ');
    }
  }, {
    key: "_selectorNeedsScoping",
    value: function _selectorNeedsScoping(selector, scopeSelector) {
      var re = this._makeScopeMatcher(scopeSelector);

      return !re.test(selector);
    }
  }, {
    key: "_makeScopeMatcher",
    value: function _makeScopeMatcher(scopeSelector) {
      var lre = /\[/g;
      var rre = /\]/g;
      scopeSelector = scopeSelector.replace(lre, '\\[').replace(rre, '\\]');
      return new RegExp('^(' + scopeSelector + ')' + _selectorReSuffix, 'm');
    }
  }, {
    key: "_applySelectorScope",
    value: function _applySelectorScope(selector, scopeSelector, hostSelector) {
      // Difference from webcomponents.js: scopeSelector could not be an array
      return this._applySimpleSelectorScope(selector, scopeSelector, hostSelector);
    } // scope via name and [is=name]

  }, {
    key: "_applySimpleSelectorScope",
    value: function _applySimpleSelectorScope(selector, scopeSelector, hostSelector) {
      // In Android browser, the lastIndex is not reset when the regex is used in String.replace()
      _polyfillHostRe.lastIndex = 0;

      if (_polyfillHostRe.test(selector)) {
        var replaceBy = this.strictStyling ? "[".concat(hostSelector, "]") : scopeSelector;
        return selector.replace(_polyfillHostNoCombinatorRe, function (hnc, selector) {
          return selector.replace(/([^:]*)(:*)(.*)/, function (_, before, colon, after) {
            return before + replaceBy + colon + after;
          });
        }).replace(_polyfillHostRe, replaceBy + ' ');
      }

      return scopeSelector + ' ' + selector;
    } // return a selector with [name] suffix on each simple selector
    // e.g. .foo.bar > .zot becomes .foo[name].bar[name] > .zot[name]  /** @internal */

  }, {
    key: "_applyStrictSelectorScope",
    value: function _applyStrictSelectorScope(selector, scopeSelector, hostSelector) {
      var _this118 = this;

      var isRe = /\[is=([^\]]*)\]/g;
      scopeSelector = scopeSelector.replace(isRe, function (_) {
        return arguments.length <= 1 ? undefined : arguments[1];
      });
      var attrName = '[' + scopeSelector + ']';

      var _scopeSelectorPart = function _scopeSelectorPart(p) {
        var scopedP = p.trim();

        if (!scopedP) {
          return '';
        }

        if (p.indexOf(_polyfillHostNoCombinator) > -1) {
          scopedP = _this118._applySimpleSelectorScope(p, scopeSelector, hostSelector);
        } else {
          // remove :host since it should be unnecessary
          var t = p.replace(_polyfillHostRe, '');

          if (t.length > 0) {
            var matches = t.match(/([^:]*)(:*)(.*)/);

            if (matches) {
              scopedP = matches[1] + attrName + matches[2] + matches[3];
            }
          }
        }

        return scopedP;
      };

      var safeContent = new SafeSelector(selector);
      selector = safeContent.content();
      var scopedSelector = '';
      var startIndex = 0;
      var res;
      var sep = /( |>|\+|~(?!=))\s*/g; // If a selector appears before :host it should not be shimmed as it
      // matches on ancestor elements and not on elements in the host's shadow
      // `:host-context(div)` is transformed to
      // `-shadowcsshost-no-combinatordiv, div -shadowcsshost-no-combinator`
      // the `div` is not part of the component in the 2nd selectors and should not be scoped.
      // Historically `component-tag:host` was matching the component so we also want to preserve
      // this behavior to avoid breaking legacy apps (it should not match).
      // The behavior should be:
      // - `tag:host` -> `tag[h]` (this is to avoid breaking legacy apps, should not match anything)
      // - `tag :host` -> `tag [h]` (`tag` is not scoped because it's considered part of a
      //   `:host-context(tag)`)

      var hasHost = selector.indexOf(_polyfillHostNoCombinator) > -1; // Only scope parts after the first `-shadowcsshost-no-combinator` when it is present

      var shouldScope = !hasHost;

      while ((res = sep.exec(selector)) !== null) {
        var separator = res[1];

        var _part = selector.slice(startIndex, res.index).trim();

        shouldScope = shouldScope || _part.indexOf(_polyfillHostNoCombinator) > -1;
        var scopedPart = shouldScope ? _scopeSelectorPart(_part) : _part;
        scopedSelector += "".concat(scopedPart, " ").concat(separator, " ");
        startIndex = sep.lastIndex;
      }

      var part = selector.substring(startIndex);
      shouldScope = shouldScope || part.indexOf(_polyfillHostNoCombinator) > -1;
      scopedSelector += shouldScope ? _scopeSelectorPart(part) : part; // replace the placeholders with their original values

      return safeContent.restore(scopedSelector);
    }
  }, {
    key: "_insertPolyfillHostInCssText",
    value: function _insertPolyfillHostInCssText(selector) {
      return selector.replace(_colonHostContextRe, _polyfillHostContext).replace(_colonHostRe, _polyfillHost);
    }
  }]);

  return ShadowCss;
}();

var SafeSelector = /*#__PURE__*/function () {
  function SafeSelector(selector) {
    var _this119 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SafeSelector);

    this.placeholders = [];
    this.index = 0; // Replaces attribute selectors with placeholders.
    // The WS in [attr="va lue"] would otherwise be interpreted as a selector separator.

    selector = selector.replace(/(\[[^\]]*\])/g, function (_, keep) {
      var replaceBy = "__ph-".concat(_this119.index, "__");

      _this119.placeholders.push(keep);

      _this119.index++;
      return replaceBy;
    }); // Replaces the expression in `:nth-child(2n + 1)` with a placeholder.
    // WS and "+" would otherwise be interpreted as selector separators.

    this._content = selector.replace(/(:nth-[-\w]+)(\([^)]+\))/g, function (_, pseudo, exp) {
      var replaceBy = "__ph-".concat(_this119.index, "__");

      _this119.placeholders.push(exp);

      _this119.index++;
      return pseudo + replaceBy;
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SafeSelector, [{
    key: "restore",
    value: function restore(content) {
      var _this120 = this;

      return content.replace(/__ph-(\d+)__/g, function (ph, index) {
        return _this120.placeholders[+index];
      });
    }
  }, {
    key: "content",
    value: function content() {
      return this._content;
    }
  }]);

  return SafeSelector;
}();

var _cssContentNextSelectorRe = /polyfill-next-selector[^}]*content:[\s]*?(['"])(.*?)\1[;\s]*}([^{]*?){/gim;
var _cssContentRuleRe = /(polyfill-rule)[^}]*(content:[\s]*(['"])(.*?)\3)[;\s]*[^}]*}/gim;
var _cssContentUnscopedRuleRe = /(polyfill-unscoped-rule)[^}]*(content:[\s]*(['"])(.*?)\3)[;\s]*[^}]*}/gim;
var _polyfillHost = '-shadowcsshost'; // note: :host-context pre-processed to -shadowcsshostcontext.

var _polyfillHostContext = '-shadowcsscontext';

var _parenSuffix = ')(?:\\((' + '(?:\\([^)(]*\\)|[^)(]*)+?' + ')\\))?([^,{]*)';

var _cssColonHostRe = new RegExp('(' + _polyfillHost + _parenSuffix, 'gim');

var _cssColonHostContextRe = new RegExp('(' + _polyfillHostContext + _parenSuffix, 'gim');

var _polyfillHostNoCombinator = _polyfillHost + '-no-combinator';

var _polyfillHostNoCombinatorRe = /-shadowcsshost-no-combinator([^\s]*)/;
var _shadowDOMSelectorsRe = [/::shadow/g, /::content/g, // Deprecated selectors
/\/shadow-deep\//g, /\/shadow\//g]; // The deep combinator is deprecated in the CSS spec
// Support for `>>>`, `deep`, `::ng-deep` is then also deprecated and will be removed in the future.
// see https://github.com/angular/angular/pull/17677

var _shadowDeepSelectors = /(?:>>>)|(?:\/deep\/)|(?:::ng-deep)/g;
var _selectorReSuffix = '([>\\s~+\[.,{:][\\s\\S]*)?$';
var _polyfillHostRe = /-shadowcsshost/gim;
var _colonHostRe = /:host/gim;
var _colonHostContextRe = /:host-context/gim;
var _commentRe = /\/\*\s*[\s\S]*?\*\//g;

function stripComments(input) {
  return input.replace(_commentRe, '');
}

var _commentWithHashRe = /\/\*\s*#\s*source(Mapping)?URL=[\s\S]+?\*\//g;

function extractCommentsWithHash(input) {
  return input.match(_commentWithHashRe) || [];
}

var _ruleRe = /(\s*)([^;\{\}]+?)(\s*)((?:{%BLOCK%}?\s*;?)|(?:\s*;))/g;
var _curlyRe = /([{}])/g;
var OPEN_CURLY = '{';
var CLOSE_CURLY = '}';
var BLOCK_PLACEHOLDER = '%BLOCK%';

var CssRule = function CssRule(selector, content) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CssRule);

  this.selector = selector;
  this.content = content;
};

function processRules(input, ruleCallback) {
  var inputWithEscapedBlocks = escapeBlocks(input);
  var nextBlockIndex = 0;
  return inputWithEscapedBlocks.escapedString.replace(_ruleRe, function () {
    var selector = arguments.length <= 2 ? undefined : arguments[2];
    var content = '';
    var suffix = arguments.length <= 4 ? undefined : arguments[4];
    var contentPrefix = '';

    if (suffix && suffix.startsWith('{' + BLOCK_PLACEHOLDER)) {
      content = inputWithEscapedBlocks.blocks[nextBlockIndex++];
      suffix = suffix.substring(BLOCK_PLACEHOLDER.length + 1);
      contentPrefix = '{';
    }

    var rule = ruleCallback(new CssRule(selector, content));
    return "".concat(arguments.length <= 1 ? undefined : arguments[1]).concat(rule.selector).concat(arguments.length <= 3 ? undefined : arguments[3]).concat(contentPrefix).concat(rule.content).concat(suffix);
  });
}

var StringWithEscapedBlocks = function StringWithEscapedBlocks(escapedString, blocks) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StringWithEscapedBlocks);

  this.escapedString = escapedString;
  this.blocks = blocks;
};

function escapeBlocks(input) {
  var inputParts = input.split(_curlyRe);
  var resultParts = [];
  var escapedBlocks = [];
  var bracketCount = 0;
  var currentBlockParts = [];

  for (var partIndex = 0; partIndex < inputParts.length; partIndex++) {
    var part = inputParts[partIndex];

    if (part == CLOSE_CURLY) {
      bracketCount--;
    }

    if (bracketCount > 0) {
      currentBlockParts.push(part);
    } else {
      if (currentBlockParts.length > 0) {
        escapedBlocks.push(currentBlockParts.join(''));
        resultParts.push(BLOCK_PLACEHOLDER);
        currentBlockParts = [];
      }

      resultParts.push(part);
    }

    if (part == OPEN_CURLY) {
      bracketCount++;
    }
  }

  if (currentBlockParts.length > 0) {
    escapedBlocks.push(currentBlockParts.join(''));
    resultParts.push(BLOCK_PLACEHOLDER);
  }

  return new StringWithEscapedBlocks(resultParts.join(''), escapedBlocks);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var COMPONENT_VARIABLE = '%COMP%';
var HOST_ATTR = "_nghost-".concat(COMPONENT_VARIABLE);
var CONTENT_ATTR = "_ngcontent-".concat(COMPONENT_VARIABLE);

var StylesCompileDependency = function StylesCompileDependency(name, moduleUrl, setValue) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StylesCompileDependency);

  this.name = name;
  this.moduleUrl = moduleUrl;
  this.setValue = setValue;
};

var CompiledStylesheet = function CompiledStylesheet(outputCtx, stylesVar, dependencies, isShimmed, meta) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompiledStylesheet);

  this.outputCtx = outputCtx;
  this.stylesVar = stylesVar;
  this.dependencies = dependencies;
  this.isShimmed = isShimmed;
  this.meta = meta;
};

var StyleCompiler = /*#__PURE__*/function () {
  function StyleCompiler(_urlResolver) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StyleCompiler);

    this._urlResolver = _urlResolver;
    this._shadowCss = new ShadowCss();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StyleCompiler, [{
    key: "compileComponent",
    value: function compileComponent(outputCtx, comp) {
      var template = comp.template;
      return this._compileStyles(outputCtx, comp, new CompileStylesheetMetadata({
        styles: template.styles,
        styleUrls: template.styleUrls,
        moduleUrl: identifierModuleUrl(comp.type)
      }), this.needsStyleShim(comp), true);
    }
  }, {
    key: "compileStyles",
    value: function compileStyles(outputCtx, comp, stylesheet) {
      var shim = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : this.needsStyleShim(comp);
      return this._compileStyles(outputCtx, comp, stylesheet, shim, false);
    }
  }, {
    key: "needsStyleShim",
    value: function needsStyleShim(comp) {
      return comp.template.encapsulation === ViewEncapsulation.Emulated;
    }
  }, {
    key: "_compileStyles",
    value: function _compileStyles(outputCtx, comp, stylesheet, shim, isComponentStylesheet) {
      var _this121 = this;

      var styleExpressions = stylesheet.styles.map(function (plainStyle) {
        return literal(_this121._shimIfNeeded(plainStyle, shim));
      });
      var dependencies = [];
      stylesheet.styleUrls.forEach(function (styleUrl) {
        var exprIndex = styleExpressions.length; // Note: This placeholder will be filled later.

        styleExpressions.push(null);
        dependencies.push(new StylesCompileDependency(getStylesVarName(null), styleUrl, function (value) {
          return styleExpressions[exprIndex] = outputCtx.importExpr(value);
        }));
      }); // styles variable contains plain strings and arrays of other styles arrays (recursive),
      // so we set its type to dynamic.

      var stylesVar = getStylesVarName(isComponentStylesheet ? comp : null);
      var stmt = variable(stylesVar).set(literalArr(styleExpressions, new ArrayType(DYNAMIC_TYPE, [TypeModifier.Const]))).toDeclStmt(null, isComponentStylesheet ? [StmtModifier.Final] : [StmtModifier.Final, StmtModifier.Exported]);
      outputCtx.statements.push(stmt);
      return new CompiledStylesheet(outputCtx, stylesVar, dependencies, shim, stylesheet);
    }
  }, {
    key: "_shimIfNeeded",
    value: function _shimIfNeeded(style, shim) {
      return shim ? this._shadowCss.shimCssText(style, CONTENT_ATTR, HOST_ATTR) : style;
    }
  }]);

  return StyleCompiler;
}();

function getStylesVarName(component) {
  var result = "styles";

  if (component) {
    result += "_".concat(identifierName(component.type));
  }

  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A path is an ordered set of elements. Typically a path is to  a
 * particular offset in a source file. The head of the list is the top
 * most node. The tail is the node that contains the offset directly.
 *
 * For example, the expression `a + b + c` might have an ast that looks
 * like:
 *     +
 *    / \
 *   a   +
 *      / \
 *     b   c
 *
 * The path to the node at offset 9 would be `['+' at 1-10, '+' at 7-10,
 * 'c' at 9-10]` and the path the node at offset 1 would be
 * `['+' at 1-10, 'a' at 1-2]`.
 */


var AstPath = /*#__PURE__*/function () {
  function AstPath(path) {
    var position = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AstPath);

    this.path = path;
    this.position = position;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AstPath, [{
    key: "parentOf",
    value: function parentOf(node) {
      return node && this.path[this.path.indexOf(node) - 1];
    }
  }, {
    key: "childOf",
    value: function childOf(node) {
      return this.path[this.path.indexOf(node) + 1];
    }
  }, {
    key: "first",
    value: function first(ctor) {
      for (var i = this.path.length - 1; i >= 0; i--) {
        var item = this.path[i];
        if (item instanceof ctor) return item;
      }
    }
  }, {
    key: "push",
    value: function push(node) {
      this.path.push(node);
    }
  }, {
    key: "pop",
    value: function pop() {
      return this.path.pop();
    }
  }, {
    key: "empty",
    get: function get() {
      return !this.path || !this.path.length;
    }
  }, {
    key: "head",
    get: function get() {
      return this.path[0];
    }
  }, {
    key: "tail",
    get: function get() {
      return this.path[this.path.length - 1];
    }
  }]);

  return AstPath;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NodeWithI18n = function NodeWithI18n(sourceSpan, i18n) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NodeWithI18n);

  this.sourceSpan = sourceSpan;
  this.i18n = i18n;
};

var Text$3 = /*#__PURE__*/function (_NodeWithI18n) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Text$3, _NodeWithI18n);

  var _super79 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Text$3);

  function Text$3(value, sourceSpan, i18n) {
    var _this122;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Text$3);

    _this122 = _super79.call(this, sourceSpan, i18n);
    _this122.value = value;
    return _this122;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Text$3, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitText(this, context);
    }
  }]);

  return Text$3;
}(NodeWithI18n);

var Expansion = /*#__PURE__*/function (_NodeWithI18n2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Expansion, _NodeWithI18n2);

  var _super80 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Expansion);

  function Expansion(switchValue, type, cases, sourceSpan, switchValueSourceSpan, i18n) {
    var _this123;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Expansion);

    _this123 = _super80.call(this, sourceSpan, i18n);
    _this123.switchValue = switchValue;
    _this123.type = type;
    _this123.cases = cases;
    _this123.switchValueSourceSpan = switchValueSourceSpan;
    return _this123;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Expansion, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitExpansion(this, context);
    }
  }]);

  return Expansion;
}(NodeWithI18n);

var ExpansionCase = /*#__PURE__*/function () {
  function ExpansionCase(value, expression, sourceSpan, valueSourceSpan, expSourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExpansionCase);

    this.value = value;
    this.expression = expression;
    this.sourceSpan = sourceSpan;
    this.valueSourceSpan = valueSourceSpan;
    this.expSourceSpan = expSourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ExpansionCase, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitExpansionCase(this, context);
    }
  }]);

  return ExpansionCase;
}();

var Attribute = /*#__PURE__*/function (_NodeWithI18n3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Attribute, _NodeWithI18n3);

  var _super81 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Attribute);

  function Attribute(name, value, sourceSpan, valueSpan, i18n) {
    var _this124;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Attribute);

    _this124 = _super81.call(this, sourceSpan, i18n);
    _this124.name = name;
    _this124.value = value;
    _this124.valueSpan = valueSpan;
    return _this124;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Attribute, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitAttribute(this, context);
    }
  }]);

  return Attribute;
}(NodeWithI18n);

var Element$1 = /*#__PURE__*/function (_NodeWithI18n4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Element$1, _NodeWithI18n4);

  var _super82 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Element$1);

  function Element$1(name, attrs, children, sourceSpan) {
    var _this125;

    var startSourceSpan = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
    var endSourceSpan = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;
    var i18n = arguments.length > 6 ? arguments[6] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Element$1);

    _this125 = _super82.call(this, sourceSpan, i18n);
    _this125.name = name;
    _this125.attrs = attrs;
    _this125.children = children;
    _this125.startSourceSpan = startSourceSpan;
    _this125.endSourceSpan = endSourceSpan;
    return _this125;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Element$1, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitElement(this, context);
    }
  }]);

  return Element$1;
}(NodeWithI18n);

var Comment = /*#__PURE__*/function () {
  function Comment(value, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Comment);

    this.value = value;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Comment, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitComment(this, context);
    }
  }]);

  return Comment;
}();

function visitAll$1(visitor, nodes) {
  var context = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var result = [];
  var visit = visitor.visit ? function (ast) {
    return visitor.visit(ast, context) || ast.visit(visitor, context);
  } : function (ast) {
    return ast.visit(visitor, context);
  };
  nodes.forEach(function (ast) {
    var astResult = visit(ast);

    if (astResult) {
      result.push(astResult);
    }
  });
  return result;
}

var RecursiveVisitor$1 = /*#__PURE__*/function () {
  function RecursiveVisitor$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, RecursiveVisitor$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(RecursiveVisitor$1, [{
    key: "visitElement",
    value: function visitElement(ast, context) {
      this.visitChildren(context, function (visit) {
        visit(ast.attrs);
        visit(ast.children);
      });
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(ast, context) {}
  }, {
    key: "visitText",
    value: function visitText(ast, context) {}
  }, {
    key: "visitComment",
    value: function visitComment(ast, context) {}
  }, {
    key: "visitExpansion",
    value: function visitExpansion(ast, context) {
      return this.visitChildren(context, function (visit) {
        visit(ast.cases);
      });
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(ast, context) {}
  }, {
    key: "visitChildren",
    value: function visitChildren(context, cb) {
      var results = [];
      var t = this;

      function visit(children) {
        if (children) results.push(visitAll$1(t, children, context));
      }

      cb(visit);
      return Array.prototype.concat.apply([], results);
    }
  }]);

  return RecursiveVisitor$1;
}();

function spanOf(ast) {
  var start = ast.sourceSpan.start.offset;
  var end = ast.sourceSpan.end.offset;

  if (ast instanceof Element$1) {
    if (ast.endSourceSpan) {
      end = ast.endSourceSpan.end.offset;
    } else if (ast.children && ast.children.length) {
      end = spanOf(ast.children[ast.children.length - 1]).end;
    }
  }

  return {
    start: start,
    end: end
  };
}

function findNode(nodes, position) {
  var path = [];
  var visitor = new ( /*#__PURE__*/function (_RecursiveVisitor$) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_class, _RecursiveVisitor$);

    var _super83 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_class);

    function _class() {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _class);

      return _super83.apply(this, arguments);
    }

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_class, [{
      key: "visit",
      value: function visit(ast, context) {
        var span = spanOf(ast);

        if (span.start <= position && position < span.end) {
          path.push(ast);
        } else {
          // Returning a value here will result in the children being skipped.
          return true;
        }
      }
    }]);

    return _class;
  }(RecursiveVisitor$1))();
  visitAll$1(visitor, nodes);
  return new AstPath(path, position);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TokenType;

(function (TokenType) {
  TokenType[TokenType["TAG_OPEN_START"] = 0] = "TAG_OPEN_START";
  TokenType[TokenType["TAG_OPEN_END"] = 1] = "TAG_OPEN_END";
  TokenType[TokenType["TAG_OPEN_END_VOID"] = 2] = "TAG_OPEN_END_VOID";
  TokenType[TokenType["TAG_CLOSE"] = 3] = "TAG_CLOSE";
  TokenType[TokenType["TEXT"] = 4] = "TEXT";
  TokenType[TokenType["ESCAPABLE_RAW_TEXT"] = 5] = "ESCAPABLE_RAW_TEXT";
  TokenType[TokenType["RAW_TEXT"] = 6] = "RAW_TEXT";
  TokenType[TokenType["COMMENT_START"] = 7] = "COMMENT_START";
  TokenType[TokenType["COMMENT_END"] = 8] = "COMMENT_END";
  TokenType[TokenType["CDATA_START"] = 9] = "CDATA_START";
  TokenType[TokenType["CDATA_END"] = 10] = "CDATA_END";
  TokenType[TokenType["ATTR_NAME"] = 11] = "ATTR_NAME";
  TokenType[TokenType["ATTR_QUOTE"] = 12] = "ATTR_QUOTE";
  TokenType[TokenType["ATTR_VALUE"] = 13] = "ATTR_VALUE";
  TokenType[TokenType["DOC_TYPE"] = 14] = "DOC_TYPE";
  TokenType[TokenType["EXPANSION_FORM_START"] = 15] = "EXPANSION_FORM_START";
  TokenType[TokenType["EXPANSION_CASE_VALUE"] = 16] = "EXPANSION_CASE_VALUE";
  TokenType[TokenType["EXPANSION_CASE_EXP_START"] = 17] = "EXPANSION_CASE_EXP_START";
  TokenType[TokenType["EXPANSION_CASE_EXP_END"] = 18] = "EXPANSION_CASE_EXP_END";
  TokenType[TokenType["EXPANSION_FORM_END"] = 19] = "EXPANSION_FORM_END";
  TokenType[TokenType["EOF"] = 20] = "EOF";
})(TokenType || (TokenType = {}));

var Token = function Token(type, parts, sourceSpan) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Token);

  this.type = type;
  this.parts = parts;
  this.sourceSpan = sourceSpan;
};

var TokenError = /*#__PURE__*/function (_ParseError) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(TokenError, _ParseError);

  var _super84 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(TokenError);

  function TokenError(errorMsg, tokenType, span) {
    var _this126;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TokenError);

    _this126 = _super84.call(this, span, errorMsg);
    _this126.tokenType = tokenType;
    return _this126;
  }

  return TokenError;
}(ParseError);

var TokenizeResult = function TokenizeResult(tokens, errors, nonNormalizedIcuExpressions) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TokenizeResult);

  this.tokens = tokens;
  this.errors = errors;
  this.nonNormalizedIcuExpressions = nonNormalizedIcuExpressions;
};

function tokenize(source, url, getTagDefinition) {
  var options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var tokenizer = new _Tokenizer(new ParseSourceFile(source, url), getTagDefinition, options);
  tokenizer.tokenize();
  return new TokenizeResult(mergeTextTokens(tokenizer.tokens), tokenizer.errors, tokenizer.nonNormalizedIcuExpressions);
}

var _CR_OR_CRLF_REGEXP = /\r\n?/g;

function _unexpectedCharacterErrorMsg(charCode) {
  var char = charCode === $EOF ? 'EOF' : String.fromCharCode(charCode);
  return "Unexpected character \"".concat(char, "\"");
}

function _unknownEntityErrorMsg(entitySrc) {
  return "Unknown entity \"".concat(entitySrc, "\" - use the \"&#<decimal>;\" or  \"&#x<hex>;\" syntax");
}

function _unparsableEntityErrorMsg(type, entityStr) {
  return "Unable to parse entity \"".concat(entityStr, "\" - ").concat(type, " character reference entities must end with \";\"");
}

var CharacterReferenceType;

(function (CharacterReferenceType) {
  CharacterReferenceType["HEX"] = "hexadecimal";
  CharacterReferenceType["DEC"] = "decimal";
})(CharacterReferenceType || (CharacterReferenceType = {}));

var _ControlFlowError = function _ControlFlowError(error) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _ControlFlowError);

  this.error = error;
}; // See http://www.w3.org/TR/html51/syntax.html#writing


var _Tokenizer = /*#__PURE__*/function () {
  /**
   * @param _file The html source file being tokenized.
   * @param _getTagDefinition A function that will retrieve a tag definition for a given tag name.
   * @param options Configuration of the tokenization.
   */
  function _Tokenizer(_file, _getTagDefinition, options) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _Tokenizer);

    this._getTagDefinition = _getTagDefinition;
    this._currentTokenStart = null;
    this._currentTokenType = null;
    this._expansionCaseStack = [];
    this._inInterpolation = false;
    this.tokens = [];
    this.errors = [];
    this.nonNormalizedIcuExpressions = [];
    this._tokenizeIcu = options.tokenizeExpansionForms || false;
    this._interpolationConfig = options.interpolationConfig || DEFAULT_INTERPOLATION_CONFIG;
    this._leadingTriviaCodePoints = options.leadingTriviaChars && options.leadingTriviaChars.map(function (c) {
      return c.codePointAt(0) || 0;
    });
    var range = options.range || {
      endPos: _file.content.length,
      startPos: 0,
      startLine: 0,
      startCol: 0
    };
    this._cursor = options.escapedString ? new EscapedCharacterCursor(_file, range) : new PlainCharacterCursor(_file, range);
    this._preserveLineEndings = options.preserveLineEndings || false;
    this._escapedString = options.escapedString || false;
    this._i18nNormalizeLineEndingsInICUs = options.i18nNormalizeLineEndingsInICUs || false;

    try {
      this._cursor.init();
    } catch (e) {
      this.handleError(e);
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_Tokenizer, [{
    key: "_processCarriageReturns",
    value: function _processCarriageReturns(content) {
      if (this._preserveLineEndings) {
        return content;
      } // http://www.w3.org/TR/html5/syntax.html#preprocessing-the-input-stream
      // In order to keep the original position in the source, we can not
      // pre-process it.
      // Instead CRs are processed right before instantiating the tokens.


      return content.replace(_CR_OR_CRLF_REGEXP, '\n');
    }
  }, {
    key: "tokenize",
    value: function tokenize() {
      while (this._cursor.peek() !== $EOF) {
        var start = this._cursor.clone();

        try {
          if (this._attemptCharCode($LT)) {
            if (this._attemptCharCode($BANG)) {
              if (this._attemptCharCode($LBRACKET)) {
                this._consumeCdata(start);
              } else if (this._attemptCharCode($MINUS)) {
                this._consumeComment(start);
              } else {
                this._consumeDocType(start);
              }
            } else if (this._attemptCharCode($SLASH)) {
              this._consumeTagClose(start);
            } else {
              this._consumeTagOpen(start);
            }
          } else if (!(this._tokenizeIcu && this._tokenizeExpansionForm())) {
            this._consumeText();
          }
        } catch (e) {
          this.handleError(e);
        }
      }

      this._beginToken(TokenType.EOF);

      this._endToken([]);
    }
    /**
     * @returns whether an ICU token has been created
     * @internal
     */

  }, {
    key: "_tokenizeExpansionForm",
    value: function _tokenizeExpansionForm() {
      if (this.isExpansionFormStart()) {
        this._consumeExpansionFormStart();

        return true;
      }

      if (isExpansionCaseStart(this._cursor.peek()) && this._isInExpansionForm()) {
        this._consumeExpansionCaseStart();

        return true;
      }

      if (this._cursor.peek() === $RBRACE) {
        if (this._isInExpansionCase()) {
          this._consumeExpansionCaseEnd();

          return true;
        }

        if (this._isInExpansionForm()) {
          this._consumeExpansionFormEnd();

          return true;
        }
      }

      return false;
    }
  }, {
    key: "_beginToken",
    value: function _beginToken(type) {
      var start = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this._cursor.clone();
      this._currentTokenStart = start;
      this._currentTokenType = type;
    }
  }, {
    key: "_endToken",
    value: function _endToken(parts, end) {
      if (this._currentTokenStart === null) {
        throw new TokenError('Programming error - attempted to end a token when there was no start to the token', this._currentTokenType, this._cursor.getSpan(end));
      }

      if (this._currentTokenType === null) {
        throw new TokenError('Programming error - attempted to end a token which has no token type', null, this._cursor.getSpan(this._currentTokenStart));
      }

      var token = new Token(this._currentTokenType, parts, this._cursor.getSpan(this._currentTokenStart, this._leadingTriviaCodePoints));
      this.tokens.push(token);
      this._currentTokenStart = null;
      this._currentTokenType = null;
      return token;
    }
  }, {
    key: "_createError",
    value: function _createError(msg, span) {
      if (this._isInExpansionForm()) {
        msg += " (Do you have an unescaped \"{\" in your template? Use \"{{ '{' }}\") to escape it.)";
      }

      var error = new TokenError(msg, this._currentTokenType, span);
      this._currentTokenStart = null;
      this._currentTokenType = null;
      return new _ControlFlowError(error);
    }
  }, {
    key: "handleError",
    value: function handleError(e) {
      if (e instanceof CursorError) {
        e = this._createError(e.msg, this._cursor.getSpan(e.cursor));
      }

      if (e instanceof _ControlFlowError) {
        this.errors.push(e.error);
      } else {
        throw e;
      }
    }
  }, {
    key: "_attemptCharCode",
    value: function _attemptCharCode(charCode) {
      if (this._cursor.peek() === charCode) {
        this._cursor.advance();

        return true;
      }

      return false;
    }
  }, {
    key: "_attemptCharCodeCaseInsensitive",
    value: function _attemptCharCodeCaseInsensitive(charCode) {
      if (compareCharCodeCaseInsensitive(this._cursor.peek(), charCode)) {
        this._cursor.advance();

        return true;
      }

      return false;
    }
  }, {
    key: "_requireCharCode",
    value: function _requireCharCode(charCode) {
      var location = this._cursor.clone();

      if (!this._attemptCharCode(charCode)) {
        throw this._createError(_unexpectedCharacterErrorMsg(this._cursor.peek()), this._cursor.getSpan(location));
      }
    }
  }, {
    key: "_attemptStr",
    value: function _attemptStr(chars) {
      var len = chars.length;

      if (this._cursor.charsLeft() < len) {
        return false;
      }

      var initialPosition = this._cursor.clone();

      for (var i = 0; i < len; i++) {
        if (!this._attemptCharCode(chars.charCodeAt(i))) {
          // If attempting to parse the string fails, we want to reset the parser
          // to where it was before the attempt
          this._cursor = initialPosition;
          return false;
        }
      }

      return true;
    }
  }, {
    key: "_attemptStrCaseInsensitive",
    value: function _attemptStrCaseInsensitive(chars) {
      for (var i = 0; i < chars.length; i++) {
        if (!this._attemptCharCodeCaseInsensitive(chars.charCodeAt(i))) {
          return false;
        }
      }

      return true;
    }
  }, {
    key: "_requireStr",
    value: function _requireStr(chars) {
      var location = this._cursor.clone();

      if (!this._attemptStr(chars)) {
        throw this._createError(_unexpectedCharacterErrorMsg(this._cursor.peek()), this._cursor.getSpan(location));
      }
    }
  }, {
    key: "_attemptCharCodeUntilFn",
    value: function _attemptCharCodeUntilFn(predicate) {
      while (!predicate(this._cursor.peek())) {
        this._cursor.advance();
      }
    }
  }, {
    key: "_requireCharCodeUntilFn",
    value: function _requireCharCodeUntilFn(predicate, len) {
      var start = this._cursor.clone();

      this._attemptCharCodeUntilFn(predicate);

      if (this._cursor.diff(start) < len) {
        throw this._createError(_unexpectedCharacterErrorMsg(this._cursor.peek()), this._cursor.getSpan(start));
      }
    }
  }, {
    key: "_attemptUntilChar",
    value: function _attemptUntilChar(char) {
      while (this._cursor.peek() !== char) {
        this._cursor.advance();
      }
    }
  }, {
    key: "_readChar",
    value: function _readChar(decodeEntities) {
      if (decodeEntities && this._cursor.peek() === $AMPERSAND) {
        return this._decodeEntity();
      } else {
        // Don't rely upon reading directly from `_input` as the actual char value
        // may have been generated from an escape sequence.
        var char = String.fromCodePoint(this._cursor.peek());

        this._cursor.advance();

        return char;
      }
    }
  }, {
    key: "_decodeEntity",
    value: function _decodeEntity() {
      var start = this._cursor.clone();

      this._cursor.advance();

      if (this._attemptCharCode($HASH)) {
        var isHex = this._attemptCharCode($x) || this._attemptCharCode($X);

        var codeStart = this._cursor.clone();

        this._attemptCharCodeUntilFn(isDigitEntityEnd);

        if (this._cursor.peek() != $SEMICOLON) {
          // Advance cursor to include the peeked character in the string provided to the error
          // message.
          this._cursor.advance();

          var entityType = isHex ? CharacterReferenceType.HEX : CharacterReferenceType.DEC;
          throw this._createError(_unparsableEntityErrorMsg(entityType, this._cursor.getChars(start)), this._cursor.getSpan());
        }

        var strNum = this._cursor.getChars(codeStart);

        this._cursor.advance();

        try {
          var charCode = parseInt(strNum, isHex ? 16 : 10);
          return String.fromCharCode(charCode);
        } catch (_a) {
          throw this._createError(_unknownEntityErrorMsg(this._cursor.getChars(start)), this._cursor.getSpan());
        }
      } else {
        var nameStart = this._cursor.clone();

        this._attemptCharCodeUntilFn(isNamedEntityEnd);

        if (this._cursor.peek() != $SEMICOLON) {
          this._cursor = nameStart;
          return '&';
        }

        var name = this._cursor.getChars(nameStart);

        this._cursor.advance();

        var char = NAMED_ENTITIES[name];

        if (!char) {
          throw this._createError(_unknownEntityErrorMsg(name), this._cursor.getSpan(start));
        }

        return char;
      }
    }
  }, {
    key: "_consumeRawText",
    value: function _consumeRawText(decodeEntities, endMarkerPredicate) {
      this._beginToken(decodeEntities ? TokenType.ESCAPABLE_RAW_TEXT : TokenType.RAW_TEXT);

      var parts = [];

      while (true) {
        var tagCloseStart = this._cursor.clone();

        var foundEndMarker = endMarkerPredicate();
        this._cursor = tagCloseStart;

        if (foundEndMarker) {
          break;
        }

        parts.push(this._readChar(decodeEntities));
      }

      return this._endToken([this._processCarriageReturns(parts.join(''))]);
    }
  }, {
    key: "_consumeComment",
    value: function _consumeComment(start) {
      var _this127 = this;

      this._beginToken(TokenType.COMMENT_START, start);

      this._requireCharCode($MINUS);

      this._endToken([]);

      this._consumeRawText(false, function () {
        return _this127._attemptStr('-->');
      });

      this._beginToken(TokenType.COMMENT_END);

      this._requireStr('-->');

      this._endToken([]);
    }
  }, {
    key: "_consumeCdata",
    value: function _consumeCdata(start) {
      var _this128 = this;

      this._beginToken(TokenType.CDATA_START, start);

      this._requireStr('CDATA[');

      this._endToken([]);

      this._consumeRawText(false, function () {
        return _this128._attemptStr(']]>');
      });

      this._beginToken(TokenType.CDATA_END);

      this._requireStr(']]>');

      this._endToken([]);
    }
  }, {
    key: "_consumeDocType",
    value: function _consumeDocType(start) {
      this._beginToken(TokenType.DOC_TYPE, start);

      var contentStart = this._cursor.clone();

      this._attemptUntilChar($GT);

      var content = this._cursor.getChars(contentStart);

      this._cursor.advance();

      this._endToken([content]);
    }
  }, {
    key: "_consumePrefixAndName",
    value: function _consumePrefixAndName() {
      var nameOrPrefixStart = this._cursor.clone();

      var prefix = '';

      while (this._cursor.peek() !== $COLON && !isPrefixEnd(this._cursor.peek())) {
        this._cursor.advance();
      }

      var nameStart;

      if (this._cursor.peek() === $COLON) {
        prefix = this._cursor.getChars(nameOrPrefixStart);

        this._cursor.advance();

        nameStart = this._cursor.clone();
      } else {
        nameStart = nameOrPrefixStart;
      }

      this._requireCharCodeUntilFn(isNameEnd, prefix === '' ? 0 : 1);

      var name = this._cursor.getChars(nameStart);

      return [prefix, name];
    }
  }, {
    key: "_consumeTagOpen",
    value: function _consumeTagOpen(start) {
      var tagName;
      var prefix;
      var openTagToken;
      var tokensBeforeTagOpen = this.tokens.length;

      var innerStart = this._cursor.clone();

      try {
        if (!isAsciiLetter(this._cursor.peek())) {
          throw this._createError(_unexpectedCharacterErrorMsg(this._cursor.peek()), this._cursor.getSpan(start));
        }

        openTagToken = this._consumeTagOpenStart(start);
        prefix = openTagToken.parts[0];
        tagName = openTagToken.parts[1];

        this._attemptCharCodeUntilFn(isNotWhitespace);

        while (this._cursor.peek() !== $SLASH && this._cursor.peek() !== $GT) {
          this._consumeAttributeName();

          this._attemptCharCodeUntilFn(isNotWhitespace);

          if (this._attemptCharCode($EQ)) {
            this._attemptCharCodeUntilFn(isNotWhitespace);

            this._consumeAttributeValue();
          }

          this._attemptCharCodeUntilFn(isNotWhitespace);
        }

        this._consumeTagOpenEnd();
      } catch (e) {
        if (e instanceof _ControlFlowError) {
          // When the start tag is invalid (including invalid "attributes"), assume we want a "<"
          this._cursor = innerStart;

          if (openTagToken) {
            this.tokens.length = tokensBeforeTagOpen;
          } // Back to back text tokens are merged at the end


          this._beginToken(TokenType.TEXT, start);

          this._endToken(['<']);

          return;
        }

        throw e;
      }

      var contentTokenType = this._getTagDefinition(tagName).contentType;

      if (contentTokenType === TagContentType.RAW_TEXT) {
        this._consumeRawTextWithTagClose(prefix, tagName, false);
      } else if (contentTokenType === TagContentType.ESCAPABLE_RAW_TEXT) {
        this._consumeRawTextWithTagClose(prefix, tagName, true);
      }
    }
  }, {
    key: "_consumeRawTextWithTagClose",
    value: function _consumeRawTextWithTagClose(prefix, tagName, decodeEntities) {
      var _this129 = this;

      var textToken = this._consumeRawText(decodeEntities, function () {
        if (!_this129._attemptCharCode($LT)) return false;
        if (!_this129._attemptCharCode($SLASH)) return false;

        _this129._attemptCharCodeUntilFn(isNotWhitespace);

        if (!_this129._attemptStrCaseInsensitive(tagName)) return false;

        _this129._attemptCharCodeUntilFn(isNotWhitespace);

        return _this129._attemptCharCode($GT);
      });

      this._beginToken(TokenType.TAG_CLOSE);

      this._requireCharCodeUntilFn(function (code) {
        return code === $GT;
      }, 3);

      this._cursor.advance(); // Consume the `>`


      this._endToken([prefix, tagName]);
    }
  }, {
    key: "_consumeTagOpenStart",
    value: function _consumeTagOpenStart(start) {
      this._beginToken(TokenType.TAG_OPEN_START, start);

      var parts = this._consumePrefixAndName();

      return this._endToken(parts);
    }
  }, {
    key: "_consumeAttributeName",
    value: function _consumeAttributeName() {
      var attrNameStart = this._cursor.peek();

      if (attrNameStart === $SQ || attrNameStart === $DQ) {
        throw this._createError(_unexpectedCharacterErrorMsg(attrNameStart), this._cursor.getSpan());
      }

      this._beginToken(TokenType.ATTR_NAME);

      var prefixAndName = this._consumePrefixAndName();

      this._endToken(prefixAndName);
    }
  }, {
    key: "_consumeAttributeValue",
    value: function _consumeAttributeValue() {
      var value;

      if (this._cursor.peek() === $SQ || this._cursor.peek() === $DQ) {
        this._beginToken(TokenType.ATTR_QUOTE);

        var quoteChar = this._cursor.peek();

        this._cursor.advance();

        this._endToken([String.fromCodePoint(quoteChar)]);

        this._beginToken(TokenType.ATTR_VALUE);

        var parts = [];

        while (this._cursor.peek() !== quoteChar) {
          parts.push(this._readChar(true));
        }

        value = parts.join('');

        this._endToken([this._processCarriageReturns(value)]);

        this._beginToken(TokenType.ATTR_QUOTE);

        this._cursor.advance();

        this._endToken([String.fromCodePoint(quoteChar)]);
      } else {
        this._beginToken(TokenType.ATTR_VALUE);

        var valueStart = this._cursor.clone();

        this._requireCharCodeUntilFn(isNameEnd, 1);

        value = this._cursor.getChars(valueStart);

        this._endToken([this._processCarriageReturns(value)]);
      }
    }
  }, {
    key: "_consumeTagOpenEnd",
    value: function _consumeTagOpenEnd() {
      var tokenType = this._attemptCharCode($SLASH) ? TokenType.TAG_OPEN_END_VOID : TokenType.TAG_OPEN_END;

      this._beginToken(tokenType);

      this._requireCharCode($GT);

      this._endToken([]);
    }
  }, {
    key: "_consumeTagClose",
    value: function _consumeTagClose(start) {
      this._beginToken(TokenType.TAG_CLOSE, start);

      this._attemptCharCodeUntilFn(isNotWhitespace);

      var prefixAndName = this._consumePrefixAndName();

      this._attemptCharCodeUntilFn(isNotWhitespace);

      this._requireCharCode($GT);

      this._endToken(prefixAndName);
    }
  }, {
    key: "_consumeExpansionFormStart",
    value: function _consumeExpansionFormStart() {
      this._beginToken(TokenType.EXPANSION_FORM_START);

      this._requireCharCode($LBRACE);

      this._endToken([]);

      this._expansionCaseStack.push(TokenType.EXPANSION_FORM_START);

      this._beginToken(TokenType.RAW_TEXT);

      var condition = this._readUntil($COMMA);

      var normalizedCondition = this._processCarriageReturns(condition);

      if (this._escapedString || this._i18nNormalizeLineEndingsInICUs) {
        // Either the template is inline or,
        // we explicitly want to normalize line endings for this text.
        this._endToken([normalizedCondition]);
      } else {
        // The expression is in an external template and, for backward compatibility,
        // we are not normalizing line endings.
        var conditionToken = this._endToken([condition]);

        if (normalizedCondition !== condition) {
          this.nonNormalizedIcuExpressions.push(conditionToken);
        }
      }

      this._requireCharCode($COMMA);

      this._attemptCharCodeUntilFn(isNotWhitespace);

      this._beginToken(TokenType.RAW_TEXT);

      var type = this._readUntil($COMMA);

      this._endToken([type]);

      this._requireCharCode($COMMA);

      this._attemptCharCodeUntilFn(isNotWhitespace);
    }
  }, {
    key: "_consumeExpansionCaseStart",
    value: function _consumeExpansionCaseStart() {
      this._beginToken(TokenType.EXPANSION_CASE_VALUE);

      var value = this._readUntil($LBRACE).trim();

      this._endToken([value]);

      this._attemptCharCodeUntilFn(isNotWhitespace);

      this._beginToken(TokenType.EXPANSION_CASE_EXP_START);

      this._requireCharCode($LBRACE);

      this._endToken([]);

      this._attemptCharCodeUntilFn(isNotWhitespace);

      this._expansionCaseStack.push(TokenType.EXPANSION_CASE_EXP_START);
    }
  }, {
    key: "_consumeExpansionCaseEnd",
    value: function _consumeExpansionCaseEnd() {
      this._beginToken(TokenType.EXPANSION_CASE_EXP_END);

      this._requireCharCode($RBRACE);

      this._endToken([]);

      this._attemptCharCodeUntilFn(isNotWhitespace);

      this._expansionCaseStack.pop();
    }
  }, {
    key: "_consumeExpansionFormEnd",
    value: function _consumeExpansionFormEnd() {
      this._beginToken(TokenType.EXPANSION_FORM_END);

      this._requireCharCode($RBRACE);

      this._endToken([]);

      this._expansionCaseStack.pop();
    }
  }, {
    key: "_consumeText",
    value: function _consumeText() {
      var start = this._cursor.clone();

      this._beginToken(TokenType.TEXT, start);

      var parts = [];

      do {
        if (this._interpolationConfig && this._attemptStr(this._interpolationConfig.start)) {
          parts.push(this._interpolationConfig.start);
          this._inInterpolation = true;
        } else if (this._interpolationConfig && this._inInterpolation && this._attemptStr(this._interpolationConfig.end)) {
          parts.push(this._interpolationConfig.end);
          this._inInterpolation = false;
        } else {
          parts.push(this._readChar(true));
        }
      } while (!this._isTextEnd());

      this._endToken([this._processCarriageReturns(parts.join(''))]);
    }
  }, {
    key: "_isTextEnd",
    value: function _isTextEnd() {
      if (this._cursor.peek() === $LT || this._cursor.peek() === $EOF) {
        return true;
      }

      if (this._tokenizeIcu && !this._inInterpolation) {
        if (this.isExpansionFormStart()) {
          // start of an expansion form
          return true;
        }

        if (this._cursor.peek() === $RBRACE && this._isInExpansionCase()) {
          // end of and expansion case
          return true;
        }
      }

      return false;
    }
  }, {
    key: "_readUntil",
    value: function _readUntil(char) {
      var start = this._cursor.clone();

      this._attemptUntilChar(char);

      return this._cursor.getChars(start);
    }
  }, {
    key: "_isInExpansionCase",
    value: function _isInExpansionCase() {
      return this._expansionCaseStack.length > 0 && this._expansionCaseStack[this._expansionCaseStack.length - 1] === TokenType.EXPANSION_CASE_EXP_START;
    }
  }, {
    key: "_isInExpansionForm",
    value: function _isInExpansionForm() {
      return this._expansionCaseStack.length > 0 && this._expansionCaseStack[this._expansionCaseStack.length - 1] === TokenType.EXPANSION_FORM_START;
    }
  }, {
    key: "isExpansionFormStart",
    value: function isExpansionFormStart() {
      if (this._cursor.peek() !== $LBRACE) {
        return false;
      }

      if (this._interpolationConfig) {
        var start = this._cursor.clone();

        var isInterpolation = this._attemptStr(this._interpolationConfig.start);

        this._cursor = start;
        return !isInterpolation;
      }

      return true;
    }
  }]);

  return _Tokenizer;
}();

function isNotWhitespace(code) {
  return !isWhitespace(code) || code === $EOF;
}

function isNameEnd(code) {
  return isWhitespace(code) || code === $GT || code === $SLASH || code === $SQ || code === $DQ || code === $EQ;
}

function isPrefixEnd(code) {
  return (code < $a || $z < code) && (code < $A || $Z < code) && (code < $0 || code > $9);
}

function isDigitEntityEnd(code) {
  return code == $SEMICOLON || code == $EOF || !isAsciiHexDigit(code);
}

function isNamedEntityEnd(code) {
  return code == $SEMICOLON || code == $EOF || !isAsciiLetter(code);
}

function isExpansionCaseStart(peek) {
  return peek !== $RBRACE;
}

function compareCharCodeCaseInsensitive(code1, code2) {
  return toUpperCaseCharCode(code1) == toUpperCaseCharCode(code2);
}

function toUpperCaseCharCode(code) {
  return code >= $a && code <= $z ? code - $a + $A : code;
}

function mergeTextTokens(srcTokens) {
  var dstTokens = [];
  var lastDstToken = undefined;

  for (var i = 0; i < srcTokens.length; i++) {
    var token = srcTokens[i];

    if (lastDstToken && lastDstToken.type == TokenType.TEXT && token.type == TokenType.TEXT) {
      lastDstToken.parts[0] += token.parts[0];
      lastDstToken.sourceSpan.end = token.sourceSpan.end;
    } else {
      lastDstToken = token;
      dstTokens.push(lastDstToken);
    }
  }

  return dstTokens;
}

var PlainCharacterCursor = /*#__PURE__*/function () {
  function PlainCharacterCursor(fileOrCursor, range) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PlainCharacterCursor);

    if (fileOrCursor instanceof PlainCharacterCursor) {
      this.file = fileOrCursor.file;
      this.input = fileOrCursor.input;
      this.end = fileOrCursor.end;
      var state = fileOrCursor.state; // Note: avoid using `{...fileOrCursor.state}` here as that has a severe performance penalty.
      // In ES5 bundles the object spread operator is translated into the `__assign` helper, which
      // is not optimized by VMs as efficiently as a raw object literal. Since this constructor is
      // called in tight loops, this difference matters.

      this.state = {
        peek: state.peek,
        offset: state.offset,
        line: state.line,
        column: state.column
      };
    } else {
      if (!range) {
        throw new Error('Programming error: the range argument must be provided with a file argument.');
      }

      this.file = fileOrCursor;
      this.input = fileOrCursor.content;
      this.end = range.endPos;
      this.state = {
        peek: -1,
        offset: range.startPos,
        line: range.startLine,
        column: range.startCol
      };
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PlainCharacterCursor, [{
    key: "clone",
    value: function clone() {
      return new PlainCharacterCursor(this);
    }
  }, {
    key: "peek",
    value: function peek() {
      return this.state.peek;
    }
  }, {
    key: "charsLeft",
    value: function charsLeft() {
      return this.end - this.state.offset;
    }
  }, {
    key: "diff",
    value: function diff(other) {
      return this.state.offset - other.state.offset;
    }
  }, {
    key: "advance",
    value: function advance() {
      this.advanceState(this.state);
    }
  }, {
    key: "init",
    value: function init() {
      this.updatePeek(this.state);
    }
  }, {
    key: "getSpan",
    value: function getSpan(start, leadingTriviaCodePoints) {
      start = start || this;
      var cloned = false;

      if (leadingTriviaCodePoints) {
        while (this.diff(start) > 0 && leadingTriviaCodePoints.indexOf(start.peek()) !== -1) {
          if (!cloned) {
            start = start.clone();
            cloned = true;
          }

          start.advance();
        }
      }

      return new ParseSourceSpan(new ParseLocation(start.file, start.state.offset, start.state.line, start.state.column), new ParseLocation(this.file, this.state.offset, this.state.line, this.state.column));
    }
  }, {
    key: "getChars",
    value: function getChars(start) {
      return this.input.substring(start.state.offset, this.state.offset);
    }
  }, {
    key: "charAt",
    value: function charAt(pos) {
      return this.input.charCodeAt(pos);
    }
  }, {
    key: "advanceState",
    value: function advanceState(state) {
      if (state.offset >= this.end) {
        this.state = state;
        throw new CursorError('Unexpected character "EOF"', this);
      }

      var currentChar = this.charAt(state.offset);

      if (currentChar === $LF) {
        state.line++;
        state.column = 0;
      } else if (!isNewLine(currentChar)) {
        state.column++;
      }

      state.offset++;
      this.updatePeek(state);
    }
  }, {
    key: "updatePeek",
    value: function updatePeek(state) {
      state.peek = state.offset >= this.end ? $EOF : this.charAt(state.offset);
    }
  }]);

  return PlainCharacterCursor;
}();

var EscapedCharacterCursor = /*#__PURE__*/function (_PlainCharacterCursor) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(EscapedCharacterCursor, _PlainCharacterCursor);

  var _super85 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(EscapedCharacterCursor);

  function EscapedCharacterCursor(fileOrCursor, range) {
    var _this130;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, EscapedCharacterCursor);

    if (fileOrCursor instanceof EscapedCharacterCursor) {
      _this130 = _super85.call(this, fileOrCursor);
      _this130.internalState = Object.assign({}, fileOrCursor.internalState);
    } else {
      _this130 = _super85.call(this, fileOrCursor, range);
      _this130.internalState = _this130.state;
    }

    return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_1__["default"])(_this130);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(EscapedCharacterCursor, [{
    key: "advance",
    value: function advance() {
      this.state = this.internalState;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(EscapedCharacterCursor.prototype), "advance", this).call(this);

      this.processEscapeSequence();
    }
  }, {
    key: "init",
    value: function init() {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(EscapedCharacterCursor.prototype), "init", this).call(this);

      this.processEscapeSequence();
    }
  }, {
    key: "clone",
    value: function clone() {
      return new EscapedCharacterCursor(this);
    }
  }, {
    key: "getChars",
    value: function getChars(start) {
      var cursor = start.clone();
      var chars = '';

      while (cursor.internalState.offset < this.internalState.offset) {
        chars += String.fromCodePoint(cursor.peek());
        cursor.advance();
      }

      return chars;
    }
    /**
     * Process the escape sequence that starts at the current position in the text.
     *
     * This method is called to ensure that `peek` has the unescaped value of escape sequences.
     */

  }, {
    key: "processEscapeSequence",
    value: function processEscapeSequence() {
      var _this131 = this;

      var peek = function peek() {
        return _this131.internalState.peek;
      };

      if (peek() === $BACKSLASH) {
        // We have hit an escape sequence so we need the internal state to become independent
        // of the external state.
        this.internalState = Object.assign({}, this.state); // Move past the backslash

        this.advanceState(this.internalState); // First check for standard control char sequences

        if (peek() === $n) {
          this.state.peek = $LF;
        } else if (peek() === $r) {
          this.state.peek = $CR;
        } else if (peek() === $v) {
          this.state.peek = $VTAB;
        } else if (peek() === $t) {
          this.state.peek = $TAB;
        } else if (peek() === $b) {
          this.state.peek = $BSPACE;
        } else if (peek() === $f) {
          this.state.peek = $FF;
        } // Now consider more complex sequences
        else if (peek() === $u) {
            // Unicode code-point sequence
            this.advanceState(this.internalState); // advance past the `u` char

            if (peek() === $LBRACE) {
              // Variable length Unicode, e.g. `\x{123}`
              this.advanceState(this.internalState); // advance past the `{` char
              // Advance past the variable number of hex digits until we hit a `}` char

              var digitStart = this.clone();
              var length = 0;

              while (peek() !== $RBRACE) {
                this.advanceState(this.internalState);
                length++;
              }

              this.state.peek = this.decodeHexDigits(digitStart, length);
            } else {
              // Fixed length Unicode, e.g. `\u1234`
              var _digitStart = this.clone();

              this.advanceState(this.internalState);
              this.advanceState(this.internalState);
              this.advanceState(this.internalState);
              this.state.peek = this.decodeHexDigits(_digitStart, 4);
            }
          } else if (peek() === $x) {
            // Hex char code, e.g. `\x2F`
            this.advanceState(this.internalState); // advance past the `x` char

            var _digitStart2 = this.clone();

            this.advanceState(this.internalState);
            this.state.peek = this.decodeHexDigits(_digitStart2, 2);
          } else if (isOctalDigit(peek())) {
            // Octal char code, e.g. `\012`,
            var octal = '';
            var _length = 0;
            var previous = this.clone();

            while (isOctalDigit(peek()) && _length < 3) {
              previous = this.clone();
              octal += String.fromCodePoint(peek());
              this.advanceState(this.internalState);
              _length++;
            }

            this.state.peek = parseInt(octal, 8); // Backup one char

            this.internalState = previous.internalState;
          } else if (isNewLine(this.internalState.peek)) {
            // Line continuation `\` followed by a new line
            this.advanceState(this.internalState); // advance over the newline

            this.state = this.internalState;
          } else {
            // If none of the `if` blocks were executed then we just have an escaped normal character.
            // In that case we just, effectively, skip the backslash from the character.
            this.state.peek = this.internalState.peek;
          }
      }
    }
  }, {
    key: "decodeHexDigits",
    value: function decodeHexDigits(start, length) {
      var hex = this.input.substr(start.internalState.offset, length);
      var charCode = parseInt(hex, 16);

      if (!isNaN(charCode)) {
        return charCode;
      } else {
        start.state = start.internalState;
        throw new CursorError('Invalid hexadecimal escape sequence', start);
      }
    }
  }]);

  return EscapedCharacterCursor;
}(PlainCharacterCursor);

var CursorError = function CursorError(msg, cursor) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CursorError);

  this.msg = msg;
  this.cursor = cursor;
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TreeError = /*#__PURE__*/function (_ParseError2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(TreeError, _ParseError2);

  var _super86 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(TreeError);

  function TreeError(elementName, span, msg) {
    var _this132;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TreeError);

    _this132 = _super86.call(this, span, msg);
    _this132.elementName = elementName;
    return _this132;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TreeError, null, [{
    key: "create",
    value: function create(elementName, span, msg) {
      return new TreeError(elementName, span, msg);
    }
  }]);

  return TreeError;
}(ParseError);

var ParseTreeResult = function ParseTreeResult(rootNodes, errors) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ParseTreeResult);

  this.rootNodes = rootNodes;
  this.errors = errors;
};

var Parser = /*#__PURE__*/function () {
  function Parser(getTagDefinition) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Parser);

    this.getTagDefinition = getTagDefinition;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Parser, [{
    key: "parse",
    value: function parse(source, url, options) {
      var tokenizeResult = tokenize(source, url, this.getTagDefinition, options);
      var parser = new _TreeBuilder(tokenizeResult.tokens, this.getTagDefinition);
      parser.build();
      return new ParseTreeResult(parser.rootNodes, tokenizeResult.errors.concat(parser.errors));
    }
  }]);

  return Parser;
}();

var _TreeBuilder = /*#__PURE__*/function () {
  function _TreeBuilder(tokens, getTagDefinition) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _TreeBuilder);

    this.tokens = tokens;
    this.getTagDefinition = getTagDefinition;
    this._index = -1;
    this._elementStack = [];
    this.rootNodes = [];
    this.errors = [];

    this._advance();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_TreeBuilder, [{
    key: "build",
    value: function build() {
      while (this._peek.type !== TokenType.EOF) {
        if (this._peek.type === TokenType.TAG_OPEN_START) {
          this._consumeStartTag(this._advance());
        } else if (this._peek.type === TokenType.TAG_CLOSE) {
          this._consumeEndTag(this._advance());
        } else if (this._peek.type === TokenType.CDATA_START) {
          this._closeVoidElement();

          this._consumeCdata(this._advance());
        } else if (this._peek.type === TokenType.COMMENT_START) {
          this._closeVoidElement();

          this._consumeComment(this._advance());
        } else if (this._peek.type === TokenType.TEXT || this._peek.type === TokenType.RAW_TEXT || this._peek.type === TokenType.ESCAPABLE_RAW_TEXT) {
          this._closeVoidElement();

          this._consumeText(this._advance());
        } else if (this._peek.type === TokenType.EXPANSION_FORM_START) {
          this._consumeExpansion(this._advance());
        } else {
          // Skip all other tokens...
          this._advance();
        }
      }
    }
  }, {
    key: "_advance",
    value: function _advance() {
      var prev = this._peek;

      if (this._index < this.tokens.length - 1) {
        // Note: there is always an EOF token at the end
        this._index++;
      }

      this._peek = this.tokens[this._index];
      return prev;
    }
  }, {
    key: "_advanceIf",
    value: function _advanceIf(type) {
      if (this._peek.type === type) {
        return this._advance();
      }

      return null;
    }
  }, {
    key: "_consumeCdata",
    value: function _consumeCdata(_startToken) {
      this._consumeText(this._advance());

      this._advanceIf(TokenType.CDATA_END);
    }
  }, {
    key: "_consumeComment",
    value: function _consumeComment(token) {
      var text = this._advanceIf(TokenType.RAW_TEXT);

      this._advanceIf(TokenType.COMMENT_END);

      var value = text != null ? text.parts[0].trim() : null;

      this._addToParent(new Comment(value, token.sourceSpan));
    }
  }, {
    key: "_consumeExpansion",
    value: function _consumeExpansion(token) {
      var switchValue = this._advance();

      var type = this._advance();

      var cases = []; // read =

      while (this._peek.type === TokenType.EXPANSION_CASE_VALUE) {
        var expCase = this._parseExpansionCase();

        if (!expCase) return; // error

        cases.push(expCase);
      } // read the final }


      if (this._peek.type !== TokenType.EXPANSION_FORM_END) {
        this.errors.push(TreeError.create(null, this._peek.sourceSpan, "Invalid ICU message. Missing '}'."));
        return;
      }

      var sourceSpan = new ParseSourceSpan(token.sourceSpan.start, this._peek.sourceSpan.end);

      this._addToParent(new Expansion(switchValue.parts[0], type.parts[0], cases, sourceSpan, switchValue.sourceSpan));

      this._advance();
    }
  }, {
    key: "_parseExpansionCase",
    value: function _parseExpansionCase() {
      var value = this._advance(); // read {


      if (this._peek.type !== TokenType.EXPANSION_CASE_EXP_START) {
        this.errors.push(TreeError.create(null, this._peek.sourceSpan, "Invalid ICU message. Missing '{'."));
        return null;
      } // read until }


      var start = this._advance();

      var exp = this._collectExpansionExpTokens(start);

      if (!exp) return null;

      var end = this._advance();

      exp.push(new Token(TokenType.EOF, [], end.sourceSpan)); // parse everything in between { and }

      var expansionCaseParser = new _TreeBuilder(exp, this.getTagDefinition);
      expansionCaseParser.build();

      if (expansionCaseParser.errors.length > 0) {
        this.errors = this.errors.concat(expansionCaseParser.errors);
        return null;
      }

      var sourceSpan = new ParseSourceSpan(value.sourceSpan.start, end.sourceSpan.end);
      var expSourceSpan = new ParseSourceSpan(start.sourceSpan.start, end.sourceSpan.end);
      return new ExpansionCase(value.parts[0], expansionCaseParser.rootNodes, sourceSpan, value.sourceSpan, expSourceSpan);
    }
  }, {
    key: "_collectExpansionExpTokens",
    value: function _collectExpansionExpTokens(start) {
      var exp = [];
      var expansionFormStack = [TokenType.EXPANSION_CASE_EXP_START];

      while (true) {
        if (this._peek.type === TokenType.EXPANSION_FORM_START || this._peek.type === TokenType.EXPANSION_CASE_EXP_START) {
          expansionFormStack.push(this._peek.type);
        }

        if (this._peek.type === TokenType.EXPANSION_CASE_EXP_END) {
          if (lastOnStack(expansionFormStack, TokenType.EXPANSION_CASE_EXP_START)) {
            expansionFormStack.pop();
            if (expansionFormStack.length == 0) return exp;
          } else {
            this.errors.push(TreeError.create(null, start.sourceSpan, "Invalid ICU message. Missing '}'."));
            return null;
          }
        }

        if (this._peek.type === TokenType.EXPANSION_FORM_END) {
          if (lastOnStack(expansionFormStack, TokenType.EXPANSION_FORM_START)) {
            expansionFormStack.pop();
          } else {
            this.errors.push(TreeError.create(null, start.sourceSpan, "Invalid ICU message. Missing '}'."));
            return null;
          }
        }

        if (this._peek.type === TokenType.EOF) {
          this.errors.push(TreeError.create(null, start.sourceSpan, "Invalid ICU message. Missing '}'."));
          return null;
        }

        exp.push(this._advance());
      }
    }
  }, {
    key: "_consumeText",
    value: function _consumeText(token) {
      var text = token.parts[0];

      if (text.length > 0 && text[0] == '\n') {
        var parent = this._getParentElement();

        if (parent != null && parent.children.length == 0 && this.getTagDefinition(parent.name).ignoreFirstLf) {
          text = text.substring(1);
        }
      }

      if (text.length > 0) {
        this._addToParent(new Text$3(text, token.sourceSpan));
      }
    }
  }, {
    key: "_closeVoidElement",
    value: function _closeVoidElement() {
      var el = this._getParentElement();

      if (el && this.getTagDefinition(el.name).isVoid) {
        this._elementStack.pop();
      }
    }
  }, {
    key: "_consumeStartTag",
    value: function _consumeStartTag(startTagToken) {
      var prefix = startTagToken.parts[0];
      var name = startTagToken.parts[1];
      var attrs = [];

      while (this._peek.type === TokenType.ATTR_NAME) {
        attrs.push(this._consumeAttr(this._advance()));
      }

      var fullName = this._getElementFullName(prefix, name, this._getParentElement());

      var selfClosing = false; // Note: There could have been a tokenizer error
      // so that we don't get a token for the end tag...

      if (this._peek.type === TokenType.TAG_OPEN_END_VOID) {
        this._advance();

        selfClosing = true;
        var tagDef = this.getTagDefinition(fullName);

        if (!(tagDef.canSelfClose || getNsPrefix(fullName) !== null || tagDef.isVoid)) {
          this.errors.push(TreeError.create(fullName, startTagToken.sourceSpan, "Only void and foreign elements can be self closed \"".concat(startTagToken.parts[1], "\"")));
        }
      } else if (this._peek.type === TokenType.TAG_OPEN_END) {
        this._advance();

        selfClosing = false;
      }

      var end = this._peek.sourceSpan.start;
      var span = new ParseSourceSpan(startTagToken.sourceSpan.start, end);
      var el = new Element$1(fullName, attrs, [], span, span, undefined);

      this._pushElement(el);

      if (selfClosing) {
        // Elements that are self-closed have their `endSourceSpan` set to the full span, as the
        // element start tag also represents the end tag.
        this._popElement(fullName, span);
      }
    }
  }, {
    key: "_pushElement",
    value: function _pushElement(el) {
      var parentEl = this._getParentElement();

      if (parentEl && this.getTagDefinition(parentEl.name).isClosedByChild(el.name)) {
        this._elementStack.pop();
      }

      this._addToParent(el);

      this._elementStack.push(el);
    }
  }, {
    key: "_consumeEndTag",
    value: function _consumeEndTag(endTagToken) {
      var fullName = this._getElementFullName(endTagToken.parts[0], endTagToken.parts[1], this._getParentElement());

      if (this.getTagDefinition(fullName).isVoid) {
        this.errors.push(TreeError.create(fullName, endTagToken.sourceSpan, "Void elements do not have end tags \"".concat(endTagToken.parts[1], "\"")));
      } else if (!this._popElement(fullName, endTagToken.sourceSpan)) {
        var errMsg = "Unexpected closing tag \"".concat(fullName, "\". It may happen when the tag has already been closed by another tag. For more info see https://www.w3.org/TR/html5/syntax.html#closing-elements-that-have-implied-end-tags");
        this.errors.push(TreeError.create(fullName, endTagToken.sourceSpan, errMsg));
      }
    }
  }, {
    key: "_popElement",
    value: function _popElement(fullName, endSourceSpan) {
      for (var stackIndex = this._elementStack.length - 1; stackIndex >= 0; stackIndex--) {
        var el = this._elementStack[stackIndex];

        if (el.name == fullName) {
          // Record the parse span with the element that is being closed. Any elements that are
          // removed from the element stack at this point are closed implicitly, so they won't get
          // an end source span (as there is no explicit closing element).
          el.endSourceSpan = endSourceSpan;

          this._elementStack.splice(stackIndex, this._elementStack.length - stackIndex);

          return true;
        }

        if (!this.getTagDefinition(el.name).closedByParent) {
          return false;
        }
      }

      return false;
    }
  }, {
    key: "_consumeAttr",
    value: function _consumeAttr(attrName) {
      var fullName = mergeNsAndName(attrName.parts[0], attrName.parts[1]);
      var end = attrName.sourceSpan.end;
      var value = '';
      var valueSpan = undefined;

      if (this._peek.type === TokenType.ATTR_QUOTE) {
        this._advance();
      }

      if (this._peek.type === TokenType.ATTR_VALUE) {
        var valueToken = this._advance();

        value = valueToken.parts[0];
        end = valueToken.sourceSpan.end;
        valueSpan = valueToken.sourceSpan;
      }

      if (this._peek.type === TokenType.ATTR_QUOTE) {
        var quoteToken = this._advance();

        end = quoteToken.sourceSpan.end;
      }

      return new Attribute(fullName, value, new ParseSourceSpan(attrName.sourceSpan.start, end), valueSpan);
    }
  }, {
    key: "_getParentElement",
    value: function _getParentElement() {
      return this._elementStack.length > 0 ? this._elementStack[this._elementStack.length - 1] : null;
    }
  }, {
    key: "_addToParent",
    value: function _addToParent(node) {
      var parent = this._getParentElement();

      if (parent != null) {
        parent.children.push(node);
      } else {
        this.rootNodes.push(node);
      }
    }
  }, {
    key: "_getElementFullName",
    value: function _getElementFullName(prefix, localName, parentElement) {
      if (prefix === '') {
        prefix = this.getTagDefinition(localName).implicitNamespacePrefix || '';

        if (prefix === '' && parentElement != null) {
          var parentTagName = splitNsName(parentElement.name)[1];
          var parentTagDefinition = this.getTagDefinition(parentTagName);

          if (!parentTagDefinition.preventNamespaceInheritance) {
            prefix = getNsPrefix(parentElement.name);
          }
        }
      }

      return mergeNsAndName(prefix, localName);
    }
  }]);

  return _TreeBuilder;
}();

function lastOnStack(stack, element) {
  return stack.length > 0 && stack[stack.length - 1] === element;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var HtmlParser = /*#__PURE__*/function (_Parser) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(HtmlParser, _Parser);

  var _super87 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(HtmlParser);

  function HtmlParser() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, HtmlParser);

    return _super87.call(this, getHtmlTagDefinition);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(HtmlParser, [{
    key: "parse",
    value: function parse(source, url, options) {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(HtmlParser.prototype), "parse", this).call(this, source, url, options);
    }
  }]);

  return HtmlParser;
}(Parser);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var PRESERVE_WS_ATTR_NAME = 'ngPreserveWhitespaces';
var SKIP_WS_TRIM_TAGS = new Set(['pre', 'template', 'textarea', 'script', 'style']); // Equivalent to \s with \u00a0 (non-breaking space) excluded.
// Based on https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/RegExp

var WS_CHARS = " \f\n\r\t\x0B\u1680\u180E\u2000-\u200A\u2028\u2029\u202F\u205F\u3000\uFEFF";
var NO_WS_REGEXP = new RegExp("[^".concat(WS_CHARS, "]"));
var WS_REPLACE_REGEXP = new RegExp("[".concat(WS_CHARS, "]{2,}"), 'g');

function hasPreserveWhitespacesAttr(attrs) {
  return attrs.some(function (attr) {
    return attr.name === PRESERVE_WS_ATTR_NAME;
  });
}
/**
 * Angular Dart introduced &ngsp; as a placeholder for non-removable space, see:
 * https://github.com/dart-lang/angular/blob/0bb611387d29d65b5af7f9d2515ab571fd3fbee4/_tests/test/compiler/preserve_whitespace_test.dart#L25-L32
 * In Angular Dart &ngsp; is converted to the 0xE500 PUA (Private Use Areas) unicode character
 * and later on replaced by a space. We are re-implementing the same idea here.
 */


function replaceNgsp(value) {
  // lexer is replacing the &ngsp; pseudo-entity with NGSP_UNICODE
  return value.replace(new RegExp(NGSP_UNICODE, 'g'), ' ');
}
/**
 * This visitor can walk HTML parse tree and remove / trim text nodes using the following rules:
 * - consider spaces, tabs and new lines as whitespace characters;
 * - drop text nodes consisting of whitespace characters only;
 * - for all other text nodes replace consecutive whitespace characters with one space;
 * - convert &ngsp; pseudo-entity to a single space;
 *
 * Removal and trimming of whitespaces have positive performance impact (less code to generate
 * while compiling templates, faster view creation). At the same time it can be "destructive"
 * in some cases (whitespaces can influence layout). Because of the potential of breaking layout
 * this visitor is not activated by default in Angular 5 and people need to explicitly opt-in for
 * whitespace removal. The default option for whitespace removal will be revisited in Angular 6
 * and might be changed to "on" by default.
 */


var WhitespaceVisitor = /*#__PURE__*/function () {
  function WhitespaceVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, WhitespaceVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(WhitespaceVisitor, [{
    key: "visitElement",
    value: function visitElement(element, context) {
      if (SKIP_WS_TRIM_TAGS.has(element.name) || hasPreserveWhitespacesAttr(element.attrs)) {
        // don't descent into elements where we need to preserve whitespaces
        // but still visit all attributes to eliminate one used as a market to preserve WS
        return new Element$1(element.name, visitAll$1(this, element.attrs), element.children, element.sourceSpan, element.startSourceSpan, element.endSourceSpan, element.i18n);
      }

      return new Element$1(element.name, element.attrs, visitAllWithSiblings(this, element.children), element.sourceSpan, element.startSourceSpan, element.endSourceSpan, element.i18n);
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {
      return attribute.name !== PRESERVE_WS_ATTR_NAME ? attribute : null;
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      var isNotBlank = text.value.match(NO_WS_REGEXP);
      var hasExpansionSibling = context && (context.prev instanceof Expansion || context.next instanceof Expansion);

      if (isNotBlank || hasExpansionSibling) {
        return new Text$3(replaceNgsp(text.value).replace(WS_REPLACE_REGEXP, ' '), text.sourceSpan, text.i18n);
      }

      return null;
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {
      return comment;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion, context) {
      return expansion;
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase, context) {
      return expansionCase;
    }
  }]);

  return WhitespaceVisitor;
}();

function removeWhitespaces(htmlAstWithErrors) {
  return new ParseTreeResult(visitAll$1(new WhitespaceVisitor(), htmlAstWithErrors.rootNodes), htmlAstWithErrors.errors);
}

function visitAllWithSiblings(visitor, nodes) {
  var result = [];
  nodes.forEach(function (ast, i) {
    var context = {
      prev: nodes[i - 1],
      next: nodes[i + 1]
    };
    var astResult = ast.visit(visitor, context);

    if (astResult) {
      result.push(astResult);
    }
  });
  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// http://cldr.unicode.org/index/cldr-spec/plural-rules


var PLURAL_CASES = ['zero', 'one', 'two', 'few', 'many', 'other'];
/**
 * Expands special forms into elements.
 *
 * For example,
 *
 * ```
 * { messages.length, plural,
 *   =0 {zero}
 *   =1 {one}
 *   other {more than one}
 * }
 * ```
 *
 * will be expanded into
 *
 * ```
 * <ng-container [ngPlural]="messages.length">
 *   <ng-template ngPluralCase="=0">zero</ng-template>
 *   <ng-template ngPluralCase="=1">one</ng-template>
 *   <ng-template ngPluralCase="other">more than one</ng-template>
 * </ng-container>
 * ```
 */

function expandNodes(nodes) {
  var expander = new _Expander();
  return new ExpansionResult(visitAll$1(expander, nodes), expander.isExpanded, expander.errors);
}

var ExpansionResult = function ExpansionResult(nodes, expanded, errors) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExpansionResult);

  this.nodes = nodes;
  this.expanded = expanded;
  this.errors = errors;
};

var ExpansionError = /*#__PURE__*/function (_ParseError3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ExpansionError, _ParseError3);

  var _super88 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ExpansionError);

  function ExpansionError(span, errorMsg) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExpansionError);

    return _super88.call(this, span, errorMsg);
  }

  return ExpansionError;
}(ParseError);
/**
 * Expand expansion forms (plural, select) to directives
 *
 * @internal
 */


var _Expander = /*#__PURE__*/function () {
  function _Expander() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _Expander);

    this.isExpanded = false;
    this.errors = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_Expander, [{
    key: "visitElement",
    value: function visitElement(element, context) {
      return new Element$1(element.name, element.attrs, visitAll$1(this, element.children), element.sourceSpan, element.startSourceSpan, element.endSourceSpan);
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {
      return attribute;
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      return text;
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {
      return comment;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(icu, context) {
      this.isExpanded = true;
      return icu.type == 'plural' ? _expandPluralForm(icu, this.errors) : _expandDefaultForm(icu, this.errors);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(icuCase, context) {
      throw new Error('Should not be reached');
    }
  }]);

  return _Expander;
}(); // Plural forms are expanded to `NgPlural` and `NgPluralCase`s


function _expandPluralForm(ast, errors) {
  var children = ast.cases.map(function (c) {
    if (PLURAL_CASES.indexOf(c.value) == -1 && !c.value.match(/^=\d+$/)) {
      errors.push(new ExpansionError(c.valueSourceSpan, "Plural cases should be \"=<number>\" or one of ".concat(PLURAL_CASES.join(', '))));
    }

    var expansionResult = expandNodes(c.expression);
    errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(expansionResult.errors));
    return new Element$1("ng-template", [new Attribute('ngPluralCase', "".concat(c.value), c.valueSourceSpan)], expansionResult.nodes, c.sourceSpan, c.sourceSpan, c.sourceSpan);
  });
  var switchAttr = new Attribute('[ngPlural]', ast.switchValue, ast.switchValueSourceSpan);
  return new Element$1('ng-container', [switchAttr], children, ast.sourceSpan, ast.sourceSpan, ast.sourceSpan);
} // ICU messages (excluding plural form) are expanded to `NgSwitch`  and `NgSwitchCase`s


function _expandDefaultForm(ast, errors) {
  var children = ast.cases.map(function (c) {
    var expansionResult = expandNodes(c.expression);
    errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(expansionResult.errors));

    if (c.value === 'other') {
      // other is the default case when no values match
      return new Element$1("ng-template", [new Attribute('ngSwitchDefault', '', c.valueSourceSpan)], expansionResult.nodes, c.sourceSpan, c.sourceSpan, c.sourceSpan);
    }

    return new Element$1("ng-template", [new Attribute('ngSwitchCase', "".concat(c.value), c.valueSourceSpan)], expansionResult.nodes, c.sourceSpan, c.sourceSpan, c.sourceSpan);
  });
  var switchAttr = new Attribute('[ngSwitch]', ast.switchValue, ast.switchValueSourceSpan);
  return new Element$1('ng-container', [switchAttr], children, ast.sourceSpan, ast.sourceSpan, ast.sourceSpan);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A segment of text within the template.
 */


var TextAst = /*#__PURE__*/function () {
  function TextAst(value, ngContentIndex, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TextAst);

    this.value = value;
    this.ngContentIndex = ngContentIndex;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TextAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitText(this, context);
    }
  }]);

  return TextAst;
}();
/**
 * A bound expression within the text of a template.
 */


var BoundTextAst = /*#__PURE__*/function () {
  function BoundTextAst(value, ngContentIndex, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundTextAst);

    this.value = value;
    this.ngContentIndex = ngContentIndex;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundTextAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitBoundText(this, context);
    }
  }]);

  return BoundTextAst;
}();
/**
 * A plain attribute on an element.
 */


var AttrAst = /*#__PURE__*/function () {
  function AttrAst(name, value, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AttrAst);

    this.name = name;
    this.value = value;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AttrAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitAttr(this, context);
    }
  }]);

  return AttrAst;
}();

var BoundPropertyMapping = (_BoundPropertyMapping = {}, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_BoundPropertyMapping, 4
/* Animation */
, 4), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_BoundPropertyMapping, 1
/* Attribute */
,
/* Animation */
1), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_BoundPropertyMapping, 2
/* Class */
,
/* Attribute */
2), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_BoundPropertyMapping, 0
/* Property */
,
/* Class */
0), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])(_BoundPropertyMapping, 3
/* Style */
,
/* Property */
3), _BoundPropertyMapping);
/**
 * A binding for an element property (e.g. `[property]="expression"`) or an animation trigger (e.g.
 * `[@trigger]="stateExp"`)
 */

var BoundElementPropertyAst = /*#__PURE__*/function () {
  function BoundElementPropertyAst(name, type, securityContext, value, unit, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundElementPropertyAst);

    this.name = name;
    this.type = type;
    this.securityContext = securityContext;
    this.value = value;
    this.unit = unit;
    this.sourceSpan = sourceSpan;
    this.isAnimation = this.type === 4
    /* Animation */
    ;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundElementPropertyAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitElementProperty(this, context);
    }
  }], [{
    key: "fromBoundProperty",
    value: function fromBoundProperty(prop) {
      var type = BoundPropertyMapping[prop.type];
      return new BoundElementPropertyAst(prop.name, type, prop.securityContext, prop.value, prop.unit, prop.sourceSpan);
    }
  }]);

  return BoundElementPropertyAst;
}();
/**
 * A binding for an element event (e.g. `(event)="handler()"`) or an animation trigger event (e.g.
 * `(@trigger.phase)="callback($event)"`).
 */


var BoundEventAst = /*#__PURE__*/function () {
  function BoundEventAst(name, target, phase, handler, sourceSpan, handlerSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundEventAst);

    this.name = name;
    this.target = target;
    this.phase = phase;
    this.handler = handler;
    this.sourceSpan = sourceSpan;
    this.handlerSpan = handlerSpan;
    this.fullName = BoundEventAst.calcFullName(this.name, this.target, this.phase);
    this.isAnimation = !!this.phase;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundEventAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitEvent(this, context);
    }
  }], [{
    key: "calcFullName",
    value: function calcFullName(name, target, phase) {
      if (target) {
        return "".concat(target, ":").concat(name);
      }

      if (phase) {
        return "@".concat(name, ".").concat(phase);
      }

      return name;
    }
  }, {
    key: "fromParsedEvent",
    value: function fromParsedEvent(event) {
      var target = event.type === 0
      /* Regular */
      ? event.targetOrPhase : null;
      var phase = event.type === 1
      /* Animation */
      ? event.targetOrPhase : null;
      return new BoundEventAst(event.name, target, phase, event.handler, event.sourceSpan, event.handlerSpan);
    }
  }]);

  return BoundEventAst;
}();
/**
 * A reference declaration on an element (e.g. `let someName="expression"`).
 */


var ReferenceAst = /*#__PURE__*/function () {
  function ReferenceAst(name, value, originalValue, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReferenceAst);

    this.name = name;
    this.value = value;
    this.originalValue = originalValue;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ReferenceAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitReference(this, context);
    }
  }]);

  return ReferenceAst;
}();
/**
 * A variable declaration on a <ng-template> (e.g. `var-someName="someLocalName"`).
 */


var VariableAst = /*#__PURE__*/function () {
  function VariableAst(name, value, sourceSpan, valueSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, VariableAst);

    this.name = name;
    this.value = value;
    this.sourceSpan = sourceSpan;
    this.valueSpan = valueSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(VariableAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitVariable(this, context);
    }
  }], [{
    key: "fromParsedVariable",
    value: function fromParsedVariable(v) {
      return new VariableAst(v.name, v.value, v.sourceSpan, v.valueSpan);
    }
  }]);

  return VariableAst;
}();
/**
 * An element declaration in a template.
 */


var ElementAst = /*#__PURE__*/function () {
  function ElementAst(name, attrs, inputs, outputs, references, directives, providers, hasViewContainer, queryMatches, children, ngContentIndex, sourceSpan, endSourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ElementAst);

    this.name = name;
    this.attrs = attrs;
    this.inputs = inputs;
    this.outputs = outputs;
    this.references = references;
    this.directives = directives;
    this.providers = providers;
    this.hasViewContainer = hasViewContainer;
    this.queryMatches = queryMatches;
    this.children = children;
    this.ngContentIndex = ngContentIndex;
    this.sourceSpan = sourceSpan;
    this.endSourceSpan = endSourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ElementAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitElement(this, context);
    }
  }]);

  return ElementAst;
}();
/**
 * A `<ng-template>` element included in an Angular template.
 */


var EmbeddedTemplateAst = /*#__PURE__*/function () {
  function EmbeddedTemplateAst(attrs, outputs, references, variables, directives, providers, hasViewContainer, queryMatches, children, ngContentIndex, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, EmbeddedTemplateAst);

    this.attrs = attrs;
    this.outputs = outputs;
    this.references = references;
    this.variables = variables;
    this.directives = directives;
    this.providers = providers;
    this.hasViewContainer = hasViewContainer;
    this.queryMatches = queryMatches;
    this.children = children;
    this.ngContentIndex = ngContentIndex;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(EmbeddedTemplateAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitEmbeddedTemplate(this, context);
    }
  }]);

  return EmbeddedTemplateAst;
}();
/**
 * A directive property with a bound value (e.g. `*ngIf="condition").
 */


var BoundDirectivePropertyAst = /*#__PURE__*/function () {
  function BoundDirectivePropertyAst(directiveName, templateName, value, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BoundDirectivePropertyAst);

    this.directiveName = directiveName;
    this.templateName = templateName;
    this.value = value;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BoundDirectivePropertyAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitDirectiveProperty(this, context);
    }
  }]);

  return BoundDirectivePropertyAst;
}();
/**
 * A directive declared on an element.
 */


var DirectiveAst = /*#__PURE__*/function () {
  function DirectiveAst(directive, inputs, hostProperties, hostEvents, contentQueryStartId, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DirectiveAst);

    this.directive = directive;
    this.inputs = inputs;
    this.hostProperties = hostProperties;
    this.hostEvents = hostEvents;
    this.contentQueryStartId = contentQueryStartId;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DirectiveAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitDirective(this, context);
    }
  }]);

  return DirectiveAst;
}();
/**
 * A provider declared on an element
 */


var ProviderAst = /*#__PURE__*/function () {
  function ProviderAst(token, multiProvider, eager, providers, providerType, lifecycleHooks, sourceSpan, isModule) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ProviderAst);

    this.token = token;
    this.multiProvider = multiProvider;
    this.eager = eager;
    this.providers = providers;
    this.providerType = providerType;
    this.lifecycleHooks = lifecycleHooks;
    this.sourceSpan = sourceSpan;
    this.isModule = isModule;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ProviderAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      // No visit method in the visitor for now...
      return null;
    }
  }]);

  return ProviderAst;
}();

var ProviderAstType;

(function (ProviderAstType) {
  ProviderAstType[ProviderAstType["PublicService"] = 0] = "PublicService";
  ProviderAstType[ProviderAstType["PrivateService"] = 1] = "PrivateService";
  ProviderAstType[ProviderAstType["Component"] = 2] = "Component";
  ProviderAstType[ProviderAstType["Directive"] = 3] = "Directive";
  ProviderAstType[ProviderAstType["Builtin"] = 4] = "Builtin";
})(ProviderAstType || (ProviderAstType = {}));
/**
 * Position where content is to be projected (instance of `<ng-content>` in a template).
 */


var NgContentAst = /*#__PURE__*/function () {
  function NgContentAst(index, ngContentIndex, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NgContentAst);

    this.index = index;
    this.ngContentIndex = ngContentIndex;
    this.sourceSpan = sourceSpan;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NgContentAst, [{
    key: "visit",
    value: function visit(visitor, context) {
      return visitor.visitNgContent(this, context);
    }
  }]);

  return NgContentAst;
}();
/**
 * A visitor that accepts each node but doesn't do anything. It is intended to be used
 * as the base class for a visitor that is only interested in a subset of the node types.
 */


var NullTemplateVisitor = /*#__PURE__*/function () {
  function NullTemplateVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NullTemplateVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NullTemplateVisitor, [{
    key: "visitNgContent",
    value: function visitNgContent(ast, context) {}
  }, {
    key: "visitEmbeddedTemplate",
    value: function visitEmbeddedTemplate(ast, context) {}
  }, {
    key: "visitElement",
    value: function visitElement(ast, context) {}
  }, {
    key: "visitReference",
    value: function visitReference(ast, context) {}
  }, {
    key: "visitVariable",
    value: function visitVariable(ast, context) {}
  }, {
    key: "visitEvent",
    value: function visitEvent(ast, context) {}
  }, {
    key: "visitElementProperty",
    value: function visitElementProperty(ast, context) {}
  }, {
    key: "visitAttr",
    value: function visitAttr(ast, context) {}
  }, {
    key: "visitBoundText",
    value: function visitBoundText(ast, context) {}
  }, {
    key: "visitText",
    value: function visitText(ast, context) {}
  }, {
    key: "visitDirective",
    value: function visitDirective(ast, context) {}
  }, {
    key: "visitDirectiveProperty",
    value: function visitDirectiveProperty(ast, context) {}
  }]);

  return NullTemplateVisitor;
}();
/**
 * Base class that can be used to build a visitor that visits each node
 * in an template ast recursively.
 */


var RecursiveTemplateAstVisitor = /*#__PURE__*/function (_NullTemplateVisitor) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(RecursiveTemplateAstVisitor, _NullTemplateVisitor);

  var _super89 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(RecursiveTemplateAstVisitor);

  function RecursiveTemplateAstVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, RecursiveTemplateAstVisitor);

    return _super89.call(this);
  } // Nodes with children


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(RecursiveTemplateAstVisitor, [{
    key: "visitEmbeddedTemplate",
    value: function visitEmbeddedTemplate(ast, context) {
      return this.visitChildren(context, function (visit) {
        visit(ast.attrs);
        visit(ast.references);
        visit(ast.variables);
        visit(ast.directives);
        visit(ast.providers);
        visit(ast.children);
      });
    }
  }, {
    key: "visitElement",
    value: function visitElement(ast, context) {
      return this.visitChildren(context, function (visit) {
        visit(ast.attrs);
        visit(ast.inputs);
        visit(ast.outputs);
        visit(ast.references);
        visit(ast.directives);
        visit(ast.providers);
        visit(ast.children);
      });
    }
  }, {
    key: "visitDirective",
    value: function visitDirective(ast, context) {
      return this.visitChildren(context, function (visit) {
        visit(ast.inputs);
        visit(ast.hostProperties);
        visit(ast.hostEvents);
      });
    }
  }, {
    key: "visitChildren",
    value: function visitChildren(context, cb) {
      var results = [];
      var t = this;

      function visit(children) {
        if (children && children.length) results.push(templateVisitAll(t, children, context));
      }

      cb(visit);
      return Array.prototype.concat.apply([], results);
    }
  }]);

  return RecursiveTemplateAstVisitor;
}(NullTemplateVisitor);
/**
 * Visit every node in a list of {@link TemplateAst}s with the given {@link TemplateAstVisitor}.
 */


function templateVisitAll(visitor, asts) {
  var context = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var result = [];
  var visit = visitor.visit ? function (ast) {
    return visitor.visit(ast, context) || ast.visit(visitor, context);
  } : function (ast) {
    return ast.visit(visitor, context);
  };
  asts.forEach(function (ast) {
    var astResult = visit(ast);

    if (astResult) {
      result.push(astResult);
    }
  });
  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ProviderError = /*#__PURE__*/function (_ParseError4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ProviderError, _ParseError4);

  var _super90 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ProviderError);

  function ProviderError(message, span) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ProviderError);

    return _super90.call(this, span, message);
  }

  return ProviderError;
}(ParseError);

var ProviderViewContext = function ProviderViewContext(reflector, component) {
  var _this133 = this;

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ProviderViewContext);

  this.reflector = reflector;
  this.component = component;
  this.errors = [];
  this.viewQueries = _getViewQueries(component);
  this.viewProviders = new Map();
  component.viewProviders.forEach(function (provider) {
    if (_this133.viewProviders.get(tokenReference(provider.token)) == null) {
      _this133.viewProviders.set(tokenReference(provider.token), true);
    }
  });
};

var ProviderElementContext = /*#__PURE__*/function () {
  function ProviderElementContext(viewContext, _parent, _isViewRoot, _directiveAsts, attrs, refs, isTemplate, contentQueryStartId, _sourceSpan) {
    var _this134 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ProviderElementContext);

    this.viewContext = viewContext;
    this._parent = _parent;
    this._isViewRoot = _isViewRoot;
    this._directiveAsts = _directiveAsts;
    this._sourceSpan = _sourceSpan;
    this._transformedProviders = new Map();
    this._seenProviders = new Map();
    this._queriedTokens = new Map();
    this.transformedHasViewContainer = false;
    this._attrs = {};
    attrs.forEach(function (attrAst) {
      return _this134._attrs[attrAst.name] = attrAst.value;
    });

    var directivesMeta = _directiveAsts.map(function (directiveAst) {
      return directiveAst.directive;
    });

    this._allProviders = _resolveProvidersFromDirectives(directivesMeta, _sourceSpan, viewContext.errors);
    this._contentQueries = _getContentQueries(contentQueryStartId, directivesMeta);
    Array.from(this._allProviders.values()).forEach(function (provider) {
      _this134._addQueryReadsTo(provider.token, provider.token, _this134._queriedTokens);
    });

    if (isTemplate) {
      var templateRefId = createTokenForExternalReference(this.viewContext.reflector, Identifiers.TemplateRef);

      this._addQueryReadsTo(templateRefId, templateRefId, this._queriedTokens);
    }

    refs.forEach(function (refAst) {
      var defaultQueryValue = refAst.value || createTokenForExternalReference(_this134.viewContext.reflector, Identifiers.ElementRef);

      _this134._addQueryReadsTo({
        value: refAst.name
      }, defaultQueryValue, _this134._queriedTokens);
    });

    if (this._queriedTokens.get(this.viewContext.reflector.resolveExternalReference(Identifiers.ViewContainerRef))) {
      this.transformedHasViewContainer = true;
    } // create the providers that we know are eager first


    Array.from(this._allProviders.values()).forEach(function (provider) {
      var eager = provider.eager || _this134._queriedTokens.get(tokenReference(provider.token));

      if (eager) {
        _this134._getOrCreateLocalProvider(provider.providerType, provider.token, true);
      }
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ProviderElementContext, [{
    key: "afterElement",
    value: function afterElement() {
      var _this135 = this;

      // collect lazy providers
      Array.from(this._allProviders.values()).forEach(function (provider) {
        _this135._getOrCreateLocalProvider(provider.providerType, provider.token, false);
      });
    }
  }, {
    key: "_addQueryReadsTo",
    value: function _addQueryReadsTo(token, defaultValue, queryReadTokens) {
      this._getQueriesFor(token).forEach(function (query) {
        var queryValue = query.meta.read || defaultValue;
        var tokenRef = tokenReference(queryValue);
        var queryMatches = queryReadTokens.get(tokenRef);

        if (!queryMatches) {
          queryMatches = [];
          queryReadTokens.set(tokenRef, queryMatches);
        }

        queryMatches.push({
          queryId: query.queryId,
          value: queryValue
        });
      });
    }
  }, {
    key: "_getQueriesFor",
    value: function _getQueriesFor(token) {
      var result = [];
      var currentEl = this;
      var distance = 0;
      var queries;

      while (currentEl !== null) {
        queries = currentEl._contentQueries.get(tokenReference(token));

        if (queries) {
          result.push.apply(result, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(queries.filter(function (query) {
            return query.meta.descendants || distance <= 1;
          })));
        }

        if (currentEl._directiveAsts.length > 0) {
          distance++;
        }

        currentEl = currentEl._parent;
      }

      queries = this.viewContext.viewQueries.get(tokenReference(token));

      if (queries) {
        result.push.apply(result, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(queries));
      }

      return result;
    }
  }, {
    key: "_getOrCreateLocalProvider",
    value: function _getOrCreateLocalProvider(requestingProviderType, token, eager) {
      var _this136 = this;

      var resolvedProvider = this._allProviders.get(tokenReference(token));

      if (!resolvedProvider || (requestingProviderType === ProviderAstType.Directive || requestingProviderType === ProviderAstType.PublicService) && resolvedProvider.providerType === ProviderAstType.PrivateService || (requestingProviderType === ProviderAstType.PrivateService || requestingProviderType === ProviderAstType.PublicService) && resolvedProvider.providerType === ProviderAstType.Builtin) {
        return null;
      }

      var transformedProviderAst = this._transformedProviders.get(tokenReference(token));

      if (transformedProviderAst) {
        return transformedProviderAst;
      }

      if (this._seenProviders.get(tokenReference(token)) != null) {
        this.viewContext.errors.push(new ProviderError("Cannot instantiate cyclic dependency! ".concat(tokenName(token)), this._sourceSpan));
        return null;
      }

      this._seenProviders.set(tokenReference(token), true);

      var transformedProviders = resolvedProvider.providers.map(function (provider) {
        var transformedUseValue = provider.useValue;
        var transformedUseExisting = provider.useExisting;
        var transformedDeps = undefined;

        if (provider.useExisting != null) {
          var existingDiDep = _this136._getDependency(resolvedProvider.providerType, {
            token: provider.useExisting
          }, eager);

          if (existingDiDep.token != null) {
            transformedUseExisting = existingDiDep.token;
          } else {
            transformedUseExisting = null;
            transformedUseValue = existingDiDep.value;
          }
        } else if (provider.useFactory) {
          var deps = provider.deps || provider.useFactory.diDeps;
          transformedDeps = deps.map(function (dep) {
            return _this136._getDependency(resolvedProvider.providerType, dep, eager);
          });
        } else if (provider.useClass) {
          var _deps = provider.deps || provider.useClass.diDeps;

          transformedDeps = _deps.map(function (dep) {
            return _this136._getDependency(resolvedProvider.providerType, dep, eager);
          });
        }

        return _transformProvider(provider, {
          useExisting: transformedUseExisting,
          useValue: transformedUseValue,
          deps: transformedDeps
        });
      });
      transformedProviderAst = _transformProviderAst(resolvedProvider, {
        eager: eager,
        providers: transformedProviders
      });

      this._transformedProviders.set(tokenReference(token), transformedProviderAst);

      return transformedProviderAst;
    }
  }, {
    key: "_getLocalDependency",
    value: function _getLocalDependency(requestingProviderType, dep) {
      var eager = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

      if (dep.isAttribute) {
        var attrValue = this._attrs[dep.token.value];
        return {
          isValue: true,
          value: attrValue == null ? null : attrValue
        };
      }

      if (dep.token != null) {
        // access builtints
        if (requestingProviderType === ProviderAstType.Directive || requestingProviderType === ProviderAstType.Component) {
          if (tokenReference(dep.token) === this.viewContext.reflector.resolveExternalReference(Identifiers.Renderer) || tokenReference(dep.token) === this.viewContext.reflector.resolveExternalReference(Identifiers.ElementRef) || tokenReference(dep.token) === this.viewContext.reflector.resolveExternalReference(Identifiers.ChangeDetectorRef) || tokenReference(dep.token) === this.viewContext.reflector.resolveExternalReference(Identifiers.TemplateRef)) {
            return dep;
          }

          if (tokenReference(dep.token) === this.viewContext.reflector.resolveExternalReference(Identifiers.ViewContainerRef)) {
            this.transformedHasViewContainer = true;
          }
        } // access the injector


        if (tokenReference(dep.token) === this.viewContext.reflector.resolveExternalReference(Identifiers.Injector)) {
          return dep;
        } // access providers


        if (this._getOrCreateLocalProvider(requestingProviderType, dep.token, eager) != null) {
          return dep;
        }
      }

      return null;
    }
  }, {
    key: "_getDependency",
    value: function _getDependency(requestingProviderType, dep) {
      var eager = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
      var currElement = this;
      var currEager = eager;
      var result = null;

      if (!dep.isSkipSelf) {
        result = this._getLocalDependency(requestingProviderType, dep, eager);
      }

      if (dep.isSelf) {
        if (!result && dep.isOptional) {
          result = {
            isValue: true,
            value: null
          };
        }
      } else {
        // check parent elements
        while (!result && currElement._parent) {
          var prevElement = currElement;
          currElement = currElement._parent;

          if (prevElement._isViewRoot) {
            currEager = false;
          }

          result = currElement._getLocalDependency(ProviderAstType.PublicService, dep, currEager);
        } // check @Host restriction


        if (!result) {
          if (!dep.isHost || this.viewContext.component.isHost || this.viewContext.component.type.reference === tokenReference(dep.token) || this.viewContext.viewProviders.get(tokenReference(dep.token)) != null) {
            result = dep;
          } else {
            result = dep.isOptional ? {
              isValue: true,
              value: null
            } : null;
          }
        }
      }

      if (!result) {
        this.viewContext.errors.push(new ProviderError("No provider for ".concat(tokenName(dep.token)), this._sourceSpan));
      }

      return result;
    }
  }, {
    key: "transformProviders",
    get: function get() {
      // Note: Maps keep their insertion order.
      var lazyProviders = [];
      var eagerProviders = [];

      this._transformedProviders.forEach(function (provider) {
        if (provider.eager) {
          eagerProviders.push(provider);
        } else {
          lazyProviders.push(provider);
        }
      });

      return lazyProviders.concat(eagerProviders);
    }
  }, {
    key: "transformedDirectiveAsts",
    get: function get() {
      var sortedProviderTypes = this.transformProviders.map(function (provider) {
        return provider.token.identifier;
      });

      var sortedDirectives = this._directiveAsts.slice();

      sortedDirectives.sort(function (dir1, dir2) {
        return sortedProviderTypes.indexOf(dir1.directive.type) - sortedProviderTypes.indexOf(dir2.directive.type);
      });
      return sortedDirectives;
    }
  }, {
    key: "queryMatches",
    get: function get() {
      var allMatches = [];

      this._queriedTokens.forEach(function (matches) {
        allMatches.push.apply(allMatches, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(matches));
      });

      return allMatches;
    }
  }]);

  return ProviderElementContext;
}();

var NgModuleProviderAnalyzer = /*#__PURE__*/function () {
  function NgModuleProviderAnalyzer(reflector, ngModule, extraProviders, sourceSpan) {
    var _this137 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NgModuleProviderAnalyzer);

    this.reflector = reflector;
    this._transformedProviders = new Map();
    this._seenProviders = new Map();
    this._errors = [];
    this._allProviders = new Map();
    ngModule.transitiveModule.modules.forEach(function (ngModuleType) {
      var ngModuleProvider = {
        token: {
          identifier: ngModuleType
        },
        useClass: ngModuleType
      };

      _resolveProviders([ngModuleProvider], ProviderAstType.PublicService, true, sourceSpan, _this137._errors, _this137._allProviders,
      /* isModule */
      true);
    });

    _resolveProviders(ngModule.transitiveModule.providers.map(function (entry) {
      return entry.provider;
    }).concat(extraProviders), ProviderAstType.PublicService, false, sourceSpan, this._errors, this._allProviders,
    /* isModule */
    false);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NgModuleProviderAnalyzer, [{
    key: "parse",
    value: function parse() {
      var _this138 = this;

      Array.from(this._allProviders.values()).forEach(function (provider) {
        _this138._getOrCreateLocalProvider(provider.token, provider.eager);
      });

      if (this._errors.length > 0) {
        var errorString = this._errors.join('\n');

        throw new Error("Provider parse errors:\n".concat(errorString));
      } // Note: Maps keep their insertion order.


      var lazyProviders = [];
      var eagerProviders = [];

      this._transformedProviders.forEach(function (provider) {
        if (provider.eager) {
          eagerProviders.push(provider);
        } else {
          lazyProviders.push(provider);
        }
      });

      return lazyProviders.concat(eagerProviders);
    }
  }, {
    key: "_getOrCreateLocalProvider",
    value: function _getOrCreateLocalProvider(token, eager) {
      var _this139 = this;

      var resolvedProvider = this._allProviders.get(tokenReference(token));

      if (!resolvedProvider) {
        return null;
      }

      var transformedProviderAst = this._transformedProviders.get(tokenReference(token));

      if (transformedProviderAst) {
        return transformedProviderAst;
      }

      if (this._seenProviders.get(tokenReference(token)) != null) {
        this._errors.push(new ProviderError("Cannot instantiate cyclic dependency! ".concat(tokenName(token)), resolvedProvider.sourceSpan));

        return null;
      }

      this._seenProviders.set(tokenReference(token), true);

      var transformedProviders = resolvedProvider.providers.map(function (provider) {
        var transformedUseValue = provider.useValue;
        var transformedUseExisting = provider.useExisting;
        var transformedDeps = undefined;

        if (provider.useExisting != null) {
          var existingDiDep = _this139._getDependency({
            token: provider.useExisting
          }, eager, resolvedProvider.sourceSpan);

          if (existingDiDep.token != null) {
            transformedUseExisting = existingDiDep.token;
          } else {
            transformedUseExisting = null;
            transformedUseValue = existingDiDep.value;
          }
        } else if (provider.useFactory) {
          var deps = provider.deps || provider.useFactory.diDeps;
          transformedDeps = deps.map(function (dep) {
            return _this139._getDependency(dep, eager, resolvedProvider.sourceSpan);
          });
        } else if (provider.useClass) {
          var _deps2 = provider.deps || provider.useClass.diDeps;

          transformedDeps = _deps2.map(function (dep) {
            return _this139._getDependency(dep, eager, resolvedProvider.sourceSpan);
          });
        }

        return _transformProvider(provider, {
          useExisting: transformedUseExisting,
          useValue: transformedUseValue,
          deps: transformedDeps
        });
      });
      transformedProviderAst = _transformProviderAst(resolvedProvider, {
        eager: eager,
        providers: transformedProviders
      });

      this._transformedProviders.set(tokenReference(token), transformedProviderAst);

      return transformedProviderAst;
    }
  }, {
    key: "_getDependency",
    value: function _getDependency(dep) {
      var eager = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      var requestorSourceSpan = arguments.length > 2 ? arguments[2] : undefined;
      var foundLocal = false;

      if (!dep.isSkipSelf && dep.token != null) {
        // access the injector
        if (tokenReference(dep.token) === this.reflector.resolveExternalReference(Identifiers.Injector) || tokenReference(dep.token) === this.reflector.resolveExternalReference(Identifiers.ComponentFactoryResolver)) {
          foundLocal = true; // access providers
        } else if (this._getOrCreateLocalProvider(dep.token, eager) != null) {
          foundLocal = true;
        }
      }

      return dep;
    }
  }]);

  return NgModuleProviderAnalyzer;
}();

function _transformProvider(provider, _ref11) {
  var useExisting = _ref11.useExisting,
      useValue = _ref11.useValue,
      deps = _ref11.deps;
  return {
    token: provider.token,
    useClass: provider.useClass,
    useExisting: useExisting,
    useFactory: provider.useFactory,
    useValue: useValue,
    deps: deps,
    multi: provider.multi
  };
}

function _transformProviderAst(provider, _ref12) {
  var eager = _ref12.eager,
      providers = _ref12.providers;
  return new ProviderAst(provider.token, provider.multiProvider, provider.eager || eager, providers, provider.providerType, provider.lifecycleHooks, provider.sourceSpan, provider.isModule);
}

function _resolveProvidersFromDirectives(directives, sourceSpan, targetErrors) {
  var providersByToken = new Map();
  directives.forEach(function (directive) {
    var dirProvider = {
      token: {
        identifier: directive.type
      },
      useClass: directive.type
    };

    _resolveProviders([dirProvider], directive.isComponent ? ProviderAstType.Component : ProviderAstType.Directive, true, sourceSpan, targetErrors, providersByToken,
    /* isModule */
    false);
  }); // Note: directives need to be able to overwrite providers of a component!

  var directivesWithComponentFirst = directives.filter(function (dir) {
    return dir.isComponent;
  }).concat(directives.filter(function (dir) {
    return !dir.isComponent;
  }));
  directivesWithComponentFirst.forEach(function (directive) {
    _resolveProviders(directive.providers, ProviderAstType.PublicService, false, sourceSpan, targetErrors, providersByToken,
    /* isModule */
    false);

    _resolveProviders(directive.viewProviders, ProviderAstType.PrivateService, false, sourceSpan, targetErrors, providersByToken,
    /* isModule */
    false);
  });
  return providersByToken;
}

function _resolveProviders(providers, providerType, eager, sourceSpan, targetErrors, targetProvidersByToken, isModule) {
  providers.forEach(function (provider) {
    var resolvedProvider = targetProvidersByToken.get(tokenReference(provider.token));

    if (resolvedProvider != null && !!resolvedProvider.multiProvider !== !!provider.multi) {
      targetErrors.push(new ProviderError("Mixing multi and non multi provider is not possible for token ".concat(tokenName(resolvedProvider.token)), sourceSpan));
    }

    if (!resolvedProvider) {
      var lifecycleHooks = provider.token.identifier && provider.token.identifier.lifecycleHooks ? provider.token.identifier.lifecycleHooks : [];
      var isUseValue = !(provider.useClass || provider.useExisting || provider.useFactory);
      resolvedProvider = new ProviderAst(provider.token, !!provider.multi, eager || isUseValue, [provider], providerType, lifecycleHooks, sourceSpan, isModule);
      targetProvidersByToken.set(tokenReference(provider.token), resolvedProvider);
    } else {
      if (!provider.multi) {
        resolvedProvider.providers.length = 0;
      }

      resolvedProvider.providers.push(provider);
    }
  });
}

function _getViewQueries(component) {
  // Note: queries start with id 1 so we can use the number in a Bloom filter!
  var viewQueryId = 1;
  var viewQueries = new Map();

  if (component.viewQueries) {
    component.viewQueries.forEach(function (query) {
      return _addQueryToTokenMap(viewQueries, {
        meta: query,
        queryId: viewQueryId++
      });
    });
  }

  return viewQueries;
}

function _getContentQueries(contentQueryStartId, directives) {
  var contentQueryId = contentQueryStartId;
  var contentQueries = new Map();
  directives.forEach(function (directive, directiveIndex) {
    if (directive.queries) {
      directive.queries.forEach(function (query) {
        return _addQueryToTokenMap(contentQueries, {
          meta: query,
          queryId: contentQueryId++
        });
      });
    }
  });
  return contentQueries;
}

function _addQueryToTokenMap(map, query) {
  query.meta.selectors.forEach(function (token) {
    var entry = map.get(tokenReference(token));

    if (!entry) {
      entry = [];
      map.set(tokenReference(token), entry);
    }

    entry.push(query);
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var StyleWithImports = function StyleWithImports(style, styleUrls) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StyleWithImports);

  this.style = style;
  this.styleUrls = styleUrls;
};

function isStyleUrlResolvable(url) {
  if (url == null || url.length === 0 || url[0] == '/') return false;
  var schemeMatch = url.match(URL_WITH_SCHEMA_REGEXP);
  return schemeMatch === null || schemeMatch[1] == 'package' || schemeMatch[1] == 'asset';
}
/**
 * Rewrites stylesheets by resolving and removing the @import urls that
 * are either relative or don't have a `package:` scheme
 */


function extractStyleUrls(resolver, baseUrl, cssText) {
  var foundUrls = [];
  var modifiedCssText = cssText.replace(CSS_STRIPPABLE_COMMENT_REGEXP, '').replace(CSS_IMPORT_REGEXP, function () {
    var url = (arguments.length <= 1 ? undefined : arguments[1]) || (arguments.length <= 2 ? undefined : arguments[2]);

    if (!isStyleUrlResolvable(url)) {
      // Do not attempt to resolve non-package absolute URLs with URI
      // scheme
      return arguments.length <= 0 ? undefined : arguments[0];
    }

    foundUrls.push(resolver.resolve(baseUrl, url));
    return '';
  });
  return new StyleWithImports(modifiedCssText, foundUrls);
}

var CSS_IMPORT_REGEXP = /@import\s+(?:url\()?\s*(?:(?:['"]([^'"]*))|([^;\)\s]*))[^;]*;?/g;
var CSS_STRIPPABLE_COMMENT_REGEXP = /\/\*(?!#\s*(?:sourceURL|sourceMappingURL)=)[\s\S]+?\*\//g;
var URL_WITH_SCHEMA_REGEXP = /^([^:/?#]+):/;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var PROPERTY_PARTS_SEPARATOR = '.';
var ATTRIBUTE_PREFIX = 'attr';
var CLASS_PREFIX = 'class';
var STYLE_PREFIX = 'style';
var TEMPLATE_ATTR_PREFIX = '*';
var ANIMATE_PROP_PREFIX = 'animate-';
/**
 * Parses bindings in templates and in the directive host area.
 */

var BindingParser = /*#__PURE__*/function () {
  function BindingParser(_exprParser, _interpolationConfig, _schemaRegistry, pipes, errors) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BindingParser);

    this._exprParser = _exprParser;
    this._interpolationConfig = _interpolationConfig;
    this._schemaRegistry = _schemaRegistry;
    this.errors = errors;
    this.pipesByName = null;
    this._usedPipes = new Map(); // When the `pipes` parameter is `null`, do not check for used pipes
    // This is used in IVY when we might not know the available pipes at compile time

    if (pipes) {
      var pipesByName = new Map();
      pipes.forEach(function (pipe) {
        return pipesByName.set(pipe.name, pipe);
      });
      this.pipesByName = pipesByName;
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BindingParser, [{
    key: "getUsedPipes",
    value: function getUsedPipes() {
      return Array.from(this._usedPipes.values());
    }
  }, {
    key: "createBoundHostProperties",
    value: function createBoundHostProperties(dirMeta, sourceSpan) {
      var _this140 = this;

      if (dirMeta.hostProperties) {
        var boundProps = [];
        Object.keys(dirMeta.hostProperties).forEach(function (propName) {
          var expression = dirMeta.hostProperties[propName];

          if (typeof expression === 'string') {
            _this140.parsePropertyBinding(propName, expression, true, sourceSpan, sourceSpan.start.offset, undefined, [], boundProps);
          } else {
            _this140._reportError("Value of the host property binding \"".concat(propName, "\" needs to be a string representing an expression but got \"").concat(expression, "\" (").concat(typeof expression, ")"), sourceSpan);
          }
        });
        return boundProps;
      }

      return null;
    }
  }, {
    key: "createDirectiveHostPropertyAsts",
    value: function createDirectiveHostPropertyAsts(dirMeta, elementSelector, sourceSpan) {
      var _this141 = this;

      var boundProps = this.createBoundHostProperties(dirMeta, sourceSpan);
      return boundProps && boundProps.map(function (prop) {
        return _this141.createBoundElementProperty(elementSelector, prop);
      });
    }
  }, {
    key: "createDirectiveHostEventAsts",
    value: function createDirectiveHostEventAsts(dirMeta, sourceSpan) {
      var _this142 = this;

      if (dirMeta.hostListeners) {
        var targetEvents = [];
        Object.keys(dirMeta.hostListeners).forEach(function (propName) {
          var expression = dirMeta.hostListeners[propName];

          if (typeof expression === 'string') {
            // TODO: pass a more accurate handlerSpan for this event.
            _this142.parseEvent(propName, expression, sourceSpan, sourceSpan, [], targetEvents);
          } else {
            _this142._reportError("Value of the host listener \"".concat(propName, "\" needs to be a string representing an expression but got \"").concat(expression, "\" (").concat(typeof expression, ")"), sourceSpan);
          }
        });
        return targetEvents;
      }

      return null;
    }
  }, {
    key: "parseInterpolation",
    value: function parseInterpolation(value, sourceSpan) {
      var sourceInfo = sourceSpan.start.toString();

      try {
        var ast = this._exprParser.parseInterpolation(value, sourceInfo, sourceSpan.start.offset, this._interpolationConfig);

        if (ast) this._reportExpressionParserErrors(ast.errors, sourceSpan);

        this._checkPipes(ast, sourceSpan);

        return ast;
      } catch (e) {
        this._reportError("".concat(e), sourceSpan);

        return this._exprParser.wrapLiteralPrimitive('ERROR', sourceInfo, sourceSpan.start.offset);
      }
    }
    /**
     * Parses the bindings in a microsyntax expression, and converts them to
     * `ParsedProperty` or `ParsedVariable`.
     *
     * @param tplKey template binding name
     * @param tplValue template binding value
     * @param sourceSpan span of template binding relative to entire the template
     * @param absoluteValueOffset start of the tplValue relative to the entire template
     * @param targetMatchableAttrs potential attributes to match in the template
     * @param targetProps target property bindings in the template
     * @param targetVars target variables in the template
     */

  }, {
    key: "parseInlineTemplateBinding",
    value: function parseInlineTemplateBinding(tplKey, tplValue, sourceSpan, absoluteValueOffset, targetMatchableAttrs, targetProps, targetVars) {
      var absoluteKeyOffset = sourceSpan.start.offset + TEMPLATE_ATTR_PREFIX.length;

      var bindings = this._parseTemplateBindings(tplKey, tplValue, sourceSpan, absoluteKeyOffset, absoluteValueOffset);

      var _iterator8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(bindings),
          _step8;

      try {
        for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
          var binding = _step8.value;
          // sourceSpan is for the entire HTML attribute. bindingSpan is for a particular
          // binding within the microsyntax expression so it's more narrow than sourceSpan.
          var bindingSpan = moveParseSourceSpan(sourceSpan, binding.sourceSpan);
          var key = binding.key.source;
          var keySpan = moveParseSourceSpan(sourceSpan, binding.key.span);

          if (binding instanceof VariableBinding) {
            var value = binding.value ? binding.value.source : '$implicit';
            var valueSpan = binding.value ? moveParseSourceSpan(sourceSpan, binding.value.span) : undefined;
            targetVars.push(new ParsedVariable(key, value, bindingSpan, keySpan, valueSpan));
          } else if (binding.value) {
            var _valueSpan = moveParseSourceSpan(sourceSpan, binding.value.ast.sourceSpan);

            this._parsePropertyAst(key, binding.value, sourceSpan, _valueSpan, targetMatchableAttrs, targetProps);
          } else {
            targetMatchableAttrs.push([key, '']);
            this.parseLiteralAttr(key, null, sourceSpan, absoluteValueOffset, undefined, targetMatchableAttrs, targetProps);
          }
        }
      } catch (err) {
        _iterator8.e(err);
      } finally {
        _iterator8.f();
      }
    }
    /**
     * Parses the bindings in a microsyntax expression, e.g.
     * ```
     *    <tag *tplKey="let value1 = prop; let value2 = localVar">
     * ```
     *
     * @param tplKey template binding name
     * @param tplValue template binding value
     * @param sourceSpan span of template binding relative to entire the template
     * @param absoluteKeyOffset start of the `tplKey`
     * @param absoluteValueOffset start of the `tplValue`
     */

  }, {
    key: "_parseTemplateBindings",
    value: function _parseTemplateBindings(tplKey, tplValue, sourceSpan, absoluteKeyOffset, absoluteValueOffset) {
      var _this143 = this;

      var sourceInfo = sourceSpan.start.toString();

      try {
        var bindingsResult = this._exprParser.parseTemplateBindings(tplKey, tplValue, sourceInfo, absoluteKeyOffset, absoluteValueOffset);

        this._reportExpressionParserErrors(bindingsResult.errors, sourceSpan);

        bindingsResult.templateBindings.forEach(function (binding) {
          if (binding.value instanceof ASTWithSource) {
            _this143._checkPipes(binding.value, sourceSpan);
          }
        });
        bindingsResult.warnings.forEach(function (warning) {
          _this143._reportError(warning, sourceSpan, ParseErrorLevel.WARNING);
        });
        return bindingsResult.templateBindings;
      } catch (e) {
        this._reportError("".concat(e), sourceSpan);

        return [];
      }
    }
  }, {
    key: "parseLiteralAttr",
    value: function parseLiteralAttr(name, value, sourceSpan, absoluteOffset, valueSpan, targetMatchableAttrs, targetProps) {
      if (isAnimationLabel(name)) {
        name = name.substring(1);

        if (value) {
          this._reportError("Assigning animation triggers via @prop=\"exp\" attributes with an expression is invalid." + " Use property bindings (e.g. [@prop]=\"exp\") or use an attribute without a value (e.g. @prop) instead.", sourceSpan, ParseErrorLevel.ERROR);
        }

        this._parseAnimation(name, value, sourceSpan, absoluteOffset, valueSpan, targetMatchableAttrs, targetProps);
      } else {
        targetProps.push(new ParsedProperty(name, this._exprParser.wrapLiteralPrimitive(value, '', absoluteOffset), ParsedPropertyType.LITERAL_ATTR, sourceSpan, valueSpan));
      }
    }
  }, {
    key: "parsePropertyBinding",
    value: function parsePropertyBinding(name, expression, isHost, sourceSpan, absoluteOffset, valueSpan, targetMatchableAttrs, targetProps) {
      if (name.length === 0) {
        this._reportError("Property name is missing in binding", sourceSpan);
      }

      var isAnimationProp = false;

      if (name.startsWith(ANIMATE_PROP_PREFIX)) {
        isAnimationProp = true;
        name = name.substring(ANIMATE_PROP_PREFIX.length);
      } else if (isAnimationLabel(name)) {
        isAnimationProp = true;
        name = name.substring(1);
      }

      if (isAnimationProp) {
        this._parseAnimation(name, expression, sourceSpan, absoluteOffset, valueSpan, targetMatchableAttrs, targetProps);
      } else {
        this._parsePropertyAst(name, this._parseBinding(expression, isHost, valueSpan || sourceSpan, absoluteOffset), sourceSpan, valueSpan, targetMatchableAttrs, targetProps);
      }
    }
  }, {
    key: "parsePropertyInterpolation",
    value: function parsePropertyInterpolation(name, value, sourceSpan, valueSpan, targetMatchableAttrs, targetProps) {
      var expr = this.parseInterpolation(value, valueSpan || sourceSpan);

      if (expr) {
        this._parsePropertyAst(name, expr, sourceSpan, valueSpan, targetMatchableAttrs, targetProps);

        return true;
      }

      return false;
    }
  }, {
    key: "_parsePropertyAst",
    value: function _parsePropertyAst(name, ast, sourceSpan, valueSpan, targetMatchableAttrs, targetProps) {
      targetMatchableAttrs.push([name, ast.source]);
      targetProps.push(new ParsedProperty(name, ast, ParsedPropertyType.DEFAULT, sourceSpan, valueSpan));
    }
  }, {
    key: "_parseAnimation",
    value: function _parseAnimation(name, expression, sourceSpan, absoluteOffset, valueSpan, targetMatchableAttrs, targetProps) {
      if (name.length === 0) {
        this._reportError('Animation trigger is missing', sourceSpan);
      } // This will occur when a @trigger is not paired with an expression.
      // For animations it is valid to not have an expression since */void
      // states will be applied by angular when the element is attached/detached


      var ast = this._parseBinding(expression || 'undefined', false, valueSpan || sourceSpan, absoluteOffset);

      targetMatchableAttrs.push([name, ast.source]);
      targetProps.push(new ParsedProperty(name, ast, ParsedPropertyType.ANIMATION, sourceSpan, valueSpan));
    }
  }, {
    key: "_parseBinding",
    value: function _parseBinding(value, isHostBinding, sourceSpan, absoluteOffset) {
      var sourceInfo = (sourceSpan && sourceSpan.start || '(unknown)').toString();

      try {
        var ast = isHostBinding ? this._exprParser.parseSimpleBinding(value, sourceInfo, absoluteOffset, this._interpolationConfig) : this._exprParser.parseBinding(value, sourceInfo, absoluteOffset, this._interpolationConfig);
        if (ast) this._reportExpressionParserErrors(ast.errors, sourceSpan);

        this._checkPipes(ast, sourceSpan);

        return ast;
      } catch (e) {
        this._reportError("".concat(e), sourceSpan);

        return this._exprParser.wrapLiteralPrimitive('ERROR', sourceInfo, absoluteOffset);
      }
    }
  }, {
    key: "createBoundElementProperty",
    value: function createBoundElementProperty(elementSelector, boundProp) {
      var skipValidation = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
      var mapPropertyName = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;

      if (boundProp.isAnimation) {
        return new BoundElementProperty(boundProp.name, 4
        /* Animation */
        , SecurityContext.NONE, boundProp.expression, null, boundProp.sourceSpan, boundProp.valueSpan);
      }

      var unit = null;
      var bindingType = undefined;
      var boundPropertyName = null;
      var parts = boundProp.name.split(PROPERTY_PARTS_SEPARATOR);
      var securityContexts = undefined; // Check for special cases (prefix style, attr, class)

      if (parts.length > 1) {
        if (parts[0] == ATTRIBUTE_PREFIX) {
          boundPropertyName = parts.slice(1).join(PROPERTY_PARTS_SEPARATOR);

          if (!skipValidation) {
            this._validatePropertyOrAttributeName(boundPropertyName, boundProp.sourceSpan, true);
          }

          securityContexts = _calcPossibleSecurityContexts(this._schemaRegistry, elementSelector, boundPropertyName, true);
          var nsSeparatorIdx = boundPropertyName.indexOf(':');

          if (nsSeparatorIdx > -1) {
            var ns = boundPropertyName.substring(0, nsSeparatorIdx);
            var name = boundPropertyName.substring(nsSeparatorIdx + 1);
            boundPropertyName = mergeNsAndName(ns, name);
          }

          bindingType = 1
          /* Attribute */
          ;
        } else if (parts[0] == CLASS_PREFIX) {
          boundPropertyName = parts[1];
          bindingType = 2
          /* Class */
          ;
          securityContexts = [SecurityContext.NONE];
        } else if (parts[0] == STYLE_PREFIX) {
          unit = parts.length > 2 ? parts[2] : null;
          boundPropertyName = parts[1];
          bindingType = 3
          /* Style */
          ;
          securityContexts = [SecurityContext.STYLE];
        }
      } // If not a special case, use the full property name


      if (boundPropertyName === null) {
        var mappedPropName = this._schemaRegistry.getMappedPropName(boundProp.name);

        boundPropertyName = mapPropertyName ? mappedPropName : boundProp.name;
        securityContexts = _calcPossibleSecurityContexts(this._schemaRegistry, elementSelector, mappedPropName, false);
        bindingType = 0
        /* Property */
        ;

        if (!skipValidation) {
          this._validatePropertyOrAttributeName(mappedPropName, boundProp.sourceSpan, false);
        }
      }

      return new BoundElementProperty(boundPropertyName, bindingType, securityContexts[0], boundProp.expression, unit, boundProp.sourceSpan, boundProp.valueSpan);
    }
  }, {
    key: "parseEvent",
    value: function parseEvent(name, expression, sourceSpan, handlerSpan, targetMatchableAttrs, targetEvents) {
      if (name.length === 0) {
        this._reportError("Event name is missing in binding", sourceSpan);
      }

      if (isAnimationLabel(name)) {
        name = name.substr(1);

        this._parseAnimationEvent(name, expression, sourceSpan, handlerSpan, targetEvents);
      } else {
        this._parseRegularEvent(name, expression, sourceSpan, handlerSpan, targetMatchableAttrs, targetEvents);
      }
    }
  }, {
    key: "calcPossibleSecurityContexts",
    value: function calcPossibleSecurityContexts(selector, propName, isAttribute) {
      var prop = this._schemaRegistry.getMappedPropName(propName);

      return _calcPossibleSecurityContexts(this._schemaRegistry, selector, prop, isAttribute);
    }
  }, {
    key: "_parseAnimationEvent",
    value: function _parseAnimationEvent(name, expression, sourceSpan, handlerSpan, targetEvents) {
      var matches = splitAtPeriod(name, [name, '']);
      var eventName = matches[0];
      var phase = matches[1].toLowerCase();

      if (phase) {
        switch (phase) {
          case 'start':
          case 'done':
            var ast = this._parseAction(expression, handlerSpan);

            targetEvents.push(new ParsedEvent(eventName, phase, 1
            /* Animation */
            , ast, sourceSpan, handlerSpan));
            break;

          default:
            this._reportError("The provided animation output phase value \"".concat(phase, "\" for \"@").concat(eventName, "\" is not supported (use start or done)"), sourceSpan);

            break;
        }
      } else {
        this._reportError("The animation trigger output event (@".concat(eventName, ") is missing its phase value name (start or done are currently supported)"), sourceSpan);
      }
    }
  }, {
    key: "_parseRegularEvent",
    value: function _parseRegularEvent(name, expression, sourceSpan, handlerSpan, targetMatchableAttrs, targetEvents) {
      // long format: 'target: eventName'
      var _splitAtColon3 = splitAtColon(name, [null, name]),
          _splitAtColon4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_splitAtColon3, 2),
          target = _splitAtColon4[0],
          eventName = _splitAtColon4[1];

      var ast = this._parseAction(expression, handlerSpan);

      targetMatchableAttrs.push([name, ast.source]);
      targetEvents.push(new ParsedEvent(eventName, target, 0
      /* Regular */
      , ast, sourceSpan, handlerSpan)); // Don't detect directives for event names for now,
      // so don't add the event name to the matchableAttrs
    }
  }, {
    key: "_parseAction",
    value: function _parseAction(value, sourceSpan) {
      var sourceInfo = (sourceSpan && sourceSpan.start || '(unknown').toString();
      var absoluteOffset = sourceSpan && sourceSpan.start ? sourceSpan.start.offset : 0;

      try {
        var ast = this._exprParser.parseAction(value, sourceInfo, absoluteOffset, this._interpolationConfig);

        if (ast) {
          this._reportExpressionParserErrors(ast.errors, sourceSpan);
        }

        if (!ast || ast.ast instanceof EmptyExpr) {
          this._reportError("Empty expressions are not allowed", sourceSpan);

          return this._exprParser.wrapLiteralPrimitive('ERROR', sourceInfo, absoluteOffset);
        }

        this._checkPipes(ast, sourceSpan);

        return ast;
      } catch (e) {
        this._reportError("".concat(e), sourceSpan);

        return this._exprParser.wrapLiteralPrimitive('ERROR', sourceInfo, absoluteOffset);
      }
    }
  }, {
    key: "_reportError",
    value: function _reportError(message, sourceSpan) {
      var level = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : ParseErrorLevel.ERROR;
      this.errors.push(new ParseError(sourceSpan, message, level));
    }
  }, {
    key: "_reportExpressionParserErrors",
    value: function _reportExpressionParserErrors(errors, sourceSpan) {
      var _iterator9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(errors),
          _step9;

      try {
        for (_iterator9.s(); !(_step9 = _iterator9.n()).done;) {
          var _error = _step9.value;

          this._reportError(_error.message, sourceSpan);
        }
      } catch (err) {
        _iterator9.e(err);
      } finally {
        _iterator9.f();
      }
    } // Make sure all the used pipes are known in `this.pipesByName`

  }, {
    key: "_checkPipes",
    value: function _checkPipes(ast, sourceSpan) {
      var _this144 = this;

      if (ast && this.pipesByName) {
        var collector = new PipeCollector();
        ast.visit(collector);
        collector.pipes.forEach(function (ast, pipeName) {
          var pipeMeta = _this144.pipesByName.get(pipeName);

          if (!pipeMeta) {
            _this144._reportError("The pipe '".concat(pipeName, "' could not be found"), new ParseSourceSpan(sourceSpan.start.moveBy(ast.span.start), sourceSpan.start.moveBy(ast.span.end)));
          } else {
            _this144._usedPipes.set(pipeName, pipeMeta);
          }
        });
      }
    }
    /**
     * @param propName the name of the property / attribute
     * @param sourceSpan
     * @param isAttr true when binding to an attribute
     */

  }, {
    key: "_validatePropertyOrAttributeName",
    value: function _validatePropertyOrAttributeName(propName, sourceSpan, isAttr) {
      var report = isAttr ? this._schemaRegistry.validateAttribute(propName) : this._schemaRegistry.validateProperty(propName);

      if (report.error) {
        this._reportError(report.msg, sourceSpan, ParseErrorLevel.ERROR);
      }
    }
  }, {
    key: "interpolationConfig",
    get: function get() {
      return this._interpolationConfig;
    }
  }]);

  return BindingParser;
}();

var PipeCollector = /*#__PURE__*/function (_RecursiveAstVisitor$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(PipeCollector, _RecursiveAstVisitor$);

  var _super91 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(PipeCollector);

  function PipeCollector() {
    var _this145;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PipeCollector);

    _this145 = _super91.apply(this, arguments);
    _this145.pipes = new Map();
    return _this145;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PipeCollector, [{
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      this.pipes.set(ast.name, ast);
      ast.exp.visit(this);
      this.visitAll(ast.args, context);
      return null;
    }
  }]);

  return PipeCollector;
}(RecursiveAstVisitor$1);

function isAnimationLabel(name) {
  return name[0] == '@';
}

function _calcPossibleSecurityContexts(registry, selector, propName, isAttribute) {
  var ctxs = [];
  CssSelector.parse(selector).forEach(function (selector) {
    var elementNames = selector.element ? [selector.element] : registry.allKnownElementNames();
    var notElementNames = new Set(selector.notSelectors.filter(function (selector) {
      return selector.isElementSelector();
    }).map(function (selector) {
      return selector.element;
    }));
    var possibleElementNames = elementNames.filter(function (elementName) {
      return !notElementNames.has(elementName);
    });
    ctxs.push.apply(ctxs, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(possibleElementNames.map(function (elementName) {
      return registry.securityContext(elementName, propName, isAttribute);
    })));
  });
  return ctxs.length === 0 ? [SecurityContext.NONE] : Array.from(new Set(ctxs)).sort();
}
/**
 * Compute a new ParseSourceSpan based off an original `sourceSpan` by using
 * absolute offsets from the specified `absoluteSpan`.
 *
 * @param sourceSpan original source span
 * @param absoluteSpan absolute source span to move to
 */


function moveParseSourceSpan(sourceSpan, absoluteSpan) {
  // The difference of two absolute offsets provide the relative offset
  var startDiff = absoluteSpan.start - sourceSpan.start.offset;
  var endDiff = absoluteSpan.end - sourceSpan.end.offset;
  return new ParseSourceSpan(sourceSpan.start.moveBy(startDiff), sourceSpan.end.moveBy(endDiff));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NG_CONTENT_SELECT_ATTR = 'select';
var LINK_ELEMENT = 'link';
var LINK_STYLE_REL_ATTR = 'rel';
var LINK_STYLE_HREF_ATTR = 'href';
var LINK_STYLE_REL_VALUE = 'stylesheet';
var STYLE_ELEMENT = 'style';
var SCRIPT_ELEMENT = 'script';
var NG_NON_BINDABLE_ATTR = 'ngNonBindable';
var NG_PROJECT_AS = 'ngProjectAs';

function preparseElement(ast) {
  var selectAttr = null;
  var hrefAttr = null;
  var relAttr = null;
  var nonBindable = false;
  var projectAs = '';
  ast.attrs.forEach(function (attr) {
    var lcAttrName = attr.name.toLowerCase();

    if (lcAttrName == NG_CONTENT_SELECT_ATTR) {
      selectAttr = attr.value;
    } else if (lcAttrName == LINK_STYLE_HREF_ATTR) {
      hrefAttr = attr.value;
    } else if (lcAttrName == LINK_STYLE_REL_ATTR) {
      relAttr = attr.value;
    } else if (attr.name == NG_NON_BINDABLE_ATTR) {
      nonBindable = true;
    } else if (attr.name == NG_PROJECT_AS) {
      if (attr.value.length > 0) {
        projectAs = attr.value;
      }
    }
  });
  selectAttr = normalizeNgContentSelect(selectAttr);
  var nodeName = ast.name.toLowerCase();
  var type = PreparsedElementType.OTHER;

  if (isNgContent(nodeName)) {
    type = PreparsedElementType.NG_CONTENT;
  } else if (nodeName == STYLE_ELEMENT) {
    type = PreparsedElementType.STYLE;
  } else if (nodeName == SCRIPT_ELEMENT) {
    type = PreparsedElementType.SCRIPT;
  } else if (nodeName == LINK_ELEMENT && relAttr == LINK_STYLE_REL_VALUE) {
    type = PreparsedElementType.STYLESHEET;
  }

  return new PreparsedElement(type, selectAttr, hrefAttr, nonBindable, projectAs);
}

var PreparsedElementType;

(function (PreparsedElementType) {
  PreparsedElementType[PreparsedElementType["NG_CONTENT"] = 0] = "NG_CONTENT";
  PreparsedElementType[PreparsedElementType["STYLE"] = 1] = "STYLE";
  PreparsedElementType[PreparsedElementType["STYLESHEET"] = 2] = "STYLESHEET";
  PreparsedElementType[PreparsedElementType["SCRIPT"] = 3] = "SCRIPT";
  PreparsedElementType[PreparsedElementType["OTHER"] = 4] = "OTHER";
})(PreparsedElementType || (PreparsedElementType = {}));

var PreparsedElement = function PreparsedElement(type, selectAttr, hrefAttr, nonBindable, projectAs) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PreparsedElement);

  this.type = type;
  this.selectAttr = selectAttr;
  this.hrefAttr = hrefAttr;
  this.nonBindable = nonBindable;
  this.projectAs = projectAs;
};

function normalizeNgContentSelect(selectAttr) {
  if (selectAttr === null || selectAttr.length === 0) {
    return '*';
  }

  return selectAttr;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var BIND_NAME_REGEXP = /^(?:(?:(?:(bind-)|(let-)|(ref-|#)|(on-)|(bindon-)|(@))(.*))|\[\(([^\)]+)\)\]|\[([^\]]+)\]|\(([^\)]+)\))$/; // Group 1 = "bind-"

var KW_BIND_IDX = 1; // Group 2 = "let-"

var KW_LET_IDX = 2; // Group 3 = "ref-/#"

var KW_REF_IDX = 3; // Group 4 = "on-"

var KW_ON_IDX = 4; // Group 5 = "bindon-"

var KW_BINDON_IDX = 5; // Group 6 = "@"

var KW_AT_IDX = 6; // Group 7 = the identifier after "bind-", "let-", "ref-/#", "on-", "bindon-" or "@"

var IDENT_KW_IDX = 7; // Group 8 = identifier inside [()]

var IDENT_BANANA_BOX_IDX = 8; // Group 9 = identifier inside []

var IDENT_PROPERTY_IDX = 9; // Group 10 = identifier inside ()

var IDENT_EVENT_IDX = 10;
var TEMPLATE_ATTR_PREFIX$1 = '*';
var CLASS_ATTR = 'class';

var _TEXT_CSS_SELECTOR;

function TEXT_CSS_SELECTOR() {
  if (!_TEXT_CSS_SELECTOR) {
    _TEXT_CSS_SELECTOR = CssSelector.parse('*')[0];
  }

  return _TEXT_CSS_SELECTOR;
}

var TemplateParseError = /*#__PURE__*/function (_ParseError5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(TemplateParseError, _ParseError5);

  var _super92 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(TemplateParseError);

  function TemplateParseError(message, span, level) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateParseError);

    return _super92.call(this, span, message, level);
  }

  return TemplateParseError;
}(ParseError);

var TemplateParseResult = function TemplateParseResult(templateAst, usedPipes, errors) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateParseResult);

  this.templateAst = templateAst;
  this.usedPipes = usedPipes;
  this.errors = errors;
};

var TemplateParser = /*#__PURE__*/function () {
  function TemplateParser(_config, _reflector, _exprParser, _schemaRegistry, _htmlParser, _console, transforms) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateParser);

    this._config = _config;
    this._reflector = _reflector;
    this._exprParser = _exprParser;
    this._schemaRegistry = _schemaRegistry;
    this._htmlParser = _htmlParser;
    this._console = _console;
    this.transforms = transforms;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TemplateParser, [{
    key: "parse",
    value: function parse(component, template, directives, pipes, schemas, templateUrl, preserveWhitespaces) {
      var _a;

      var result = this.tryParse(component, template, directives, pipes, schemas, templateUrl, preserveWhitespaces);
      var warnings = result.errors.filter(function (error) {
        return error.level === ParseErrorLevel.WARNING;
      });
      var errors = result.errors.filter(function (error) {
        return error.level === ParseErrorLevel.ERROR;
      });

      if (warnings.length > 0) {
        (_a = this._console) === null || _a === void 0 ? void 0 : _a.warn("Template parse warnings:\n".concat(warnings.join('\n')));
      }

      if (errors.length > 0) {
        var errorString = errors.join('\n');
        throw syntaxError("Template parse errors:\n".concat(errorString), errors);
      }

      return {
        template: result.templateAst,
        pipes: result.usedPipes
      };
    }
  }, {
    key: "tryParse",
    value: function tryParse(component, template, directives, pipes, schemas, templateUrl, preserveWhitespaces) {
      var htmlParseResult = typeof template === 'string' ? this._htmlParser.parse(template, templateUrl, {
        tokenizeExpansionForms: true,
        interpolationConfig: this.getInterpolationConfig(component)
      }) : template;

      if (!preserveWhitespaces) {
        htmlParseResult = removeWhitespaces(htmlParseResult);
      }

      return this.tryParseHtml(this.expandHtml(htmlParseResult), component, directives, pipes, schemas);
    }
  }, {
    key: "tryParseHtml",
    value: function tryParseHtml(htmlAstWithErrors, component, directives, pipes, schemas) {
      var result;
      var errors = htmlAstWithErrors.errors;
      var usedPipes = [];

      if (htmlAstWithErrors.rootNodes.length > 0) {
        var uniqDirectives = removeSummaryDuplicates(directives);
        var uniqPipes = removeSummaryDuplicates(pipes);
        var providerViewContext = new ProviderViewContext(this._reflector, component);
        var interpolationConfig = undefined;

        if (component.template && component.template.interpolation) {
          interpolationConfig = {
            start: component.template.interpolation[0],
            end: component.template.interpolation[1]
          };
        }

        var bindingParser = new BindingParser(this._exprParser, interpolationConfig, this._schemaRegistry, uniqPipes, errors);
        var parseVisitor = new TemplateParseVisitor(this._reflector, this._config, providerViewContext, uniqDirectives, bindingParser, this._schemaRegistry, schemas, errors);
        result = visitAll$1(parseVisitor, htmlAstWithErrors.rootNodes, EMPTY_ELEMENT_CONTEXT);
        errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(providerViewContext.errors));
        usedPipes.push.apply(usedPipes, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(bindingParser.getUsedPipes()));
      } else {
        result = [];
      }

      this._assertNoReferenceDuplicationOnTemplate(result, errors);

      if (errors.length > 0) {
        return new TemplateParseResult(result, usedPipes, errors);
      }

      if (this.transforms) {
        this.transforms.forEach(function (transform) {
          result = templateVisitAll(transform, result);
        });
      }

      return new TemplateParseResult(result, usedPipes, errors);
    }
  }, {
    key: "expandHtml",
    value: function expandHtml(htmlAstWithErrors) {
      var forced = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      var errors = htmlAstWithErrors.errors;

      if (errors.length == 0 || forced) {
        // Transform ICU messages to angular directives
        var expandedHtmlAst = expandNodes(htmlAstWithErrors.rootNodes);
        errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(expandedHtmlAst.errors));
        htmlAstWithErrors = new ParseTreeResult(expandedHtmlAst.nodes, errors);
      }

      return htmlAstWithErrors;
    }
  }, {
    key: "getInterpolationConfig",
    value: function getInterpolationConfig(component) {
      if (component.template) {
        return InterpolationConfig.fromArray(component.template.interpolation);
      }

      return undefined;
    }
    /** @internal */

  }, {
    key: "_assertNoReferenceDuplicationOnTemplate",
    value: function _assertNoReferenceDuplicationOnTemplate(result, errors) {
      var existingReferences = [];
      result.filter(function (element) {
        return !!element.references;
      }).forEach(function (element) {
        return element.references.forEach(function (reference) {
          var name = reference.name;

          if (existingReferences.indexOf(name) < 0) {
            existingReferences.push(name);
          } else {
            var _error2 = new TemplateParseError("Reference \"#".concat(name, "\" is defined several times"), reference.sourceSpan, ParseErrorLevel.ERROR);

            errors.push(_error2);
          }
        });
      });
    }
  }, {
    key: "expressionParser",
    get: function get() {
      return this._exprParser;
    }
  }]);

  return TemplateParser;
}();

var TemplateParseVisitor = /*#__PURE__*/function () {
  function TemplateParseVisitor(reflector, config, providerViewContext, directives, _bindingParser, _schemaRegistry, _schemas, _targetErrors) {
    var _this146 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateParseVisitor);

    this.reflector = reflector;
    this.config = config;
    this.providerViewContext = providerViewContext;
    this._bindingParser = _bindingParser;
    this._schemaRegistry = _schemaRegistry;
    this._schemas = _schemas;
    this._targetErrors = _targetErrors;
    this.selectorMatcher = new SelectorMatcher();
    this.directivesIndex = new Map();
    this.ngContentCount = 0; // Note: queries start with id 1 so we can use the number in a Bloom filter!

    this.contentQueryStartId = providerViewContext.component.viewQueries.length + 1;
    directives.forEach(function (directive, index) {
      var selector = CssSelector.parse(directive.selector);

      _this146.selectorMatcher.addSelectables(selector, directive);

      _this146.directivesIndex.set(directive, index);
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TemplateParseVisitor, [{
    key: "visitExpansion",
    value: function visitExpansion(expansion, context) {
      return null;
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase, context) {
      return null;
    }
  }, {
    key: "visitText",
    value: function visitText(text, parent) {
      var ngContentIndex = parent.findNgContentIndex(TEXT_CSS_SELECTOR());
      var valueNoNgsp = replaceNgsp(text.value);

      var expr = this._bindingParser.parseInterpolation(valueNoNgsp, text.sourceSpan);

      return expr ? new BoundTextAst(expr, ngContentIndex, text.sourceSpan) : new TextAst(valueNoNgsp, ngContentIndex, text.sourceSpan);
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {
      return new AttrAst(attribute.name, attribute.value, attribute.sourceSpan);
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {
      return null;
    }
  }, {
    key: "visitElement",
    value: function visitElement(element, parent) {
      var _this147 = this;

      var queryStartIndex = this.contentQueryStartId;
      var elName = element.name;
      var preparsedElement = preparseElement(element);

      if (preparsedElement.type === PreparsedElementType.SCRIPT || preparsedElement.type === PreparsedElementType.STYLE) {
        // Skipping <script> for security reasons
        // Skipping <style> as we already processed them
        // in the StyleCompiler
        return null;
      }

      if (preparsedElement.type === PreparsedElementType.STYLESHEET && isStyleUrlResolvable(preparsedElement.hrefAttr)) {
        // Skipping stylesheets with either relative urls or package scheme as we already processed
        // them in the StyleCompiler
        return null;
      }

      var matchableAttrs = [];
      var elementOrDirectiveProps = [];
      var elementOrDirectiveRefs = [];
      var elementVars = [];
      var events = [];
      var templateElementOrDirectiveProps = [];
      var templateMatchableAttrs = [];
      var templateElementVars = [];
      var hasInlineTemplates = false;
      var attrs = [];
      var isTemplateElement = isNgTemplate(element.name);
      element.attrs.forEach(function (attr) {
        var parsedVariables = [];

        var hasBinding = _this147._parseAttr(isTemplateElement, attr, matchableAttrs, elementOrDirectiveProps, events, elementOrDirectiveRefs, elementVars);

        elementVars.push.apply(elementVars, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(parsedVariables.map(function (v) {
          return VariableAst.fromParsedVariable(v);
        })));
        var templateValue;
        var templateKey;

        var normalizedName = _this147._normalizeAttributeName(attr.name);

        if (normalizedName.startsWith(TEMPLATE_ATTR_PREFIX$1)) {
          templateValue = attr.value;
          templateKey = normalizedName.substring(TEMPLATE_ATTR_PREFIX$1.length);
        }

        var hasTemplateBinding = templateValue != null;

        if (hasTemplateBinding) {
          if (hasInlineTemplates) {
            _this147._reportError("Can't have multiple template bindings on one element. Use only one attribute prefixed with *", attr.sourceSpan);
          }

          hasInlineTemplates = true;
          var _parsedVariables = [];
          var absoluteOffset = (attr.valueSpan || attr.sourceSpan).start.offset;

          _this147._bindingParser.parseInlineTemplateBinding(templateKey, templateValue, attr.sourceSpan, absoluteOffset, templateMatchableAttrs, templateElementOrDirectiveProps, _parsedVariables);

          templateElementVars.push.apply(templateElementVars, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_parsedVariables.map(function (v) {
            return VariableAst.fromParsedVariable(v);
          })));
        }

        if (!hasBinding && !hasTemplateBinding) {
          // don't include the bindings as attributes as well in the AST
          attrs.push(_this147.visitAttribute(attr, null));
          matchableAttrs.push([attr.name, attr.value]);
        }
      });
      var elementCssSelector = createElementCssSelector(elName, matchableAttrs);

      var _this$_parseDirective = this._parseDirectives(this.selectorMatcher, elementCssSelector),
          directiveMetas = _this$_parseDirective.directives,
          matchElement = _this$_parseDirective.matchElement;

      var references = [];
      var boundDirectivePropNames = new Set();

      var directiveAsts = this._createDirectiveAsts(isTemplateElement, element.name, directiveMetas, elementOrDirectiveProps, elementOrDirectiveRefs, element.sourceSpan, references, boundDirectivePropNames);

      var elementProps = this._createElementPropertyAsts(element.name, elementOrDirectiveProps, boundDirectivePropNames);

      var isViewRoot = parent.isTemplateElement || hasInlineTemplates;
      var providerContext = new ProviderElementContext(this.providerViewContext, parent.providerContext, isViewRoot, directiveAsts, attrs, references, isTemplateElement, queryStartIndex, element.sourceSpan);
      var children = visitAll$1(preparsedElement.nonBindable ? NON_BINDABLE_VISITOR : this, element.children, ElementContext.create(isTemplateElement, directiveAsts, isTemplateElement ? parent.providerContext : providerContext));
      providerContext.afterElement(); // Override the actual selector when the `ngProjectAs` attribute is provided

      var projectionSelector = preparsedElement.projectAs != '' ? CssSelector.parse(preparsedElement.projectAs)[0] : elementCssSelector;
      var ngContentIndex = parent.findNgContentIndex(projectionSelector);
      var parsedElement;

      if (preparsedElement.type === PreparsedElementType.NG_CONTENT) {
        // `<ng-content>` element
        if (element.children && !element.children.every(_isEmptyTextNode)) {
          this._reportError("<ng-content> element cannot have content.", element.sourceSpan);
        }

        parsedElement = new NgContentAst(this.ngContentCount++, hasInlineTemplates ? null : ngContentIndex, element.sourceSpan);
      } else if (isTemplateElement) {
        // `<ng-template>` element
        this._assertAllEventsPublishedByDirectives(directiveAsts, events);

        this._assertNoComponentsNorElementBindingsOnTemplate(directiveAsts, elementProps, element.sourceSpan);

        parsedElement = new EmbeddedTemplateAst(attrs, events, references, elementVars, providerContext.transformedDirectiveAsts, providerContext.transformProviders, providerContext.transformedHasViewContainer, providerContext.queryMatches, children, hasInlineTemplates ? null : ngContentIndex, element.sourceSpan);
      } else {
        // element other than `<ng-content>` and `<ng-template>`
        this._assertElementExists(matchElement, element);

        this._assertOnlyOneComponent(directiveAsts, element.sourceSpan);

        var _ngContentIndex = hasInlineTemplates ? null : parent.findNgContentIndex(projectionSelector);

        parsedElement = new ElementAst(elName, attrs, elementProps, events, references, providerContext.transformedDirectiveAsts, providerContext.transformProviders, providerContext.transformedHasViewContainer, providerContext.queryMatches, children, hasInlineTemplates ? null : _ngContentIndex, element.sourceSpan, element.endSourceSpan || null);
      }

      if (hasInlineTemplates) {
        // The element as a *-attribute
        var templateQueryStartIndex = this.contentQueryStartId;
        var templateSelector = createElementCssSelector('ng-template', templateMatchableAttrs);

        var _this$_parseDirective2 = this._parseDirectives(this.selectorMatcher, templateSelector),
            directives = _this$_parseDirective2.directives;

        var templateBoundDirectivePropNames = new Set();

        var templateDirectiveAsts = this._createDirectiveAsts(true, elName, directives, templateElementOrDirectiveProps, [], element.sourceSpan, [], templateBoundDirectivePropNames);

        var templateElementProps = this._createElementPropertyAsts(elName, templateElementOrDirectiveProps, templateBoundDirectivePropNames);

        this._assertNoComponentsNorElementBindingsOnTemplate(templateDirectiveAsts, templateElementProps, element.sourceSpan);

        var templateProviderContext = new ProviderElementContext(this.providerViewContext, parent.providerContext, parent.isTemplateElement, templateDirectiveAsts, [], [], true, templateQueryStartIndex, element.sourceSpan);
        templateProviderContext.afterElement();
        parsedElement = new EmbeddedTemplateAst([], [], [], templateElementVars, templateProviderContext.transformedDirectiveAsts, templateProviderContext.transformProviders, templateProviderContext.transformedHasViewContainer, templateProviderContext.queryMatches, [parsedElement], ngContentIndex, element.sourceSpan);
      }

      return parsedElement;
    }
  }, {
    key: "_parseAttr",
    value: function _parseAttr(isTemplateElement, attr, targetMatchableAttrs, targetProps, targetEvents, targetRefs, targetVars) {
      var name = this._normalizeAttributeName(attr.name);

      var value = attr.value;
      var srcSpan = attr.sourceSpan;
      var absoluteOffset = attr.valueSpan ? attr.valueSpan.start.offset : srcSpan.start.offset;
      var boundEvents = [];
      var bindParts = name.match(BIND_NAME_REGEXP);
      var hasBinding = false;

      if (bindParts !== null) {
        hasBinding = true;

        if (bindParts[KW_BIND_IDX] != null) {
          this._bindingParser.parsePropertyBinding(bindParts[IDENT_KW_IDX], value, false, srcSpan, absoluteOffset, attr.valueSpan, targetMatchableAttrs, targetProps);
        } else if (bindParts[KW_LET_IDX]) {
          if (isTemplateElement) {
            var identifier = bindParts[IDENT_KW_IDX];

            this._parseVariable(identifier, value, srcSpan, targetVars);
          } else {
            this._reportError("\"let-\" is only supported on ng-template elements.", srcSpan);
          }
        } else if (bindParts[KW_REF_IDX]) {
          var _identifier = bindParts[IDENT_KW_IDX];

          this._parseReference(_identifier, value, srcSpan, targetRefs);
        } else if (bindParts[KW_ON_IDX]) {
          this._bindingParser.parseEvent(bindParts[IDENT_KW_IDX], value, srcSpan, attr.valueSpan || srcSpan, targetMatchableAttrs, boundEvents);
        } else if (bindParts[KW_BINDON_IDX]) {
          this._bindingParser.parsePropertyBinding(bindParts[IDENT_KW_IDX], value, false, srcSpan, absoluteOffset, attr.valueSpan, targetMatchableAttrs, targetProps);

          this._parseAssignmentEvent(bindParts[IDENT_KW_IDX], value, srcSpan, attr.valueSpan || srcSpan, targetMatchableAttrs, boundEvents);
        } else if (bindParts[KW_AT_IDX]) {
          this._bindingParser.parseLiteralAttr(name, value, srcSpan, absoluteOffset, attr.valueSpan, targetMatchableAttrs, targetProps);
        } else if (bindParts[IDENT_BANANA_BOX_IDX]) {
          this._bindingParser.parsePropertyBinding(bindParts[IDENT_BANANA_BOX_IDX], value, false, srcSpan, absoluteOffset, attr.valueSpan, targetMatchableAttrs, targetProps);

          this._parseAssignmentEvent(bindParts[IDENT_BANANA_BOX_IDX], value, srcSpan, attr.valueSpan || srcSpan, targetMatchableAttrs, boundEvents);
        } else if (bindParts[IDENT_PROPERTY_IDX]) {
          this._bindingParser.parsePropertyBinding(bindParts[IDENT_PROPERTY_IDX], value, false, srcSpan, absoluteOffset, attr.valueSpan, targetMatchableAttrs, targetProps);
        } else if (bindParts[IDENT_EVENT_IDX]) {
          this._bindingParser.parseEvent(bindParts[IDENT_EVENT_IDX], value, srcSpan, attr.valueSpan || srcSpan, targetMatchableAttrs, boundEvents);
        }
      } else {
        hasBinding = this._bindingParser.parsePropertyInterpolation(name, value, srcSpan, attr.valueSpan, targetMatchableAttrs, targetProps);
      }

      if (!hasBinding) {
        this._bindingParser.parseLiteralAttr(name, value, srcSpan, absoluteOffset, attr.valueSpan, targetMatchableAttrs, targetProps);
      }

      targetEvents.push.apply(targetEvents, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(boundEvents.map(function (e) {
        return BoundEventAst.fromParsedEvent(e);
      })));
      return hasBinding;
    }
  }, {
    key: "_normalizeAttributeName",
    value: function _normalizeAttributeName(attrName) {
      return /^data-/i.test(attrName) ? attrName.substring(5) : attrName;
    }
  }, {
    key: "_parseVariable",
    value: function _parseVariable(identifier, value, sourceSpan, targetVars) {
      if (identifier.indexOf('-') > -1) {
        this._reportError("\"-\" is not allowed in variable names", sourceSpan);
      } else if (identifier.length === 0) {
        this._reportError("Variable does not have a name", sourceSpan);
      }

      targetVars.push(new VariableAst(identifier, value, sourceSpan));
    }
  }, {
    key: "_parseReference",
    value: function _parseReference(identifier, value, sourceSpan, targetRefs) {
      if (identifier.indexOf('-') > -1) {
        this._reportError("\"-\" is not allowed in reference names", sourceSpan);
      } else if (identifier.length === 0) {
        this._reportError("Reference does not have a name", sourceSpan);
      }

      targetRefs.push(new ElementOrDirectiveRef(identifier, value, sourceSpan));
    }
  }, {
    key: "_parseAssignmentEvent",
    value: function _parseAssignmentEvent(name, expression, sourceSpan, valueSpan, targetMatchableAttrs, targetEvents) {
      this._bindingParser.parseEvent("".concat(name, "Change"), "".concat(expression, "=$event"), sourceSpan, valueSpan, targetMatchableAttrs, targetEvents);
    }
  }, {
    key: "_parseDirectives",
    value: function _parseDirectives(selectorMatcher, elementCssSelector) {
      var _this148 = this;

      // Need to sort the directives so that we get consistent results throughout,
      // as selectorMatcher uses Maps inside.
      // Also deduplicate directives as they might match more than one time!
      var directives = newArray(this.directivesIndex.size); // Whether any directive selector matches on the element name

      var matchElement = false;
      selectorMatcher.match(elementCssSelector, function (selector, directive) {
        directives[_this148.directivesIndex.get(directive)] = directive;
        matchElement = matchElement || selector.hasElementSelector();
      });
      return {
        directives: directives.filter(function (dir) {
          return !!dir;
        }),
        matchElement: matchElement
      };
    }
  }, {
    key: "_createDirectiveAsts",
    value: function _createDirectiveAsts(isTemplateElement, elementName, directives, props, elementOrDirectiveRefs, elementSourceSpan, targetReferences, targetBoundDirectivePropNames) {
      var _this149 = this;

      var matchedReferences = new Set();
      var component = null;
      var directiveAsts = directives.map(function (directive) {
        var sourceSpan = new ParseSourceSpan(elementSourceSpan.start, elementSourceSpan.end, "Directive ".concat(identifierName(directive.type)));

        if (directive.isComponent) {
          component = directive;
        }

        var directiveProperties = [];

        var boundProperties = _this149._bindingParser.createDirectiveHostPropertyAsts(directive, elementName, sourceSpan);

        var hostProperties = boundProperties.map(function (prop) {
          return BoundElementPropertyAst.fromBoundProperty(prop);
        }); // Note: We need to check the host properties here as well,
        // as we don't know the element name in the DirectiveWrapperCompiler yet.

        hostProperties = _this149._checkPropertiesInSchema(elementName, hostProperties);

        var parsedEvents = _this149._bindingParser.createDirectiveHostEventAsts(directive, sourceSpan);

        _this149._createDirectivePropertyAsts(directive.inputs, props, directiveProperties, targetBoundDirectivePropNames);

        elementOrDirectiveRefs.forEach(function (elOrDirRef) {
          if (elOrDirRef.value.length === 0 && directive.isComponent || elOrDirRef.isReferenceToDirective(directive)) {
            targetReferences.push(new ReferenceAst(elOrDirRef.name, createTokenForReference(directive.type.reference), elOrDirRef.value, elOrDirRef.sourceSpan));
            matchedReferences.add(elOrDirRef.name);
          }
        });
        var hostEvents = parsedEvents.map(function (e) {
          return BoundEventAst.fromParsedEvent(e);
        });
        var contentQueryStartId = _this149.contentQueryStartId;
        _this149.contentQueryStartId += directive.queries.length;
        return new DirectiveAst(directive, directiveProperties, hostProperties, hostEvents, contentQueryStartId, sourceSpan);
      });
      elementOrDirectiveRefs.forEach(function (elOrDirRef) {
        if (elOrDirRef.value.length > 0) {
          if (!matchedReferences.has(elOrDirRef.name)) {
            _this149._reportError("There is no directive with \"exportAs\" set to \"".concat(elOrDirRef.value, "\""), elOrDirRef.sourceSpan);
          }
        } else if (!component) {
          var refToken = null;

          if (isTemplateElement) {
            refToken = createTokenForExternalReference(_this149.reflector, Identifiers.TemplateRef);
          }

          targetReferences.push(new ReferenceAst(elOrDirRef.name, refToken, elOrDirRef.value, elOrDirRef.sourceSpan));
        }
      });
      return directiveAsts;
    }
  }, {
    key: "_createDirectivePropertyAsts",
    value: function _createDirectivePropertyAsts(directiveProperties, boundProps, targetBoundDirectiveProps, targetBoundDirectivePropNames) {
      if (directiveProperties) {
        var boundPropsByName = new Map();
        boundProps.forEach(function (boundProp) {
          var prevValue = boundPropsByName.get(boundProp.name);

          if (!prevValue || prevValue.isLiteral) {
            // give [a]="b" a higher precedence than a="b" on the same element
            boundPropsByName.set(boundProp.name, boundProp);
          }
        });
        Object.keys(directiveProperties).forEach(function (dirProp) {
          var elProp = directiveProperties[dirProp];
          var boundProp = boundPropsByName.get(elProp); // Bindings are optional, so this binding only needs to be set up if an expression is given.

          if (boundProp) {
            targetBoundDirectivePropNames.add(boundProp.name);

            if (!isEmptyExpression(boundProp.expression)) {
              targetBoundDirectiveProps.push(new BoundDirectivePropertyAst(dirProp, boundProp.name, boundProp.expression, boundProp.sourceSpan));
            }
          }
        });
      }
    }
  }, {
    key: "_createElementPropertyAsts",
    value: function _createElementPropertyAsts(elementName, props, boundDirectivePropNames) {
      var _this150 = this;

      var boundElementProps = [];
      props.forEach(function (prop) {
        if (!prop.isLiteral && !boundDirectivePropNames.has(prop.name)) {
          var boundProp = _this150._bindingParser.createBoundElementProperty(elementName, prop);

          boundElementProps.push(BoundElementPropertyAst.fromBoundProperty(boundProp));
        }
      });
      return this._checkPropertiesInSchema(elementName, boundElementProps);
    }
  }, {
    key: "_findComponentDirectives",
    value: function _findComponentDirectives(directives) {
      return directives.filter(function (directive) {
        return directive.directive.isComponent;
      });
    }
  }, {
    key: "_findComponentDirectiveNames",
    value: function _findComponentDirectiveNames(directives) {
      return this._findComponentDirectives(directives).map(function (directive) {
        return identifierName(directive.directive.type);
      });
    }
  }, {
    key: "_assertOnlyOneComponent",
    value: function _assertOnlyOneComponent(directives, sourceSpan) {
      var componentTypeNames = this._findComponentDirectiveNames(directives);

      if (componentTypeNames.length > 1) {
        this._reportError("More than one component matched on this element.\n" + "Make sure that only one component's selector can match a given element.\n" + "Conflicting components: ".concat(componentTypeNames.join(',')), sourceSpan);
      }
    }
    /**
     * Make sure that non-angular tags conform to the schemas.
     *
     * Note: An element is considered an angular tag when at least one directive selector matches the
     * tag name.
     *
     * @param matchElement Whether any directive has matched on the tag name
     * @param element the html element
     */

  }, {
    key: "_assertElementExists",
    value: function _assertElementExists(matchElement, element) {
      var elName = element.name.replace(/^:xhtml:/, '');

      if (!matchElement && !this._schemaRegistry.hasElement(elName, this._schemas)) {
        var errorMsg = "'".concat(elName, "' is not a known element:\n");
        errorMsg += "1. If '".concat(elName, "' is an Angular component, then verify that it is part of this module.\n");

        if (elName.indexOf('-') > -1) {
          errorMsg += "2. If '".concat(elName, "' is a Web Component then add 'CUSTOM_ELEMENTS_SCHEMA' to the '@NgModule.schemas' of this component to suppress this message.");
        } else {
          errorMsg += "2. To allow any element add 'NO_ERRORS_SCHEMA' to the '@NgModule.schemas' of this component.";
        }

        this._reportError(errorMsg, element.sourceSpan);
      }
    }
  }, {
    key: "_assertNoComponentsNorElementBindingsOnTemplate",
    value: function _assertNoComponentsNorElementBindingsOnTemplate(directives, elementProps, sourceSpan) {
      var _this151 = this;

      var componentTypeNames = this._findComponentDirectiveNames(directives);

      if (componentTypeNames.length > 0) {
        this._reportError("Components on an embedded template: ".concat(componentTypeNames.join(',')), sourceSpan);
      }

      elementProps.forEach(function (prop) {
        _this151._reportError("Property binding ".concat(prop.name, " not used by any directive on an embedded template. Make sure that the property name is spelled correctly and all directives are listed in the \"@NgModule.declarations\"."), sourceSpan);
      });
    }
  }, {
    key: "_assertAllEventsPublishedByDirectives",
    value: function _assertAllEventsPublishedByDirectives(directives, events) {
      var _this152 = this;

      var allDirectiveEvents = new Set();
      directives.forEach(function (directive) {
        Object.keys(directive.directive.outputs).forEach(function (k) {
          var eventName = directive.directive.outputs[k];
          allDirectiveEvents.add(eventName);
        });
      });
      events.forEach(function (event) {
        if (event.target != null || !allDirectiveEvents.has(event.name)) {
          _this152._reportError("Event binding ".concat(event.fullName, " not emitted by any directive on an embedded template. Make sure that the event name is spelled correctly and all directives are listed in the \"@NgModule.declarations\"."), event.sourceSpan);
        }
      });
    }
  }, {
    key: "_checkPropertiesInSchema",
    value: function _checkPropertiesInSchema(elementName, boundProps) {
      var _this153 = this;

      // Note: We can't filter out empty expressions before this method,
      // as we still want to validate them!
      return boundProps.filter(function (boundProp) {
        if (boundProp.type === 0
        /* Property */
        && !_this153._schemaRegistry.hasProperty(elementName, boundProp.name, _this153._schemas)) {
          var errorMsg = "Can't bind to '".concat(boundProp.name, "' since it isn't a known property of '").concat(elementName, "'.");

          if (elementName.startsWith('ng-')) {
            errorMsg += "\n1. If '".concat(boundProp.name, "' is an Angular directive, then add 'CommonModule' to the '@NgModule.imports' of this component.") + "\n2. To allow any property add 'NO_ERRORS_SCHEMA' to the '@NgModule.schemas' of this component.";
          } else if (elementName.indexOf('-') > -1) {
            errorMsg += "\n1. If '".concat(elementName, "' is an Angular component and it has '").concat(boundProp.name, "' input, then verify that it is part of this module.") + "\n2. If '".concat(elementName, "' is a Web Component then add 'CUSTOM_ELEMENTS_SCHEMA' to the '@NgModule.schemas' of this component to suppress this message.") + "\n3. To allow any property add 'NO_ERRORS_SCHEMA' to the '@NgModule.schemas' of this component.";
          }

          _this153._reportError(errorMsg, boundProp.sourceSpan);
        }

        return !isEmptyExpression(boundProp.value);
      });
    }
  }, {
    key: "_reportError",
    value: function _reportError(message, sourceSpan) {
      var level = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : ParseErrorLevel.ERROR;

      this._targetErrors.push(new ParseError(sourceSpan, message, level));
    }
  }]);

  return TemplateParseVisitor;
}();

var NonBindableVisitor = /*#__PURE__*/function () {
  function NonBindableVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NonBindableVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NonBindableVisitor, [{
    key: "visitElement",
    value: function visitElement(ast, parent) {
      var preparsedElement = preparseElement(ast);

      if (preparsedElement.type === PreparsedElementType.SCRIPT || preparsedElement.type === PreparsedElementType.STYLE || preparsedElement.type === PreparsedElementType.STYLESHEET) {
        // Skipping <script> for security reasons
        // Skipping <style> and stylesheets as we already processed them
        // in the StyleCompiler
        return null;
      }

      var attrNameAndValues = ast.attrs.map(function (attr) {
        return [attr.name, attr.value];
      });
      var selector = createElementCssSelector(ast.name, attrNameAndValues);
      var ngContentIndex = parent.findNgContentIndex(selector);
      var children = visitAll$1(this, ast.children, EMPTY_ELEMENT_CONTEXT);
      return new ElementAst(ast.name, visitAll$1(this, ast.attrs), [], [], [], [], [], false, [], children, ngContentIndex, ast.sourceSpan, ast.endSourceSpan);
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {
      return null;
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {
      return new AttrAst(attribute.name, attribute.value, attribute.sourceSpan);
    }
  }, {
    key: "visitText",
    value: function visitText(text, parent) {
      var ngContentIndex = parent.findNgContentIndex(TEXT_CSS_SELECTOR());
      return new TextAst(text.value, ngContentIndex, text.sourceSpan);
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion, context) {
      return expansion;
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase, context) {
      return expansionCase;
    }
  }]);

  return NonBindableVisitor;
}();
/**
 * A reference to an element or directive in a template. E.g., the reference in this template:
 *
 * <div #myMenu="coolMenu">
 *
 * would be {name: 'myMenu', value: 'coolMenu', sourceSpan: ...}
 */


var ElementOrDirectiveRef = /*#__PURE__*/function () {
  function ElementOrDirectiveRef(name, value, sourceSpan) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ElementOrDirectiveRef);

    this.name = name;
    this.value = value;
    this.sourceSpan = sourceSpan;
  }
  /** Gets whether this is a reference to the given directive. */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ElementOrDirectiveRef, [{
    key: "isReferenceToDirective",
    value: function isReferenceToDirective(directive) {
      return splitExportAs(directive.exportAs).indexOf(this.value) !== -1;
    }
  }]);

  return ElementOrDirectiveRef;
}();
/** Splits a raw, potentially comma-delimited `exportAs` value into an array of names. */


function splitExportAs(exportAs) {
  return exportAs ? exportAs.split(',').map(function (e) {
    return e.trim();
  }) : [];
}

function splitClasses(classAttrValue) {
  return classAttrValue.trim().split(/\s+/g);
}

var ElementContext = /*#__PURE__*/function () {
  function ElementContext(isTemplateElement, _ngContentIndexMatcher, _wildcardNgContentIndex, providerContext) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ElementContext);

    this.isTemplateElement = isTemplateElement;
    this._ngContentIndexMatcher = _ngContentIndexMatcher;
    this._wildcardNgContentIndex = _wildcardNgContentIndex;
    this.providerContext = providerContext;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ElementContext, [{
    key: "findNgContentIndex",
    value: function findNgContentIndex(selector) {
      var ngContentIndices = [];

      this._ngContentIndexMatcher.match(selector, function (selector, ngContentIndex) {
        ngContentIndices.push(ngContentIndex);
      });

      ngContentIndices.sort();

      if (this._wildcardNgContentIndex != null) {
        ngContentIndices.push(this._wildcardNgContentIndex);
      }

      return ngContentIndices.length > 0 ? ngContentIndices[0] : null;
    }
  }], [{
    key: "create",
    value: function create(isTemplateElement, directives, providerContext) {
      var matcher = new SelectorMatcher();
      var wildcardNgContentIndex = null;
      var component = directives.find(function (directive) {
        return directive.directive.isComponent;
      });

      if (component) {
        var ngContentSelectors = component.directive.template.ngContentSelectors;

        for (var i = 0; i < ngContentSelectors.length; i++) {
          var selector = ngContentSelectors[i];

          if (selector === '*') {
            wildcardNgContentIndex = i;
          } else {
            matcher.addSelectables(CssSelector.parse(ngContentSelectors[i]), i);
          }
        }
      }

      return new ElementContext(isTemplateElement, matcher, wildcardNgContentIndex, providerContext);
    }
  }]);

  return ElementContext;
}();

function createElementCssSelector(elementName, attributes) {
  var cssSelector = new CssSelector();
  var elNameNoNs = splitNsName(elementName)[1];
  cssSelector.setElement(elNameNoNs);

  for (var i = 0; i < attributes.length; i++) {
    var attrName = attributes[i][0];
    var attrNameNoNs = splitNsName(attrName)[1];
    var attrValue = attributes[i][1];
    cssSelector.addAttribute(attrNameNoNs, attrValue);

    if (attrName.toLowerCase() == CLASS_ATTR) {
      var classes = splitClasses(attrValue);
      classes.forEach(function (className) {
        return cssSelector.addClassName(className);
      });
    }
  }

  return cssSelector;
}

var EMPTY_ELEMENT_CONTEXT = new ElementContext(true, new SelectorMatcher(), null, null);
var NON_BINDABLE_VISITOR = new NonBindableVisitor();

function _isEmptyTextNode(node) {
  return node instanceof Text$3 && node.value.trim().length == 0;
}

function removeSummaryDuplicates(items) {
  var map = new Map();
  items.forEach(function (item) {
    if (!map.get(item.type.reference)) {
      map.set(item.type.reference, item);
    }
  });
  return Array.from(map.values());
}

function isEmptyExpression(ast) {
  if (ast instanceof ASTWithSource) {
    ast = ast.ast;
  }

  return ast instanceof EmptyExpr;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Parses string representation of a style and converts it into object literal.
 *
 * @param value string representation of style as used in the `style` attribute in HTML.
 *   Example: `color: red; height: auto`.
 * @returns An array of style property name and value pairs, e.g. `['color', 'red', 'height',
 * 'auto']`
 */


function parse(value) {
  // we use a string array here instead of a string map
  // because a string-map is not guaranteed to retain the
  // order of the entries whereas a string array can be
  // constructed in a [key, value, key, value] format.
  var styles = [];
  var i = 0;
  var parenDepth = 0;
  var quote = 0
  /* QuoteNone */
  ;
  var valueStart = 0;
  var propStart = 0;
  var currentProp = null;
  var valueHasQuotes = false;

  while (i < value.length) {
    var token = value.charCodeAt(i++);

    switch (token) {
      case 40
      /* OpenParen */
      :
        parenDepth++;
        break;

      case 41
      /* CloseParen */
      :
        parenDepth--;
        break;

      case 39
      /* QuoteSingle */
      :
        // valueStart needs to be there since prop values don't
        // have quotes in CSS
        valueHasQuotes = valueHasQuotes || valueStart > 0;

        if (quote === 0
        /* QuoteNone */
        ) {
            quote = 39
            /* QuoteSingle */
            ;
          } else if (quote === 39
        /* QuoteSingle */
        && value.charCodeAt(i - 1) !== 92
        /* BackSlash */
        ) {
            quote = 0
            /* QuoteNone */
            ;
          }

        break;

      case 34
      /* QuoteDouble */
      :
        // same logic as above
        valueHasQuotes = valueHasQuotes || valueStart > 0;

        if (quote === 0
        /* QuoteNone */
        ) {
            quote = 34
            /* QuoteDouble */
            ;
          } else if (quote === 34
        /* QuoteDouble */
        && value.charCodeAt(i - 1) !== 92
        /* BackSlash */
        ) {
            quote = 0
            /* QuoteNone */
            ;
          }

        break;

      case 58
      /* Colon */
      :
        if (!currentProp && parenDepth === 0 && quote === 0
        /* QuoteNone */
        ) {
            currentProp = hyphenate(value.substring(propStart, i - 1).trim());
            valueStart = i;
          }

        break;

      case 59
      /* Semicolon */
      :
        if (currentProp && valueStart > 0 && parenDepth === 0 && quote === 0
        /* QuoteNone */
        ) {
            var styleVal = value.substring(valueStart, i - 1).trim();
            styles.push(currentProp, valueHasQuotes ? stripUnnecessaryQuotes(styleVal) : styleVal);
            propStart = i;
            valueStart = 0;
            currentProp = null;
            valueHasQuotes = false;
          }

        break;
    }
  }

  if (currentProp && valueStart) {
    var _styleVal = value.substr(valueStart).trim();

    styles.push(currentProp, valueHasQuotes ? stripUnnecessaryQuotes(_styleVal) : _styleVal);
  }

  return styles;
}

function stripUnnecessaryQuotes(value) {
  var qS = value.charCodeAt(0);
  var qE = value.charCodeAt(value.length - 1);

  if (qS == qE && (qS == 39
  /* QuoteSingle */
  || qS == 34
  /* QuoteDouble */
  )) {
    var tempValue = value.substring(1, value.length - 1); // special case to avoid using a multi-quoted string that was just chomped
    // (e.g. `font-family: "Verdana", "sans-serif"`)

    if (tempValue.indexOf('\'') == -1 && tempValue.indexOf('"') == -1) {
      value = tempValue;
    }
  }

  return value;
}

function hyphenate(value) {
  return value.replace(/[a-z][A-Z]/g, function (v) {
    return v.charAt(0) + '-' + v.charAt(1);
  }).toLowerCase();
}

var IMPORTANT_FLAG = '!important';
/**
 * Minimum amount of binding slots required in the runtime for style/class bindings.
 *
 * Styling in Angular uses up two slots in the runtime LView/TData data structures to
 * record binding data, property information and metadata.
 *
 * When a binding is registered it will place the following information in the `LView`:
 *
 * slot 1) binding value
 * slot 2) cached value (all other values collected before it in string form)
 *
 * When a binding is registered it will place the following information in the `TData`:
 *
 * slot 1) prop name
 * slot 2) binding index that points to the previous style/class binding (and some extra config
 * values)
 *
 * Let's imagine we have a binding that looks like so:
 *
 * ```
 * <div [style.width]="x" [style.height]="y">
 * ```
 *
 * Our `LView` and `TData` data-structures look like so:
 *
 * ```typescript
 * LView = [
 *   // ...
 *   x, // value of x
 *   "width: x",
 *
 *   y, // value of y
 *   "width: x; height: y",
 *   // ...
 * ];
 *
 * TData = [
 *   // ...
 *   "width", // binding slot 20
 *   0,
 *
 *   "height",
 *   20,
 *   // ...
 * ];
 * ```
 *
 * */

var MIN_STYLING_BINDING_SLOTS_REQUIRED = 2;
/**
 * Produces creation/update instructions for all styling bindings (class and style)
 *
 * It also produces the creation instruction to register all initial styling values
 * (which are all the static class="..." and style="..." attribute values that exist
 * on an element within a template).
 *
 * The builder class below handles producing instructions for the following cases:
 *
 * - Static style/class attributes (style="..." and class="...")
 * - Dynamic style/class map bindings ([style]="map" and [class]="map|string")
 * - Dynamic style/class property bindings ([style.prop]="exp" and [class.name]="exp")
 *
 * Due to the complex relationship of all of these cases, the instructions generated
 * for these attributes/properties/bindings must be done so in the correct order. The
 * order which these must be generated is as follows:
 *
 * if (createMode) {
 *   styling(...)
 * }
 * if (updateMode) {
 *   styleMap(...)
 *   classMap(...)
 *   styleProp(...)
 *   classProp(...)
 * }
 *
 * The creation/update methods within the builder class produce these instructions.
 */

var StylingBuilder = /*#__PURE__*/function () {
  function StylingBuilder(_directiveExpr) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StylingBuilder);

    this._directiveExpr = _directiveExpr;
    /** Whether or not there are any static styling values present */

    this._hasInitialValues = false;
    /**
     *  Whether or not there are any styling bindings present
     *  (i.e. `[style]`, `[class]`, `[style.prop]` or `[class.name]`)
     */

    this.hasBindings = false;
    this.hasBindingsWithPipes = false;
    /** the input for [class] (if it exists) */

    this._classMapInput = null;
    /** the input for [style] (if it exists) */

    this._styleMapInput = null;
    /** an array of each [style.prop] input */

    this._singleStyleInputs = null;
    /** an array of each [class.name] input */

    this._singleClassInputs = null;
    this._lastStylingInput = null;
    this._firstStylingInput = null; // maps are used instead of hash maps because a Map will
    // retain the ordering of the keys

    /**
     * Represents the location of each style binding in the template
     * (e.g. `<div [style.width]="w" [style.height]="h">` implies
     * that `width=0` and `height=1`)
     */

    this._stylesIndex = new Map();
    /**
     * Represents the location of each class binding in the template
     * (e.g. `<div [class.big]="b" [class.hidden]="h">` implies
     * that `big=0` and `hidden=1`)
     */

    this._classesIndex = new Map();
    this._initialStyleValues = [];
    this._initialClassValues = [];
  }
  /**
   * Registers a given input to the styling builder to be later used when producing AOT code.
   *
   * The code below will only accept the input if it is somehow tied to styling (whether it be
   * style/class bindings or static style/class attributes).
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StylingBuilder, [{
    key: "registerBoundInput",
    value: function registerBoundInput(input) {
      // [attr.style] or [attr.class] are skipped in the code below,
      // they should not be treated as styling-based bindings since
      // they are intended to be written directly to the attr and
      // will therefore skip all style/class resolution that is present
      // with style="", [style]="" and [style.prop]="", class="",
      // [class.prop]="". [class]="" assignments
      var binding = null;
      var name = input.name;

      switch (input.type) {
        case 0
        /* Property */
        :
          binding = this.registerInputBasedOnName(name, input.value, input.sourceSpan);
          break;

        case 3
        /* Style */
        :
          binding = this.registerStyleInput(name, false, input.value, input.sourceSpan, input.unit);
          break;

        case 2
        /* Class */
        :
          binding = this.registerClassInput(name, false, input.value, input.sourceSpan);
          break;
      }

      return binding ? true : false;
    }
  }, {
    key: "registerInputBasedOnName",
    value: function registerInputBasedOnName(name, expression, sourceSpan) {
      var binding = null;
      var prefix = name.substring(0, 6);
      var isStyle = name === 'style' || prefix === 'style.' || prefix === 'style!';
      var isClass = !isStyle && (name === 'class' || prefix === 'class.' || prefix === 'class!');

      if (isStyle || isClass) {
        var isMapBased = name.charAt(5) !== '.'; // style.prop or class.prop makes this a no

        var property = name.substr(isMapBased ? 5 : 6); // the dot explains why there's a +1

        if (isStyle) {
          binding = this.registerStyleInput(property, isMapBased, expression, sourceSpan);
        } else {
          binding = this.registerClassInput(property, isMapBased, expression, sourceSpan);
        }
      }

      return binding;
    }
  }, {
    key: "registerStyleInput",
    value: function registerStyleInput(name, isMapBased, value, sourceSpan, suffix) {
      if (isEmptyExpression(value)) {
        return null;
      }

      name = normalizePropName(name);

      var _parseProperty = parseProperty(name),
          property = _parseProperty.property,
          hasOverrideFlag = _parseProperty.hasOverrideFlag,
          bindingSuffix = _parseProperty.suffix;

      suffix = typeof suffix === 'string' && suffix.length !== 0 ? suffix : bindingSuffix;
      var entry = {
        name: property,
        suffix: suffix,
        value: value,
        sourceSpan: sourceSpan,
        hasOverrideFlag: hasOverrideFlag
      };

      if (isMapBased) {
        this._styleMapInput = entry;
      } else {
        (this._singleStyleInputs = this._singleStyleInputs || []).push(entry);
        registerIntoMap(this._stylesIndex, property);
      }

      this._lastStylingInput = entry;
      this._firstStylingInput = this._firstStylingInput || entry;

      this._checkForPipes(value);

      this.hasBindings = true;
      return entry;
    }
  }, {
    key: "registerClassInput",
    value: function registerClassInput(name, isMapBased, value, sourceSpan) {
      if (isEmptyExpression(value)) {
        return null;
      }

      var _parseProperty2 = parseProperty(name),
          property = _parseProperty2.property,
          hasOverrideFlag = _parseProperty2.hasOverrideFlag;

      var entry = {
        name: property,
        value: value,
        sourceSpan: sourceSpan,
        hasOverrideFlag: hasOverrideFlag,
        suffix: null
      };

      if (isMapBased) {
        if (this._classMapInput) {
          throw new Error('[class] and [className] bindings cannot be used on the same element simultaneously');
        }

        this._classMapInput = entry;
      } else {
        (this._singleClassInputs = this._singleClassInputs || []).push(entry);
        registerIntoMap(this._classesIndex, property);
      }

      this._lastStylingInput = entry;
      this._firstStylingInput = this._firstStylingInput || entry;

      this._checkForPipes(value);

      this.hasBindings = true;
      return entry;
    }
  }, {
    key: "_checkForPipes",
    value: function _checkForPipes(value) {
      if (value instanceof ASTWithSource && value.ast instanceof BindingPipe) {
        this.hasBindingsWithPipes = true;
      }
    }
    /**
     * Registers the element's static style string value to the builder.
     *
     * @param value the style string (e.g. `width:100px; height:200px;`)
     */

  }, {
    key: "registerStyleAttr",
    value: function registerStyleAttr(value) {
      this._initialStyleValues = parse(value);
      this._hasInitialValues = true;
    }
    /**
     * Registers the element's static class string value to the builder.
     *
     * @param value the className string (e.g. `disabled gold zoom`)
     */

  }, {
    key: "registerClassAttr",
    value: function registerClassAttr(value) {
      this._initialClassValues = value.trim().split(/\s+/g);
      this._hasInitialValues = true;
    }
    /**
     * Appends all styling-related expressions to the provided attrs array.
     *
     * @param attrs an existing array where each of the styling expressions
     * will be inserted into.
     */

  }, {
    key: "populateInitialStylingAttrs",
    value: function populateInitialStylingAttrs(attrs) {
      // [CLASS_MARKER, 'foo', 'bar', 'baz' ...]
      if (this._initialClassValues.length) {
        attrs.push(literal(1
        /* Classes */
        ));

        for (var i = 0; i < this._initialClassValues.length; i++) {
          attrs.push(literal(this._initialClassValues[i]));
        }
      } // [STYLE_MARKER, 'width', '200px', 'height', '100px', ...]


      if (this._initialStyleValues.length) {
        attrs.push(literal(2
        /* Styles */
        ));

        for (var _i6 = 0; _i6 < this._initialStyleValues.length; _i6 += 2) {
          attrs.push(literal(this._initialStyleValues[_i6]), literal(this._initialStyleValues[_i6 + 1]));
        }
      }
    }
    /**
     * Builds an instruction with all the expressions and parameters for `elementHostAttrs`.
     *
     * The instruction generation code below is used for producing the AOT statement code which is
     * responsible for registering initial styles (within a directive hostBindings' creation block),
     * as well as any of the provided attribute values, to the directive host element.
     */

  }, {
    key: "assignHostAttrs",
    value: function assignHostAttrs(attrs, definitionMap) {
      if (this._directiveExpr && (attrs.length || this._hasInitialValues)) {
        this.populateInitialStylingAttrs(attrs);
        definitionMap.set('hostAttrs', literalArr(attrs));
      }
    }
    /**
     * Builds an instruction with all the expressions and parameters for `classMap`.
     *
     * The instruction data will contain all expressions for `classMap` to function
     * which includes the `[class]` expression params.
     */

  }, {
    key: "buildClassMapInstruction",
    value: function buildClassMapInstruction(valueConverter) {
      if (this._classMapInput) {
        return this._buildMapBasedInstruction(valueConverter, true, this._classMapInput);
      }

      return null;
    }
    /**
     * Builds an instruction with all the expressions and parameters for `styleMap`.
     *
     * The instruction data will contain all expressions for `styleMap` to function
     * which includes the `[style]` expression params.
     */

  }, {
    key: "buildStyleMapInstruction",
    value: function buildStyleMapInstruction(valueConverter) {
      if (this._styleMapInput) {
        return this._buildMapBasedInstruction(valueConverter, false, this._styleMapInput);
      }

      return null;
    }
  }, {
    key: "_buildMapBasedInstruction",
    value: function _buildMapBasedInstruction(valueConverter, isClassBased, stylingInput) {
      // each styling binding value is stored in the LView
      // map-based bindings allocate two slots: one for the
      // previous binding value and another for the previous
      // className or style attribute value.
      var totalBindingSlotsRequired = MIN_STYLING_BINDING_SLOTS_REQUIRED; // these values must be outside of the update block so that they can
      // be evaluated (the AST visit call) during creation time so that any
      // pipes can be picked up in time before the template is built

      var mapValue = stylingInput.value.visit(valueConverter);
      var reference;

      if (mapValue instanceof Interpolation) {
        totalBindingSlotsRequired += mapValue.expressions.length;
        reference = isClassBased ? getClassMapInterpolationExpression(mapValue) : getStyleMapInterpolationExpression(mapValue);
      } else {
        reference = isClassBased ? Identifiers$1.classMap : Identifiers$1.styleMap;
      }

      return {
        reference: reference,
        calls: [{
          supportsInterpolation: true,
          sourceSpan: stylingInput.sourceSpan,
          allocateBindingSlots: totalBindingSlotsRequired,
          params: function params(convertFn) {
            var convertResult = convertFn(mapValue);
            var params = Array.isArray(convertResult) ? convertResult : [convertResult];
            return params;
          }
        }]
      };
    }
  }, {
    key: "_buildSingleInputs",
    value: function _buildSingleInputs(reference, inputs, valueConverter, getInterpolationExpressionFn, isClassBased) {
      var instructions = [];
      inputs.forEach(function (input) {
        var previousInstruction = instructions[instructions.length - 1];
        var value = input.value.visit(valueConverter);
        var referenceForCall = reference; // each styling binding value is stored in the LView
        // but there are two values stored for each binding:
        //   1) the value itself
        //   2) an intermediate value (concatenation of style up to this point).
        //      We need to store the intermediate value so that we don't allocate
        //      the strings on each CD.

        var totalBindingSlotsRequired = MIN_STYLING_BINDING_SLOTS_REQUIRED;

        if (value instanceof Interpolation) {
          totalBindingSlotsRequired += value.expressions.length;

          if (getInterpolationExpressionFn) {
            referenceForCall = getInterpolationExpressionFn(value);
          }
        }

        var call = {
          sourceSpan: input.sourceSpan,
          allocateBindingSlots: totalBindingSlotsRequired,
          supportsInterpolation: !!getInterpolationExpressionFn,
          params: function params(convertFn) {
            // params => stylingProp(propName, value, suffix)
            var params = [];
            params.push(literal(input.name));
            var convertResult = convertFn(value);

            if (Array.isArray(convertResult)) {
              params.push.apply(params, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(convertResult));
            } else {
              params.push(convertResult);
            } // [style.prop] bindings may use suffix values (e.g. px, em, etc...), therefore,
            // if that is detected then we need to pass that in as an optional param.


            if (!isClassBased && input.suffix !== null) {
              params.push(literal(input.suffix));
            }

            return params;
          }
        }; // If we ended up generating a call to the same instruction as the previous styling property
        // we can chain the calls together safely to save some bytes, otherwise we have to generate
        // a separate instruction call. This is primarily a concern with interpolation instructions
        // where we may start off with one `reference`, but end up using another based on the
        // number of interpolations.

        if (previousInstruction && previousInstruction.reference === referenceForCall) {
          previousInstruction.calls.push(call);
        } else {
          instructions.push({
            reference: referenceForCall,
            calls: [call]
          });
        }
      });
      return instructions;
    }
  }, {
    key: "_buildClassInputs",
    value: function _buildClassInputs(valueConverter) {
      if (this._singleClassInputs) {
        return this._buildSingleInputs(Identifiers$1.classProp, this._singleClassInputs, valueConverter, null, true);
      }

      return [];
    }
  }, {
    key: "_buildStyleInputs",
    value: function _buildStyleInputs(valueConverter) {
      if (this._singleStyleInputs) {
        return this._buildSingleInputs(Identifiers$1.styleProp, this._singleStyleInputs, valueConverter, getStylePropInterpolationExpression, false);
      }

      return [];
    }
    /**
     * Constructs all instructions which contain the expressions that will be placed
     * into the update block of a template function or a directive hostBindings function.
     */

  }, {
    key: "buildUpdateLevelInstructions",
    value: function buildUpdateLevelInstructions(valueConverter) {
      var instructions = [];

      if (this.hasBindings) {
        var styleMapInstruction = this.buildStyleMapInstruction(valueConverter);

        if (styleMapInstruction) {
          instructions.push(styleMapInstruction);
        }

        var classMapInstruction = this.buildClassMapInstruction(valueConverter);

        if (classMapInstruction) {
          instructions.push(classMapInstruction);
        }

        instructions.push.apply(instructions, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._buildStyleInputs(valueConverter)));
        instructions.push.apply(instructions, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._buildClassInputs(valueConverter)));
      }

      return instructions;
    }
  }]);

  return StylingBuilder;
}();

function registerIntoMap(map, key) {
  if (!map.has(key)) {
    map.set(key, map.size);
  }
}

function parseProperty(name) {
  var hasOverrideFlag = false;
  var overrideIndex = name.indexOf(IMPORTANT_FLAG);

  if (overrideIndex !== -1) {
    name = overrideIndex > 0 ? name.substring(0, overrideIndex) : '';
    hasOverrideFlag = true;
  }

  var suffix = null;
  var property = name;
  var unitIndex = name.lastIndexOf('.');

  if (unitIndex > 0) {
    suffix = name.substr(unitIndex + 1);
    property = name.substring(0, unitIndex);
  }

  return {
    property: property,
    suffix: suffix,
    hasOverrideFlag: hasOverrideFlag
  };
}
/**
 * Gets the instruction to generate for an interpolated class map.
 * @param interpolation An Interpolation AST
 */


function getClassMapInterpolationExpression(interpolation) {
  switch (getInterpolationArgsLength(interpolation)) {
    case 1:
      return Identifiers$1.classMap;

    case 3:
      return Identifiers$1.classMapInterpolate1;

    case 5:
      return Identifiers$1.classMapInterpolate2;

    case 7:
      return Identifiers$1.classMapInterpolate3;

    case 9:
      return Identifiers$1.classMapInterpolate4;

    case 11:
      return Identifiers$1.classMapInterpolate5;

    case 13:
      return Identifiers$1.classMapInterpolate6;

    case 15:
      return Identifiers$1.classMapInterpolate7;

    case 17:
      return Identifiers$1.classMapInterpolate8;

    default:
      return Identifiers$1.classMapInterpolateV;
  }
}
/**
 * Gets the instruction to generate for an interpolated style map.
 * @param interpolation An Interpolation AST
 */


function getStyleMapInterpolationExpression(interpolation) {
  switch (getInterpolationArgsLength(interpolation)) {
    case 1:
      return Identifiers$1.styleMap;

    case 3:
      return Identifiers$1.styleMapInterpolate1;

    case 5:
      return Identifiers$1.styleMapInterpolate2;

    case 7:
      return Identifiers$1.styleMapInterpolate3;

    case 9:
      return Identifiers$1.styleMapInterpolate4;

    case 11:
      return Identifiers$1.styleMapInterpolate5;

    case 13:
      return Identifiers$1.styleMapInterpolate6;

    case 15:
      return Identifiers$1.styleMapInterpolate7;

    case 17:
      return Identifiers$1.styleMapInterpolate8;

    default:
      return Identifiers$1.styleMapInterpolateV;
  }
}
/**
 * Gets the instruction to generate for an interpolated style prop.
 * @param interpolation An Interpolation AST
 */


function getStylePropInterpolationExpression(interpolation) {
  switch (getInterpolationArgsLength(interpolation)) {
    case 1:
      return Identifiers$1.styleProp;

    case 3:
      return Identifiers$1.stylePropInterpolate1;

    case 5:
      return Identifiers$1.stylePropInterpolate2;

    case 7:
      return Identifiers$1.stylePropInterpolate3;

    case 9:
      return Identifiers$1.stylePropInterpolate4;

    case 11:
      return Identifiers$1.stylePropInterpolate5;

    case 13:
      return Identifiers$1.stylePropInterpolate6;

    case 15:
      return Identifiers$1.stylePropInterpolate7;

    case 17:
      return Identifiers$1.stylePropInterpolate8;

    default:
      return Identifiers$1.stylePropInterpolateV;
  }
}

function normalizePropName(prop) {
  return hyphenate(prop);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TokenType$1;

(function (TokenType) {
  TokenType[TokenType["Character"] = 0] = "Character";
  TokenType[TokenType["Identifier"] = 1] = "Identifier";
  TokenType[TokenType["Keyword"] = 2] = "Keyword";
  TokenType[TokenType["String"] = 3] = "String";
  TokenType[TokenType["Operator"] = 4] = "Operator";
  TokenType[TokenType["Number"] = 5] = "Number";
  TokenType[TokenType["Error"] = 6] = "Error";
})(TokenType$1 || (TokenType$1 = {}));

var KEYWORDS = ['var', 'let', 'as', 'null', 'undefined', 'true', 'false', 'if', 'else', 'this'];

var Lexer = /*#__PURE__*/function () {
  function Lexer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Lexer);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Lexer, [{
    key: "tokenize",
    value: function tokenize(text) {
      var scanner = new _Scanner(text);
      var tokens = [];
      var token = scanner.scanToken();

      while (token != null) {
        tokens.push(token);
        token = scanner.scanToken();
      }

      return tokens;
    }
  }]);

  return Lexer;
}();

var Token$1 = /*#__PURE__*/function () {
  function Token$1(index, end, type, numValue, strValue) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Token$1);

    this.index = index;
    this.end = end;
    this.type = type;
    this.numValue = numValue;
    this.strValue = strValue;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Token$1, [{
    key: "isCharacter",
    value: function isCharacter(code) {
      return this.type == TokenType$1.Character && this.numValue == code;
    }
  }, {
    key: "isNumber",
    value: function isNumber() {
      return this.type == TokenType$1.Number;
    }
  }, {
    key: "isString",
    value: function isString() {
      return this.type == TokenType$1.String;
    }
  }, {
    key: "isOperator",
    value: function isOperator(operator) {
      return this.type == TokenType$1.Operator && this.strValue == operator;
    }
  }, {
    key: "isIdentifier",
    value: function isIdentifier() {
      return this.type == TokenType$1.Identifier;
    }
  }, {
    key: "isKeyword",
    value: function isKeyword() {
      return this.type == TokenType$1.Keyword;
    }
  }, {
    key: "isKeywordLet",
    value: function isKeywordLet() {
      return this.type == TokenType$1.Keyword && this.strValue == 'let';
    }
  }, {
    key: "isKeywordAs",
    value: function isKeywordAs() {
      return this.type == TokenType$1.Keyword && this.strValue == 'as';
    }
  }, {
    key: "isKeywordNull",
    value: function isKeywordNull() {
      return this.type == TokenType$1.Keyword && this.strValue == 'null';
    }
  }, {
    key: "isKeywordUndefined",
    value: function isKeywordUndefined() {
      return this.type == TokenType$1.Keyword && this.strValue == 'undefined';
    }
  }, {
    key: "isKeywordTrue",
    value: function isKeywordTrue() {
      return this.type == TokenType$1.Keyword && this.strValue == 'true';
    }
  }, {
    key: "isKeywordFalse",
    value: function isKeywordFalse() {
      return this.type == TokenType$1.Keyword && this.strValue == 'false';
    }
  }, {
    key: "isKeywordThis",
    value: function isKeywordThis() {
      return this.type == TokenType$1.Keyword && this.strValue == 'this';
    }
  }, {
    key: "isError",
    value: function isError() {
      return this.type == TokenType$1.Error;
    }
  }, {
    key: "toNumber",
    value: function toNumber() {
      return this.type == TokenType$1.Number ? this.numValue : -1;
    }
  }, {
    key: "toString",
    value: function toString() {
      switch (this.type) {
        case TokenType$1.Character:
        case TokenType$1.Identifier:
        case TokenType$1.Keyword:
        case TokenType$1.Operator:
        case TokenType$1.String:
        case TokenType$1.Error:
          return this.strValue;

        case TokenType$1.Number:
          return this.numValue.toString();

        default:
          return null;
      }
    }
  }]);

  return Token$1;
}();

function newCharacterToken(index, end, code) {
  return new Token$1(index, end, TokenType$1.Character, code, String.fromCharCode(code));
}

function newIdentifierToken(index, end, text) {
  return new Token$1(index, end, TokenType$1.Identifier, 0, text);
}

function newKeywordToken(index, end, text) {
  return new Token$1(index, end, TokenType$1.Keyword, 0, text);
}

function newOperatorToken(index, end, text) {
  return new Token$1(index, end, TokenType$1.Operator, 0, text);
}

function newStringToken(index, end, text) {
  return new Token$1(index, end, TokenType$1.String, 0, text);
}

function newNumberToken(index, end, n) {
  return new Token$1(index, end, TokenType$1.Number, n, '');
}

function newErrorToken(index, end, message) {
  return new Token$1(index, end, TokenType$1.Error, 0, message);
}

var EOF = new Token$1(-1, -1, TokenType$1.Character, 0, '');

var _Scanner = /*#__PURE__*/function () {
  function _Scanner(input) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _Scanner);

    this.input = input;
    this.peek = 0;
    this.index = -1;
    this.length = input.length;
    this.advance();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_Scanner, [{
    key: "advance",
    value: function advance() {
      this.peek = ++this.index >= this.length ? $EOF : this.input.charCodeAt(this.index);
    }
  }, {
    key: "scanToken",
    value: function scanToken() {
      var input = this.input,
          length = this.length;
      var peek = this.peek,
          index = this.index; // Skip whitespace.

      while (peek <= $SPACE) {
        if (++index >= length) {
          peek = $EOF;
          break;
        } else {
          peek = input.charCodeAt(index);
        }
      }

      this.peek = peek;
      this.index = index;

      if (index >= length) {
        return null;
      } // Handle identifiers and numbers.


      if (isIdentifierStart(peek)) return this.scanIdentifier();
      if (isDigit(peek)) return this.scanNumber(index);
      var start = index;

      switch (peek) {
        case $PERIOD:
          this.advance();
          return isDigit(this.peek) ? this.scanNumber(start) : newCharacterToken(start, this.index, $PERIOD);

        case $LPAREN:
        case $RPAREN:
        case $LBRACE:
        case $RBRACE:
        case $LBRACKET:
        case $RBRACKET:
        case $COMMA:
        case $COLON:
        case $SEMICOLON:
          return this.scanCharacter(start, peek);

        case $SQ:
        case $DQ:
          return this.scanString();

        case $HASH:
        case $PLUS:
        case $MINUS:
        case $STAR:
        case $SLASH:
        case $PERCENT:
        case $CARET:
          return this.scanOperator(start, String.fromCharCode(peek));

        case $QUESTION:
          return this.scanComplexOperator(start, '?', $PERIOD, '.');

        case $LT:
        case $GT:
          return this.scanComplexOperator(start, String.fromCharCode(peek), $EQ, '=');

        case $BANG:
        case $EQ:
          return this.scanComplexOperator(start, String.fromCharCode(peek), $EQ, '=', $EQ, '=');

        case $AMPERSAND:
          return this.scanComplexOperator(start, '&', $AMPERSAND, '&');

        case $BAR:
          return this.scanComplexOperator(start, '|', $BAR, '|');

        case $NBSP:
          while (isWhitespace(this.peek)) {
            this.advance();
          }

          return this.scanToken();
      }

      this.advance();
      return this.error("Unexpected character [".concat(String.fromCharCode(peek), "]"), 0);
    }
  }, {
    key: "scanCharacter",
    value: function scanCharacter(start, code) {
      this.advance();
      return newCharacterToken(start, this.index, code);
    }
  }, {
    key: "scanOperator",
    value: function scanOperator(start, str) {
      this.advance();
      return newOperatorToken(start, this.index, str);
    }
    /**
     * Tokenize a 2/3 char long operator
     *
     * @param start start index in the expression
     * @param one first symbol (always part of the operator)
     * @param twoCode code point for the second symbol
     * @param two second symbol (part of the operator when the second code point matches)
     * @param threeCode code point for the third symbol
     * @param three third symbol (part of the operator when provided and matches source expression)
     */

  }, {
    key: "scanComplexOperator",
    value: function scanComplexOperator(start, one, twoCode, two, threeCode, three) {
      this.advance();
      var str = one;

      if (this.peek == twoCode) {
        this.advance();
        str += two;
      }

      if (threeCode != null && this.peek == threeCode) {
        this.advance();
        str += three;
      }

      return newOperatorToken(start, this.index, str);
    }
  }, {
    key: "scanIdentifier",
    value: function scanIdentifier() {
      var start = this.index;
      this.advance();

      while (isIdentifierPart(this.peek)) {
        this.advance();
      }

      var str = this.input.substring(start, this.index);
      return KEYWORDS.indexOf(str) > -1 ? newKeywordToken(start, this.index, str) : newIdentifierToken(start, this.index, str);
    }
  }, {
    key: "scanNumber",
    value: function scanNumber(start) {
      var simple = this.index === start;
      this.advance(); // Skip initial digit.

      while (true) {
        if (isDigit(this.peek)) {// Do nothing.
        } else if (this.peek == $PERIOD) {
          simple = false;
        } else if (isExponentStart(this.peek)) {
          this.advance();
          if (isExponentSign(this.peek)) this.advance();
          if (!isDigit(this.peek)) return this.error('Invalid exponent', -1);
          simple = false;
        } else {
          break;
        }

        this.advance();
      }

      var str = this.input.substring(start, this.index);
      var value = simple ? parseIntAutoRadix(str) : parseFloat(str);
      return newNumberToken(start, this.index, value);
    }
  }, {
    key: "scanString",
    value: function scanString() {
      var start = this.index;
      var quote = this.peek;
      this.advance(); // Skip initial quote.

      var buffer = '';
      var marker = this.index;
      var input = this.input;

      while (this.peek != quote) {
        if (this.peek == $BACKSLASH) {
          buffer += input.substring(marker, this.index);
          this.advance();
          var unescapedCode = void 0; // Workaround for TS2.1-introduced type strictness

          this.peek = this.peek;

          if (this.peek == $u) {
            // 4 character hex code for unicode character.
            var hex = input.substring(this.index + 1, this.index + 5);

            if (/^[0-9a-f]+$/i.test(hex)) {
              unescapedCode = parseInt(hex, 16);
            } else {
              return this.error("Invalid unicode escape [\\u".concat(hex, "]"), 0);
            }

            for (var i = 0; i < 5; i++) {
              this.advance();
            }
          } else {
            unescapedCode = unescape(this.peek);
            this.advance();
          }

          buffer += String.fromCharCode(unescapedCode);
          marker = this.index;
        } else if (this.peek == $EOF) {
          return this.error('Unterminated quote', 0);
        } else {
          this.advance();
        }
      }

      var last = input.substring(marker, this.index);
      this.advance(); // Skip terminating quote.

      return newStringToken(start, this.index, buffer + last);
    }
  }, {
    key: "error",
    value: function error(message, offset) {
      var position = this.index + offset;
      return newErrorToken(position, this.index, "Lexer Error: ".concat(message, " at column ").concat(position, " in expression [").concat(this.input, "]"));
    }
  }]);

  return _Scanner;
}();

function isIdentifierStart(code) {
  return $a <= code && code <= $z || $A <= code && code <= $Z || code == $_ || code == $$;
}

function isIdentifier(input) {
  if (input.length == 0) return false;
  var scanner = new _Scanner(input);
  if (!isIdentifierStart(scanner.peek)) return false;
  scanner.advance();

  while (scanner.peek !== $EOF) {
    if (!isIdentifierPart(scanner.peek)) return false;
    scanner.advance();
  }

  return true;
}

function isIdentifierPart(code) {
  return isAsciiLetter(code) || isDigit(code) || code == $_ || code == $$;
}

function isExponentStart(code) {
  return code == $e || code == $E;
}

function isExponentSign(code) {
  return code == $MINUS || code == $PLUS;
}

function isQuote(code) {
  return code === $SQ || code === $DQ || code === $BT;
}

function unescape(code) {
  switch (code) {
    case $n:
      return $LF;

    case $f:
      return $FF;

    case $r:
      return $CR;

    case $t:
      return $TAB;

    case $v:
      return $VTAB;

    default:
      return code;
  }
}

function parseIntAutoRadix(text) {
  var result = parseInt(text);

  if (isNaN(result)) {
    throw new Error('Invalid integer literal when parsing ' + text);
  }

  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SplitInterpolation = function SplitInterpolation(strings, stringSpans, expressions, expressionsSpans, offsets) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SplitInterpolation);

  this.strings = strings;
  this.stringSpans = stringSpans;
  this.expressions = expressions;
  this.expressionsSpans = expressionsSpans;
  this.offsets = offsets;
};

var TemplateBindingParseResult = function TemplateBindingParseResult(templateBindings, warnings, errors) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateBindingParseResult);

  this.templateBindings = templateBindings;
  this.warnings = warnings;
  this.errors = errors;
};

var defaultInterpolateRegExp = _createInterpolateRegExp(DEFAULT_INTERPOLATION_CONFIG);

function _getInterpolateRegExp(config) {
  if (config === DEFAULT_INTERPOLATION_CONFIG) {
    return defaultInterpolateRegExp;
  } else {
    return _createInterpolateRegExp(config);
  }
}

function _createInterpolateRegExp(config) {
  var pattern = escapeRegExp(config.start) + '([\\s\\S]*?)' + escapeRegExp(config.end);
  return new RegExp(pattern, 'g');
}

var Parser$1 = /*#__PURE__*/function () {
  function Parser$1(_lexer) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Parser$1);

    this._lexer = _lexer;
    this.errors = [];
    this.simpleExpressionChecker = SimpleExpressionChecker;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Parser$1, [{
    key: "parseAction",
    value: function parseAction(input, location, absoluteOffset) {
      var interpolationConfig = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : DEFAULT_INTERPOLATION_CONFIG;

      this._checkNoInterpolation(input, location, interpolationConfig);

      var sourceToLex = this._stripComments(input);

      var tokens = this._lexer.tokenize(this._stripComments(input));

      var ast = new _ParseAST(input, location, absoluteOffset, tokens, sourceToLex.length, true, this.errors, input.length - sourceToLex.length).parseChain();
      return new ASTWithSource(ast, input, location, absoluteOffset, this.errors);
    }
  }, {
    key: "parseBinding",
    value: function parseBinding(input, location, absoluteOffset) {
      var interpolationConfig = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : DEFAULT_INTERPOLATION_CONFIG;

      var ast = this._parseBindingAst(input, location, absoluteOffset, interpolationConfig);

      return new ASTWithSource(ast, input, location, absoluteOffset, this.errors);
    }
  }, {
    key: "checkSimpleExpression",
    value: function checkSimpleExpression(ast) {
      var checker = new this.simpleExpressionChecker();
      ast.visit(checker);
      return checker.errors;
    }
  }, {
    key: "parseSimpleBinding",
    value: function parseSimpleBinding(input, location, absoluteOffset) {
      var interpolationConfig = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : DEFAULT_INTERPOLATION_CONFIG;

      var ast = this._parseBindingAst(input, location, absoluteOffset, interpolationConfig);

      var errors = this.checkSimpleExpression(ast);

      if (errors.length > 0) {
        this._reportError("Host binding expression cannot contain ".concat(errors.join(' ')), input, location);
      }

      return new ASTWithSource(ast, input, location, absoluteOffset, this.errors);
    }
  }, {
    key: "_reportError",
    value: function _reportError(message, input, errLocation, ctxLocation) {
      this.errors.push(new ParserError(message, input, errLocation, ctxLocation));
    }
  }, {
    key: "_parseBindingAst",
    value: function _parseBindingAst(input, location, absoluteOffset, interpolationConfig) {
      // Quotes expressions use 3rd-party expression language. We don't want to use
      // our lexer or parser for that, so we check for that ahead of time.
      var quote = this._parseQuote(input, location, absoluteOffset);

      if (quote != null) {
        return quote;
      }

      this._checkNoInterpolation(input, location, interpolationConfig);

      var sourceToLex = this._stripComments(input);

      var tokens = this._lexer.tokenize(sourceToLex);

      return new _ParseAST(input, location, absoluteOffset, tokens, sourceToLex.length, false, this.errors, input.length - sourceToLex.length).parseChain();
    }
  }, {
    key: "_parseQuote",
    value: function _parseQuote(input, location, absoluteOffset) {
      if (input == null) return null;
      var prefixSeparatorIndex = input.indexOf(':');
      if (prefixSeparatorIndex == -1) return null;
      var prefix = input.substring(0, prefixSeparatorIndex).trim();
      if (!isIdentifier(prefix)) return null;
      var uninterpretedExpression = input.substring(prefixSeparatorIndex + 1);
      var span = new ParseSpan(0, input.length);
      return new Quote(span, span.toAbsolute(absoluteOffset), prefix, uninterpretedExpression, location);
    }
    /**
     * Parse microsyntax template expression and return a list of bindings or
     * parsing errors in case the given expression is invalid.
     *
     * For example,
     * ```
     *   <div *ngFor="let item of items">
     *         ^      ^ absoluteValueOffset for `templateValue`
     *         absoluteKeyOffset for `templateKey`
     * ```
     * contains three bindings:
     * 1. ngFor -> null
     * 2. item -> NgForOfContext.$implicit
     * 3. ngForOf -> items
     *
     * This is apparent from the de-sugared template:
     * ```
     *   <ng-template ngFor let-item [ngForOf]="items">
     * ```
     *
     * @param templateKey name of directive, without the * prefix. For example: ngIf, ngFor
     * @param templateValue RHS of the microsyntax attribute
     * @param templateUrl template filename if it's external, component filename if it's inline
     * @param absoluteKeyOffset start of the `templateKey`
     * @param absoluteValueOffset start of the `templateValue`
     */

  }, {
    key: "parseTemplateBindings",
    value: function parseTemplateBindings(templateKey, templateValue, templateUrl, absoluteKeyOffset, absoluteValueOffset) {
      var tokens = this._lexer.tokenize(templateValue);

      var parser = new _ParseAST(templateValue, templateUrl, absoluteValueOffset, tokens, templateValue.length, false
      /* parseAction */
      , this.errors, 0
      /* relative offset */
      );
      return parser.parseTemplateBindings({
        source: templateKey,
        span: new AbsoluteSourceSpan(absoluteKeyOffset, absoluteKeyOffset + templateKey.length)
      });
    }
  }, {
    key: "parseInterpolation",
    value: function parseInterpolation(input, location, absoluteOffset) {
      var interpolationConfig = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : DEFAULT_INTERPOLATION_CONFIG;
      var split = this.splitInterpolation(input, location, interpolationConfig);
      if (split == null) return null;
      var expressions = [];

      for (var i = 0; i < split.expressions.length; ++i) {
        var expressionText = split.expressions[i];

        var sourceToLex = this._stripComments(expressionText);

        var tokens = this._lexer.tokenize(sourceToLex);

        var ast = new _ParseAST(input, location, absoluteOffset, tokens, sourceToLex.length, false, this.errors, split.offsets[i] + (expressionText.length - sourceToLex.length)).parseChain();
        expressions.push(ast);
      }

      var span = new ParseSpan(0, input == null ? 0 : input.length);
      return new ASTWithSource(new Interpolation(span, span.toAbsolute(absoluteOffset), split.strings, expressions), input, location, absoluteOffset, this.errors);
    }
  }, {
    key: "splitInterpolation",
    value: function splitInterpolation(input, location) {
      var interpolationConfig = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : DEFAULT_INTERPOLATION_CONFIG;

      var regexp = _getInterpolateRegExp(interpolationConfig);

      var parts = input.split(regexp);

      if (parts.length <= 1) {
        return null;
      }

      var strings = [];
      var expressions = [];
      var offsets = [];
      var stringSpans = [];
      var expressionSpans = [];
      var offset = 0;

      for (var i = 0; i < parts.length; i++) {
        var part = parts[i];

        if (i % 2 === 0) {
          // fixed string
          strings.push(part);
          var start = offset;
          offset += part.length;
          stringSpans.push({
            start: start,
            end: offset
          });
        } else if (part.trim().length > 0) {
          var _start = offset;
          offset += interpolationConfig.start.length;
          expressions.push(part);
          offsets.push(offset);
          offset += part.length + interpolationConfig.end.length;
          expressionSpans.push({
            start: _start,
            end: offset
          });
        } else {
          this._reportError('Blank expressions are not allowed in interpolated strings', input, "at column ".concat(this._findInterpolationErrorColumn(parts, i, interpolationConfig), " in"), location);

          expressions.push('$implicit');
          offsets.push(offset);
          expressionSpans.push({
            start: offset,
            end: offset
          });
        }
      }

      return new SplitInterpolation(strings, stringSpans, expressions, expressionSpans, offsets);
    }
  }, {
    key: "wrapLiteralPrimitive",
    value: function wrapLiteralPrimitive(input, location, absoluteOffset) {
      var span = new ParseSpan(0, input == null ? 0 : input.length);
      return new ASTWithSource(new LiteralPrimitive(span, span.toAbsolute(absoluteOffset), input), input, location, absoluteOffset, this.errors);
    }
  }, {
    key: "_stripComments",
    value: function _stripComments(input) {
      var i = this._commentStart(input);

      return i != null ? input.substring(0, i).trim() : input;
    }
  }, {
    key: "_commentStart",
    value: function _commentStart(input) {
      var outerQuote = null;

      for (var i = 0; i < input.length - 1; i++) {
        var char = input.charCodeAt(i);
        var nextChar = input.charCodeAt(i + 1);
        if (char === $SLASH && nextChar == $SLASH && outerQuote == null) return i;

        if (outerQuote === char) {
          outerQuote = null;
        } else if (outerQuote == null && isQuote(char)) {
          outerQuote = char;
        }
      }

      return null;
    }
  }, {
    key: "_checkNoInterpolation",
    value: function _checkNoInterpolation(input, location, interpolationConfig) {
      var regexp = _getInterpolateRegExp(interpolationConfig);

      var parts = input.split(regexp);

      if (parts.length > 1) {
        this._reportError("Got interpolation (".concat(interpolationConfig.start).concat(interpolationConfig.end, ") where expression was expected"), input, "at column ".concat(this._findInterpolationErrorColumn(parts, 1, interpolationConfig), " in"), location);
      }
    }
  }, {
    key: "_findInterpolationErrorColumn",
    value: function _findInterpolationErrorColumn(parts, partInErrIdx, interpolationConfig) {
      var errLocation = '';

      for (var j = 0; j < partInErrIdx; j++) {
        errLocation += j % 2 === 0 ? parts[j] : "".concat(interpolationConfig.start).concat(parts[j]).concat(interpolationConfig.end);
      }

      return errLocation.length;
    }
  }]);

  return Parser$1;
}();

var IvyParser = /*#__PURE__*/function (_Parser$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(IvyParser, _Parser$);

  var _super93 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(IvyParser);

  function IvyParser() {
    var _this154;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, IvyParser);

    _this154 = _super93.apply(this, arguments);
    _this154.simpleExpressionChecker = IvySimpleExpressionChecker; //

    return _this154;
  }

  return IvyParser;
}(Parser$1);

var _ParseAST = /*#__PURE__*/function () {
  function _ParseAST(input, location, absoluteOffset, tokens, inputLength, parseAction, errors, offset) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _ParseAST);

    this.input = input;
    this.location = location;
    this.absoluteOffset = absoluteOffset;
    this.tokens = tokens;
    this.inputLength = inputLength;
    this.parseAction = parseAction;
    this.errors = errors;
    this.offset = offset;
    this.rparensExpected = 0;
    this.rbracketsExpected = 0;
    this.rbracesExpected = 0; // Cache of expression start and input indeces to the absolute source span they map to, used to
    // prevent creating superfluous source spans in `sourceSpan`.
    // A serial of the expression start and input index is used for mapping because both are stateful
    // and may change for subsequent expressions visited by the parser.

    this.sourceSpanCache = new Map();
    this.index = 0;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_ParseAST, [{
    key: "peek",
    value: function peek(offset) {
      var i = this.index + offset;
      return i < this.tokens.length ? this.tokens[i] : EOF;
    }
  }, {
    key: "span",
    value: function span(start) {
      return new ParseSpan(start, this.currentEndIndex);
    }
  }, {
    key: "sourceSpan",
    value: function sourceSpan(start) {
      var serial = "".concat(start, "@").concat(this.inputIndex);

      if (!this.sourceSpanCache.has(serial)) {
        this.sourceSpanCache.set(serial, this.span(start).toAbsolute(this.absoluteOffset));
      }

      return this.sourceSpanCache.get(serial);
    }
  }, {
    key: "advance",
    value: function advance() {
      this.index++;
    }
  }, {
    key: "consumeOptionalCharacter",
    value: function consumeOptionalCharacter(code) {
      if (this.next.isCharacter(code)) {
        this.advance();
        return true;
      } else {
        return false;
      }
    }
  }, {
    key: "peekKeywordLet",
    value: function peekKeywordLet() {
      return this.next.isKeywordLet();
    }
  }, {
    key: "peekKeywordAs",
    value: function peekKeywordAs() {
      return this.next.isKeywordAs();
    }
  }, {
    key: "expectCharacter",
    value: function expectCharacter(code) {
      if (this.consumeOptionalCharacter(code)) return;
      this.error("Missing expected ".concat(String.fromCharCode(code)));
    }
  }, {
    key: "consumeOptionalOperator",
    value: function consumeOptionalOperator(op) {
      if (this.next.isOperator(op)) {
        this.advance();
        return true;
      } else {
        return false;
      }
    }
  }, {
    key: "expectOperator",
    value: function expectOperator(operator) {
      if (this.consumeOptionalOperator(operator)) return;
      this.error("Missing expected operator ".concat(operator));
    }
  }, {
    key: "expectIdentifierOrKeyword",
    value: function expectIdentifierOrKeyword() {
      var n = this.next;

      if (!n.isIdentifier() && !n.isKeyword()) {
        this.error("Unexpected token ".concat(n, ", expected identifier or keyword"));
        return '';
      }

      this.advance();
      return n.toString();
    }
  }, {
    key: "expectIdentifierOrKeywordOrString",
    value: function expectIdentifierOrKeywordOrString() {
      var n = this.next;

      if (!n.isIdentifier() && !n.isKeyword() && !n.isString()) {
        this.error("Unexpected token ".concat(n, ", expected identifier, keyword, or string"));
        return '';
      }

      this.advance();
      return n.toString();
    }
  }, {
    key: "parseChain",
    value: function parseChain() {
      var exprs = [];
      var start = this.inputIndex;

      while (this.index < this.tokens.length) {
        var expr = this.parsePipe();
        exprs.push(expr);

        if (this.consumeOptionalCharacter($SEMICOLON)) {
          if (!this.parseAction) {
            this.error('Binding expression cannot contain chained expression');
          }

          while (this.consumeOptionalCharacter($SEMICOLON)) {} // read all semicolons

        } else if (this.index < this.tokens.length) {
          this.error("Unexpected token '".concat(this.next, "'"));
        }
      }

      if (exprs.length == 0) return new EmptyExpr(this.span(start), this.sourceSpan(start));
      if (exprs.length == 1) return exprs[0];
      return new Chain(this.span(start), this.sourceSpan(start), exprs);
    }
  }, {
    key: "parsePipe",
    value: function parsePipe() {
      var result = this.parseExpression();

      if (this.consumeOptionalOperator('|')) {
        if (this.parseAction) {
          this.error('Cannot have a pipe in an action expression');
        }

        do {
          var nameStart = this.inputIndex;
          var name = this.expectIdentifierOrKeyword();
          var nameSpan = this.sourceSpan(nameStart);
          var args = [];

          while (this.consumeOptionalCharacter($COLON)) {
            args.push(this.parseExpression());
          }

          var start = result.span.start;
          result = new BindingPipe(this.span(start), this.sourceSpan(start), result, name, args, nameSpan);
        } while (this.consumeOptionalOperator('|'));
      }

      return result;
    }
  }, {
    key: "parseExpression",
    value: function parseExpression() {
      return this.parseConditional();
    }
  }, {
    key: "parseConditional",
    value: function parseConditional() {
      var start = this.inputIndex;
      var result = this.parseLogicalOr();

      if (this.consumeOptionalOperator('?')) {
        var yes = this.parsePipe();
        var no;

        if (!this.consumeOptionalCharacter($COLON)) {
          var end = this.inputIndex;
          var expression = this.input.substring(start, end);
          this.error("Conditional expression ".concat(expression, " requires all 3 expressions"));
          no = new EmptyExpr(this.span(start), this.sourceSpan(start));
        } else {
          no = this.parsePipe();
        }

        return new Conditional(this.span(start), this.sourceSpan(start), result, yes, no);
      } else {
        return result;
      }
    }
  }, {
    key: "parseLogicalOr",
    value: function parseLogicalOr() {
      // '||'
      var result = this.parseLogicalAnd();

      while (this.consumeOptionalOperator('||')) {
        var right = this.parseLogicalAnd();
        var start = result.span.start;
        result = new Binary(this.span(start), this.sourceSpan(start), '||', result, right);
      }

      return result;
    }
  }, {
    key: "parseLogicalAnd",
    value: function parseLogicalAnd() {
      // '&&'
      var result = this.parseEquality();

      while (this.consumeOptionalOperator('&&')) {
        var right = this.parseEquality();
        var start = result.span.start;
        result = new Binary(this.span(start), this.sourceSpan(start), '&&', result, right);
      }

      return result;
    }
  }, {
    key: "parseEquality",
    value: function parseEquality() {
      // '==','!=','===','!=='
      var result = this.parseRelational();

      while (this.next.type == TokenType$1.Operator) {
        var operator = this.next.strValue;

        switch (operator) {
          case '==':
          case '===':
          case '!=':
          case '!==':
            this.advance();
            var right = this.parseRelational();
            var start = result.span.start;
            result = new Binary(this.span(start), this.sourceSpan(start), operator, result, right);
            continue;
        }

        break;
      }

      return result;
    }
  }, {
    key: "parseRelational",
    value: function parseRelational() {
      // '<', '>', '<=', '>='
      var result = this.parseAdditive();

      while (this.next.type == TokenType$1.Operator) {
        var operator = this.next.strValue;

        switch (operator) {
          case '<':
          case '>':
          case '<=':
          case '>=':
            this.advance();
            var right = this.parseAdditive();
            var start = result.span.start;
            result = new Binary(this.span(start), this.sourceSpan(start), operator, result, right);
            continue;
        }

        break;
      }

      return result;
    }
  }, {
    key: "parseAdditive",
    value: function parseAdditive() {
      // '+', '-'
      var result = this.parseMultiplicative();

      while (this.next.type == TokenType$1.Operator) {
        var operator = this.next.strValue;

        switch (operator) {
          case '+':
          case '-':
            this.advance();
            var right = this.parseMultiplicative();
            var start = result.span.start;
            result = new Binary(this.span(start), this.sourceSpan(start), operator, result, right);
            continue;
        }

        break;
      }

      return result;
    }
  }, {
    key: "parseMultiplicative",
    value: function parseMultiplicative() {
      // '*', '%', '/'
      var result = this.parsePrefix();

      while (this.next.type == TokenType$1.Operator) {
        var operator = this.next.strValue;

        switch (operator) {
          case '*':
          case '%':
          case '/':
            this.advance();
            var right = this.parsePrefix();
            var start = result.span.start;
            result = new Binary(this.span(start), this.sourceSpan(start), operator, result, right);
            continue;
        }

        break;
      }

      return result;
    }
  }, {
    key: "parsePrefix",
    value: function parsePrefix() {
      if (this.next.type == TokenType$1.Operator) {
        var start = this.inputIndex;
        var operator = this.next.strValue;
        var result;

        switch (operator) {
          case '+':
            this.advance();
            result = this.parsePrefix();
            return Unary.createPlus(this.span(start), this.sourceSpan(start), result);

          case '-':
            this.advance();
            result = this.parsePrefix();
            return Unary.createMinus(this.span(start), this.sourceSpan(start), result);

          case '!':
            this.advance();
            result = this.parsePrefix();
            return new PrefixNot(this.span(start), this.sourceSpan(start), result);
        }
      }

      return this.parseCallChain();
    }
  }, {
    key: "parseCallChain",
    value: function parseCallChain() {
      var result = this.parsePrimary();
      var resultStart = result.span.start;

      while (true) {
        if (this.consumeOptionalCharacter($PERIOD)) {
          result = this.parseAccessMemberOrMethodCall(result, false);
        } else if (this.consumeOptionalOperator('?.')) {
          result = this.parseAccessMemberOrMethodCall(result, true);
        } else if (this.consumeOptionalCharacter($LBRACKET)) {
          this.rbracketsExpected++;
          var key = this.parsePipe();
          this.rbracketsExpected--;
          this.expectCharacter($RBRACKET);

          if (this.consumeOptionalOperator('=')) {
            var value = this.parseConditional();
            result = new KeyedWrite(this.span(resultStart), this.sourceSpan(resultStart), result, key, value);
          } else {
            result = new KeyedRead(this.span(resultStart), this.sourceSpan(resultStart), result, key);
          }
        } else if (this.consumeOptionalCharacter($LPAREN)) {
          this.rparensExpected++;
          var args = this.parseCallArguments();
          this.rparensExpected--;
          this.expectCharacter($RPAREN);
          result = new FunctionCall(this.span(resultStart), this.sourceSpan(resultStart), result, args);
        } else if (this.consumeOptionalOperator('!')) {
          result = new NonNullAssert(this.span(resultStart), this.sourceSpan(resultStart), result);
        } else {
          return result;
        }
      }
    }
  }, {
    key: "parsePrimary",
    value: function parsePrimary() {
      var start = this.inputIndex;

      if (this.consumeOptionalCharacter($LPAREN)) {
        this.rparensExpected++;
        var result = this.parsePipe();
        this.rparensExpected--;
        this.expectCharacter($RPAREN);
        return result;
      } else if (this.next.isKeywordNull()) {
        this.advance();
        return new LiteralPrimitive(this.span(start), this.sourceSpan(start), null);
      } else if (this.next.isKeywordUndefined()) {
        this.advance();
        return new LiteralPrimitive(this.span(start), this.sourceSpan(start), void 0);
      } else if (this.next.isKeywordTrue()) {
        this.advance();
        return new LiteralPrimitive(this.span(start), this.sourceSpan(start), true);
      } else if (this.next.isKeywordFalse()) {
        this.advance();
        return new LiteralPrimitive(this.span(start), this.sourceSpan(start), false);
      } else if (this.next.isKeywordThis()) {
        this.advance();
        return new ImplicitReceiver(this.span(start), this.sourceSpan(start));
      } else if (this.consumeOptionalCharacter($LBRACKET)) {
        this.rbracketsExpected++;
        var elements = this.parseExpressionList($RBRACKET);
        this.rbracketsExpected--;
        this.expectCharacter($RBRACKET);
        return new LiteralArray(this.span(start), this.sourceSpan(start), elements);
      } else if (this.next.isCharacter($LBRACE)) {
        return this.parseLiteralMap();
      } else if (this.next.isIdentifier()) {
        return this.parseAccessMemberOrMethodCall(new ImplicitReceiver(this.span(start), this.sourceSpan(start)), false);
      } else if (this.next.isNumber()) {
        var value = this.next.toNumber();
        this.advance();
        return new LiteralPrimitive(this.span(start), this.sourceSpan(start), value);
      } else if (this.next.isString()) {
        var literalValue = this.next.toString();
        this.advance();
        return new LiteralPrimitive(this.span(start), this.sourceSpan(start), literalValue);
      } else if (this.index >= this.tokens.length) {
        this.error("Unexpected end of expression: ".concat(this.input));
        return new EmptyExpr(this.span(start), this.sourceSpan(start));
      } else {
        this.error("Unexpected token ".concat(this.next));
        return new EmptyExpr(this.span(start), this.sourceSpan(start));
      }
    }
  }, {
    key: "parseExpressionList",
    value: function parseExpressionList(terminator) {
      var result = [];

      if (!this.next.isCharacter(terminator)) {
        do {
          result.push(this.parsePipe());
        } while (this.consumeOptionalCharacter($COMMA));
      }

      return result;
    }
  }, {
    key: "parseLiteralMap",
    value: function parseLiteralMap() {
      var keys = [];
      var values = [];
      var start = this.inputIndex;
      this.expectCharacter($LBRACE);

      if (!this.consumeOptionalCharacter($RBRACE)) {
        this.rbracesExpected++;

        do {
          var quoted = this.next.isString();
          var key = this.expectIdentifierOrKeywordOrString();
          keys.push({
            key: key,
            quoted: quoted
          });
          this.expectCharacter($COLON);
          values.push(this.parsePipe());
        } while (this.consumeOptionalCharacter($COMMA));

        this.rbracesExpected--;
        this.expectCharacter($RBRACE);
      }

      return new LiteralMap(this.span(start), this.sourceSpan(start), keys, values);
    }
  }, {
    key: "parseAccessMemberOrMethodCall",
    value: function parseAccessMemberOrMethodCall(receiver) {
      var isSafe = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      var start = receiver.span.start;
      var nameStart = this.inputIndex;
      var id = this.expectIdentifierOrKeyword();
      var nameSpan = this.sourceSpan(nameStart);

      if (this.consumeOptionalCharacter($LPAREN)) {
        this.rparensExpected++;
        var args = this.parseCallArguments();
        this.expectCharacter($RPAREN);
        this.rparensExpected--;
        var span = this.span(start);
        var sourceSpan = this.sourceSpan(start);
        return isSafe ? new SafeMethodCall(span, sourceSpan, nameSpan, receiver, id, args) : new MethodCall(span, sourceSpan, nameSpan, receiver, id, args);
      } else {
        if (isSafe) {
          if (this.consumeOptionalOperator('=')) {
            this.error('The \'?.\' operator cannot be used in the assignment');
            return new EmptyExpr(this.span(start), this.sourceSpan(start));
          } else {
            return new SafePropertyRead(this.span(start), this.sourceSpan(start), nameSpan, receiver, id);
          }
        } else {
          if (this.consumeOptionalOperator('=')) {
            if (!this.parseAction) {
              this.error('Bindings cannot contain assignments');
              return new EmptyExpr(this.span(start), this.sourceSpan(start));
            }

            var value = this.parseConditional();
            return new PropertyWrite(this.span(start), this.sourceSpan(start), nameSpan, receiver, id, value);
          } else {
            return new PropertyRead(this.span(start), this.sourceSpan(start), nameSpan, receiver, id);
          }
        }
      }
    }
  }, {
    key: "parseCallArguments",
    value: function parseCallArguments() {
      if (this.next.isCharacter($RPAREN)) return [];
      var positionals = [];

      do {
        positionals.push(this.parsePipe());
      } while (this.consumeOptionalCharacter($COMMA));

      return positionals;
    }
    /**
     * Parses an identifier, a keyword, a string with an optional `-` in between,
     * and returns the string along with its absolute source span.
     */

  }, {
    key: "expectTemplateBindingKey",
    value: function expectTemplateBindingKey() {
      var result = '';
      var operatorFound = false;
      var start = this.currentAbsoluteOffset;

      do {
        result += this.expectIdentifierOrKeywordOrString();
        operatorFound = this.consumeOptionalOperator('-');

        if (operatorFound) {
          result += '-';
        }
      } while (operatorFound);

      return {
        source: result,
        span: new AbsoluteSourceSpan(start, start + result.length)
      };
    }
    /**
     * Parse microsyntax template expression and return a list of bindings or
     * parsing errors in case the given expression is invalid.
     *
     * For example,
     * ```
     *   <div *ngFor="let item of items; index as i; trackBy: func">
     * ```
     * contains five bindings:
     * 1. ngFor -> null
     * 2. item -> NgForOfContext.$implicit
     * 3. ngForOf -> items
     * 4. i -> NgForOfContext.index
     * 5. ngForTrackBy -> func
     *
     * For a full description of the microsyntax grammar, see
     * https://gist.github.com/mhevery/d3530294cff2e4a1b3fe15ff75d08855
     *
     * @param templateKey name of the microsyntax directive, like ngIf, ngFor,
     * without the *, along with its absolute span.
     */

  }, {
    key: "parseTemplateBindings",
    value: function parseTemplateBindings(templateKey) {
      var bindings = []; // The first binding is for the template key itself
      // In *ngFor="let item of items", key = "ngFor", value = null
      // In *ngIf="cond | pipe", key = "ngIf", value = "cond | pipe"

      bindings.push.apply(bindings, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this.parseDirectiveKeywordBindings(templateKey)));

      while (this.index < this.tokens.length) {
        // If it starts with 'let', then this must be variable declaration
        var letBinding = this.parseLetBinding();

        if (letBinding) {
          bindings.push(letBinding);
        } else {
          // Two possible cases here, either `value "as" key` or
          // "directive-keyword expression". We don't know which case, but both
          // "value" and "directive-keyword" are template binding key, so consume
          // the key first.
          var key = this.expectTemplateBindingKey(); // Peek at the next token, if it is "as" then this must be variable
          // declaration.

          var binding = this.parseAsBinding(key);

          if (binding) {
            bindings.push(binding);
          } else {
            // Otherwise the key must be a directive keyword, like "of". Transform
            // the key to actual key. Eg. of -> ngForOf, trackBy -> ngForTrackBy
            key.source = templateKey.source + key.source[0].toUpperCase() + key.source.substring(1);
            bindings.push.apply(bindings, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this.parseDirectiveKeywordBindings(key)));
          }
        }

        this.consumeStatementTerminator();
      }

      return new TemplateBindingParseResult(bindings, []
      /* warnings */
      , this.errors);
    }
    /**
     * Parse a directive keyword, followed by a mandatory expression.
     * For example, "of items", "trackBy: func".
     * The bindings are: ngForOf -> items, ngForTrackBy -> func
     * There could be an optional "as" binding that follows the expression.
     * For example,
     * ```
     *   *ngFor="let item of items | slice:0:1 as collection".
     *                    ^^ ^^^^^^^^^^^^^^^^^ ^^^^^^^^^^^^^
     *               keyword    bound target   optional 'as' binding
     * ```
     *
     * @param key binding key, for example, ngFor, ngIf, ngForOf, along with its
     * absolute span.
     */

  }, {
    key: "parseDirectiveKeywordBindings",
    value: function parseDirectiveKeywordBindings(key) {
      var bindings = [];
      this.consumeOptionalCharacter($COLON); // trackBy: trackByFunction

      var value = this.getDirectiveBoundTarget();
      var spanEnd = this.currentAbsoluteOffset; // The binding could optionally be followed by "as". For example,
      // *ngIf="cond | pipe as x". In this case, the key in the "as" binding
      // is "x" and the value is the template key itself ("ngIf"). Note that the
      // 'key' in the current context now becomes the "value" in the next binding.

      var asBinding = this.parseAsBinding(key);

      if (!asBinding) {
        this.consumeStatementTerminator();
        spanEnd = this.currentAbsoluteOffset;
      }

      var sourceSpan = new AbsoluteSourceSpan(key.span.start, spanEnd);
      bindings.push(new ExpressionBinding(sourceSpan, key, value));

      if (asBinding) {
        bindings.push(asBinding);
      }

      return bindings;
    }
    /**
     * Return the expression AST for the bound target of a directive keyword
     * binding. For example,
     * ```
     *   *ngIf="condition | pipe"
     *          ^^^^^^^^^^^^^^^^ bound target for "ngIf"
     *   *ngFor="let item of items"
     *                       ^^^^^ bound target for "ngForOf"
     * ```
     */

  }, {
    key: "getDirectiveBoundTarget",
    value: function getDirectiveBoundTarget() {
      if (this.next === EOF || this.peekKeywordAs() || this.peekKeywordLet()) {
        return null;
      }

      var ast = this.parsePipe(); // example: "condition | async"

      var _ast$span = ast.span,
          start = _ast$span.start,
          end = _ast$span.end;
      var value = this.input.substring(start, end);
      return new ASTWithSource(ast, value, this.location, this.absoluteOffset + start, this.errors);
    }
    /**
     * Return the binding for a variable declared using `as`. Note that the order
     * of the key-value pair in this declaration is reversed. For example,
     * ```
     *   *ngFor="let item of items; index as i"
     *                              ^^^^^    ^
     *                              value    key
     * ```
     *
     * @param value name of the value in the declaration, "ngIf" in the example
     * above, along with its absolute span.
     */

  }, {
    key: "parseAsBinding",
    value: function parseAsBinding(value) {
      if (!this.peekKeywordAs()) {
        return null;
      }

      this.advance(); // consume the 'as' keyword

      var key = this.expectTemplateBindingKey();
      this.consumeStatementTerminator();
      var sourceSpan = new AbsoluteSourceSpan(value.span.start, this.currentAbsoluteOffset);
      return new VariableBinding(sourceSpan, key, value);
    }
    /**
     * Return the binding for a variable declared using `let`. For example,
     * ```
     *   *ngFor="let item of items; let i=index;"
     *           ^^^^^^^^           ^^^^^^^^^^^
     * ```
     * In the first binding, `item` is bound to `NgForOfContext.$implicit`.
     * In the second binding, `i` is bound to `NgForOfContext.index`.
     */

  }, {
    key: "parseLetBinding",
    value: function parseLetBinding() {
      if (!this.peekKeywordLet()) {
        return null;
      }

      var spanStart = this.currentAbsoluteOffset;
      this.advance(); // consume the 'let' keyword

      var key = this.expectTemplateBindingKey();
      var value = null;

      if (this.consumeOptionalOperator('=')) {
        value = this.expectTemplateBindingKey();
      }

      this.consumeStatementTerminator();
      var sourceSpan = new AbsoluteSourceSpan(spanStart, this.currentAbsoluteOffset);
      return new VariableBinding(sourceSpan, key, value);
    }
    /**
     * Consume the optional statement terminator: semicolon or comma.
     */

  }, {
    key: "consumeStatementTerminator",
    value: function consumeStatementTerminator() {
      this.consumeOptionalCharacter($SEMICOLON) || this.consumeOptionalCharacter($COMMA);
    }
  }, {
    key: "error",
    value: function error(message) {
      var index = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      this.errors.push(new ParserError(message, this.input, this.locationText(index), this.location));
      this.skip();
    }
  }, {
    key: "locationText",
    value: function locationText() {
      var index = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      if (index == null) index = this.index;
      return index < this.tokens.length ? "at column ".concat(this.tokens[index].index + 1, " in") : "at the end of the expression";
    } // Error recovery should skip tokens until it encounters a recovery point. skip() treats
    // the end of input and a ';' as unconditionally a recovery point. It also treats ')',
    // '}' and ']' as conditional recovery points if one of calling productions is expecting
    // one of these symbols. This allows skip() to recover from errors such as '(a.) + 1' allowing
    // more of the AST to be retained (it doesn't skip any tokens as the ')' is retained because
    // of the '(' begins an '(' <expr> ')' production). The recovery points of grouping symbols
    // must be conditional as they must be skipped if none of the calling productions are not
    // expecting the closing token else we will never make progress in the case of an
    // extraneous group closing symbol (such as a stray ')'). This is not the case for ';' because
    // parseChain() is always the root production and it expects a ';'.
    // If a production expects one of these token it increments the corresponding nesting count,
    // and then decrements it just prior to checking if the token is in the input.

  }, {
    key: "skip",
    value: function skip() {
      var n = this.next;

      while (this.index < this.tokens.length && !n.isCharacter($SEMICOLON) && (this.rparensExpected <= 0 || !n.isCharacter($RPAREN)) && (this.rbracesExpected <= 0 || !n.isCharacter($RBRACE)) && (this.rbracketsExpected <= 0 || !n.isCharacter($RBRACKET))) {
        if (this.next.isError()) {
          this.errors.push(new ParserError(this.next.toString(), this.input, this.locationText(), this.location));
        }

        this.advance();
        n = this.next;
      }
    }
  }, {
    key: "next",
    get: function get() {
      return this.peek(0);
    }
    /** Whether all the parser input has been processed. */

  }, {
    key: "atEOF",
    get: function get() {
      return this.index >= this.tokens.length;
    }
    /**
     * Index of the next token to be processed, or the end of the last token if all have been
     * processed.
     */

  }, {
    key: "inputIndex",
    get: function get() {
      return this.atEOF ? this.currentEndIndex : this.next.index + this.offset;
    }
    /**
     * End index of the last processed token, or the start of the first token if none have been
     * processed.
     */

  }, {
    key: "currentEndIndex",
    get: function get() {
      if (this.index > 0) {
        var curToken = this.peek(-1);
        return curToken.end + this.offset;
      } // No tokens have been processed yet; return the next token's start or the length of the input
      // if there is no token.


      if (this.tokens.length === 0) {
        return this.inputLength + this.offset;
      }

      return this.next.index + this.offset;
    }
    /**
     * Returns the absolute offset of the start of the current token.
     */

  }, {
    key: "currentAbsoluteOffset",
    get: function get() {
      return this.absoluteOffset + this.inputIndex;
    }
  }]);

  return _ParseAST;
}();

var SimpleExpressionChecker = /*#__PURE__*/function () {
  function SimpleExpressionChecker() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SimpleExpressionChecker);

    this.errors = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(SimpleExpressionChecker, [{
    key: "visitImplicitReceiver",
    value: function visitImplicitReceiver(ast, context) {}
  }, {
    key: "visitInterpolation",
    value: function visitInterpolation(ast, context) {}
  }, {
    key: "visitLiteralPrimitive",
    value: function visitLiteralPrimitive(ast, context) {}
  }, {
    key: "visitPropertyRead",
    value: function visitPropertyRead(ast, context) {}
  }, {
    key: "visitPropertyWrite",
    value: function visitPropertyWrite(ast, context) {}
  }, {
    key: "visitSafePropertyRead",
    value: function visitSafePropertyRead(ast, context) {}
  }, {
    key: "visitMethodCall",
    value: function visitMethodCall(ast, context) {}
  }, {
    key: "visitSafeMethodCall",
    value: function visitSafeMethodCall(ast, context) {}
  }, {
    key: "visitFunctionCall",
    value: function visitFunctionCall(ast, context) {}
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(ast, context) {
      this.visitAll(ast.expressions, context);
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(ast, context) {
      this.visitAll(ast.values, context);
    }
  }, {
    key: "visitUnary",
    value: function visitUnary(ast, context) {}
  }, {
    key: "visitBinary",
    value: function visitBinary(ast, context) {}
  }, {
    key: "visitPrefixNot",
    value: function visitPrefixNot(ast, context) {}
  }, {
    key: "visitNonNullAssert",
    value: function visitNonNullAssert(ast, context) {}
  }, {
    key: "visitConditional",
    value: function visitConditional(ast, context) {}
  }, {
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      this.errors.push('pipes');
    }
  }, {
    key: "visitKeyedRead",
    value: function visitKeyedRead(ast, context) {}
  }, {
    key: "visitKeyedWrite",
    value: function visitKeyedWrite(ast, context) {}
  }, {
    key: "visitAll",
    value: function visitAll(asts, context) {
      var _this155 = this;

      return asts.map(function (node) {
        return node.visit(_this155, context);
      });
    }
  }, {
    key: "visitChain",
    value: function visitChain(ast, context) {}
  }, {
    key: "visitQuote",
    value: function visitQuote(ast, context) {}
  }]);

  return SimpleExpressionChecker;
}();
/**
 * This class implements SimpleExpressionChecker used in View Engine and performs more strict checks
 * to make sure host bindings do not contain pipes. In View Engine, having pipes in host bindings is
 * not supported as well, but in some cases (like `!(value | async)`) the error is not triggered at
 * compile time. In order to preserve View Engine behavior, more strict checks are introduced for
 * Ivy mode only.
 */


var IvySimpleExpressionChecker = /*#__PURE__*/function (_RecursiveAstVisitor$2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(IvySimpleExpressionChecker, _RecursiveAstVisitor$2);

  var _super94 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(IvySimpleExpressionChecker);

  function IvySimpleExpressionChecker() {
    var _this156;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, IvySimpleExpressionChecker);

    _this156 = _super94.apply(this, arguments);
    _this156.errors = [];
    return _this156;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(IvySimpleExpressionChecker, [{
    key: "visitPipe",
    value: function visitPipe() {
      this.errors.push('pipes');
    }
  }]);

  return IvySimpleExpressionChecker;
}(RecursiveAstVisitor$1);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// =================================================================================================
// =================================================================================================
// =========== S T O P   -  S T O P   -  S T O P   -  S T O P   -  S T O P   -  S T O P  ===========
// =================================================================================================
// =================================================================================================
//
//        DO NOT EDIT THIS LIST OF SECURITY SENSITIVE PROPERTIES WITHOUT A SECURITY REVIEW!
//                               Reach out to mprobst for details.
//
// =================================================================================================

/** Map from tagName|propertyName SecurityContext. Properties applying to all tags use '*'. */


var _SECURITY_SCHEMA;

function SECURITY_SCHEMA() {
  if (!_SECURITY_SCHEMA) {
    _SECURITY_SCHEMA = {}; // Case is insignificant below, all element and attribute names are lower-cased for lookup.

    registerContext(SecurityContext.HTML, ['iframe|srcdoc', '*|innerHTML', '*|outerHTML']);
    registerContext(SecurityContext.STYLE, ['*|style']); // NB: no SCRIPT contexts here, they are never allowed due to the parser stripping them.

    registerContext(SecurityContext.URL, ['*|formAction', 'area|href', 'area|ping', 'audio|src', 'a|href', 'a|ping', 'blockquote|cite', 'body|background', 'del|cite', 'form|action', 'img|src', 'img|srcset', 'input|src', 'ins|cite', 'q|cite', 'source|src', 'source|srcset', 'track|src', 'video|poster', 'video|src']);
    registerContext(SecurityContext.RESOURCE_URL, ['applet|code', 'applet|codebase', 'base|href', 'embed|src', 'frame|src', 'head|profile', 'html|manifest', 'iframe|src', 'link|href', 'media|src', 'object|codebase', 'object|data', 'script|src']);
  }

  return _SECURITY_SCHEMA;
}

function registerContext(ctx, specs) {
  var _iterator10 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(specs),
      _step10;

  try {
    for (_iterator10.s(); !(_step10 = _iterator10.n()).done;) {
      var spec = _step10.value;
      _SECURITY_SCHEMA[spec.toLowerCase()] = ctx;
    }
  } catch (err) {
    _iterator10.e(err);
  } finally {
    _iterator10.f();
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ElementSchemaRegistry = function ElementSchemaRegistry() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ElementSchemaRegistry);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var BOOLEAN = 'boolean';
var NUMBER = 'number';
var STRING = 'string';
var OBJECT = 'object';
/**
 * This array represents the DOM schema. It encodes inheritance, properties, and events.
 *
 * ## Overview
 *
 * Each line represents one kind of element. The `element_inheritance` and properties are joined
 * using `element_inheritance|properties` syntax.
 *
 * ## Element Inheritance
 *
 * The `element_inheritance` can be further subdivided as `element1,element2,...^parentElement`.
 * Here the individual elements are separated by `,` (commas). Every element in the list
 * has identical properties.
 *
 * An `element` may inherit additional properties from `parentElement` If no `^parentElement` is
 * specified then `""` (blank) element is assumed.
 *
 * NOTE: The blank element inherits from root `[Element]` element, the super element of all
 * elements.
 *
 * NOTE an element prefix such as `:svg:` has no special meaning to the schema.
 *
 * ## Properties
 *
 * Each element has a set of properties separated by `,` (commas). Each property can be prefixed
 * by a special character designating its type:
 *
 * - (no prefix): property is a string.
 * - `*`: property represents an event.
 * - `!`: property is a boolean.
 * - `#`: property is a number.
 * - `%`: property is an object.
 *
 * ## Query
 *
 * The class creates an internal squas representation which allows to easily answer the query of
 * if a given property exist on a given element.
 *
 * NOTE: We don't yet support querying for types or events.
 * NOTE: This schema is auto extracted from `schema_extractor.ts` located in the test folder,
 *       see dom_element_schema_registry_spec.ts
 */
// =================================================================================================
// =================================================================================================
// =========== S T O P   -  S T O P   -  S T O P   -  S T O P   -  S T O P   -  S T O P  ===========
// =================================================================================================
// =================================================================================================
//
//                       DO NOT EDIT THIS DOM SCHEMA WITHOUT A SECURITY REVIEW!
//
// Newly added properties must be security reviewed and assigned an appropriate SecurityContext in
// dom_security_schema.ts. Reach out to mprobst & rjamet for details.
//
// =================================================================================================

var SCHEMA = ['[Element]|textContent,%classList,className,id,innerHTML,*beforecopy,*beforecut,*beforepaste,*copy,*cut,*paste,*search,*selectstart,*webkitfullscreenchange,*webkitfullscreenerror,*wheel,outerHTML,#scrollLeft,#scrollTop,slot' +
/* added manually to avoid breaking changes */
',*message,*mozfullscreenchange,*mozfullscreenerror,*mozpointerlockchange,*mozpointerlockerror,*webglcontextcreationerror,*webglcontextlost,*webglcontextrestored', '[HTMLElement]^[Element]|accessKey,contentEditable,dir,!draggable,!hidden,innerText,lang,*abort,*auxclick,*blur,*cancel,*canplay,*canplaythrough,*change,*click,*close,*contextmenu,*cuechange,*dblclick,*drag,*dragend,*dragenter,*dragleave,*dragover,*dragstart,*drop,*durationchange,*emptied,*ended,*error,*focus,*gotpointercapture,*input,*invalid,*keydown,*keypress,*keyup,*load,*loadeddata,*loadedmetadata,*loadstart,*lostpointercapture,*mousedown,*mouseenter,*mouseleave,*mousemove,*mouseout,*mouseover,*mouseup,*mousewheel,*pause,*play,*playing,*pointercancel,*pointerdown,*pointerenter,*pointerleave,*pointermove,*pointerout,*pointerover,*pointerup,*progress,*ratechange,*reset,*resize,*scroll,*seeked,*seeking,*select,*show,*stalled,*submit,*suspend,*timeupdate,*toggle,*volumechange,*waiting,outerText,!spellcheck,%style,#tabIndex,title,!translate', 'abbr,address,article,aside,b,bdi,bdo,cite,code,dd,dfn,dt,em,figcaption,figure,footer,header,i,kbd,main,mark,nav,noscript,rb,rp,rt,rtc,ruby,s,samp,section,small,strong,sub,sup,u,var,wbr^[HTMLElement]|accessKey,contentEditable,dir,!draggable,!hidden,innerText,lang,*abort,*auxclick,*blur,*cancel,*canplay,*canplaythrough,*change,*click,*close,*contextmenu,*cuechange,*dblclick,*drag,*dragend,*dragenter,*dragleave,*dragover,*dragstart,*drop,*durationchange,*emptied,*ended,*error,*focus,*gotpointercapture,*input,*invalid,*keydown,*keypress,*keyup,*load,*loadeddata,*loadedmetadata,*loadstart,*lostpointercapture,*mousedown,*mouseenter,*mouseleave,*mousemove,*mouseout,*mouseover,*mouseup,*mousewheel,*pause,*play,*playing,*pointercancel,*pointerdown,*pointerenter,*pointerleave,*pointermove,*pointerout,*pointerover,*pointerup,*progress,*ratechange,*reset,*resize,*scroll,*seeked,*seeking,*select,*show,*stalled,*submit,*suspend,*timeupdate,*toggle,*volumechange,*waiting,outerText,!spellcheck,%style,#tabIndex,title,!translate', 'media^[HTMLElement]|!autoplay,!controls,%controlsList,%crossOrigin,#currentTime,!defaultMuted,#defaultPlaybackRate,!disableRemotePlayback,!loop,!muted,*encrypted,*waitingforkey,#playbackRate,preload,src,%srcObject,#volume', ':svg:^[HTMLElement]|*abort,*auxclick,*blur,*cancel,*canplay,*canplaythrough,*change,*click,*close,*contextmenu,*cuechange,*dblclick,*drag,*dragend,*dragenter,*dragleave,*dragover,*dragstart,*drop,*durationchange,*emptied,*ended,*error,*focus,*gotpointercapture,*input,*invalid,*keydown,*keypress,*keyup,*load,*loadeddata,*loadedmetadata,*loadstart,*lostpointercapture,*mousedown,*mouseenter,*mouseleave,*mousemove,*mouseout,*mouseover,*mouseup,*mousewheel,*pause,*play,*playing,*pointercancel,*pointerdown,*pointerenter,*pointerleave,*pointermove,*pointerout,*pointerover,*pointerup,*progress,*ratechange,*reset,*resize,*scroll,*seeked,*seeking,*select,*show,*stalled,*submit,*suspend,*timeupdate,*toggle,*volumechange,*waiting,%style,#tabIndex', ':svg:graphics^:svg:|', ':svg:animation^:svg:|*begin,*end,*repeat', ':svg:geometry^:svg:|', ':svg:componentTransferFunction^:svg:|', ':svg:gradient^:svg:|', ':svg:textContent^:svg:graphics|', ':svg:textPositioning^:svg:textContent|', 'a^[HTMLElement]|charset,coords,download,hash,host,hostname,href,hreflang,name,password,pathname,ping,port,protocol,referrerPolicy,rel,rev,search,shape,target,text,type,username', 'area^[HTMLElement]|alt,coords,download,hash,host,hostname,href,!noHref,password,pathname,ping,port,protocol,referrerPolicy,rel,search,shape,target,username', 'audio^media|', 'br^[HTMLElement]|clear', 'base^[HTMLElement]|href,target', 'body^[HTMLElement]|aLink,background,bgColor,link,*beforeunload,*blur,*error,*focus,*hashchange,*languagechange,*load,*message,*offline,*online,*pagehide,*pageshow,*popstate,*rejectionhandled,*resize,*scroll,*storage,*unhandledrejection,*unload,text,vLink', 'button^[HTMLElement]|!autofocus,!disabled,formAction,formEnctype,formMethod,!formNoValidate,formTarget,name,type,value', 'canvas^[HTMLElement]|#height,#width', 'content^[HTMLElement]|select', 'dl^[HTMLElement]|!compact', 'datalist^[HTMLElement]|', 'details^[HTMLElement]|!open', 'dialog^[HTMLElement]|!open,returnValue', 'dir^[HTMLElement]|!compact', 'div^[HTMLElement]|align', 'embed^[HTMLElement]|align,height,name,src,type,width', 'fieldset^[HTMLElement]|!disabled,name', 'font^[HTMLElement]|color,face,size', 'form^[HTMLElement]|acceptCharset,action,autocomplete,encoding,enctype,method,name,!noValidate,target', 'frame^[HTMLElement]|frameBorder,longDesc,marginHeight,marginWidth,name,!noResize,scrolling,src', 'frameset^[HTMLElement]|cols,*beforeunload,*blur,*error,*focus,*hashchange,*languagechange,*load,*message,*offline,*online,*pagehide,*pageshow,*popstate,*rejectionhandled,*resize,*scroll,*storage,*unhandledrejection,*unload,rows', 'hr^[HTMLElement]|align,color,!noShade,size,width', 'head^[HTMLElement]|', 'h1,h2,h3,h4,h5,h6^[HTMLElement]|align', 'html^[HTMLElement]|version', 'iframe^[HTMLElement]|align,!allowFullscreen,frameBorder,height,longDesc,marginHeight,marginWidth,name,referrerPolicy,%sandbox,scrolling,src,srcdoc,width', 'img^[HTMLElement]|align,alt,border,%crossOrigin,#height,#hspace,!isMap,longDesc,lowsrc,name,referrerPolicy,sizes,src,srcset,useMap,#vspace,#width', 'input^[HTMLElement]|accept,align,alt,autocapitalize,autocomplete,!autofocus,!checked,!defaultChecked,defaultValue,dirName,!disabled,%files,formAction,formEnctype,formMethod,!formNoValidate,formTarget,#height,!incremental,!indeterminate,max,#maxLength,min,#minLength,!multiple,name,pattern,placeholder,!readOnly,!required,selectionDirection,#selectionEnd,#selectionStart,#size,src,step,type,useMap,value,%valueAsDate,#valueAsNumber,#width', 'li^[HTMLElement]|type,#value', 'label^[HTMLElement]|htmlFor', 'legend^[HTMLElement]|align', 'link^[HTMLElement]|as,charset,%crossOrigin,!disabled,href,hreflang,integrity,media,referrerPolicy,rel,%relList,rev,%sizes,target,type', 'map^[HTMLElement]|name', 'marquee^[HTMLElement]|behavior,bgColor,direction,height,#hspace,#loop,#scrollAmount,#scrollDelay,!trueSpeed,#vspace,width', 'menu^[HTMLElement]|!compact', 'meta^[HTMLElement]|content,httpEquiv,name,scheme', 'meter^[HTMLElement]|#high,#low,#max,#min,#optimum,#value', 'ins,del^[HTMLElement]|cite,dateTime', 'ol^[HTMLElement]|!compact,!reversed,#start,type', 'object^[HTMLElement]|align,archive,border,code,codeBase,codeType,data,!declare,height,#hspace,name,standby,type,useMap,#vspace,width', 'optgroup^[HTMLElement]|!disabled,label', 'option^[HTMLElement]|!defaultSelected,!disabled,label,!selected,text,value', 'output^[HTMLElement]|defaultValue,%htmlFor,name,value', 'p^[HTMLElement]|align', 'param^[HTMLElement]|name,type,value,valueType', 'picture^[HTMLElement]|', 'pre^[HTMLElement]|#width', 'progress^[HTMLElement]|#max,#value', 'q,blockquote,cite^[HTMLElement]|', 'script^[HTMLElement]|!async,charset,%crossOrigin,!defer,event,htmlFor,integrity,src,text,type', 'select^[HTMLElement]|!autofocus,!disabled,#length,!multiple,name,!required,#selectedIndex,#size,value', 'shadow^[HTMLElement]|', 'slot^[HTMLElement]|name', 'source^[HTMLElement]|media,sizes,src,srcset,type', 'span^[HTMLElement]|', 'style^[HTMLElement]|!disabled,media,type', 'caption^[HTMLElement]|align', 'th,td^[HTMLElement]|abbr,align,axis,bgColor,ch,chOff,#colSpan,headers,height,!noWrap,#rowSpan,scope,vAlign,width', 'col,colgroup^[HTMLElement]|align,ch,chOff,#span,vAlign,width', 'table^[HTMLElement]|align,bgColor,border,%caption,cellPadding,cellSpacing,frame,rules,summary,%tFoot,%tHead,width', 'tr^[HTMLElement]|align,bgColor,ch,chOff,vAlign', 'tfoot,thead,tbody^[HTMLElement]|align,ch,chOff,vAlign', 'template^[HTMLElement]|', 'textarea^[HTMLElement]|autocapitalize,!autofocus,#cols,defaultValue,dirName,!disabled,#maxLength,#minLength,name,placeholder,!readOnly,!required,#rows,selectionDirection,#selectionEnd,#selectionStart,value,wrap', 'title^[HTMLElement]|text', 'track^[HTMLElement]|!default,kind,label,src,srclang', 'ul^[HTMLElement]|!compact,type', 'unknown^[HTMLElement]|', 'video^media|#height,poster,#width', ':svg:a^:svg:graphics|', ':svg:animate^:svg:animation|', ':svg:animateMotion^:svg:animation|', ':svg:animateTransform^:svg:animation|', ':svg:circle^:svg:geometry|', ':svg:clipPath^:svg:graphics|', ':svg:defs^:svg:graphics|', ':svg:desc^:svg:|', ':svg:discard^:svg:|', ':svg:ellipse^:svg:geometry|', ':svg:feBlend^:svg:|', ':svg:feColorMatrix^:svg:|', ':svg:feComponentTransfer^:svg:|', ':svg:feComposite^:svg:|', ':svg:feConvolveMatrix^:svg:|', ':svg:feDiffuseLighting^:svg:|', ':svg:feDisplacementMap^:svg:|', ':svg:feDistantLight^:svg:|', ':svg:feDropShadow^:svg:|', ':svg:feFlood^:svg:|', ':svg:feFuncA^:svg:componentTransferFunction|', ':svg:feFuncB^:svg:componentTransferFunction|', ':svg:feFuncG^:svg:componentTransferFunction|', ':svg:feFuncR^:svg:componentTransferFunction|', ':svg:feGaussianBlur^:svg:|', ':svg:feImage^:svg:|', ':svg:feMerge^:svg:|', ':svg:feMergeNode^:svg:|', ':svg:feMorphology^:svg:|', ':svg:feOffset^:svg:|', ':svg:fePointLight^:svg:|', ':svg:feSpecularLighting^:svg:|', ':svg:feSpotLight^:svg:|', ':svg:feTile^:svg:|', ':svg:feTurbulence^:svg:|', ':svg:filter^:svg:|', ':svg:foreignObject^:svg:graphics|', ':svg:g^:svg:graphics|', ':svg:image^:svg:graphics|', ':svg:line^:svg:geometry|', ':svg:linearGradient^:svg:gradient|', ':svg:mpath^:svg:|', ':svg:marker^:svg:|', ':svg:mask^:svg:|', ':svg:metadata^:svg:|', ':svg:path^:svg:geometry|', ':svg:pattern^:svg:|', ':svg:polygon^:svg:geometry|', ':svg:polyline^:svg:geometry|', ':svg:radialGradient^:svg:gradient|', ':svg:rect^:svg:geometry|', ':svg:svg^:svg:graphics|#currentScale,#zoomAndPan', ':svg:script^:svg:|type', ':svg:set^:svg:animation|', ':svg:stop^:svg:|', ':svg:style^:svg:|!disabled,media,title,type', ':svg:switch^:svg:graphics|', ':svg:symbol^:svg:|', ':svg:tspan^:svg:textPositioning|', ':svg:text^:svg:textPositioning|', ':svg:textPath^:svg:textContent|', ':svg:title^:svg:|', ':svg:use^:svg:graphics|', ':svg:view^:svg:|#zoomAndPan', 'data^[HTMLElement]|value', 'keygen^[HTMLElement]|!autofocus,challenge,!disabled,form,keytype,name', 'menuitem^[HTMLElement]|type,label,icon,!disabled,!checked,radiogroup,!default', 'summary^[HTMLElement]|', 'time^[HTMLElement]|dateTime', ':svg:cursor^:svg:|'];
var _ATTR_TO_PROP = {
  'class': 'className',
  'for': 'htmlFor',
  'formaction': 'formAction',
  'innerHtml': 'innerHTML',
  'readonly': 'readOnly',
  'tabindex': 'tabIndex'
};

var DomElementSchemaRegistry = /*#__PURE__*/function (_ElementSchemaRegistr) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(DomElementSchemaRegistry, _ElementSchemaRegistr);

  var _super95 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(DomElementSchemaRegistry);

  function DomElementSchemaRegistry() {
    var _this157;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DomElementSchemaRegistry);

    _this157 = _super95.call(this);
    _this157._schema = {};
    SCHEMA.forEach(function (encodedType) {
      var type = {};

      var _encodedType$split = encodedType.split('|'),
          _encodedType$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_encodedType$split, 2),
          strType = _encodedType$split2[0],
          strProperties = _encodedType$split2[1];

      var properties = strProperties.split(',');

      var _strType$split = strType.split('^'),
          _strType$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_strType$split, 2),
          typeNames = _strType$split2[0],
          superName = _strType$split2[1];

      typeNames.split(',').forEach(function (tag) {
        return _this157._schema[tag.toLowerCase()] = type;
      });

      var superType = superName && _this157._schema[superName.toLowerCase()];

      if (superType) {
        Object.keys(superType).forEach(function (prop) {
          type[prop] = superType[prop];
        });
      }

      properties.forEach(function (property) {
        if (property.length > 0) {
          switch (property[0]) {
            case '*':
              // We don't yet support events.
              // If ever allowing to bind to events, GO THROUGH A SECURITY REVIEW, allowing events
              // will
              // almost certainly introduce bad XSS vulnerabilities.
              // type[property.substring(1)] = EVENT;
              break;

            case '!':
              type[property.substring(1)] = BOOLEAN;
              break;

            case '#':
              type[property.substring(1)] = NUMBER;
              break;

            case '%':
              type[property.substring(1)] = OBJECT;
              break;

            default:
              type[property] = STRING;
          }
        }
      });
    });
    return _this157;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DomElementSchemaRegistry, [{
    key: "hasProperty",
    value: function hasProperty(tagName, propName, schemaMetas) {
      if (schemaMetas.some(function (schema) {
        return schema.name === NO_ERRORS_SCHEMA.name;
      })) {
        return true;
      }

      if (tagName.indexOf('-') > -1) {
        if (isNgContainer(tagName) || isNgContent(tagName)) {
          return false;
        }

        if (schemaMetas.some(function (schema) {
          return schema.name === CUSTOM_ELEMENTS_SCHEMA.name;
        })) {
          // Can't tell now as we don't know which properties a custom element will get
          // once it is instantiated
          return true;
        }
      }

      var elementProperties = this._schema[tagName.toLowerCase()] || this._schema['unknown'];

      return !!elementProperties[propName];
    }
  }, {
    key: "hasElement",
    value: function hasElement(tagName, schemaMetas) {
      if (schemaMetas.some(function (schema) {
        return schema.name === NO_ERRORS_SCHEMA.name;
      })) {
        return true;
      }

      if (tagName.indexOf('-') > -1) {
        if (isNgContainer(tagName) || isNgContent(tagName)) {
          return true;
        }

        if (schemaMetas.some(function (schema) {
          return schema.name === CUSTOM_ELEMENTS_SCHEMA.name;
        })) {
          // Allow any custom elements
          return true;
        }
      }

      return !!this._schema[tagName.toLowerCase()];
    }
    /**
     * securityContext returns the security context for the given property on the given DOM tag.
     *
     * Tag and property name are statically known and cannot change at runtime, i.e. it is not
     * possible to bind a value into a changing attribute or tag name.
     *
     * The filtering is based on a list of allowed tags|attributes. All attributes in the schema
     * above are assumed to have the 'NONE' security context, i.e. that they are safe inert
     * string values. Only specific well known attack vectors are assigned their appropriate context.
     */

  }, {
    key: "securityContext",
    value: function securityContext(tagName, propName, isAttribute) {
      if (isAttribute) {
        // NB: For security purposes, use the mapped property name, not the attribute name.
        propName = this.getMappedPropName(propName);
      } // Make sure comparisons are case insensitive, so that case differences between attribute and
      // property names do not have a security impact.


      tagName = tagName.toLowerCase();
      propName = propName.toLowerCase();
      var ctx = SECURITY_SCHEMA()[tagName + '|' + propName];

      if (ctx) {
        return ctx;
      }

      ctx = SECURITY_SCHEMA()['*|' + propName];
      return ctx ? ctx : SecurityContext.NONE;
    }
  }, {
    key: "getMappedPropName",
    value: function getMappedPropName(propName) {
      return _ATTR_TO_PROP[propName] || propName;
    }
  }, {
    key: "getDefaultComponentElementName",
    value: function getDefaultComponentElementName() {
      return 'ng-component';
    }
  }, {
    key: "validateProperty",
    value: function validateProperty(name) {
      if (name.toLowerCase().startsWith('on')) {
        var msg = "Binding to event property '".concat(name, "' is disallowed for security reasons, ") + "please use (".concat(name.slice(2), ")=...") + "\nIf '".concat(name, "' is a directive input, make sure the directive is imported by the") + " current module.";
        return {
          error: true,
          msg: msg
        };
      } else {
        return {
          error: false
        };
      }
    }
  }, {
    key: "validateAttribute",
    value: function validateAttribute(name) {
      if (name.toLowerCase().startsWith('on')) {
        var msg = "Binding to event attribute '".concat(name, "' is disallowed for security reasons, ") + "please use (".concat(name.slice(2), ")=...");
        return {
          error: true,
          msg: msg
        };
      } else {
        return {
          error: false
        };
      }
    }
  }, {
    key: "allKnownElementNames",
    value: function allKnownElementNames() {
      return Object.keys(this._schema);
    }
  }, {
    key: "normalizeAnimationStyleProperty",
    value: function normalizeAnimationStyleProperty(propName) {
      return dashCaseToCamelCase(propName);
    }
  }, {
    key: "normalizeAnimationStyleValue",
    value: function normalizeAnimationStyleValue(camelCaseProp, userProvidedProp, val) {
      var unit = '';
      var strVal = val.toString().trim();
      var errorMsg = null;

      if (_isPixelDimensionStyle(camelCaseProp) && val !== 0 && val !== '0') {
        if (typeof val === 'number') {
          unit = 'px';
        } else {
          var valAndSuffixMatch = val.match(/^[+-]?[\d\.]+([a-z]*)$/);

          if (valAndSuffixMatch && valAndSuffixMatch[1].length == 0) {
            errorMsg = "Please provide a CSS unit value for ".concat(userProvidedProp, ":").concat(val);
          }
        }
      }

      return {
        error: errorMsg,
        value: strVal + unit
      };
    }
  }]);

  return DomElementSchemaRegistry;
}(ElementSchemaRegistry);

function _isPixelDimensionStyle(prop) {
  switch (prop) {
    case 'width':
    case 'height':
    case 'minWidth':
    case 'minHeight':
    case 'maxWidth':
    case 'maxHeight':
    case 'left':
    case 'top':
    case 'bottom':
    case 'right':
    case 'fontSize':
    case 'outlineWidth':
    case 'outlineOffset':
    case 'paddingTop':
    case 'paddingLeft':
    case 'paddingBottom':
    case 'paddingRight':
    case 'marginTop':
    case 'marginLeft':
    case 'marginBottom':
    case 'marginRight':
    case 'borderRadius':
    case 'borderWidth':
    case 'borderTopWidth':
    case 'borderLeftWidth':
    case 'borderRightWidth':
    case 'borderBottomWidth':
    case 'textIndent':
      return true;

    default:
      return false;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var BIND_NAME_REGEXP$1 = /^(?:(?:(?:(bind-)|(let-)|(ref-|#)|(on-)|(bindon-)|(@))(.*))|\[\(([^\)]+)\)\]|\[([^\]]+)\]|\(([^\)]+)\))$/; // Group 1 = "bind-"

var KW_BIND_IDX$1 = 1; // Group 2 = "let-"

var KW_LET_IDX$1 = 2; // Group 3 = "ref-/#"

var KW_REF_IDX$1 = 3; // Group 4 = "on-"

var KW_ON_IDX$1 = 4; // Group 5 = "bindon-"

var KW_BINDON_IDX$1 = 5; // Group 6 = "@"

var KW_AT_IDX$1 = 6; // Group 7 = the identifier after "bind-", "let-", "ref-/#", "on-", "bindon-" or "@"

var IDENT_KW_IDX$1 = 7; // Group 8 = identifier inside [()]

var IDENT_BANANA_BOX_IDX$1 = 8; // Group 9 = identifier inside []

var IDENT_PROPERTY_IDX$1 = 9; // Group 10 = identifier inside ()

var IDENT_EVENT_IDX$1 = 10;
var TEMPLATE_ATTR_PREFIX$2 = '*';

function htmlAstToRender3Ast(htmlNodes, bindingParser) {
  var transformer = new HtmlAstToIvyAst(bindingParser);
  var ivyNodes = visitAll$1(transformer, htmlNodes); // Errors might originate in either the binding parser or the html to ivy transformer

  var allErrors = bindingParser.errors.concat(transformer.errors);
  return {
    nodes: ivyNodes,
    errors: allErrors,
    styleUrls: transformer.styleUrls,
    styles: transformer.styles,
    ngContentSelectors: transformer.ngContentSelectors
  };
}

var HtmlAstToIvyAst = /*#__PURE__*/function () {
  function HtmlAstToIvyAst(bindingParser) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, HtmlAstToIvyAst);

    this.bindingParser = bindingParser;
    this.errors = [];
    this.styles = [];
    this.styleUrls = [];
    this.ngContentSelectors = [];
    this.inI18nBlock = false;
  } // HTML visitor


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(HtmlAstToIvyAst, [{
    key: "visitElement",
    value: function visitElement(element) {
      var _this158 = this;

      var isI18nRootElement = isI18nRootNode(element.i18n);

      if (isI18nRootElement) {
        if (this.inI18nBlock) {
          this.reportError('Cannot mark an element as translatable inside of a translatable section. Please remove the nested i18n marker.', element.sourceSpan);
        }

        this.inI18nBlock = true;
      }

      var preparsedElement = preparseElement(element);

      if (preparsedElement.type === PreparsedElementType.SCRIPT) {
        return null;
      } else if (preparsedElement.type === PreparsedElementType.STYLE) {
        var contents = textContents(element);

        if (contents !== null) {
          this.styles.push(contents);
        }

        return null;
      } else if (preparsedElement.type === PreparsedElementType.STYLESHEET && isStyleUrlResolvable(preparsedElement.hrefAttr)) {
        this.styleUrls.push(preparsedElement.hrefAttr);
        return null;
      } // Whether the element is a `<ng-template>`


      var isTemplateElement = isNgTemplate(element.name);
      var parsedProperties = [];
      var boundEvents = [];
      var variables = [];
      var references = [];
      var attributes = [];
      var i18nAttrsMeta = {};
      var templateParsedProperties = [];
      var templateVariables = []; // Whether the element has any *-attribute

      var elementHasInlineTemplate = false;

      var _iterator11 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(element.attrs),
          _step11;

      try {
        for (_iterator11.s(); !(_step11 = _iterator11.n()).done;) {
          var attribute = _step11.value;
          var hasBinding = false;
          var normalizedName = normalizeAttributeName(attribute.name); // `*attr` defines template bindings

          var isTemplateBinding = false;

          if (attribute.i18n) {
            i18nAttrsMeta[attribute.name] = attribute.i18n;
          }

          if (normalizedName.startsWith(TEMPLATE_ATTR_PREFIX$2)) {
            // *-attributes
            if (elementHasInlineTemplate) {
              this.reportError("Can't have multiple template bindings on one element. Use only one attribute prefixed with *", attribute.sourceSpan);
            }

            isTemplateBinding = true;
            elementHasInlineTemplate = true;
            var templateValue = attribute.value;
            var templateKey = normalizedName.substring(TEMPLATE_ATTR_PREFIX$2.length);
            var parsedVariables = [];
            var absoluteValueOffset = attribute.valueSpan ? attribute.valueSpan.start.offset : // If there is no value span the attribute does not have a value, like `attr` in
            //`<div attr></div>`. In this case, point to one character beyond the last character of
            // the attribute name.
            attribute.sourceSpan.start.offset + attribute.name.length;
            this.bindingParser.parseInlineTemplateBinding(templateKey, templateValue, attribute.sourceSpan, absoluteValueOffset, [], templateParsedProperties, parsedVariables);
            templateVariables.push.apply(templateVariables, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(parsedVariables.map(function (v) {
              return new Variable(v.name, v.value, v.sourceSpan, v.valueSpan);
            })));
          } else {
            // Check for variables, events, property bindings, interpolation
            hasBinding = this.parseAttribute(isTemplateElement, attribute, [], parsedProperties, boundEvents, variables, references);
          }

          if (!hasBinding && !isTemplateBinding) {
            // don't include the bindings as attributes as well in the AST
            attributes.push(this.visitAttribute(attribute));
          }
        }
      } catch (err) {
        _iterator11.e(err);
      } finally {
        _iterator11.f();
      }

      var children = visitAll$1(preparsedElement.nonBindable ? NON_BINDABLE_VISITOR$1 : this, element.children);
      var parsedElement;

      if (preparsedElement.type === PreparsedElementType.NG_CONTENT) {
        // `<ng-content>`
        if (element.children && !element.children.every(function (node) {
          return isEmptyTextNode(node) || isCommentNode(node);
        })) {
          this.reportError("<ng-content> element cannot have content.", element.sourceSpan);
        }

        var selector = preparsedElement.selectAttr;
        var attrs = element.attrs.map(function (attr) {
          return _this158.visitAttribute(attr);
        });
        parsedElement = new Content(selector, attrs, element.sourceSpan, element.i18n);
        this.ngContentSelectors.push(selector);
      } else if (isTemplateElement) {
        // `<ng-template>`
        var _attrs = this.extractAttributes(element.name, parsedProperties, i18nAttrsMeta);

        parsedElement = new Template(element.name, attributes, _attrs.bound, boundEvents, [
          /* no template attributes */
        ], children, references, variables, element.sourceSpan, element.startSourceSpan, element.endSourceSpan, element.i18n);
      } else {
        var _attrs2 = this.extractAttributes(element.name, parsedProperties, i18nAttrsMeta);

        parsedElement = new Element(element.name, attributes, _attrs2.bound, boundEvents, children, references, element.sourceSpan, element.startSourceSpan, element.endSourceSpan, element.i18n);
      }

      if (elementHasInlineTemplate) {
        // If this node is an inline-template (e.g. has *ngFor) then we need to create a template
        // node that contains this node.
        // Moreover, if the node is an element, then we need to hoist its attributes to the template
        // node for matching against content projection selectors.
        var _attrs3 = this.extractAttributes('ng-template', templateParsedProperties, i18nAttrsMeta);

        var templateAttrs = [];

        _attrs3.literal.forEach(function (attr) {
          return templateAttrs.push(attr);
        });

        _attrs3.bound.forEach(function (attr) {
          return templateAttrs.push(attr);
        });

        var hoistedAttrs = parsedElement instanceof Element ? {
          attributes: parsedElement.attributes,
          inputs: parsedElement.inputs,
          outputs: parsedElement.outputs
        } : {
          attributes: [],
          inputs: [],
          outputs: []
        }; // For <ng-template>s with structural directives on them, avoid passing i18n information to
        // the wrapping template to prevent unnecessary i18n instructions from being generated. The
        // necessary i18n meta information will be extracted from child elements.

        var i18n = isTemplateElement && isI18nRootElement ? undefined : element.i18n; // TODO(pk): test for this case

        parsedElement = new Template(parsedElement.name, hoistedAttrs.attributes, hoistedAttrs.inputs, hoistedAttrs.outputs, templateAttrs, [parsedElement], [
          /* no references */
        ], templateVariables, element.sourceSpan, element.startSourceSpan, element.endSourceSpan, i18n);
      }

      if (isI18nRootElement) {
        this.inI18nBlock = false;
      }

      return parsedElement;
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute) {
      return new TextAttribute(attribute.name, attribute.value, attribute.sourceSpan, attribute.valueSpan, attribute.i18n);
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      return this._visitTextWithInterpolation(text.value, text.sourceSpan, text.i18n);
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion) {
      var _this159 = this;

      if (!expansion.i18n) {
        // do not generate Icu in case it was created
        // outside of i18n block in a template
        return null;
      }

      if (!isI18nRootNode(expansion.i18n)) {
        throw new Error("Invalid type \"".concat(expansion.i18n.constructor, "\" for \"i18n\" property of ").concat(expansion.sourceSpan.toString(), ". Expected a \"Message\""));
      }

      var message = expansion.i18n;
      var vars = {};
      var placeholders = {}; // extract VARs from ICUs - we process them separately while
      // assembling resulting message via goog.getMsg function, since
      // we need to pass them to top-level goog.getMsg call

      Object.keys(message.placeholders).forEach(function (key) {
        var value = message.placeholders[key];

        if (key.startsWith(I18N_ICU_VAR_PREFIX)) {
          var config = _this159.bindingParser.interpolationConfig; // ICU expression is a plain string, not wrapped into start
          // and end tags, so we wrap it before passing to binding parser

          var wrapped = "".concat(config.start).concat(value).concat(config.end); // Currently when the `plural` or `select` keywords in an ICU contain trailing spaces (e.g.
          // `{count, select , ...}`), these spaces are also included into the key names in ICU vars
          // (e.g. "VAR_SELECT "). These trailing spaces are not desirable, since they will later be
          // converted into `_` symbols while normalizing placeholder names, which might lead to
          // mismatches at runtime (i.e. placeholder will not be replaced with the correct value).

          var formattedKey = key.trim();
          vars[formattedKey] = _this159._visitTextWithInterpolation(wrapped, expansion.sourceSpan);
        } else {
          placeholders[key] = _this159._visitTextWithInterpolation(value, expansion.sourceSpan);
        }
      });
      return new Icu(vars, placeholders, expansion.sourceSpan, message);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase) {
      return null;
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment) {
      return null;
    } // convert view engine `ParsedProperty` to a format suitable for IVY

  }, {
    key: "extractAttributes",
    value: function extractAttributes(elementName, properties, i18nPropsMeta) {
      var _this160 = this;

      var bound = [];
      var literal = [];
      properties.forEach(function (prop) {
        var i18n = i18nPropsMeta[prop.name];

        if (prop.isLiteral) {
          literal.push(new TextAttribute(prop.name, prop.expression.source || '', prop.sourceSpan, undefined, i18n));
        } else {
          // Note that validation is skipped and property mapping is disabled
          // due to the fact that we need to make sure a given prop is not an
          // input of a directive and directive matching happens at runtime.
          var bep = _this160.bindingParser.createBoundElementProperty(elementName, prop,
          /* skipValidation */
          true,
          /* mapPropertyName */
          false);

          bound.push(BoundAttribute.fromBoundElementProperty(bep, i18n));
        }
      });
      return {
        bound: bound,
        literal: literal
      };
    }
  }, {
    key: "parseAttribute",
    value: function parseAttribute(isTemplateElement, attribute, matchableAttributes, parsedProperties, boundEvents, variables, references) {
      var name = normalizeAttributeName(attribute.name);
      var value = attribute.value;
      var srcSpan = attribute.sourceSpan;
      var absoluteOffset = attribute.valueSpan ? attribute.valueSpan.start.offset : srcSpan.start.offset;
      var bindParts = name.match(BIND_NAME_REGEXP$1);
      var hasBinding = false;

      if (bindParts) {
        hasBinding = true;

        if (bindParts[KW_BIND_IDX$1] != null) {
          this.bindingParser.parsePropertyBinding(bindParts[IDENT_KW_IDX$1], value, false, srcSpan, absoluteOffset, attribute.valueSpan, matchableAttributes, parsedProperties);
        } else if (bindParts[KW_LET_IDX$1]) {
          if (isTemplateElement) {
            var identifier = bindParts[IDENT_KW_IDX$1];
            this.parseVariable(identifier, value, srcSpan, attribute.valueSpan, variables);
          } else {
            this.reportError("\"let-\" is only supported on ng-template elements.", srcSpan);
          }
        } else if (bindParts[KW_REF_IDX$1]) {
          var _identifier2 = bindParts[IDENT_KW_IDX$1];
          this.parseReference(_identifier2, value, srcSpan, attribute.valueSpan, references);
        } else if (bindParts[KW_ON_IDX$1]) {
          var events = [];
          this.bindingParser.parseEvent(bindParts[IDENT_KW_IDX$1], value, srcSpan, attribute.valueSpan || srcSpan, matchableAttributes, events);
          addEvents(events, boundEvents);
        } else if (bindParts[KW_BINDON_IDX$1]) {
          this.bindingParser.parsePropertyBinding(bindParts[IDENT_KW_IDX$1], value, false, srcSpan, absoluteOffset, attribute.valueSpan, matchableAttributes, parsedProperties);
          this.parseAssignmentEvent(bindParts[IDENT_KW_IDX$1], value, srcSpan, attribute.valueSpan, matchableAttributes, boundEvents);
        } else if (bindParts[KW_AT_IDX$1]) {
          this.bindingParser.parseLiteralAttr(name, value, srcSpan, absoluteOffset, attribute.valueSpan, matchableAttributes, parsedProperties);
        } else if (bindParts[IDENT_BANANA_BOX_IDX$1]) {
          this.bindingParser.parsePropertyBinding(bindParts[IDENT_BANANA_BOX_IDX$1], value, false, srcSpan, absoluteOffset, attribute.valueSpan, matchableAttributes, parsedProperties);
          this.parseAssignmentEvent(bindParts[IDENT_BANANA_BOX_IDX$1], value, srcSpan, attribute.valueSpan, matchableAttributes, boundEvents);
        } else if (bindParts[IDENT_PROPERTY_IDX$1]) {
          this.bindingParser.parsePropertyBinding(bindParts[IDENT_PROPERTY_IDX$1], value, false, srcSpan, absoluteOffset, attribute.valueSpan, matchableAttributes, parsedProperties);
        } else if (bindParts[IDENT_EVENT_IDX$1]) {
          var _events = [];
          this.bindingParser.parseEvent(bindParts[IDENT_EVENT_IDX$1], value, srcSpan, attribute.valueSpan || srcSpan, matchableAttributes, _events);
          addEvents(_events, boundEvents);
        }
      } else {
        hasBinding = this.bindingParser.parsePropertyInterpolation(name, value, srcSpan, attribute.valueSpan, matchableAttributes, parsedProperties);
      }

      return hasBinding;
    }
  }, {
    key: "_visitTextWithInterpolation",
    value: function _visitTextWithInterpolation(value, sourceSpan, i18n) {
      var valueNoNgsp = replaceNgsp(value);
      var expr = this.bindingParser.parseInterpolation(valueNoNgsp, sourceSpan);
      return expr ? new BoundText(expr, sourceSpan, i18n) : new Text(valueNoNgsp, sourceSpan);
    }
  }, {
    key: "parseVariable",
    value: function parseVariable(identifier, value, sourceSpan, valueSpan, variables) {
      if (identifier.indexOf('-') > -1) {
        this.reportError("\"-\" is not allowed in variable names", sourceSpan);
      } else if (identifier.length === 0) {
        this.reportError("Variable does not have a name", sourceSpan);
      }

      variables.push(new Variable(identifier, value, sourceSpan, valueSpan));
    }
  }, {
    key: "parseReference",
    value: function parseReference(identifier, value, sourceSpan, valueSpan, references) {
      if (identifier.indexOf('-') > -1) {
        this.reportError("\"-\" is not allowed in reference names", sourceSpan);
      } else if (identifier.length === 0) {
        this.reportError("Reference does not have a name", sourceSpan);
      }

      references.push(new Reference(identifier, value, sourceSpan, valueSpan));
    }
  }, {
    key: "parseAssignmentEvent",
    value: function parseAssignmentEvent(name, expression, sourceSpan, valueSpan, targetMatchableAttrs, boundEvents) {
      var events = [];
      this.bindingParser.parseEvent("".concat(name, "Change"), "".concat(expression, "=$event"), sourceSpan, valueSpan || sourceSpan, targetMatchableAttrs, events);
      addEvents(events, boundEvents);
    }
  }, {
    key: "reportError",
    value: function reportError(message, sourceSpan) {
      var level = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : ParseErrorLevel.ERROR;
      this.errors.push(new ParseError(sourceSpan, message, level));
    }
  }]);

  return HtmlAstToIvyAst;
}();

var NonBindableVisitor$1 = /*#__PURE__*/function () {
  function NonBindableVisitor$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NonBindableVisitor$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NonBindableVisitor$1, [{
    key: "visitElement",
    value: function visitElement(ast) {
      var preparsedElement = preparseElement(ast);

      if (preparsedElement.type === PreparsedElementType.SCRIPT || preparsedElement.type === PreparsedElementType.STYLE || preparsedElement.type === PreparsedElementType.STYLESHEET) {
        // Skipping <script> for security reasons
        // Skipping <style> and stylesheets as we already processed them
        // in the StyleCompiler
        return null;
      }

      var children = visitAll$1(this, ast.children, null);
      return new Element(ast.name, visitAll$1(this, ast.attrs),
      /* inputs */
      [],
      /* outputs */
      [], children,
      /* references */
      [], ast.sourceSpan, ast.startSourceSpan, ast.endSourceSpan);
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment) {
      return null;
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute) {
      return new TextAttribute(attribute.name, attribute.value, attribute.sourceSpan, undefined, attribute.i18n);
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      return new Text(text.value, text.sourceSpan);
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion) {
      return null;
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase) {
      return null;
    }
  }]);

  return NonBindableVisitor$1;
}();

var NON_BINDABLE_VISITOR$1 = new NonBindableVisitor$1();

function normalizeAttributeName(attrName) {
  return /^data-/i.test(attrName) ? attrName.substring(5) : attrName;
}

function addEvents(events, boundEvents) {
  boundEvents.push.apply(boundEvents, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(events.map(function (e) {
    return BoundEvent.fromParsedEvent(e);
  })));
}

function isEmptyTextNode(node) {
  return node instanceof Text$3 && node.value.trim().length == 0;
}

function isCommentNode(node) {
  return node instanceof Comment;
}

function textContents(node) {
  if (node.children.length !== 1 || !(node.children[0] instanceof Text$3)) {
    return null;
  } else {
    return node.children[0].value;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TagType;

(function (TagType) {
  TagType[TagType["ELEMENT"] = 0] = "ELEMENT";
  TagType[TagType["TEMPLATE"] = 1] = "TEMPLATE";
  TagType[TagType["PROJECTION"] = 2] = "PROJECTION";
})(TagType || (TagType = {}));
/**
 * Generates an object that is used as a shared state between parent and all child contexts.
 */


function setupRegistry() {
  return {
    getUniqueId: getSeqNumberGenerator(),
    icus: new Map()
  };
}
/**
 * I18nContext is a helper class which keeps track of all i18n-related aspects
 * (accumulates placeholders, bindings, etc) between i18nStart and i18nEnd instructions.
 *
 * When we enter a nested template, the top-level context is being passed down
 * to the nested component, which uses this context to generate a child instance
 * of I18nContext class (to handle nested template) and at the end, reconciles it back
 * with the parent context.
 *
 * @param index Instruction index of i18nStart, which initiates this context
 * @param ref Reference to a translation const that represents the content if thus context
 * @param level Nestng level defined for child contexts
 * @param templateIndex Instruction index of a template which this context belongs to
 * @param meta Meta information (id, meaning, description, etc) associated with this context
 */


var I18nContext = /*#__PURE__*/function () {
  function I18nContext(index, ref) {
    var level = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
    var templateIndex = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
    var meta = arguments.length > 4 ? arguments[4] : undefined;
    var registry = arguments.length > 5 ? arguments[5] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, I18nContext);

    this.index = index;
    this.ref = ref;
    this.level = level;
    this.templateIndex = templateIndex;
    this.meta = meta;
    this.registry = registry;
    this.bindings = new Set();
    this.placeholders = new Map();
    this.isEmitted = false;
    this._unresolvedCtxCount = 0;
    this._registry = registry || setupRegistry();
    this.id = this._registry.getUniqueId();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(I18nContext, [{
    key: "appendTag",
    value: function appendTag(type, node, index, closed) {
      if (node.isVoid && closed) {
        return; // ignore "close" for void tags
      }

      var ph = node.isVoid || !closed ? node.startName : node.closeName;
      var content = {
        type: type,
        index: index,
        ctx: this.id,
        isVoid: node.isVoid,
        closed: closed
      };
      updatePlaceholderMap(this.placeholders, ph, content);
    }
  }, {
    key: "getSerializedPlaceholders",
    value: function getSerializedPlaceholders() {
      var result = new Map();
      this.placeholders.forEach(function (values, key) {
        return result.set(key, values.map(serializePlaceholderValue));
      });
      return result;
    } // public API to accumulate i18n-related content

  }, {
    key: "appendBinding",
    value: function appendBinding(binding) {
      this.bindings.add(binding);
    }
  }, {
    key: "appendIcu",
    value: function appendIcu(name, ref) {
      updatePlaceholderMap(this._registry.icus, name, ref);
    }
  }, {
    key: "appendBoundText",
    value: function appendBoundText(node) {
      var _this161 = this;

      var phs = assembleBoundTextPlaceholders(node, this.bindings.size, this.id);
      phs.forEach(function (values, key) {
        return updatePlaceholderMap.apply(void 0, [_this161.placeholders, key].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(values)));
      });
    }
  }, {
    key: "appendTemplate",
    value: function appendTemplate(node, index) {
      // add open and close tags at the same time,
      // since we process nested templates separately
      this.appendTag(TagType.TEMPLATE, node, index, false);
      this.appendTag(TagType.TEMPLATE, node, index, true);
      this._unresolvedCtxCount++;
    }
  }, {
    key: "appendElement",
    value: function appendElement(node, index, closed) {
      this.appendTag(TagType.ELEMENT, node, index, closed);
    }
  }, {
    key: "appendProjection",
    value: function appendProjection(node, index) {
      // add open and close tags at the same time,
      // since we process projected content separately
      this.appendTag(TagType.PROJECTION, node, index, false);
      this.appendTag(TagType.PROJECTION, node, index, true);
    }
    /**
     * Generates an instance of a child context based on the root one,
     * when we enter a nested template within I18n section.
     *
     * @param index Instruction index of corresponding i18nStart, which initiates this context
     * @param templateIndex Instruction index of a template which this context belongs to
     * @param meta Meta information (id, meaning, description, etc) associated with this context
     *
     * @returns I18nContext instance
     */

  }, {
    key: "forkChildContext",
    value: function forkChildContext(index, templateIndex, meta) {
      return new I18nContext(index, this.ref, this.level + 1, templateIndex, meta, this._registry);
    }
    /**
     * Reconciles child context into parent one once the end of the i18n block is reached (i18nEnd).
     *
     * @param context Child I18nContext instance to be reconciled with parent context.
     */

  }, {
    key: "reconcileChildContext",
    value: function reconcileChildContext(context) {
      var _this162 = this;

      // set the right context id for open and close
      // template tags, so we can use it as sub-block ids
      ['start', 'close'].forEach(function (op) {
        var key = context.meta["".concat(op, "Name")];
        var phs = _this162.placeholders.get(key) || [];
        var tag = phs.find(findTemplateFn(_this162.id, context.templateIndex));

        if (tag) {
          tag.ctx = context.id;
        }
      }); // reconcile placeholders

      var childPhs = context.placeholders;
      childPhs.forEach(function (values, key) {
        var phs = _this162.placeholders.get(key);

        if (!phs) {
          _this162.placeholders.set(key, values);

          return;
        } // try to find matching template...


        var tmplIdx = phs.findIndex(findTemplateFn(context.id, context.templateIndex));

        if (tmplIdx >= 0) {
          // ... if found - replace it with nested template content
          var isCloseTag = key.startsWith('CLOSE');
          var isTemplateTag = key.endsWith('NG-TEMPLATE');

          if (isTemplateTag) {
            // current template's content is placed before or after
            // parent template tag, depending on the open/close atrribute
            phs.splice.apply(phs, [tmplIdx + (isCloseTag ? 0 : 1), 0].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(values)));
          } else {
            var idx = isCloseTag ? values.length - 1 : 0;
            values[idx].tmpl = phs[tmplIdx];
            phs.splice.apply(phs, [tmplIdx, 1].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(values)));
          }
        } else {
          // ... otherwise just append content to placeholder value
          phs.push.apply(phs, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(values));
        }

        _this162.placeholders.set(key, phs);
      });
      this._unresolvedCtxCount--;
    }
  }, {
    key: "icus",
    get: function get() {
      return this._registry.icus;
    }
  }, {
    key: "isRoot",
    get: function get() {
      return this.level === 0;
    }
  }, {
    key: "isResolved",
    get: function get() {
      return this._unresolvedCtxCount === 0;
    }
  }]);

  return I18nContext;
}(); //
// Helper methods
//


function wrap(symbol, index, contextId, closed) {
  var state = closed ? '/' : '';
  return wrapI18nPlaceholder("".concat(state).concat(symbol).concat(index), contextId);
}

function wrapTag(symbol, _ref13, closed) {
  var index = _ref13.index,
      ctx = _ref13.ctx,
      isVoid = _ref13.isVoid;
  return isVoid ? wrap(symbol, index, ctx) + wrap(symbol, index, ctx, true) : wrap(symbol, index, ctx, closed);
}

function findTemplateFn(ctx, templateIndex) {
  return function (token) {
    return typeof token === 'object' && token.type === TagType.TEMPLATE && token.index === templateIndex && token.ctx === ctx;
  };
}

function serializePlaceholderValue(value) {
  var element = function element(data, closed) {
    return wrapTag('#', data, closed);
  };

  var template = function template(data, closed) {
    return wrapTag('*', data, closed);
  };

  var projection = function projection(data, closed) {
    return wrapTag('!', data, closed);
  };

  switch (value.type) {
    case TagType.ELEMENT:
      // close element tag
      if (value.closed) {
        return element(value, true) + (value.tmpl ? template(value.tmpl, true) : '');
      } // open element tag that also initiates a template


      if (value.tmpl) {
        return template(value.tmpl) + element(value) + (value.isVoid ? template(value.tmpl, true) : '');
      }

      return element(value);

    case TagType.TEMPLATE:
      return template(value, value.closed);

    case TagType.PROJECTION:
      return projection(value, value.closed);

    default:
      return value;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var IcuSerializerVisitor = /*#__PURE__*/function () {
  function IcuSerializerVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, IcuSerializerVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(IcuSerializerVisitor, [{
    key: "visitText",
    value: function visitText(text) {
      return text.value;
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container) {
      var _this163 = this;

      return container.children.map(function (child) {
        return child.visit(_this163);
      }).join('');
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {
      var _this164 = this;

      var strCases = Object.keys(icu.cases).map(function (k) {
        return "".concat(k, " {").concat(icu.cases[k].visit(_this164), "}");
      });
      var result = "{".concat(icu.expressionPlaceholder, ", ").concat(icu.type, ", ").concat(strCases.join(' '), "}");
      return result;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph) {
      var _this165 = this;

      return ph.isVoid ? this.formatPh(ph.startName) : "".concat(this.formatPh(ph.startName)).concat(ph.children.map(function (child) {
        return child.visit(_this165);
      }).join('')).concat(this.formatPh(ph.closeName));
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph) {
      return this.formatPh(ph.name);
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      return this.formatPh(ph.name);
    }
  }, {
    key: "formatPh",
    value: function formatPh(value) {
      return "{".concat(formatI18nPlaceholderName(value,
      /* useCamelCase */
      false), "}");
    }
  }]);

  return IcuSerializerVisitor;
}();

var serializer = new IcuSerializerVisitor();

function serializeIcuNode(icu) {
  return icu.visit(serializer);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TAG_TO_PLACEHOLDER_NAMES = {
  'A': 'LINK',
  'B': 'BOLD_TEXT',
  'BR': 'LINE_BREAK',
  'EM': 'EMPHASISED_TEXT',
  'H1': 'HEADING_LEVEL1',
  'H2': 'HEADING_LEVEL2',
  'H3': 'HEADING_LEVEL3',
  'H4': 'HEADING_LEVEL4',
  'H5': 'HEADING_LEVEL5',
  'H6': 'HEADING_LEVEL6',
  'HR': 'HORIZONTAL_RULE',
  'I': 'ITALIC_TEXT',
  'LI': 'LIST_ITEM',
  'LINK': 'MEDIA_LINK',
  'OL': 'ORDERED_LIST',
  'P': 'PARAGRAPH',
  'Q': 'QUOTATION',
  'S': 'STRIKETHROUGH_TEXT',
  'SMALL': 'SMALL_TEXT',
  'SUB': 'SUBSTRIPT',
  'SUP': 'SUPERSCRIPT',
  'TBODY': 'TABLE_BODY',
  'TD': 'TABLE_CELL',
  'TFOOT': 'TABLE_FOOTER',
  'TH': 'TABLE_HEADER_CELL',
  'THEAD': 'TABLE_HEADER',
  'TR': 'TABLE_ROW',
  'TT': 'MONOSPACED_TEXT',
  'U': 'UNDERLINED_TEXT',
  'UL': 'UNORDERED_LIST'
};
/**
 * Creates unique names for placeholder with different content.
 *
 * Returns the same placeholder name when the content is identical.
 */

var PlaceholderRegistry = /*#__PURE__*/function () {
  function PlaceholderRegistry() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PlaceholderRegistry);

    // Count the occurrence of the base name top generate a unique name
    this._placeHolderNameCounts = {}; // Maps signature to placeholder names

    this._signatureToName = {};
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PlaceholderRegistry, [{
    key: "getStartTagPlaceholderName",
    value: function getStartTagPlaceholderName(tag, attrs, isVoid) {
      var signature = this._hashTag(tag, attrs, isVoid);

      if (this._signatureToName[signature]) {
        return this._signatureToName[signature];
      }

      var upperTag = tag.toUpperCase();
      var baseName = TAG_TO_PLACEHOLDER_NAMES[upperTag] || "TAG_".concat(upperTag);

      var name = this._generateUniqueName(isVoid ? baseName : "START_".concat(baseName));

      this._signatureToName[signature] = name;
      return name;
    }
  }, {
    key: "getCloseTagPlaceholderName",
    value: function getCloseTagPlaceholderName(tag) {
      var signature = this._hashClosingTag(tag);

      if (this._signatureToName[signature]) {
        return this._signatureToName[signature];
      }

      var upperTag = tag.toUpperCase();
      var baseName = TAG_TO_PLACEHOLDER_NAMES[upperTag] || "TAG_".concat(upperTag);

      var name = this._generateUniqueName("CLOSE_".concat(baseName));

      this._signatureToName[signature] = name;
      return name;
    }
  }, {
    key: "getPlaceholderName",
    value: function getPlaceholderName(name, content) {
      var upperName = name.toUpperCase();
      var signature = "PH: ".concat(upperName, "=").concat(content);

      if (this._signatureToName[signature]) {
        return this._signatureToName[signature];
      }

      var uniqueName = this._generateUniqueName(upperName);

      this._signatureToName[signature] = uniqueName;
      return uniqueName;
    }
  }, {
    key: "getUniquePlaceholder",
    value: function getUniquePlaceholder(name) {
      return this._generateUniqueName(name.toUpperCase());
    } // Generate a hash for a tag - does not take attribute order into account

  }, {
    key: "_hashTag",
    value: function _hashTag(tag, attrs, isVoid) {
      var start = "<".concat(tag);
      var strAttrs = Object.keys(attrs).sort().map(function (name) {
        return " ".concat(name, "=").concat(attrs[name]);
      }).join('');
      var end = isVoid ? '/>' : "></".concat(tag, ">");
      return start + strAttrs + end;
    }
  }, {
    key: "_hashClosingTag",
    value: function _hashClosingTag(tag) {
      return this._hashTag("/".concat(tag), {}, false);
    }
  }, {
    key: "_generateUniqueName",
    value: function _generateUniqueName(base) {
      var seen = this._placeHolderNameCounts.hasOwnProperty(base);

      if (!seen) {
        this._placeHolderNameCounts[base] = 1;
        return base;
      }

      var id = this._placeHolderNameCounts[base];
      this._placeHolderNameCounts[base] = id + 1;
      return "".concat(base, "_").concat(id);
    }
  }]);

  return PlaceholderRegistry;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _expParser = new Parser$1(new Lexer());
/**
 * Returns a function converting html nodes to an i18n Message given an interpolationConfig
 */


function createI18nMessageFactory(interpolationConfig) {
  var visitor = new _I18nVisitor(_expParser, interpolationConfig);
  return function (nodes, meaning, description, customId, visitNodeFn) {
    return visitor.toI18nMessage(nodes, meaning, description, customId, visitNodeFn);
  };
}

function noopVisitNodeFn(_html, i18n) {
  return i18n;
}

var _I18nVisitor = /*#__PURE__*/function () {
  function _I18nVisitor(_expressionParser, _interpolationConfig) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _I18nVisitor);

    this._expressionParser = _expressionParser;
    this._interpolationConfig = _interpolationConfig;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_I18nVisitor, [{
    key: "toI18nMessage",
    value: function toI18nMessage(nodes) {
      var meaning = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var description = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
      var customId = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
      var visitNodeFn = arguments.length > 4 ? arguments[4] : undefined;
      var context = {
        isIcu: nodes.length == 1 && nodes[0] instanceof Expansion,
        icuDepth: 0,
        placeholderRegistry: new PlaceholderRegistry(),
        placeholderToContent: {},
        placeholderToMessage: {},
        visitNodeFn: visitNodeFn || noopVisitNodeFn
      };
      var i18nodes = visitAll$1(this, nodes, context);
      return new Message(i18nodes, context.placeholderToContent, context.placeholderToMessage, meaning, description, customId);
    }
  }, {
    key: "visitElement",
    value: function visitElement(el, context) {
      var children = visitAll$1(this, el.children, context);
      var attrs = {};
      el.attrs.forEach(function (attr) {
        // Do not visit the attributes, translatable ones are top-level ASTs
        attrs[attr.name] = attr.value;
      });
      var isVoid = getHtmlTagDefinition(el.name).isVoid;
      var startPhName = context.placeholderRegistry.getStartTagPlaceholderName(el.name, attrs, isVoid);
      context.placeholderToContent[startPhName] = el.sourceSpan.toString();
      var closePhName = '';

      if (!isVoid) {
        closePhName = context.placeholderRegistry.getCloseTagPlaceholderName(el.name);
        context.placeholderToContent[closePhName] = "</".concat(el.name, ">");
      }

      var node = new TagPlaceholder(el.name, attrs, startPhName, closePhName, children, isVoid, el.sourceSpan, el.startSourceSpan, el.endSourceSpan);
      return context.visitNodeFn(el, node);
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {
      var node = this._visitTextWithInterpolation(attribute.value, attribute.sourceSpan, context);

      return context.visitNodeFn(attribute, node);
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      var node = this._visitTextWithInterpolation(text.value, text.sourceSpan, context);

      return context.visitNodeFn(text, node);
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {
      return null;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(icu, context) {
      var _this166 = this;

      context.icuDepth++;
      var i18nIcuCases = {};
      var i18nIcu = new Icu$1(icu.switchValue, icu.type, i18nIcuCases, icu.sourceSpan);
      icu.cases.forEach(function (caze) {
        i18nIcuCases[caze.value] = new Container(caze.expression.map(function (node) {
          return node.visit(_this166, context);
        }), caze.expSourceSpan);
      });
      context.icuDepth--;

      if (context.isIcu || context.icuDepth > 0) {
        // Returns an ICU node when:
        // - the message (vs a part of the message) is an ICU message, or
        // - the ICU message is nested.
        var expPh = context.placeholderRegistry.getUniquePlaceholder("VAR_".concat(icu.type));
        i18nIcu.expressionPlaceholder = expPh;
        context.placeholderToContent[expPh] = icu.switchValue;
        return context.visitNodeFn(icu, i18nIcu);
      } // Else returns a placeholder
      // ICU placeholders should not be replaced with their original content but with the their
      // translations.
      // TODO(vicb): add a html.Node -> i18n.Message cache to avoid having to re-create the msg


      var phName = context.placeholderRegistry.getPlaceholderName('ICU', icu.sourceSpan.toString());
      context.placeholderToMessage[phName] = this.toI18nMessage([icu], '', '', '', undefined);
      var node = new IcuPlaceholder(i18nIcu, phName, icu.sourceSpan);
      return context.visitNodeFn(icu, node);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(_icuCase, _context) {
      throw new Error('Unreachable code');
    }
  }, {
    key: "_visitTextWithInterpolation",
    value: function _visitTextWithInterpolation(text, sourceSpan, context) {
      var splitInterpolation = this._expressionParser.splitInterpolation(text, sourceSpan.start.toString(), this._interpolationConfig);

      if (!splitInterpolation) {
        // No expression, return a single text
        return new Text$1(text, sourceSpan);
      } // Return a group of text + expressions


      var nodes = [];
      var container = new Container(nodes, sourceSpan);
      var _this$_interpolationC = this._interpolationConfig,
          sDelimiter = _this$_interpolationC.start,
          eDelimiter = _this$_interpolationC.end;

      for (var i = 0; i < splitInterpolation.strings.length - 1; i++) {
        var expression = splitInterpolation.expressions[i];
        var baseName = _extractPlaceholderName(expression) || 'INTERPOLATION';
        var phName = context.placeholderRegistry.getPlaceholderName(baseName, expression);

        if (splitInterpolation.strings[i].length) {
          // No need to add empty strings
          var stringSpan = getOffsetSourceSpan(sourceSpan, splitInterpolation.stringSpans[i]);
          nodes.push(new Text$1(splitInterpolation.strings[i], stringSpan));
        }

        var expressionSpan = getOffsetSourceSpan(sourceSpan, splitInterpolation.expressionsSpans[i]);
        nodes.push(new Placeholder(expression, phName, expressionSpan));
        context.placeholderToContent[phName] = sDelimiter + expression + eDelimiter;
      } // The last index contains no expression


      var lastStringIdx = splitInterpolation.strings.length - 1;

      if (splitInterpolation.strings[lastStringIdx].length) {
        var _stringSpan = getOffsetSourceSpan(sourceSpan, splitInterpolation.stringSpans[lastStringIdx]);

        nodes.push(new Text$1(splitInterpolation.strings[lastStringIdx], _stringSpan));
      }

      return container;
    }
  }]);

  return _I18nVisitor;
}();

function getOffsetSourceSpan(sourceSpan, _ref14) {
  var start = _ref14.start,
      end = _ref14.end;
  return new ParseSourceSpan(sourceSpan.start.moveBy(start), sourceSpan.start.moveBy(end));
}

var _CUSTOM_PH_EXP = /\/\/[\s\S]*i18n[\s\S]*\([\s\S]*ph[\s\S]*=[\s\S]*("|')([\s\S]*?)\1[\s\S]*\)/g;

function _extractPlaceholderName(input) {
  return input.split(_CUSTOM_PH_EXP)[2];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var setI18nRefs = function setI18nRefs(htmlNode, i18nNode) {
  if (htmlNode instanceof NodeWithI18n) {
    if (i18nNode instanceof IcuPlaceholder && htmlNode.i18n instanceof Message) {
      // This html node represents an ICU but this is a second processing pass, and the legacy id
      // was computed in the previous pass and stored in the `i18n` property as a message.
      // We are about to wipe out that property so capture the previous message to be reused when
      // generating the message for this ICU later. See `_generateI18nMessage()`.
      i18nNode.previousMessage = htmlNode.i18n;
    }

    htmlNode.i18n = i18nNode;
  }

  return i18nNode;
};
/**
 * This visitor walks over HTML parse tree and converts information stored in
 * i18n-related attributes ("i18n" and "i18n-*") into i18n meta object that is
 * stored with other element's and attribute's information.
 */


var I18nMetaVisitor = /*#__PURE__*/function () {
  function I18nMetaVisitor() {
    var interpolationConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DEFAULT_INTERPOLATION_CONFIG;
    var keepI18nAttrs = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    var enableI18nLegacyMessageIdFormat = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, I18nMetaVisitor);

    this.interpolationConfig = interpolationConfig;
    this.keepI18nAttrs = keepI18nAttrs;
    this.enableI18nLegacyMessageIdFormat = enableI18nLegacyMessageIdFormat; // whether visited nodes contain i18n information

    this.hasI18nMeta = false; // i18n message generation factory

    this._createI18nMessage = createI18nMessageFactory(this.interpolationConfig);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(I18nMetaVisitor, [{
    key: "_generateI18nMessage",
    value: function _generateI18nMessage(nodes) {
      var meta = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var visitNodeFn = arguments.length > 2 ? arguments[2] : undefined;

      var _this$_parseMetadata = this._parseMetadata(meta),
          meaning = _this$_parseMetadata.meaning,
          description = _this$_parseMetadata.description,
          customId = _this$_parseMetadata.customId;

      var message = this._createI18nMessage(nodes, meaning, description, customId, visitNodeFn);

      this._setMessageId(message, meta);

      this._setLegacyIds(message, meta);

      return message;
    }
  }, {
    key: "visitElement",
    value: function visitElement(element) {
      if (hasI18nAttrs(element)) {
        this.hasI18nMeta = true;
        var attrs = [];
        var attrsMeta = {};

        var _iterator12 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(element.attrs),
            _step12;

        try {
          for (_iterator12.s(); !(_step12 = _iterator12.n()).done;) {
            var _attr = _step12.value;

            if (_attr.name === I18N_ATTR) {
              // root 'i18n' node attribute
              var i18n = element.i18n || _attr.value;

              var message = this._generateI18nMessage(element.children, i18n, setI18nRefs); // do not assign empty i18n meta


              if (message.nodes.length) {
                element.i18n = message;
              }
            } else if (_attr.name.startsWith(I18N_ATTR_PREFIX)) {
              // 'i18n-*' attributes
              var key = _attr.name.slice(I18N_ATTR_PREFIX.length);

              attrsMeta[key] = _attr.value;
            } else {
              // non-i18n attributes
              attrs.push(_attr);
            }
          } // set i18n meta for attributes

        } catch (err) {
          _iterator12.e(err);
        } finally {
          _iterator12.f();
        }

        if (Object.keys(attrsMeta).length) {
          var _iterator13 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(attrs),
              _step13;

          try {
            for (_iterator13.s(); !(_step13 = _iterator13.n()).done;) {
              var attr = _step13.value;
              var meta = attrsMeta[attr.name]; // do not create translation for empty attributes

              if (meta !== undefined && attr.value) {
                attr.i18n = this._generateI18nMessage([attr], attr.i18n || meta);
              }
            }
          } catch (err) {
            _iterator13.e(err);
          } finally {
            _iterator13.f();
          }
        }

        if (!this.keepI18nAttrs) {
          // update element's attributes,
          // keeping only non-i18n related ones
          element.attrs = attrs;
        }
      }

      visitAll$1(this, element.children, element.i18n);
      return element;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion, currentMessage) {
      var message;
      var meta = expansion.i18n;
      this.hasI18nMeta = true;

      if (meta instanceof IcuPlaceholder) {
        // set ICU placeholder name (e.g. "ICU_1"),
        // generated while processing root element contents,
        // so we can reference it when we output translation
        var name = meta.name;
        message = this._generateI18nMessage([expansion], meta);
        var icu = icuFromI18nMessage(message);
        icu.name = name;
      } else {
        // ICU is a top level message, try to use metadata from container element if provided via
        // `context` argument. Note: context may not be available for standalone ICUs (without
        // wrapping element), so fallback to ICU metadata in this case.
        message = this._generateI18nMessage([expansion], currentMessage || meta);
      }

      expansion.i18n = message;
      return expansion;
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      return text;
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute) {
      return attribute;
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment) {
      return comment;
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase) {
      return expansionCase;
    }
    /**
     * Parse the general form `meta` passed into extract the explicit metadata needed to create a
     * `Message`.
     *
     * There are three possibilities for the `meta` variable
     * 1) a string from an `i18n` template attribute: parse it to extract the metadata values.
     * 2) a `Message` from a previous processing pass: reuse the metadata values in the message.
     * 4) other: ignore this and just process the message metadata as normal
     *
     * @param meta the bucket that holds information about the message
     * @returns the parsed metadata.
     */

  }, {
    key: "_parseMetadata",
    value: function _parseMetadata(meta) {
      return typeof meta === 'string' ? parseI18nMeta(meta) : meta instanceof Message ? meta : {};
    }
    /**
     * Generate (or restore) message id if not specified already.
     */

  }, {
    key: "_setMessageId",
    value: function _setMessageId(message, meta) {
      if (!message.id) {
        message.id = meta instanceof Message && meta.id || decimalDigest(message);
      }
    }
    /**
     * Update the `message` with a `legacyId` if necessary.
     *
     * @param message the message whose legacy id should be set
     * @param meta information about the message being processed
     */

  }, {
    key: "_setLegacyIds",
    value: function _setLegacyIds(message, meta) {
      if (this.enableI18nLegacyMessageIdFormat) {
        message.legacyIds = [computeDigest(message), computeDecimalDigest(message)];
      } else if (typeof meta !== 'string') {
        // This occurs if we are doing the 2nd pass after whitespace removal (see `parseTemplate()` in
        // `packages/compiler/src/render3/view/template.ts`).
        // In that case we want to reuse the legacy message generated in the 1st pass (see
        // `setI18nRefs()`).
        var previousMessage = meta instanceof Message ? meta : meta instanceof IcuPlaceholder ? meta.previousMessage : undefined;
        message.legacyIds = previousMessage ? previousMessage.legacyIds : [];
      }
    }
  }]);

  return I18nMetaVisitor;
}();
/** I18n separators for metadata **/


var I18N_MEANING_SEPARATOR = '|';
var I18N_ID_SEPARATOR = '@@';
/**
 * Parses i18n metas like:
 *  - "@@id",
 *  - "description[@@id]",
 *  - "meaning|description[@@id]"
 * and returns an object with parsed output.
 *
 * @param meta String that represents i18n meta
 * @returns Object with id, meaning and description fields
 */

function parseI18nMeta() {
  var meta = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var customId;
  var meaning;
  var description;
  meta = meta.trim();

  if (meta) {
    var idIndex = meta.indexOf(I18N_ID_SEPARATOR);
    var descIndex = meta.indexOf(I18N_MEANING_SEPARATOR);
    var meaningAndDesc;

    var _ref15 = idIndex > -1 ? [meta.slice(0, idIndex), meta.slice(idIndex + 2)] : [meta, ''];

    var _ref16 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_ref15, 2);

    meaningAndDesc = _ref16[0];
    customId = _ref16[1];

    var _ref17 = descIndex > -1 ? [meaningAndDesc.slice(0, descIndex), meaningAndDesc.slice(descIndex + 1)] : ['', meaningAndDesc];

    var _ref18 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_ref17, 2);

    meaning = _ref18[0];
    description = _ref18[1];
  }

  return {
    customId: customId,
    meaning: meaning,
    description: description
  };
} // Converts i18n meta information for a message (id, description, meaning)
// to a JsDoc statement formatted as expected by the Closure compiler.


function i18nMetaToJSDoc(meta) {
  var tags = [];

  if (meta.description) {
    tags.push({
      tagName: "desc"
      /* Desc */
      ,
      text: meta.description
    });
  }

  if (meta.meaning) {
    tags.push({
      tagName: "meaning"
      /* Meaning */
      ,
      text: meta.meaning
    });
  }

  return tags.length == 0 ? null : jsDocComment(tags);
}
/** Closure uses `goog.getMsg(message)` to lookup translations */


var GOOG_GET_MSG = 'goog.getMsg';

function createGoogleGetMsgStatements(variable$1, message, closureVar, params) {
  var messageString = serializeI18nMessageForGetMsg(message);
  var args = [literal(messageString)];

  if (Object.keys(params).length) {
    args.push(mapLiteral(params, true));
  } // /**
  //  * @desc description of message
  //  * @meaning meaning of message
  //  */
  // const MSG_... = goog.getMsg(..);
  // I18N_X = MSG_...;


  var googGetMsgStmt = closureVar.set(variable(GOOG_GET_MSG).callFn(args)).toConstDecl();
  var metaComment = i18nMetaToJSDoc(message);

  if (metaComment !== null) {
    googGetMsgStmt.addLeadingComment(metaComment);
  }

  var i18nAssignmentStmt = new ExpressionStatement(variable$1.set(closureVar));
  return [googGetMsgStmt, i18nAssignmentStmt];
}
/**
 * This visitor walks over i18n tree and generates its string representation, including ICUs and
 * placeholders in `{$placeholder}` (for plain messages) or `{PLACEHOLDER}` (inside ICUs) format.
 */


var GetMsgSerializerVisitor = /*#__PURE__*/function () {
  function GetMsgSerializerVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, GetMsgSerializerVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(GetMsgSerializerVisitor, [{
    key: "formatPh",
    value: function formatPh(value) {
      return "{$".concat(formatI18nPlaceholderName(value), "}");
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      return text.value;
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container) {
      var _this167 = this;

      return container.children.map(function (child) {
        return child.visit(_this167);
      }).join('');
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {
      return serializeIcuNode(icu);
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph) {
      var _this168 = this;

      return ph.isVoid ? this.formatPh(ph.startName) : "".concat(this.formatPh(ph.startName)).concat(ph.children.map(function (child) {
        return child.visit(_this168);
      }).join('')).concat(this.formatPh(ph.closeName));
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph) {
      return this.formatPh(ph.name);
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      return this.formatPh(ph.name);
    }
  }]);

  return GetMsgSerializerVisitor;
}();

var serializerVisitor$1 = new GetMsgSerializerVisitor();

function serializeI18nMessageForGetMsg(message) {
  return message.nodes.map(function (node) {
    return node.visit(serializerVisitor$1, null);
  }).join('');
}

function createLocalizeStatements(variable, message, params) {
  var _serializeI18nMessage = serializeI18nMessageForLocalize(message),
      messageParts = _serializeI18nMessage.messageParts,
      placeHolders = _serializeI18nMessage.placeHolders;

  var sourceSpan = getSourceSpan(message);
  var expressions = placeHolders.map(function (ph) {
    return params[ph.text];
  });
  var localizedString$1 = localizedString(message, messageParts, placeHolders, expressions, sourceSpan);
  var variableInitialization = variable.set(localizedString$1);
  return [new ExpressionStatement(variableInitialization)];
}
/**
 * This visitor walks over an i18n tree, capturing literal strings and placeholders.
 *
 * The result can be used for generating the `$localize` tagged template literals.
 */


var LocalizeSerializerVisitor = /*#__PURE__*/function () {
  function LocalizeSerializerVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, LocalizeSerializerVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(LocalizeSerializerVisitor, [{
    key: "visitText",
    value: function visitText(text, context) {
      if (context[context.length - 1] instanceof LiteralPiece) {
        // Two literal pieces in a row means that there was some comment node in-between.
        context[context.length - 1].text += text.value;
      } else {
        context.push(new LiteralPiece(text.value, text.sourceSpan));
      }
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this169 = this;

      container.children.forEach(function (child) {
        return child.visit(_this169, context);
      });
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      context.push(new LiteralPiece(serializeIcuNode(icu), icu.sourceSpan));
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var _this170 = this;

      var _a, _b;

      context.push(this.createPlaceholderPiece(ph.startName, (_a = ph.startSourceSpan) !== null && _a !== void 0 ? _a : ph.sourceSpan));

      if (!ph.isVoid) {
        ph.children.forEach(function (child) {
          return child.visit(_this170, context);
        });
        context.push(this.createPlaceholderPiece(ph.closeName, (_b = ph.endSourceSpan) !== null && _b !== void 0 ? _b : ph.sourceSpan));
      }
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      context.push(this.createPlaceholderPiece(ph.name, ph.sourceSpan));
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      context.push(this.createPlaceholderPiece(ph.name, ph.sourceSpan));
    }
  }, {
    key: "createPlaceholderPiece",
    value: function createPlaceholderPiece(name, sourceSpan) {
      return new PlaceholderPiece(formatI18nPlaceholderName(name,
      /* useCamelCase */
      false), sourceSpan);
    }
  }]);

  return LocalizeSerializerVisitor;
}();

var serializerVisitor$2 = new LocalizeSerializerVisitor();
/**
 * Serialize an i18n message into two arrays: messageParts and placeholders.
 *
 * These arrays will be used to generate `$localize` tagged template literals.
 *
 * @param message The message to be serialized.
 * @returns an object containing the messageParts and placeholders.
 */

function serializeI18nMessageForLocalize(message) {
  var pieces = [];
  message.nodes.forEach(function (node) {
    return node.visit(serializerVisitor$2, pieces);
  });
  return processMessagePieces(pieces);
}

function getSourceSpan(message) {
  var startNode = message.nodes[0];
  var endNode = message.nodes[message.nodes.length - 1];
  return new ParseSourceSpan(startNode.sourceSpan.start, endNode.sourceSpan.end, startNode.sourceSpan.details);
}
/**
 * Convert the list of serialized MessagePieces into two arrays.
 *
 * One contains the literal string pieces and the other the placeholders that will be replaced by
 * expressions when rendering `$localize` tagged template literals.
 *
 * @param pieces The pieces to process.
 * @returns an object containing the messageParts and placeholders.
 */


function processMessagePieces(pieces) {
  var messageParts = [];
  var placeHolders = [];

  if (pieces[0] instanceof PlaceholderPiece) {
    // The first piece was a placeholder so we need to add an initial empty message part.
    messageParts.push(createEmptyMessagePart(pieces[0].sourceSpan.start));
  }

  for (var i = 0; i < pieces.length; i++) {
    var part = pieces[i];

    if (part instanceof LiteralPiece) {
      messageParts.push(part);
    } else {
      placeHolders.push(part);

      if (pieces[i - 1] instanceof PlaceholderPiece) {
        // There were two placeholders in a row, so we need to add an empty message part.
        messageParts.push(createEmptyMessagePart(part.sourceSpan.end));
      }
    }
  }

  if (pieces[pieces.length - 1] instanceof PlaceholderPiece) {
    // The last piece was a placeholder so we need to add a final empty message part.
    messageParts.push(createEmptyMessagePart(pieces[pieces.length - 1].sourceSpan.end));
  }

  return {
    messageParts: messageParts,
    placeHolders: placeHolders
  };
}

function createEmptyMessagePart(location) {
  return new LiteralPiece('', new ParseSourceSpan(location, location));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Selector attribute name of `<ng-content>`


var NG_CONTENT_SELECT_ATTR$1 = 'select'; // Attribute name of `ngProjectAs`.

var NG_PROJECT_AS_ATTR_NAME = 'ngProjectAs'; // List of supported global targets for event listeners

var GLOBAL_TARGET_RESOLVERS = new Map([['window', Identifiers$1.resolveWindow], ['document', Identifiers$1.resolveDocument], ['body', Identifiers$1.resolveBody]]);
var LEADING_TRIVIA_CHARS = [' ', '\n', '\r', '\t']; //  if (rf & flags) { .. }

function renderFlagCheckIfStmt(flags, statements) {
  return ifStmt(variable(RENDER_FLAGS).bitwiseAnd(literal(flags), null, false), statements);
}

function prepareEventListenerParameters(eventAst) {
  var handlerName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var scope = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var type = eventAst.type,
      name = eventAst.name,
      target = eventAst.target,
      phase = eventAst.phase,
      handler = eventAst.handler;

  if (target && !GLOBAL_TARGET_RESOLVERS.has(target)) {
    throw new Error("Unexpected global target '".concat(target, "' defined for '").concat(name, "' event.\n        Supported list of global targets: ").concat(Array.from(GLOBAL_TARGET_RESOLVERS.keys()), "."));
  }

  var eventArgumentName = '$event';
  var implicitReceiverAccesses = new Set();
  var implicitReceiverExpr = scope === null || scope.bindingLevel === 0 ? variable(CONTEXT_NAME) : scope.getOrCreateSharedContextVar(0);
  var bindingExpr = convertActionBinding(scope, implicitReceiverExpr, handler, 'b', function () {
    return error('Unexpected interpolation');
  }, eventAst.handlerSpan, implicitReceiverAccesses);
  var statements = [];

  if (scope) {
    statements.push.apply(statements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(scope.restoreViewStatement()));
    statements.push.apply(statements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(scope.variableDeclarations()));
  }

  statements.push.apply(statements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(bindingExpr.render3Stmts));
  var eventName = type === 1
  /* Animation */
  ? prepareSyntheticListenerName(name, phase) : name;
  var fnName = handlerName && sanitizeIdentifier(handlerName);
  var fnArgs = [];

  if (implicitReceiverAccesses.has(eventArgumentName)) {
    fnArgs.push(new FnParam(eventArgumentName, DYNAMIC_TYPE));
  }

  var handlerFn = fn(fnArgs, statements, INFERRED_TYPE, null, fnName);
  var params = [literal(eventName), handlerFn];

  if (target) {
    params.push(literal(false), // `useCapture` flag, defaults to `false`
    importExpr(GLOBAL_TARGET_RESOLVERS.get(target)));
  }

  return params;
}

function createComponentDefConsts() {
  return {
    prepareStatements: [],
    constExpressions: []
  };
}

var TemplateDefinitionBuilder = /*#__PURE__*/function () {
  function TemplateDefinitionBuilder(constantPool, parentBindingScope) {
    var _this171 = this;

    var level = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
    var contextName = arguments.length > 3 ? arguments[3] : undefined;
    var i18nContext = arguments.length > 4 ? arguments[4] : undefined;
    var templateIndex = arguments.length > 5 ? arguments[5] : undefined;
    var templateName = arguments.length > 6 ? arguments[6] : undefined;
    var directiveMatcher = arguments.length > 7 ? arguments[7] : undefined;
    var directives = arguments.length > 8 ? arguments[8] : undefined;
    var pipeTypeByName = arguments.length > 9 ? arguments[9] : undefined;
    var pipes = arguments.length > 10 ? arguments[10] : undefined;

    var _namespace = arguments.length > 11 ? arguments[11] : undefined;

    var relativeContextFilePath = arguments.length > 12 ? arguments[12] : undefined;
    var i18nUseExternalIds = arguments.length > 13 ? arguments[13] : undefined;

    var _constants = arguments.length > 14 && arguments[14] !== undefined ? arguments[14] : createComponentDefConsts();

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateDefinitionBuilder);

    this.constantPool = constantPool;
    this.level = level;
    this.contextName = contextName;
    this.i18nContext = i18nContext;
    this.templateIndex = templateIndex;
    this.templateName = templateName;
    this.directiveMatcher = directiveMatcher;
    this.directives = directives;
    this.pipeTypeByName = pipeTypeByName;
    this.pipes = pipes;
    this._namespace = _namespace;
    this.i18nUseExternalIds = i18nUseExternalIds;
    this._constants = _constants;
    this._dataIndex = 0;
    this._bindingContext = 0;
    this._prefixCode = [];
    /**
     * List of callbacks to generate creation mode instructions. We store them here as we process
     * the template so bindings in listeners are resolved only once all nodes have been visited.
     * This ensures all local refs and context variables are available for matching.
     */

    this._creationCodeFns = [];
    /**
     * List of callbacks to generate update mode instructions. We store them here as we process
     * the template so bindings are resolved only once all nodes have been visited. This ensures
     * all local refs and context variables are available for matching.
     */

    this._updateCodeFns = [];
    /** Index of the currently-selected node. */

    this._currentIndex = 0;
    /** Temporary variable declarations generated from visiting pipes, literals, etc. */

    this._tempVariables = [];
    /**
     * List of callbacks to build nested templates. Nested templates must not be visited until
     * after the parent template has finished visiting all of its nodes. This ensures that all
     * local ref bindings in nested templates are able to find local ref values if the refs
     * are defined after the template declaration.
     */

    this._nestedTemplateFns = [];
    this._unsupported = unsupported; // i18n context local to this template

    this.i18n = null; // Number of slots to reserve for pureFunctions

    this._pureFunctionSlots = 0; // Number of binding slots

    this._bindingSlots = 0; // Projection slots found in the template. Projection slots can distribute projected
    // nodes based on a selector, or can just use the wildcard selector to match
    // all nodes which aren't matching any selector.

    this._ngContentReservedSlots = []; // Number of non-default selectors found in all parent templates of this template. We need to
    // track it to properly adjust projection slot index in the `projection` instruction.

    this._ngContentSelectorsOffset = 0; // Expression that should be used as implicit receiver when converting template
    // expressions to output AST.

    this._implicitReceiverExpr = null; // These should be handled in the template or element directly.

    this.visitReference = invalid$1;
    this.visitVariable = invalid$1;
    this.visitTextAttribute = invalid$1;
    this.visitBoundAttribute = invalid$1;
    this.visitBoundEvent = invalid$1;
    this._bindingScope = parentBindingScope.nestedScope(level); // Turn the relative context file path into an identifier by replacing non-alphanumeric
    // characters with underscores.

    this.fileBasedI18nSuffix = relativeContextFilePath.replace(/[^A-Za-z0-9]/g, '_') + '_';
    this._valueConverter = new ValueConverter(constantPool, function () {
      return _this171.allocateDataSlot();
    }, function (numSlots) {
      return _this171.allocatePureFunctionSlots(numSlots);
    }, function (name, localName, slot, value) {
      var pipeType = pipeTypeByName.get(name);

      if (pipeType) {
        _this171.pipes.add(pipeType);
      }

      _this171._bindingScope.set(_this171.level, localName, value);

      _this171.creationInstruction(null, Identifiers$1.pipe, [literal(slot), literal(name)]);
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TemplateDefinitionBuilder, [{
    key: "buildTemplateFunction",
    value: function buildTemplateFunction(nodes, variables) {
      var _this172 = this;

      var ngContentSelectorsOffset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
      var i18n = arguments.length > 3 ? arguments[3] : undefined;
      this._ngContentSelectorsOffset = ngContentSelectorsOffset;

      if (this._namespace !== Identifiers$1.namespaceHTML) {
        this.creationInstruction(null, this._namespace);
      } // Create variable bindings


      variables.forEach(function (v) {
        return _this172.registerContextVariables(v);
      }); // Initiate i18n context in case:
      // - this template has parent i18n context
      // - or the template has i18n meta associated with it,
      //   but it's not initiated by the Element (e.g. <ng-template i18n>)

      var initI18nContext = this.i18nContext || isI18nRootNode(i18n) && !isSingleI18nIcu(i18n) && !(isSingleElementTemplate(nodes) && nodes[0].i18n === i18n);
      var selfClosingI18nInstruction = hasTextChildrenOnly(nodes);

      if (initI18nContext) {
        this.i18nStart(null, i18n, selfClosingI18nInstruction);
      } // This is the initial pass through the nodes of this template. In this pass, we
      // queue all creation mode and update mode instructions for generation in the second
      // pass. It's necessary to separate the passes to ensure local refs are defined before
      // resolving bindings. We also count bindings in this pass as we walk bound expressions.


      visitAll(this, nodes); // Add total binding count to pure function count so pure function instructions are
      // generated with the correct slot offset when update instructions are processed.

      this._pureFunctionSlots += this._bindingSlots; // Pipes are walked in the first pass (to enqueue `pipe()` creation instructions and
      // `pipeBind` update instructions), so we have to update the slot offsets manually
      // to account for bindings.

      this._valueConverter.updatePipeSlotOffsets(this._bindingSlots); // Nested templates must be processed before creation instructions so template()
      // instructions can be generated with the correct internal const count.


      this._nestedTemplateFns.forEach(function (buildTemplateFn) {
        return buildTemplateFn();
      }); // Output the `projectionDef` instruction when some `<ng-content>` tags are present.
      // The `projectionDef` instruction is only emitted for the component template and
      // is skipped for nested templates (<ng-template> tags).


      if (this.level === 0 && this._ngContentReservedSlots.length) {
        var parameters = []; // By default the `projectionDef` instructions creates one slot for the wildcard
        // selector if no parameters are passed. Therefore we only want to allocate a new
        // array for the projection slots if the default projection slot is not sufficient.

        if (this._ngContentReservedSlots.length > 1 || this._ngContentReservedSlots[0] !== '*') {
          var r3ReservedSlots = this._ngContentReservedSlots.map(function (s) {
            return s !== '*' ? parseSelectorToR3Selector(s) : s;
          });

          parameters.push(this.constantPool.getConstLiteral(asLiteral(r3ReservedSlots), true));
        } // Since we accumulate ngContent selectors while processing template elements,
        // we *prepend* `projectionDef` to creation instructions block, to put it before
        // any `projection` instructions


        this.creationInstruction(null, Identifiers$1.projectionDef, parameters,
        /* prepend */
        true);
      }

      if (initI18nContext) {
        this.i18nEnd(null, selfClosingI18nInstruction);
      } // Generate all the creation mode instructions (e.g. resolve bindings in listeners)


      var creationStatements = this._creationCodeFns.map(function (fn) {
        return fn();
      }); // Generate all the update mode instructions (e.g. resolve property or text bindings)


      var updateStatements = this._updateCodeFns.map(function (fn) {
        return fn();
      }); //  Variable declaration must occur after binding resolution so we can generate context
      //  instructions that build on each other.
      // e.g. const b = nextContext().$implicit(); const b = nextContext();


      var creationVariables = this._bindingScope.viewSnapshotStatements();

      var updateVariables = this._bindingScope.variableDeclarations().concat(this._tempVariables);

      var creationBlock = creationStatements.length > 0 ? [renderFlagCheckIfStmt(1
      /* Create */
      , creationVariables.concat(creationStatements))] : [];
      var updateBlock = updateStatements.length > 0 ? [renderFlagCheckIfStmt(2
      /* Update */
      , updateVariables.concat(updateStatements))] : [];
      return fn( // i.e. (rf: RenderFlags, ctx: any)
      [new FnParam(RENDER_FLAGS, NUMBER_TYPE), new FnParam(CONTEXT_NAME, null)], [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._prefixCode), creationBlock, updateBlock), INFERRED_TYPE, null, this.templateName);
    } // LocalResolver

  }, {
    key: "getLocal",
    value: function getLocal(name) {
      return this._bindingScope.get(name);
    } // LocalResolver

  }, {
    key: "notifyImplicitReceiverUse",
    value: function notifyImplicitReceiverUse() {
      this._bindingScope.notifyImplicitReceiverUse();
    }
  }, {
    key: "i18nTranslate",
    value: function i18nTranslate(message) {
      var _this$_constants$prep;

      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var ref = arguments.length > 2 ? arguments[2] : undefined;
      var transformFn = arguments.length > 3 ? arguments[3] : undefined;

      var _ref = ref || this.i18nGenerateMainBlockVar(); // Closure Compiler requires const names to start with `MSG_` but disallows any other const to
      // start with `MSG_`. We define a variable starting with `MSG_` just for the `goog.getMsg` call


      var closureVar = this.i18nGenerateClosureVar(message.id);
      var statements = getTranslationDeclStmts(message, _ref, closureVar, params, transformFn);

      (_this$_constants$prep = this._constants.prepareStatements).push.apply(_this$_constants$prep, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(statements));

      return _ref;
    }
  }, {
    key: "registerContextVariables",
    value: function registerContextVariables(variable$1) {
      var scopedName = this._bindingScope.freshReferenceName();

      var retrievalLevel = this.level;
      var lhs = variable(variable$1.name + scopedName);

      this._bindingScope.set(retrievalLevel, variable$1.name, lhs, 1
      /* CONTEXT */
      , function (scope, relativeLevel) {
        var rhs;

        if (scope.bindingLevel === retrievalLevel) {
          // e.g. ctx
          rhs = variable(CONTEXT_NAME);
        } else {
          var sharedCtxVar = scope.getSharedContextName(retrievalLevel); // e.g. ctx_r0   OR  x(2);

          rhs = sharedCtxVar ? sharedCtxVar : generateNextContextExpr(relativeLevel);
        } // e.g. const $item$ = x(2).$implicit;


        return [lhs.set(rhs.prop(variable$1.value || IMPLICIT_REFERENCE)).toConstDecl()];
      });
    }
  }, {
    key: "i18nAppendBindings",
    value: function i18nAppendBindings(expressions) {
      var _this173 = this;

      if (expressions.length > 0) {
        expressions.forEach(function (expression) {
          return _this173.i18n.appendBinding(expression);
        });
      }
    }
  }, {
    key: "i18nBindProps",
    value: function i18nBindProps(props) {
      var _this174 = this;

      var bound = {};
      Object.keys(props).forEach(function (key) {
        var prop = props[key];

        if (prop instanceof Text) {
          bound[key] = literal(prop.value);
        } else {
          var value = prop.value.visit(_this174._valueConverter);

          _this174.allocateBindingSlots(value);

          if (value instanceof Interpolation) {
            var strings = value.strings,
                expressions = value.expressions;
            var _this174$i18n = _this174.i18n,
                id = _this174$i18n.id,
                bindings = _this174$i18n.bindings;
            var label = assembleI18nBoundString(strings, bindings.size, id);

            _this174.i18nAppendBindings(expressions);

            bound[key] = literal(label);
          }
        }
      });
      return bound;
    } // Generates top level vars for i18n blocks (i.e. `i18n_N`).

  }, {
    key: "i18nGenerateMainBlockVar",
    value: function i18nGenerateMainBlockVar() {
      return variable(this.constantPool.uniqueName(TRANSLATION_VAR_PREFIX));
    } // Generates vars with Closure-specific names for i18n blocks (i.e. `MSG_XXX`).

  }, {
    key: "i18nGenerateClosureVar",
    value: function i18nGenerateClosureVar(messageId) {
      var name;
      var suffix = this.fileBasedI18nSuffix.toUpperCase();

      if (this.i18nUseExternalIds) {
        var prefix = getTranslationConstPrefix("EXTERNAL_");
        var uniqueSuffix = this.constantPool.uniqueName(suffix);
        name = "".concat(prefix).concat(sanitizeIdentifier(messageId), "$$").concat(uniqueSuffix);
      } else {
        var _prefix = getTranslationConstPrefix(suffix);

        name = this.constantPool.uniqueName(_prefix);
      }

      return variable(name);
    }
  }, {
    key: "i18nUpdateRef",
    value: function i18nUpdateRef(context) {
      var icus = context.icus,
          meta = context.meta,
          isRoot = context.isRoot,
          isResolved = context.isResolved,
          isEmitted = context.isEmitted;

      if (isRoot && isResolved && !isEmitted && !isSingleI18nIcu(meta)) {
        context.isEmitted = true;
        var placeholders = context.getSerializedPlaceholders();
        var icuMapping = {};
        var params = placeholders.size ? placeholdersToParams(placeholders) : {};

        if (icus.size) {
          icus.forEach(function (refs, key) {
            if (refs.length === 1) {
              // if we have one ICU defined for a given
              // placeholder - just output its reference
              params[key] = refs[0];
            } else {
              // ... otherwise we need to activate post-processing
              // to replace ICU placeholders with proper values
              var placeholder = wrapI18nPlaceholder("".concat(I18N_ICU_MAPPING_PREFIX).concat(key));
              params[key] = literal(placeholder);
              icuMapping[key] = literalArr(refs);
            }
          });
        } // translation requires post processing in 2 cases:
        // - if we have placeholders with multiple values (ex. `START_DIV`: [�#1�, �#2�, ...])
        // - if we have multiple ICUs that refer to the same placeholder name


        var needsPostprocessing = Array.from(placeholders.values()).some(function (value) {
          return value.length > 1;
        }) || Object.keys(icuMapping).length;
        var transformFn;

        if (needsPostprocessing) {
          transformFn = function transformFn(raw) {
            var args = [raw];

            if (Object.keys(icuMapping).length) {
              args.push(mapLiteral(icuMapping, true));
            }

            return instruction(null, Identifiers$1.i18nPostprocess, args);
          };
        }

        this.i18nTranslate(meta, params, context.ref, transformFn);
      }
    }
  }, {
    key: "i18nStart",
    value: function i18nStart() {
      var span = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      var meta = arguments.length > 1 ? arguments[1] : undefined;
      var selfClosing = arguments.length > 2 ? arguments[2] : undefined;
      var index = this.allocateDataSlot();
      this.i18n = this.i18nContext ? this.i18nContext.forkChildContext(index, this.templateIndex, meta) : new I18nContext(index, this.i18nGenerateMainBlockVar(), 0, this.templateIndex, meta); // generate i18nStart instruction

      var _this$i18n = this.i18n,
          id = _this$i18n.id,
          ref = _this$i18n.ref;
      var params = [literal(index), this.addToConsts(ref)];

      if (id > 0) {
        // do not push 3rd argument (sub-block id)
        // into i18nStart call for top level i18n context
        params.push(literal(id));
      }

      this.creationInstruction(span, selfClosing ? Identifiers$1.i18n : Identifiers$1.i18nStart, params);
    }
  }, {
    key: "i18nEnd",
    value: function i18nEnd() {
      var _this175 = this;

      var span = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      var selfClosing = arguments.length > 1 ? arguments[1] : undefined;

      if (!this.i18n) {
        throw new Error('i18nEnd is executed with no i18n context present');
      }

      if (this.i18nContext) {
        this.i18nContext.reconcileChildContext(this.i18n);
        this.i18nUpdateRef(this.i18nContext);
      } else {
        this.i18nUpdateRef(this.i18n);
      } // setup accumulated bindings


      var _this$i18n2 = this.i18n,
          index = _this$i18n2.index,
          bindings = _this$i18n2.bindings;

      if (bindings.size) {
        var chainBindings = [];
        bindings.forEach(function (binding) {
          chainBindings.push({
            sourceSpan: span,
            value: function value() {
              return _this175.convertPropertyBinding(binding);
            }
          });
        }); // for i18n block, advance to the most recent element index (by taking the current number of
        // elements and subtracting one) before invoking `i18nExp` instructions, to make sure the
        // necessary lifecycle hooks of components/directives are properly flushed.

        this.updateInstructionChainWithAdvance(this.getConstCount() - 1, Identifiers$1.i18nExp, chainBindings);
        this.updateInstruction(span, Identifiers$1.i18nApply, [literal(index)]);
      }

      if (!selfClosing) {
        this.creationInstruction(span, Identifiers$1.i18nEnd);
      }

      this.i18n = null; // reset local i18n context
    }
  }, {
    key: "i18nAttributesInstruction",
    value: function i18nAttributesInstruction(nodeIndex, attrs, sourceSpan) {
      var _this176 = this;

      var hasBindings = false;
      var i18nAttrArgs = [];
      var bindings = [];
      attrs.forEach(function (attr) {
        var message = attr.i18n;

        if (attr instanceof TextAttribute) {
          i18nAttrArgs.push(literal(attr.name), _this176.i18nTranslate(message));
        } else {
          var converted = attr.value.visit(_this176._valueConverter);

          _this176.allocateBindingSlots(converted);

          if (converted instanceof Interpolation) {
            var placeholders = assembleBoundTextPlaceholders(message);
            var params = placeholdersToParams(placeholders);
            i18nAttrArgs.push(literal(attr.name), _this176.i18nTranslate(message, params));
            converted.expressions.forEach(function (expression) {
              hasBindings = true;
              bindings.push({
                sourceSpan: sourceSpan,
                value: function value() {
                  return _this176.convertPropertyBinding(expression);
                }
              });
            });
          }
        }
      });

      if (bindings.length > 0) {
        this.updateInstructionChainWithAdvance(nodeIndex, Identifiers$1.i18nExp, bindings);
      }

      if (i18nAttrArgs.length > 0) {
        var index = literal(this.allocateDataSlot());
        var constIndex = this.addToConsts(literalArr(i18nAttrArgs));
        this.creationInstruction(sourceSpan, Identifiers$1.i18nAttributes, [index, constIndex]);

        if (hasBindings) {
          this.updateInstruction(sourceSpan, Identifiers$1.i18nApply, [index]);
        }
      }
    }
  }, {
    key: "getNamespaceInstruction",
    value: function getNamespaceInstruction(namespaceKey) {
      switch (namespaceKey) {
        case 'math':
          return Identifiers$1.namespaceMathML;

        case 'svg':
          return Identifiers$1.namespaceSVG;

        default:
          return Identifiers$1.namespaceHTML;
      }
    }
  }, {
    key: "addNamespaceInstruction",
    value: function addNamespaceInstruction(nsInstruction, element) {
      this._namespace = nsInstruction;
      this.creationInstruction(element.sourceSpan, nsInstruction);
    }
    /**
     * Adds an update instruction for an interpolated property or attribute, such as
     * `prop="{{value}}"` or `attr.title="{{value}}"`
     */

  }, {
    key: "interpolatedUpdateInstruction",
    value: function interpolatedUpdateInstruction(instruction, elementIndex, attrName, input, value, params) {
      var _this177 = this;

      this.updateInstructionWithAdvance(elementIndex, input.sourceSpan, instruction, function () {
        return [literal(attrName)].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this177.getUpdateInstructionArguments(value)), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(params));
      });
    }
  }, {
    key: "visitContent",
    value: function visitContent(ngContent) {
      var slot = this.allocateDataSlot();
      var projectionSlotIdx = this._ngContentSelectorsOffset + this._ngContentReservedSlots.length;
      var parameters = [literal(slot)];

      this._ngContentReservedSlots.push(ngContent.selector);

      var nonContentSelectAttributes = ngContent.attributes.filter(function (attr) {
        return attr.name.toLowerCase() !== NG_CONTENT_SELECT_ATTR$1;
      });
      var attributes = this.getAttributeExpressions(nonContentSelectAttributes, [], []);

      if (attributes.length > 0) {
        parameters.push(literal(projectionSlotIdx), literalArr(attributes));
      } else if (projectionSlotIdx !== 0) {
        parameters.push(literal(projectionSlotIdx));
      }

      this.creationInstruction(ngContent.sourceSpan, Identifiers$1.projection, parameters);

      if (this.i18n) {
        this.i18n.appendProjection(ngContent.i18n, slot);
      }
    }
  }, {
    key: "visitElement",
    value: function visitElement(element) {
      var _this178 = this;

      var elementIndex = this.allocateDataSlot();
      var stylingBuilder = new StylingBuilder(null);
      var isNonBindableMode = false;
      var isI18nRootElement = isI18nRootNode(element.i18n) && !isSingleI18nIcu(element.i18n);
      var i18nAttrs = [];
      var outputAttrs = [];

      var _splitNsName = splitNsName(element.name),
          _splitNsName2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_splitNsName, 2),
          namespaceKey = _splitNsName2[0],
          elementName = _splitNsName2[1];

      var isNgContainer$1 = isNgContainer(element.name); // Handle styling, i18n, ngNonBindable attributes

      var _iterator14 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(element.attributes),
          _step14;

      try {
        for (_iterator14.s(); !(_step14 = _iterator14.n()).done;) {
          var attr = _step14.value;
          var name = attr.name,
              value = attr.value;

          if (name === NON_BINDABLE_ATTR) {
            isNonBindableMode = true;
          } else if (name === 'style') {
            stylingBuilder.registerStyleAttr(value);
          } else if (name === 'class') {
            stylingBuilder.registerClassAttr(value);
          } else {
            (attr.i18n ? i18nAttrs : outputAttrs).push(attr);
          }
        } // Match directives on non i18n attributes

      } catch (err) {
        _iterator14.e(err);
      } finally {
        _iterator14.f();
      }

      this.matchDirectives(element.name, element); // Regular element or ng-container creation mode

      var parameters = [literal(elementIndex)];

      if (!isNgContainer$1) {
        parameters.push(literal(elementName));
      } // Add the attributes


      var allOtherInputs = [];
      element.inputs.forEach(function (input) {
        var stylingInputWasSet = stylingBuilder.registerBoundInput(input);

        if (!stylingInputWasSet) {
          if (input.type === 0
          /* Property */
          && input.i18n) {
            i18nAttrs.push(input);
          } else {
            allOtherInputs.push(input);
          }
        }
      }); // add attributes for directive and projection matching purposes

      var attributes = this.getAttributeExpressions(outputAttrs, allOtherInputs, element.outputs, stylingBuilder, [], i18nAttrs);
      parameters.push(this.addAttrsToConsts(attributes)); // local refs (ex.: <div #foo #bar="baz">)

      var refs = this.prepareRefsArray(element.references);
      parameters.push(this.addToConsts(refs));
      var wasInNamespace = this._namespace;
      var currentNamespace = this.getNamespaceInstruction(namespaceKey); // If the namespace is changing now, include an instruction to change it
      // during element creation.

      if (currentNamespace !== wasInNamespace) {
        this.addNamespaceInstruction(currentNamespace, element);
      }

      if (this.i18n) {
        this.i18n.appendElement(element.i18n, elementIndex);
      } // Note that we do not append text node instructions and ICUs inside i18n section,
      // so we exclude them while calculating whether current element has children


      var hasChildren = !isI18nRootElement && this.i18n ? !hasTextChildrenOnly(element.children) : element.children.length > 0;
      var createSelfClosingInstruction = !stylingBuilder.hasBindingsWithPipes && element.outputs.length === 0 && i18nAttrs.length === 0 && !hasChildren;
      var createSelfClosingI18nInstruction = !createSelfClosingInstruction && hasTextChildrenOnly(element.children);

      if (createSelfClosingInstruction) {
        this.creationInstruction(element.sourceSpan, isNgContainer$1 ? Identifiers$1.elementContainer : Identifiers$1.element, trimTrailingNulls(parameters));
      } else {
        this.creationInstruction(element.sourceSpan, isNgContainer$1 ? Identifiers$1.elementContainerStart : Identifiers$1.elementStart, trimTrailingNulls(parameters));

        if (isNonBindableMode) {
          this.creationInstruction(element.sourceSpan, Identifiers$1.disableBindings);
        }

        if (i18nAttrs.length > 0) {
          this.i18nAttributesInstruction(elementIndex, i18nAttrs, element.sourceSpan);
        } // Generate Listeners (outputs)


        if (element.outputs.length > 0) {
          var listeners = element.outputs.map(function (outputAst) {
            return {
              sourceSpan: outputAst.sourceSpan,
              params: _this178.prepareListenerParameter(element.name, outputAst, elementIndex)
            };
          });
          this.creationInstructionChain(Identifiers$1.listener, listeners);
        } // Note: it's important to keep i18n/i18nStart instructions after i18nAttributes and
        // listeners, to make sure i18nAttributes instruction targets current element at runtime.


        if (isI18nRootElement) {
          this.i18nStart(element.sourceSpan, element.i18n, createSelfClosingI18nInstruction);
        }
      } // the code here will collect all update-level styling instructions and add them to the
      // update block of the template function AOT code. Instructions like `styleProp`,
      // `styleMap`, `classMap`, `classProp`
      // are all generated and assigned in the code below.


      var stylingInstructions = stylingBuilder.buildUpdateLevelInstructions(this._valueConverter);
      var limit = stylingInstructions.length - 1;

      for (var i = 0; i <= limit; i++) {
        var _instruction = stylingInstructions[i];
        this._bindingSlots += this.processStylingUpdateInstruction(elementIndex, _instruction);
      } // the reason why `undefined` is used is because the renderer understands this as a
      // special value to symbolize that there is no RHS to this binding
      // TODO (matsko): revisit this once FW-959 is approached


      var emptyValueBindInstruction = literal(undefined);
      var propertyBindings = [];
      var attributeBindings = []; // Generate element input bindings

      allOtherInputs.forEach(function (input) {
        var inputType = input.type;

        if (inputType === 4
        /* Animation */
        ) {
            var _value2 = input.value.visit(_this178._valueConverter); // animation bindings can be presented in the following formats:
            // 1. [@binding]="fooExp"
            // 2. [@binding]="{value:fooExp, params:{...}}"
            // 3. [@binding]
            // 4. @binding
            // All formats will be valid for when a synthetic binding is created.
            // The reasoning for this is because the renderer should get each
            // synthetic binding value in the order of the array that they are
            // defined in...


            var hasValue = _value2 instanceof LiteralPrimitive ? !!_value2.value : true;

            _this178.allocateBindingSlots(_value2);

            propertyBindings.push({
              name: prepareSyntheticPropertyName(input.name),
              sourceSpan: input.sourceSpan,
              value: function value() {
                return hasValue ? _this178.convertPropertyBinding(_value2) : emptyValueBindInstruction;
              }
            });
          } else {
          // we must skip attributes with associated i18n context, since these attributes are handled
          // separately and corresponding `i18nExp` and `i18nApply` instructions will be generated
          if (input.i18n) return;

          var _value3 = input.value.visit(_this178._valueConverter);

          if (_value3 !== undefined) {
            var params = [];

            var _splitNsName3 = splitNsName(input.name),
                _splitNsName4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_splitNsName3, 2),
                attrNamespace = _splitNsName4[0],
                attrName = _splitNsName4[1];

            var isAttributeBinding = inputType === 1
            /* Attribute */
            ;
            var sanitizationRef = resolveSanitizationFn(input.securityContext, isAttributeBinding);
            if (sanitizationRef) params.push(sanitizationRef);

            if (attrNamespace) {
              var namespaceLiteral = literal(attrNamespace);

              if (sanitizationRef) {
                params.push(namespaceLiteral);
              } else {
                // If there wasn't a sanitization ref, we need to add
                // an extra param so that we can pass in the namespace.
                params.push(literal(null), namespaceLiteral);
              }
            }

            _this178.allocateBindingSlots(_value3);

            if (inputType === 0
            /* Property */
            ) {
                if (_value3 instanceof Interpolation) {
                  // prop="{{value}}" and friends
                  _this178.interpolatedUpdateInstruction(getPropertyInterpolationExpression(_value3), elementIndex, attrName, input, _value3, params);
                } else {
                  // [prop]="value"
                  // Collect all the properties so that we can chain into a single function at the end.
                  propertyBindings.push({
                    name: attrName,
                    sourceSpan: input.sourceSpan,
                    value: function value() {
                      return _this178.convertPropertyBinding(_value3);
                    },
                    params: params
                  });
                }
              } else if (inputType === 1
            /* Attribute */
            ) {
                if (_value3 instanceof Interpolation && getInterpolationArgsLength(_value3) > 1) {
                  // attr.name="text{{value}}" and friends
                  _this178.interpolatedUpdateInstruction(getAttributeInterpolationExpression(_value3), elementIndex, attrName, input, _value3, params);
                } else {
                  var boundValue = _value3 instanceof Interpolation ? _value3.expressions[0] : _value3; // [attr.name]="value" or attr.name="{{value}}"
                  // Collect the attribute bindings so that they can be chained at the end.

                  attributeBindings.push({
                    name: attrName,
                    sourceSpan: input.sourceSpan,
                    value: function value() {
                      return _this178.convertPropertyBinding(boundValue);
                    },
                    params: params
                  });
                }
              } else {
              // class prop
              _this178.updateInstructionWithAdvance(elementIndex, input.sourceSpan, Identifiers$1.classProp, function () {
                return [literal(elementIndex), literal(attrName), _this178.convertPropertyBinding(_value3)].concat(params);
              });
            }
          }
        }
      });

      if (propertyBindings.length > 0) {
        this.updateInstructionChainWithAdvance(elementIndex, Identifiers$1.property, propertyBindings);
      }

      if (attributeBindings.length > 0) {
        this.updateInstructionChainWithAdvance(elementIndex, Identifiers$1.attribute, attributeBindings);
      } // Traverse element child nodes


      visitAll(this, element.children);

      if (!isI18nRootElement && this.i18n) {
        this.i18n.appendElement(element.i18n, elementIndex, true);
      }

      if (!createSelfClosingInstruction) {
        // Finish element construction mode.
        var span = element.endSourceSpan || element.sourceSpan;

        if (isI18nRootElement) {
          this.i18nEnd(span, createSelfClosingI18nInstruction);
        }

        if (isNonBindableMode) {
          this.creationInstruction(span, Identifiers$1.enableBindings);
        }

        this.creationInstruction(span, isNgContainer$1 ? Identifiers$1.elementContainerEnd : Identifiers$1.elementEnd);
      }
    }
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {
      var _this179 = this;

      var NG_TEMPLATE_TAG_NAME = 'ng-template';
      var templateIndex = this.allocateDataSlot();

      if (this.i18n) {
        this.i18n.appendTemplate(template.i18n, templateIndex);
      }

      var tagName = sanitizeIdentifier(template.tagName || '');
      var contextName = "".concat(this.contextName).concat(tagName ? '_' + tagName : '', "_").concat(templateIndex);
      var templateName = "".concat(contextName, "_Template");
      var parameters = [literal(templateIndex), variable(templateName), // We don't care about the tag's namespace here, because we infer
      // it based on the parent nodes inside the template instruction.
      literal(template.tagName ? splitNsName(template.tagName)[1] : template.tagName)]; // find directives matching on a given <ng-template> node

      this.matchDirectives(NG_TEMPLATE_TAG_NAME, template); // prepare attributes parameter (including attributes used for directive matching)

      var _partitionArray = partitionArray(template.attributes, hasI18nMeta),
          _partitionArray2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_partitionArray, 2),
          i18nStaticAttrs = _partitionArray2[0],
          staticAttrs = _partitionArray2[1];

      var attrsExprs = this.getAttributeExpressions(staticAttrs, template.inputs, template.outputs, undefined
      /* styles */
      , template.templateAttrs, i18nStaticAttrs);
      parameters.push(this.addAttrsToConsts(attrsExprs)); // local refs (ex.: <ng-template #foo>)

      if (template.references && template.references.length) {
        var refs = this.prepareRefsArray(template.references);
        parameters.push(this.addToConsts(refs));
        parameters.push(importExpr(Identifiers$1.templateRefExtractor));
      } // Create the template function


      var templateVisitor = new TemplateDefinitionBuilder(this.constantPool, this._bindingScope, this.level + 1, contextName, this.i18n, templateIndex, templateName, this.directiveMatcher, this.directives, this.pipeTypeByName, this.pipes, this._namespace, this.fileBasedI18nSuffix, this.i18nUseExternalIds, this._constants); // Nested templates must not be visited until after their parent templates have completed
      // processing, so they are queued here until after the initial pass. Otherwise, we wouldn't
      // be able to support bindings in nested templates to local refs that occur after the
      // template definition. e.g. <div *ngIf="showing">{{ foo }}</div>  <div #foo></div>

      this._nestedTemplateFns.push(function () {
        var templateFunctionExpr = templateVisitor.buildTemplateFunction(template.children, template.variables, _this179._ngContentReservedSlots.length + _this179._ngContentSelectorsOffset, template.i18n);

        _this179.constantPool.statements.push(templateFunctionExpr.toDeclStmt(templateName));

        if (templateVisitor._ngContentReservedSlots.length) {
          var _this179$_ngContentRe;

          (_this179$_ngContentRe = _this179._ngContentReservedSlots).push.apply(_this179$_ngContentRe, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(templateVisitor._ngContentReservedSlots));
        }
      }); // e.g. template(1, MyComp_Template_1)


      this.creationInstruction(template.sourceSpan, Identifiers$1.templateCreate, function () {
        parameters.splice(2, 0, literal(templateVisitor.getConstCount()), literal(templateVisitor.getVarCount()));
        return trimTrailingNulls(parameters);
      }); // handle property bindings e.g. ɵɵproperty('ngForOf', ctx.items), et al;

      this.templatePropertyBindings(templateIndex, template.templateAttrs); // Only add normal input/output binding instructions on explicit <ng-template> elements.

      if (template.tagName === NG_TEMPLATE_TAG_NAME) {
        var _partitionArray3 = partitionArray(template.inputs, hasI18nMeta),
            _partitionArray4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_partitionArray3, 2),
            i18nInputs = _partitionArray4[0],
            inputs = _partitionArray4[1];

        var i18nAttrs = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(i18nStaticAttrs), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(i18nInputs)); // Add i18n attributes that may act as inputs to directives. If such attributes are present,
        // generate `i18nAttributes` instruction. Note: we generate it only for explicit <ng-template>
        // elements, in case of inline templates, corresponding instructions will be generated in the
        // nested template function.

        if (i18nAttrs.length > 0) {
          this.i18nAttributesInstruction(templateIndex, i18nAttrs, template.sourceSpan);
        } // Add the input bindings


        if (inputs.length > 0) {
          this.templatePropertyBindings(templateIndex, inputs);
        } // Generate listeners for directive output


        if (template.outputs.length > 0) {
          var listeners = template.outputs.map(function (outputAst) {
            return {
              sourceSpan: outputAst.sourceSpan,
              params: _this179.prepareListenerParameter('ng_template', outputAst, templateIndex)
            };
          });
          this.creationInstructionChain(Identifiers$1.listener, listeners);
        }
      }
    }
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {
      var _this180 = this;

      if (this.i18n) {
        var _value4 = text.value.visit(this._valueConverter);

        this.allocateBindingSlots(_value4);

        if (_value4 instanceof Interpolation) {
          this.i18n.appendBoundText(text.i18n);
          this.i18nAppendBindings(_value4.expressions);
        }

        return;
      }

      var nodeIndex = this.allocateDataSlot();
      this.creationInstruction(text.sourceSpan, Identifiers$1.text, [literal(nodeIndex)]);
      var value = text.value.visit(this._valueConverter);
      this.allocateBindingSlots(value);

      if (value instanceof Interpolation) {
        this.updateInstructionWithAdvance(nodeIndex, text.sourceSpan, getTextInterpolationExpression(value), function () {
          return _this180.getUpdateInstructionArguments(value);
        });
      } else {
        error('Text nodes should be interpolated and never bound directly.');
      }
    }
  }, {
    key: "visitText",
    value: function visitText(text) {
      // when a text element is located within a translatable
      // block, we exclude this text element from instructions set,
      // since it will be captured in i18n content and processed at runtime
      if (!this.i18n) {
        this.creationInstruction(text.sourceSpan, Identifiers$1.text, [literal(this.allocateDataSlot()), literal(text.value)]);
      }
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {
      var initWasInvoked = false; // if an ICU was created outside of i18n block, we still treat
      // it as a translatable entity and invoke i18nStart and i18nEnd
      // to generate i18n context and the necessary instructions

      if (!this.i18n) {
        initWasInvoked = true;
        this.i18nStart(null, icu.i18n, true);
      }

      var i18n = this.i18n;
      var vars = this.i18nBindProps(icu.vars);
      var placeholders = this.i18nBindProps(icu.placeholders); // output ICU directly and keep ICU reference in context

      var message = icu.i18n; // we always need post-processing function for ICUs, to make sure that:
      // - all placeholders in a form of {PLACEHOLDER} are replaced with actual values (note:
      // `goog.getMsg` does not process ICUs and uses the `{PLACEHOLDER}` format for placeholders
      // inside ICUs)
      // - all ICU vars (such as `VAR_SELECT` or `VAR_PLURAL`) are replaced with correct values

      var transformFn = function transformFn(raw) {
        var params = Object.assign(Object.assign({}, vars), placeholders);
        var formatted = i18nFormatPlaceholderNames(params,
        /* useCamelCase */
        false);
        return instruction(null, Identifiers$1.i18nPostprocess, [raw, mapLiteral(formatted, true)]);
      }; // in case the whole i18n message is a single ICU - we do not need to
      // create a separate top-level translation, we can use the root ref instead
      // and make this ICU a top-level translation
      // note: ICU placeholders are replaced with actual values in `i18nPostprocess` function
      // separately, so we do not pass placeholders into `i18nTranslate` function.


      if (isSingleI18nIcu(i18n.meta)) {
        this.i18nTranslate(message,
        /* placeholders */
        {}, i18n.ref, transformFn);
      } else {
        // output ICU directly and keep ICU reference in context
        var ref = this.i18nTranslate(message,
        /* placeholders */
        {},
        /* ref */
        undefined, transformFn);
        i18n.appendIcu(icuFromI18nMessage(message).name, ref);
      }

      if (initWasInvoked) {
        this.i18nEnd(null, true);
      }

      return null;
    }
  }, {
    key: "allocateDataSlot",
    value: function allocateDataSlot() {
      return this._dataIndex++;
    }
  }, {
    key: "getConstCount",
    value: function getConstCount() {
      return this._dataIndex;
    }
  }, {
    key: "getVarCount",
    value: function getVarCount() {
      return this._pureFunctionSlots;
    }
  }, {
    key: "getConsts",
    value: function getConsts() {
      return this._constants;
    }
  }, {
    key: "getNgContentSelectors",
    value: function getNgContentSelectors() {
      return this._ngContentReservedSlots.length ? this.constantPool.getConstLiteral(asLiteral(this._ngContentReservedSlots), true) : null;
    }
  }, {
    key: "bindingContext",
    value: function bindingContext() {
      return "".concat(this._bindingContext++);
    }
  }, {
    key: "templatePropertyBindings",
    value: function templatePropertyBindings(templateIndex, attrs) {
      var _this181 = this;

      var propertyBindings = [];
      attrs.forEach(function (input) {
        if (input instanceof BoundAttribute) {
          var _value5 = input.value.visit(_this181._valueConverter);

          if (_value5 !== undefined) {
            _this181.allocateBindingSlots(_value5);

            if (_value5 instanceof Interpolation) {
              // Params typically contain attribute namespace and value sanitizer, which is applicable
              // for regular HTML elements, but not applicable for <ng-template> (since props act as
              // inputs to directives), so keep params array empty.
              var params = []; // prop="{{value}}" case

              _this181.interpolatedUpdateInstruction(getPropertyInterpolationExpression(_value5), templateIndex, input.name, input, _value5, params);
            } else {
              // [prop]="value" case
              propertyBindings.push({
                name: input.name,
                sourceSpan: input.sourceSpan,
                value: function value() {
                  return _this181.convertPropertyBinding(_value5);
                }
              });
            }
          }
        }
      });

      if (propertyBindings.length > 0) {
        this.updateInstructionChainWithAdvance(templateIndex, Identifiers$1.property, propertyBindings);
      }
    } // Bindings must only be resolved after all local refs have been visited, so all
    // instructions are queued in callbacks that execute once the initial pass has completed.
    // Otherwise, we wouldn't be able to support local refs that are defined after their
    // bindings. e.g. {{ foo }} <div #foo></div>

  }, {
    key: "instructionFn",
    value: function instructionFn(fns, span, reference, paramsOrFn) {
      var prepend = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
      fns[prepend ? 'unshift' : 'push'](function () {
        var params = Array.isArray(paramsOrFn) ? paramsOrFn : paramsOrFn();
        return instruction(span, reference, params).toStmt();
      });
    }
  }, {
    key: "processStylingUpdateInstruction",
    value: function processStylingUpdateInstruction(elementIndex, instruction) {
      var _this182 = this;

      var allocateBindingSlots = 0;

      if (instruction) {
        var calls = [];
        instruction.calls.forEach(function (call) {
          allocateBindingSlots += call.allocateBindingSlots;
          calls.push({
            sourceSpan: call.sourceSpan,
            value: function value() {
              return call.params(function (value) {
                return call.supportsInterpolation && value instanceof Interpolation ? _this182.getUpdateInstructionArguments(value) : _this182.convertPropertyBinding(value);
              });
            }
          });
        });
        this.updateInstructionChainWithAdvance(elementIndex, instruction.reference, calls);
      }

      return allocateBindingSlots;
    }
  }, {
    key: "creationInstruction",
    value: function creationInstruction(span, reference, paramsOrFn, prepend) {
      this.instructionFn(this._creationCodeFns, span, reference, paramsOrFn || [], prepend);
    }
  }, {
    key: "creationInstructionChain",
    value: function creationInstructionChain(reference, calls) {
      var span = calls.length ? calls[0].sourceSpan : null;

      this._creationCodeFns.push(function () {
        return chainedInstruction(reference, calls.map(function (call) {
          return call.params();
        }), span).toStmt();
      });
    }
  }, {
    key: "updateInstructionWithAdvance",
    value: function updateInstructionWithAdvance(nodeIndex, span, reference, paramsOrFn) {
      this.addAdvanceInstructionIfNecessary(nodeIndex, span);
      this.updateInstruction(span, reference, paramsOrFn);
    }
  }, {
    key: "updateInstruction",
    value: function updateInstruction(span, reference, paramsOrFn) {
      this.instructionFn(this._updateCodeFns, span, reference, paramsOrFn || []);
    }
  }, {
    key: "updateInstructionChain",
    value: function updateInstructionChain(reference, bindings) {
      var span = bindings.length ? bindings[0].sourceSpan : null;

      this._updateCodeFns.push(function () {
        var calls = bindings.map(function (property) {
          var value = property.value();
          var fnParams = Array.isArray(value) ? value : [value];

          if (property.params) {
            fnParams.push.apply(fnParams, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(property.params));
          }

          if (property.name) {
            // We want the property name to always be the first function parameter.
            fnParams.unshift(literal(property.name));
          }

          return fnParams;
        });
        return chainedInstruction(reference, calls, span).toStmt();
      });
    }
  }, {
    key: "updateInstructionChainWithAdvance",
    value: function updateInstructionChainWithAdvance(nodeIndex, reference, bindings) {
      this.addAdvanceInstructionIfNecessary(nodeIndex, bindings.length ? bindings[0].sourceSpan : null);
      this.updateInstructionChain(reference, bindings);
    }
  }, {
    key: "addAdvanceInstructionIfNecessary",
    value: function addAdvanceInstructionIfNecessary(nodeIndex, span) {
      if (nodeIndex !== this._currentIndex) {
        var delta = nodeIndex - this._currentIndex;

        if (delta < 1) {
          throw new Error('advance instruction can only go forwards');
        }

        this.instructionFn(this._updateCodeFns, span, Identifiers$1.advance, [literal(delta)]);
        this._currentIndex = nodeIndex;
      }
    }
  }, {
    key: "allocatePureFunctionSlots",
    value: function allocatePureFunctionSlots(numSlots) {
      var originalSlots = this._pureFunctionSlots;
      this._pureFunctionSlots += numSlots;
      return originalSlots;
    }
  }, {
    key: "allocateBindingSlots",
    value: function allocateBindingSlots(value) {
      this._bindingSlots += value instanceof Interpolation ? value.expressions.length : 1;
    }
    /**
     * Gets an expression that refers to the implicit receiver. The implicit
     * receiver is always the root level context.
     */

  }, {
    key: "getImplicitReceiverExpr",
    value: function getImplicitReceiverExpr() {
      if (this._implicitReceiverExpr) {
        return this._implicitReceiverExpr;
      }

      return this._implicitReceiverExpr = this.level === 0 ? variable(CONTEXT_NAME) : this._bindingScope.getOrCreateSharedContextVar(0);
    }
  }, {
    key: "convertPropertyBinding",
    value: function convertPropertyBinding(value) {
      var _this$_tempVariables;

      var convertedPropertyBinding = _convertPropertyBinding(this, this.getImplicitReceiverExpr(), value, this.bindingContext(), BindingForm.Expression, function () {
        return error('Unexpected interpolation');
      });

      var valExpr = convertedPropertyBinding.currValExpr;

      (_this$_tempVariables = this._tempVariables).push.apply(_this$_tempVariables, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(convertedPropertyBinding.stmts));

      return valExpr;
    }
    /**
     * Gets a list of argument expressions to pass to an update instruction expression. Also updates
     * the temp variables state with temp variables that were identified as needing to be created
     * while visiting the arguments.
     * @param value The original expression we will be resolving an arguments list from.
     */

  }, {
    key: "getUpdateInstructionArguments",
    value: function getUpdateInstructionArguments(value) {
      var _this$_tempVariables2;

      var _convertUpdateArgumen = convertUpdateArguments(this, this.getImplicitReceiverExpr(), value, this.bindingContext()),
          args = _convertUpdateArgumen.args,
          stmts = _convertUpdateArgumen.stmts;

      (_this$_tempVariables2 = this._tempVariables).push.apply(_this$_tempVariables2, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(stmts));

      return args;
    }
  }, {
    key: "matchDirectives",
    value: function matchDirectives(elementName, elOrTpl) {
      var _this183 = this;

      if (this.directiveMatcher) {
        var selector = createCssSelector(elementName, getAttrsForDirectiveMatching(elOrTpl));
        this.directiveMatcher.match(selector, function (cssSelector, staticType) {
          _this183.directives.add(staticType);
        });
      }
    }
    /**
     * Prepares all attribute expression values for the `TAttributes` array.
     *
     * The purpose of this function is to properly construct an attributes array that
     * is passed into the `elementStart` (or just `element`) functions. Because there
     * are many different types of attributes, the array needs to be constructed in a
     * special way so that `elementStart` can properly evaluate them.
     *
     * The format looks like this:
     *
     * ```
     * attrs = [prop, value, prop2, value2,
     *   PROJECT_AS, selector,
     *   CLASSES, class1, class2,
     *   STYLES, style1, value1, style2, value2,
     *   BINDINGS, name1, name2, name3,
     *   TEMPLATE, name4, name5, name6,
     *   I18N, name7, name8, ...]
     * ```
     *
     * Note that this function will fully ignore all synthetic (@foo) attribute values
     * because those values are intended to always be generated as property instructions.
     */

  }, {
    key: "getAttributeExpressions",
    value: function getAttributeExpressions(renderAttributes, inputs, outputs, styles) {
      var templateAttrs = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : [];
      var i18nAttrs = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [];
      var alreadySeen = new Set();
      var attrExprs = [];
      var ngProjectAsAttr;
      renderAttributes.forEach(function (attr) {
        if (attr.name === NG_PROJECT_AS_ATTR_NAME) {
          ngProjectAsAttr = attr;
        }

        attrExprs.push.apply(attrExprs, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(getAttributeNameLiterals(attr.name)).concat([asLiteral(attr.value)]));
      }); // Keep ngProjectAs next to the other name, value pairs so we can verify that we match
      // ngProjectAs marker in the attribute name slot.

      if (ngProjectAsAttr) {
        attrExprs.push.apply(attrExprs, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(getNgProjectAsLiteral(ngProjectAsAttr)));
      }

      function addAttrExpr(key, value) {
        if (typeof key === 'string') {
          if (!alreadySeen.has(key)) {
            attrExprs.push.apply(attrExprs, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(getAttributeNameLiterals(key)));
            value !== undefined && attrExprs.push(value);
            alreadySeen.add(key);
          }
        } else {
          attrExprs.push(literal(key));
        }
      } // it's important that this occurs before BINDINGS and TEMPLATE because once `elementStart`
      // comes across the BINDINGS or TEMPLATE markers then it will continue reading each value as
      // as single property value cell by cell.


      if (styles) {
        styles.populateInitialStylingAttrs(attrExprs);
      }

      if (inputs.length || outputs.length) {
        var attrsLengthBeforeInputs = attrExprs.length;

        for (var i = 0; i < inputs.length; i++) {
          var input = inputs[i]; // We don't want the animation and attribute bindings in the
          // attributes array since they aren't used for directive matching.

          if (input.type !== 4
          /* Animation */
          && input.type !== 1
          /* Attribute */
          ) {
              addAttrExpr(input.name);
            }
        }

        for (var _i7 = 0; _i7 < outputs.length; _i7++) {
          var output = outputs[_i7];

          if (output.type !== 1
          /* Animation */
          ) {
              addAttrExpr(output.name);
            }
        } // this is a cheap way of adding the marker only after all the input/output
        // values have been filtered (by not including the animation ones) and added
        // to the expressions. The marker is important because it tells the runtime
        // code that this is where attributes without values start...


        if (attrExprs.length !== attrsLengthBeforeInputs) {
          attrExprs.splice(attrsLengthBeforeInputs, 0, literal(3
          /* Bindings */
          ));
        }
      }

      if (templateAttrs.length) {
        attrExprs.push(literal(4
        /* Template */
        ));
        templateAttrs.forEach(function (attr) {
          return addAttrExpr(attr.name);
        });
      }

      if (i18nAttrs.length) {
        attrExprs.push(literal(6
        /* I18n */
        ));
        i18nAttrs.forEach(function (attr) {
          return addAttrExpr(attr.name);
        });
      }

      return attrExprs;
    }
  }, {
    key: "addToConsts",
    value: function addToConsts(expression) {
      if (isNull(expression)) {
        return TYPED_NULL_EXPR;
      }

      var consts = this._constants.constExpressions; // Try to reuse a literal that's already in the array, if possible.

      for (var i = 0; i < consts.length; i++) {
        if (consts[i].isEquivalent(expression)) {
          return literal(i);
        }
      }

      return literal(consts.push(expression) - 1);
    }
  }, {
    key: "addAttrsToConsts",
    value: function addAttrsToConsts(attrs) {
      return attrs.length > 0 ? this.addToConsts(literalArr(attrs)) : TYPED_NULL_EXPR;
    }
  }, {
    key: "prepareRefsArray",
    value: function prepareRefsArray(references) {
      var _this184 = this;

      if (!references || references.length === 0) {
        return TYPED_NULL_EXPR;
      }

      var refsParam = flatten(references.map(function (reference) {
        var slot = _this184.allocateDataSlot(); // Generate the update temporary.


        var variableName = _this184._bindingScope.freshReferenceName();

        var retrievalLevel = _this184.level;
        var lhs = variable(variableName);

        _this184._bindingScope.set(retrievalLevel, reference.name, lhs, 0
        /* DEFAULT */
        , function (scope, relativeLevel) {
          // e.g. nextContext(2);
          var nextContextStmt = relativeLevel > 0 ? [generateNextContextExpr(relativeLevel).toStmt()] : []; // e.g. const $foo$ = reference(1);

          var refExpr = lhs.set(importExpr(Identifiers$1.reference).callFn([literal(slot)]));
          return nextContextStmt.concat(refExpr.toConstDecl());
        }, true);

        return [reference.name, reference.value];
      }));
      return asLiteral(refsParam);
    }
  }, {
    key: "prepareListenerParameter",
    value: function prepareListenerParameter(tagName, outputAst, index) {
      var _this185 = this;

      return function () {
        var eventName = outputAst.name;
        var bindingFnName = outputAst.type === 1
        /* Animation */
        ? // synthetic @listener.foo values are treated the exact same as are standard listeners
        prepareSyntheticListenerFunctionName(eventName, outputAst.phase) : sanitizeIdentifier(eventName);
        var handlerName = "".concat(_this185.templateName, "_").concat(tagName, "_").concat(bindingFnName, "_").concat(index, "_listener");

        var scope = _this185._bindingScope.nestedScope(_this185._bindingScope.bindingLevel);

        return prepareEventListenerParameters(outputAst, handlerName, scope);
      };
    }
  }]);

  return TemplateDefinitionBuilder;
}();

var ValueConverter = /*#__PURE__*/function (_AstMemoryEfficientTr) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ValueConverter, _AstMemoryEfficientTr);

  var _super96 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ValueConverter);

  function ValueConverter(constantPool, allocateSlot, allocatePureFunctionSlots, definePipe) {
    var _this186;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ValueConverter);

    _this186 = _super96.call(this);
    _this186.constantPool = constantPool;
    _this186.allocateSlot = allocateSlot;
    _this186.allocatePureFunctionSlots = allocatePureFunctionSlots;
    _this186.definePipe = definePipe;
    _this186._pipeBindExprs = [];
    return _this186;
  } // AstMemoryEfficientTransformer


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ValueConverter, [{
    key: "visitPipe",
    value: function visitPipe(pipe, context) {
      // Allocate a slot to create the pipe
      var slot = this.allocateSlot();
      var slotPseudoLocal = "PIPE:".concat(slot); // Allocate one slot for the result plus one slot per pipe argument

      var pureFunctionSlot = this.allocatePureFunctionSlots(2 + pipe.args.length);
      var target = new PropertyRead(pipe.span, pipe.sourceSpan, pipe.nameSpan, new ImplicitReceiver(pipe.span, pipe.sourceSpan), slotPseudoLocal);

      var _pipeBindingCallInfo = pipeBindingCallInfo(pipe.args),
          identifier = _pipeBindingCallInfo.identifier,
          isVarLength = _pipeBindingCallInfo.isVarLength;

      this.definePipe(pipe.name, slotPseudoLocal, slot, importExpr(identifier));
      var args = [pipe.exp].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(pipe.args));
      var convertedArgs = isVarLength ? this.visitAll([new LiteralArray(pipe.span, pipe.sourceSpan, args)]) : this.visitAll(args);
      var pipeBindExpr = new FunctionCall(pipe.span, pipe.sourceSpan, target, [new LiteralPrimitive(pipe.span, pipe.sourceSpan, slot), new LiteralPrimitive(pipe.span, pipe.sourceSpan, pureFunctionSlot)].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(convertedArgs)));

      this._pipeBindExprs.push(pipeBindExpr);

      return pipeBindExpr;
    }
  }, {
    key: "updatePipeSlotOffsets",
    value: function updatePipeSlotOffsets(bindingSlots) {
      this._pipeBindExprs.forEach(function (pipe) {
        // update the slot offset arg (index 1) to account for binding slots
        var slotOffset = pipe.args[1];
        slotOffset.value += bindingSlots;
      });
    }
  }, {
    key: "visitLiteralArray",
    value: function visitLiteralArray(array, context) {
      var _this187 = this;

      return new BuiltinFunctionCall(array.span, array.sourceSpan, this.visitAll(array.expressions), function (values) {
        // If the literal has calculated (non-literal) elements transform it into
        // calls to literal factories that compose the literal and will cache intermediate
        // values.
        var literal = literalArr(values);
        return getLiteralFactory(_this187.constantPool, literal, _this187.allocatePureFunctionSlots);
      });
    }
  }, {
    key: "visitLiteralMap",
    value: function visitLiteralMap(map, context) {
      var _this188 = this;

      return new BuiltinFunctionCall(map.span, map.sourceSpan, this.visitAll(map.values), function (values) {
        // If the literal has calculated (non-literal) elements  transform it into
        // calls to literal factories that compose the literal and will cache intermediate
        // values.
        var literal = literalMap(values.map(function (value, index) {
          return {
            key: map.keys[index].key,
            value: value,
            quoted: map.keys[index].quoted
          };
        }));
        return getLiteralFactory(_this188.constantPool, literal, _this188.allocatePureFunctionSlots);
      });
    }
  }]);

  return ValueConverter;
}(AstMemoryEfficientTransformer); // Pipes always have at least one parameter, the value they operate on


var pipeBindingIdentifiers = [Identifiers$1.pipeBind1, Identifiers$1.pipeBind2, Identifiers$1.pipeBind3, Identifiers$1.pipeBind4];

function pipeBindingCallInfo(args) {
  var identifier = pipeBindingIdentifiers[args.length];
  return {
    identifier: identifier || Identifiers$1.pipeBindV,
    isVarLength: !identifier
  };
}

var pureFunctionIdentifiers = [Identifiers$1.pureFunction0, Identifiers$1.pureFunction1, Identifiers$1.pureFunction2, Identifiers$1.pureFunction3, Identifiers$1.pureFunction4, Identifiers$1.pureFunction5, Identifiers$1.pureFunction6, Identifiers$1.pureFunction7, Identifiers$1.pureFunction8];

function pureFunctionCallInfo(args) {
  var identifier = pureFunctionIdentifiers[args.length];
  return {
    identifier: identifier || Identifiers$1.pureFunctionV,
    isVarLength: !identifier
  };
}

function instruction(span, reference, params) {
  return importExpr(reference, null, span).callFn(params, span);
} // e.g. x(2);


function generateNextContextExpr(relativeLevelDiff) {
  return importExpr(Identifiers$1.nextContext).callFn(relativeLevelDiff > 1 ? [literal(relativeLevelDiff)] : []);
}

function getLiteralFactory(constantPool, literal$1, allocateSlots) {
  var _constantPool$getLite = constantPool.getLiteralFactory(literal$1),
      literalFactory = _constantPool$getLite.literalFactory,
      literalFactoryArguments = _constantPool$getLite.literalFactoryArguments; // Allocate 1 slot for the result plus 1 per argument


  var startSlot = allocateSlots(1 + literalFactoryArguments.length);

  var _pureFunctionCallInfo = pureFunctionCallInfo(literalFactoryArguments),
      identifier = _pureFunctionCallInfo.identifier,
      isVarLength = _pureFunctionCallInfo.isVarLength; // Literal factories are pure functions that only need to be re-invoked when the parameters
  // change.


  var args = [literal(startSlot), literalFactory];

  if (isVarLength) {
    args.push(literalArr(literalFactoryArguments));
  } else {
    args.push.apply(args, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(literalFactoryArguments));
  }

  return importExpr(identifier).callFn(args);
}
/**
 * Gets an array of literals that can be added to an expression
 * to represent the name and namespace of an attribute. E.g.
 * `:xlink:href` turns into `[AttributeMarker.NamespaceURI, 'xlink', 'href']`.
 *
 * @param name Name of the attribute, including the namespace.
 */


function getAttributeNameLiterals(name) {
  var _splitNsName5 = splitNsName(name),
      _splitNsName6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_splitNsName5, 2),
      attributeNamespace = _splitNsName6[0],
      attributeName = _splitNsName6[1];

  var nameLiteral = literal(attributeName);

  if (attributeNamespace) {
    return [literal(0
    /* NamespaceURI */
    ), literal(attributeNamespace), nameLiteral];
  }

  return [nameLiteral];
}
/** The prefix used to get a shared context in BindingScope's map. */


var SHARED_CONTEXT_KEY = '$$shared_ctx$$';

var BindingScope = /*#__PURE__*/function () {
  function BindingScope() {
    var bindingLevel = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    var parent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BindingScope);

    this.bindingLevel = bindingLevel;
    this.parent = parent;
    /** Keeps a map from local variables to their BindingData. */

    this.map = new Map();
    this.referenceNameIndex = 0;
    this.restoreViewVariable = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BindingScope, [{
    key: "get",
    value: function get(name) {
      var current = this;

      while (current) {
        var value = current.map.get(name);

        if (value != null) {
          if (current !== this) {
            // make a local copy and reset the `declare` state
            value = {
              retrievalLevel: value.retrievalLevel,
              lhs: value.lhs,
              declareLocalCallback: value.declareLocalCallback,
              declare: false,
              priority: value.priority,
              localRef: value.localRef
            }; // Cache the value locally.

            this.map.set(name, value); // Possibly generate a shared context var

            this.maybeGenerateSharedContextVar(value);
            this.maybeRestoreView(value.retrievalLevel, value.localRef);
          }

          if (value.declareLocalCallback && !value.declare) {
            value.declare = true;
          }

          return value.lhs;
        }

        current = current.parent;
      } // If we get to this point, we are looking for a property on the top level component
      // - If level === 0, we are on the top and don't need to re-declare `ctx`.
      // - If level > 0, we are in an embedded view. We need to retrieve the name of the
      // local var we used to store the component context, e.g. const $comp$ = x();


      return this.bindingLevel === 0 ? null : this.getComponentProperty(name);
    }
    /**
     * Create a local variable for later reference.
     *
     * @param retrievalLevel The level from which this value can be retrieved
     * @param name Name of the variable.
     * @param lhs AST representing the left hand side of the `let lhs = rhs;`.
     * @param priority The sorting priority of this var
     * @param declareLocalCallback The callback to invoke when declaring this local var
     * @param localRef Whether or not this is a local ref
     */

  }, {
    key: "set",
    value: function set(retrievalLevel, name, lhs) {
      var priority = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
      var
      /* DEFAULT */
      declareLocalCallback = arguments.length > 4 ? arguments[4] : undefined;
      var localRef = arguments.length > 5 ? arguments[5] : undefined;

      if (this.map.has(name)) {
        if (localRef) {
          // Do not throw an error if it's a local ref and do not update existing value,
          // so the first defined ref is always returned.
          return this;
        }

        error("The name ".concat(name, " is already defined in scope to be ").concat(this.map.get(name)));
      }

      this.map.set(name, {
        retrievalLevel: retrievalLevel,
        lhs: lhs,
        declare: false,
        declareLocalCallback: declareLocalCallback,
        priority: priority,
        localRef: localRef || false
      });
      return this;
    } // Implemented as part of LocalResolver.

  }, {
    key: "getLocal",
    value: function getLocal(name) {
      return this.get(name);
    } // Implemented as part of LocalResolver.

  }, {
    key: "notifyImplicitReceiverUse",
    value: function notifyImplicitReceiverUse() {
      if (this.bindingLevel !== 0) {
        // Since the implicit receiver is accessed in an embedded view, we need to
        // ensure that we declare a shared context variable for the current template
        // in the update variables.
        this.map.get(SHARED_CONTEXT_KEY + 0).declare = true;
      }
    }
  }, {
    key: "nestedScope",
    value: function nestedScope(level) {
      var newScope = new BindingScope(level, this);
      if (level > 0) newScope.generateSharedContextVar(0);
      return newScope;
    }
    /**
     * Gets or creates a shared context variable and returns its expression. Note that
     * this does not mean that the shared variable will be declared. Variables in the
     * binding scope will be only declared if they are used.
     */

  }, {
    key: "getOrCreateSharedContextVar",
    value: function getOrCreateSharedContextVar(retrievalLevel) {
      var bindingKey = SHARED_CONTEXT_KEY + retrievalLevel;

      if (!this.map.has(bindingKey)) {
        this.generateSharedContextVar(retrievalLevel);
      } // Shared context variables are always generated as "ReadVarExpr".


      return this.map.get(bindingKey).lhs;
    }
  }, {
    key: "getSharedContextName",
    value: function getSharedContextName(retrievalLevel) {
      var sharedCtxObj = this.map.get(SHARED_CONTEXT_KEY + retrievalLevel); // Shared context variables are always generated as "ReadVarExpr".

      return sharedCtxObj && sharedCtxObj.declare ? sharedCtxObj.lhs : null;
    }
  }, {
    key: "maybeGenerateSharedContextVar",
    value: function maybeGenerateSharedContextVar(value) {
      if (value.priority === 1
      /* CONTEXT */
      && value.retrievalLevel < this.bindingLevel) {
        var sharedCtxObj = this.map.get(SHARED_CONTEXT_KEY + value.retrievalLevel);

        if (sharedCtxObj) {
          sharedCtxObj.declare = true;
        } else {
          this.generateSharedContextVar(value.retrievalLevel);
        }
      }
    }
  }, {
    key: "generateSharedContextVar",
    value: function generateSharedContextVar(retrievalLevel) {
      var lhs = variable(CONTEXT_NAME + this.freshReferenceName());
      this.map.set(SHARED_CONTEXT_KEY + retrievalLevel, {
        retrievalLevel: retrievalLevel,
        lhs: lhs,
        declareLocalCallback: function declareLocalCallback(scope, relativeLevel) {
          // const ctx_r0 = nextContext(2);
          return [lhs.set(generateNextContextExpr(relativeLevel)).toConstDecl()];
        },
        declare: false,
        priority: 2
        /* SHARED_CONTEXT */
        ,
        localRef: false
      });
    }
  }, {
    key: "getComponentProperty",
    value: function getComponentProperty(name) {
      var componentValue = this.map.get(SHARED_CONTEXT_KEY + 0);
      componentValue.declare = true;
      this.maybeRestoreView(0, false);
      return componentValue.lhs.prop(name);
    }
  }, {
    key: "maybeRestoreView",
    value: function maybeRestoreView(retrievalLevel, localRefLookup) {
      // We want to restore the current view in listener fns if:
      // 1 - we are accessing a value in a parent view, which requires walking the view tree rather
      // than using the ctx arg. In this case, the retrieval and binding level will be different.
      // 2 - we are looking up a local ref, which requires restoring the view where the local
      // ref is stored
      if (this.isListenerScope() && (retrievalLevel < this.bindingLevel || localRefLookup)) {
        if (!this.parent.restoreViewVariable) {
          // parent saves variable to generate a shared `const $s$ = getCurrentView();` instruction
          this.parent.restoreViewVariable = variable(this.parent.freshReferenceName());
        }

        this.restoreViewVariable = this.parent.restoreViewVariable;
      }
    }
  }, {
    key: "restoreViewStatement",
    value: function restoreViewStatement() {
      // restoreView($state$);
      return this.restoreViewVariable ? [instruction(null, Identifiers$1.restoreView, [this.restoreViewVariable]).toStmt()] : [];
    }
  }, {
    key: "viewSnapshotStatements",
    value: function viewSnapshotStatements() {
      // const $state$ = getCurrentView();
      var getCurrentViewInstruction = instruction(null, Identifiers$1.getCurrentView, []);
      return this.restoreViewVariable ? [this.restoreViewVariable.set(getCurrentViewInstruction).toConstDecl()] : [];
    }
  }, {
    key: "isListenerScope",
    value: function isListenerScope() {
      return this.parent && this.parent.bindingLevel === this.bindingLevel;
    }
  }, {
    key: "variableDeclarations",
    value: function variableDeclarations() {
      var _this189 = this;

      var currentContextLevel = 0;
      return Array.from(this.map.values()).filter(function (value) {
        return value.declare;
      }).sort(function (a, b) {
        return b.retrievalLevel - a.retrievalLevel || b.priority - a.priority;
      }).reduce(function (stmts, value) {
        var levelDiff = _this189.bindingLevel - value.retrievalLevel;
        var currStmts = value.declareLocalCallback(_this189, levelDiff - currentContextLevel);
        currentContextLevel = levelDiff;
        return stmts.concat(currStmts);
      }, []);
    }
  }, {
    key: "freshReferenceName",
    value: function freshReferenceName() {
      var current = this; // Find the top scope as it maintains the global reference count

      while (current.parent) {
        current = current.parent;
      }

      var ref = "".concat(REFERENCE_PREFIX).concat(current.referenceNameIndex++);
      return ref;
    }
  }], [{
    key: "createRootScope",
    value: function createRootScope() {
      return new BindingScope().set(0, '$event', variable('$event'));
    }
  }]);

  return BindingScope;
}();
/**
 * Creates a `CssSelector` given a tag name and a map of attributes
 */


function createCssSelector(elementName, attributes) {
  var cssSelector = new CssSelector();
  var elementNameNoNs = splitNsName(elementName)[1];
  cssSelector.setElement(elementNameNoNs);
  Object.getOwnPropertyNames(attributes).forEach(function (name) {
    var nameNoNs = splitNsName(name)[1];
    var value = attributes[name];
    cssSelector.addAttribute(nameNoNs, value);

    if (name.toLowerCase() === 'class') {
      var classes = value.trim().split(/\s+/);
      classes.forEach(function (className) {
        return cssSelector.addClassName(className);
      });
    }
  });
  return cssSelector;
}
/**
 * Creates an array of expressions out of an `ngProjectAs` attributes
 * which can be added to the instruction parameters.
 */


function getNgProjectAsLiteral(attribute) {
  // Parse the attribute value into a CssSelectorList. Note that we only take the
  // first selector, because we don't support multiple selectors in ngProjectAs.
  var parsedR3Selector = parseSelectorToR3Selector(attribute.value)[0];
  return [literal(5
  /* ProjectAs */
  ), asLiteral(parsedR3Selector)];
}
/**
 * Gets the instruction to generate for an interpolated property
 * @param interpolation An Interpolation AST
 */


function getPropertyInterpolationExpression(interpolation) {
  switch (getInterpolationArgsLength(interpolation)) {
    case 1:
      return Identifiers$1.propertyInterpolate;

    case 3:
      return Identifiers$1.propertyInterpolate1;

    case 5:
      return Identifiers$1.propertyInterpolate2;

    case 7:
      return Identifiers$1.propertyInterpolate3;

    case 9:
      return Identifiers$1.propertyInterpolate4;

    case 11:
      return Identifiers$1.propertyInterpolate5;

    case 13:
      return Identifiers$1.propertyInterpolate6;

    case 15:
      return Identifiers$1.propertyInterpolate7;

    case 17:
      return Identifiers$1.propertyInterpolate8;

    default:
      return Identifiers$1.propertyInterpolateV;
  }
}
/**
 * Gets the instruction to generate for an interpolated attribute
 * @param interpolation An Interpolation AST
 */


function getAttributeInterpolationExpression(interpolation) {
  switch (getInterpolationArgsLength(interpolation)) {
    case 3:
      return Identifiers$1.attributeInterpolate1;

    case 5:
      return Identifiers$1.attributeInterpolate2;

    case 7:
      return Identifiers$1.attributeInterpolate3;

    case 9:
      return Identifiers$1.attributeInterpolate4;

    case 11:
      return Identifiers$1.attributeInterpolate5;

    case 13:
      return Identifiers$1.attributeInterpolate6;

    case 15:
      return Identifiers$1.attributeInterpolate7;

    case 17:
      return Identifiers$1.attributeInterpolate8;

    default:
      return Identifiers$1.attributeInterpolateV;
  }
}
/**
 * Gets the instruction to generate for interpolated text.
 * @param interpolation An Interpolation AST
 */


function getTextInterpolationExpression(interpolation) {
  switch (getInterpolationArgsLength(interpolation)) {
    case 1:
      return Identifiers$1.textInterpolate;

    case 3:
      return Identifiers$1.textInterpolate1;

    case 5:
      return Identifiers$1.textInterpolate2;

    case 7:
      return Identifiers$1.textInterpolate3;

    case 9:
      return Identifiers$1.textInterpolate4;

    case 11:
      return Identifiers$1.textInterpolate5;

    case 13:
      return Identifiers$1.textInterpolate6;

    case 15:
      return Identifiers$1.textInterpolate7;

    case 17:
      return Identifiers$1.textInterpolate8;

    default:
      return Identifiers$1.textInterpolateV;
  }
}
/**
 * Parse a template into render3 `Node`s and additional metadata, with no other dependencies.
 *
 * @param template text of the template to parse
 * @param templateUrl URL to use for source mapping of the parsed template
 * @param options options to modify how the template is parsed
 */


function parseTemplate(template, templateUrl) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var interpolationConfig = options.interpolationConfig,
      preserveWhitespaces = options.preserveWhitespaces,
      enableI18nLegacyMessageIdFormat = options.enableI18nLegacyMessageIdFormat;
  var bindingParser = makeBindingParser(interpolationConfig);
  var htmlParser = new HtmlParser();
  var parseResult = htmlParser.parse(template, templateUrl, Object.assign(Object.assign({
    leadingTriviaChars: LEADING_TRIVIA_CHARS
  }, options), {
    tokenizeExpansionForms: true
  }));

  if (parseResult.errors && parseResult.errors.length > 0) {
    return {
      errors: parseResult.errors,
      nodes: [],
      styleUrls: [],
      styles: [],
      ngContentSelectors: []
    };
  }

  var rootNodes = parseResult.rootNodes; // process i18n meta information (scan attributes, generate ids)
  // before we run whitespace removal process, because existing i18n
  // extraction process (ng xi18n) relies on a raw content to generate
  // message ids

  var i18nMetaVisitor = new I18nMetaVisitor(interpolationConfig,
  /* keepI18nAttrs */
  !preserveWhitespaces, enableI18nLegacyMessageIdFormat);
  rootNodes = visitAll$1(i18nMetaVisitor, rootNodes);

  if (!preserveWhitespaces) {
    rootNodes = visitAll$1(new WhitespaceVisitor(), rootNodes); // run i18n meta visitor again in case whitespaces are removed (because that might affect
    // generated i18n message content) and first pass indicated that i18n content is present in a
    // template. During this pass i18n IDs generated at the first pass will be preserved, so we can
    // mimic existing extraction process (ng xi18n)

    if (i18nMetaVisitor.hasI18nMeta) {
      rootNodes = visitAll$1(new I18nMetaVisitor(interpolationConfig,
      /* keepI18nAttrs */
      false), rootNodes);
    }
  }

  var _htmlAstToRender3Ast = htmlAstToRender3Ast(rootNodes, bindingParser),
      nodes = _htmlAstToRender3Ast.nodes,
      errors = _htmlAstToRender3Ast.errors,
      styleUrls = _htmlAstToRender3Ast.styleUrls,
      styles = _htmlAstToRender3Ast.styles,
      ngContentSelectors = _htmlAstToRender3Ast.ngContentSelectors;

  if (errors && errors.length > 0) {
    return {
      errors: errors,
      nodes: [],
      styleUrls: [],
      styles: [],
      ngContentSelectors: []
    };
  }

  return {
    nodes: nodes,
    styleUrls: styleUrls,
    styles: styles,
    ngContentSelectors: ngContentSelectors
  };
}

var elementRegistry = new DomElementSchemaRegistry();
/**
 * Construct a `BindingParser` with a default configuration.
 */

function makeBindingParser() {
  var interpolationConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DEFAULT_INTERPOLATION_CONFIG;
  return new BindingParser(new IvyParser(new Lexer()), interpolationConfig, elementRegistry, null, []);
}

function resolveSanitizationFn(context, isAttribute) {
  switch (context) {
    case SecurityContext.HTML:
      return importExpr(Identifiers$1.sanitizeHtml);

    case SecurityContext.SCRIPT:
      return importExpr(Identifiers$1.sanitizeScript);

    case SecurityContext.STYLE:
      // the compiler does not fill in an instruction for [style.prop?] binding
      // values because the style algorithm knows internally what props are subject
      // to sanitization (only [attr.style] values are explicitly sanitized)
      return isAttribute ? importExpr(Identifiers$1.sanitizeStyle) : null;

    case SecurityContext.URL:
      return importExpr(Identifiers$1.sanitizeUrl);

    case SecurityContext.RESOURCE_URL:
      return importExpr(Identifiers$1.sanitizeResourceUrl);

    default:
      return null;
  }
}

function isSingleElementTemplate(children) {
  return children.length === 1 && children[0] instanceof Element;
}

function isTextNode(node) {
  return node instanceof Text || node instanceof BoundText || node instanceof Icu;
}

function hasTextChildrenOnly(children) {
  return children.every(isTextNode);
}
/** Name of the global variable that is used to determine if we use Closure translations or not */


var NG_I18N_CLOSURE_MODE = 'ngI18nClosureMode';
/**
 * Generate statements that define a given translation message.
 *
 * ```
 * var I18N_1;
 * if (typeof ngI18nClosureMode !== undefined && ngI18nClosureMode) {
 *     var MSG_EXTERNAL_XXX = goog.getMsg(
 *          "Some message with {$interpolation}!",
 *          { "interpolation": "\uFFFD0\uFFFD" }
 *     );
 *     I18N_1 = MSG_EXTERNAL_XXX;
 * }
 * else {
 *     I18N_1 = $localize`Some message with ${'\uFFFD0\uFFFD'}!`;
 * }
 * ```
 *
 * @param message The original i18n AST message node
 * @param variable The variable that will be assigned the translation, e.g. `I18N_1`.
 * @param closureVar The variable for Closure `goog.getMsg` calls, e.g. `MSG_EXTERNAL_XXX`.
 * @param params Object mapping placeholder names to their values (e.g.
 * `{ "interpolation": "\uFFFD0\uFFFD" }`).
 * @param transformFn Optional transformation function that will be applied to the translation (e.g.
 * post-processing).
 * @returns An array of statements that defined a given translation.
 */

function getTranslationDeclStmts(message, variable, closureVar) {
  var params = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var transformFn = arguments.length > 4 ? arguments[4] : undefined;
  var statements = [declareI18nVariable(variable), ifStmt(createClosureModeGuard(), createGoogleGetMsgStatements(variable, message, closureVar, i18nFormatPlaceholderNames(params,
  /* useCamelCase */
  true)), createLocalizeStatements(variable, message, i18nFormatPlaceholderNames(params,
  /* useCamelCase */
  false)))];

  if (transformFn) {
    statements.push(new ExpressionStatement(variable.set(transformFn(variable))));
  }

  return statements;
}
/**
 * Create the expression that will be used to guard the closure mode block
 * It is equivalent to:
 *
 * ```
 * typeof ngI18nClosureMode !== undefined && ngI18nClosureMode
 * ```
 */


function createClosureModeGuard() {
  return typeofExpr(variable(NG_I18N_CLOSURE_MODE)).notIdentical(literal('undefined', STRING_TYPE)).and(variable(NG_I18N_CLOSURE_MODE));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var EMPTY_ARRAY = []; // This regex matches any binding names that contain the "attr." prefix, e.g. "attr.required"
// If there is a match, the first matching group will contain the attribute name to bind.

var ATTR_REGEX = /attr\.([^\]]+)/;

function baseDirectiveFields(meta, constantPool, bindingParser) {
  var definitionMap = new DefinitionMap();
  var selectors = parseSelectorToR3Selector(meta.selector); // e.g. `type: MyDirective`

  definitionMap.set('type', meta.internalType); // e.g. `selectors: [['', 'someDir', '']]`

  if (selectors.length > 0) {
    definitionMap.set('selectors', asLiteral(selectors));
  }

  if (meta.queries.length > 0) {
    // e.g. `contentQueries: (rf, ctx, dirIndex) => { ... }
    definitionMap.set('contentQueries', createContentQueriesFunction(meta.queries, constantPool, meta.name));
  }

  if (meta.viewQueries.length) {
    definitionMap.set('viewQuery', createViewQueriesFunction(meta.viewQueries, constantPool, meta.name));
  } // e.g. `hostBindings: (rf, ctx) => { ... }


  definitionMap.set('hostBindings', createHostBindingsFunction(meta.host, meta.typeSourceSpan, bindingParser, constantPool, meta.selector || '', meta.name, definitionMap)); // e.g 'inputs: {a: 'a'}`

  definitionMap.set('inputs', conditionallyCreateMapObjectLiteral(meta.inputs, true)); // e.g 'outputs: {a: 'a'}`

  definitionMap.set('outputs', conditionallyCreateMapObjectLiteral(meta.outputs));

  if (meta.exportAs !== null) {
    definitionMap.set('exportAs', literalArr(meta.exportAs.map(function (e) {
      return literal(e);
    })));
  }

  return definitionMap;
}
/**
 * Add features to the definition map.
 */


function addFeatures(definitionMap, meta) {
  // e.g. `features: [NgOnChangesFeature]`
  var features = [];
  var providers = meta.providers;
  var viewProviders = meta.viewProviders;

  if (providers || viewProviders) {
    var args = [providers || new LiteralArrayExpr([])];

    if (viewProviders) {
      args.push(viewProviders);
    }

    features.push(importExpr(Identifiers$1.ProvidersFeature).callFn(args));
  }

  if (meta.usesInheritance) {
    features.push(importExpr(Identifiers$1.InheritDefinitionFeature));
  }

  if (meta.fullInheritance) {
    features.push(importExpr(Identifiers$1.CopyDefinitionFeature));
  }

  if (meta.lifecycle.usesOnChanges) {
    features.push(importExpr(Identifiers$1.NgOnChangesFeature));
  }

  if (features.length) {
    definitionMap.set('features', literalArr(features));
  }
}
/**
 * Compile a directive for the render3 runtime as defined by the `R3DirectiveMetadata`.
 */


function compileDirectiveFromMetadata(meta, constantPool, bindingParser) {
  var definitionMap = baseDirectiveFields(meta, constantPool, bindingParser);
  addFeatures(definitionMap, meta);
  var expression = importExpr(Identifiers$1.defineDirective).callFn([definitionMap.toLiteralMap()]);
  var typeParams = createDirectiveTypeParams(meta);
  var type = expressionType(importExpr(Identifiers$1.DirectiveDefWithMeta, typeParams));
  return {
    expression: expression,
    type: type
  };
}
/**
 * Compile a component for the render3 runtime as defined by the `R3ComponentMetadata`.
 */


function compileComponentFromMetadata(meta, constantPool, bindingParser) {
  var definitionMap = baseDirectiveFields(meta, constantPool, bindingParser);
  addFeatures(definitionMap, meta);
  var selector = meta.selector && CssSelector.parse(meta.selector);
  var firstSelector = selector && selector[0]; // e.g. `attr: ["class", ".my.app"]`
  // This is optional an only included if the first selector of a component specifies attributes.

  if (firstSelector) {
    var selectorAttributes = firstSelector.getAttrs();

    if (selectorAttributes.length) {
      definitionMap.set('attrs', constantPool.getConstLiteral(literalArr(selectorAttributes.map(function (value) {
        return value != null ? literal(value) : literal(undefined);
      })),
      /* forceShared */
      true));
    }
  } // Generate the CSS matcher that recognize directive


  var directiveMatcher = null;

  if (meta.directives.length > 0) {
    var matcher = new SelectorMatcher();

    var _iterator15 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(meta.directives),
        _step15;

    try {
      for (_iterator15.s(); !(_step15 = _iterator15.n()).done;) {
        var _step15$value = _step15.value,
            _selector = _step15$value.selector,
            _expression = _step15$value.expression;
        matcher.addSelectables(CssSelector.parse(_selector), _expression);
      }
    } catch (err) {
      _iterator15.e(err);
    } finally {
      _iterator15.f();
    }

    directiveMatcher = matcher;
  } // e.g. `template: function MyComponent_Template(_ctx, _cm) {...}`


  var templateTypeName = meta.name;
  var templateName = templateTypeName ? "".concat(templateTypeName, "_Template") : null;
  var directivesUsed = new Set();
  var pipesUsed = new Set();
  var changeDetection = meta.changeDetection;
  var template = meta.template;
  var templateBuilder = new TemplateDefinitionBuilder(constantPool, BindingScope.createRootScope(), 0, templateTypeName, null, null, templateName, directiveMatcher, directivesUsed, meta.pipes, pipesUsed, Identifiers$1.namespaceHTML, meta.relativeContextFilePath, meta.i18nUseExternalIds);
  var templateFunctionExpression = templateBuilder.buildTemplateFunction(template.nodes, []); // We need to provide this so that dynamically generated components know what
  // projected content blocks to pass through to the component when it is instantiated.

  var ngContentSelectors = templateBuilder.getNgContentSelectors();

  if (ngContentSelectors) {
    definitionMap.set('ngContentSelectors', ngContentSelectors);
  } // e.g. `decls: 2`


  definitionMap.set('decls', literal(templateBuilder.getConstCount())); // e.g. `vars: 2`

  definitionMap.set('vars', literal(templateBuilder.getVarCount())); // Generate `consts` section of ComponentDef:
  // - either as an array:
  //   `consts: [['one', 'two'], ['three', 'four']]`
  // - or as a factory function in case additional statements are present (to support i18n):
  //   `consts: function() { var i18n_0; if (ngI18nClosureMode) {...} else {...} return [i18n_0]; }`

  var _templateBuilder$getC = templateBuilder.getConsts(),
      constExpressions = _templateBuilder$getC.constExpressions,
      prepareStatements = _templateBuilder$getC.prepareStatements;

  if (constExpressions.length > 0) {
    var constsExpr = literalArr(constExpressions); // Prepare statements are present - turn `consts` into a function.

    if (prepareStatements.length > 0) {
      constsExpr = fn([], [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(prepareStatements), [new ReturnStatement(constsExpr)]));
    }

    definitionMap.set('consts', constsExpr);
  }

  definitionMap.set('template', templateFunctionExpression); // e.g. `directives: [MyDirective]`

  if (directivesUsed.size) {
    var directivesExpr = literalArr(Array.from(directivesUsed));

    if (meta.wrapDirectivesAndPipesInClosure) {
      directivesExpr = fn([], [new ReturnStatement(directivesExpr)]);
    }

    definitionMap.set('directives', directivesExpr);
  } // e.g. `pipes: [MyPipe]`


  if (pipesUsed.size) {
    var pipesExpr = literalArr(Array.from(pipesUsed));

    if (meta.wrapDirectivesAndPipesInClosure) {
      pipesExpr = fn([], [new ReturnStatement(pipesExpr)]);
    }

    definitionMap.set('pipes', pipesExpr);
  }

  if (meta.encapsulation === null) {
    meta.encapsulation = ViewEncapsulation.Emulated;
  } // e.g. `styles: [str1, str2]`


  if (meta.styles && meta.styles.length) {
    var styleValues = meta.encapsulation == ViewEncapsulation.Emulated ? compileStyles(meta.styles, CONTENT_ATTR, HOST_ATTR) : meta.styles;
    var strings = styleValues.map(function (str) {
      return constantPool.getConstLiteral(literal(str));
    });
    definitionMap.set('styles', literalArr(strings));
  } else if (meta.encapsulation === ViewEncapsulation.Emulated) {
    // If there is no style, don't generate css selectors on elements
    meta.encapsulation = ViewEncapsulation.None;
  } // Only set view encapsulation if it's not the default value


  if (meta.encapsulation !== ViewEncapsulation.Emulated) {
    definitionMap.set('encapsulation', literal(meta.encapsulation));
  } // e.g. `animation: [trigger('123', [])]`


  if (meta.animations !== null) {
    definitionMap.set('data', literalMap([{
      key: 'animation',
      value: meta.animations,
      quoted: false
    }]));
  } // Only set the change detection flag if it's defined and it's not the default.


  if (changeDetection != null && changeDetection !== ChangeDetectionStrategy.Default) {
    definitionMap.set('changeDetection', literal(changeDetection));
  }

  var expression = importExpr(Identifiers$1.defineComponent).callFn([definitionMap.toLiteralMap()]);
  var typeParams = createDirectiveTypeParams(meta);
  typeParams.push(stringArrayAsType(meta.template.ngContentSelectors));
  var type = expressionType(importExpr(Identifiers$1.ComponentDefWithMeta, typeParams));
  return {
    expression: expression,
    type: type
  };
}
/**
 * A wrapper around `compileDirective` which depends on render2 global analysis data as its input
 * instead of the `R3DirectiveMetadata`.
 *
 * `R3DirectiveMetadata` is computed from `CompileDirectiveMetadata` and other statically reflected
 * information.
 */


function compileDirectiveFromRender2(outputCtx, directive, reflector, bindingParser) {
  var name = identifierName(directive.type);
  name || error("Cannot resolver the name of ".concat(directive.type));
  var definitionField = outputCtx.constantPool.propertyNameOf(1
  /* Directive */
  );
  var meta = directiveMetadataFromGlobalMetadata(directive, outputCtx, reflector);
  var res = compileDirectiveFromMetadata(meta, outputCtx.constantPool, bindingParser);
  var factoryRes = compileFactoryFunction(Object.assign(Object.assign({}, meta), {
    injectFn: Identifiers$1.directiveInject,
    target: R3FactoryTarget.Directive
  }));
  var ngFactoryDefStatement = new ClassStmt(name, null, [new ClassField('ɵfac', INFERRED_TYPE, [StmtModifier.Static], factoryRes.factory)], [], new ClassMethod(null, [], []), []);
  var directiveDefStatement = new ClassStmt(name, null, [new ClassField(definitionField, INFERRED_TYPE, [StmtModifier.Static], res.expression)], [], new ClassMethod(null, [], []), []); // Create the partial class to be merged with the actual class.

  outputCtx.statements.push(ngFactoryDefStatement, directiveDefStatement);
}
/**
 * A wrapper around `compileComponent` which depends on render2 global analysis data as its input
 * instead of the `R3DirectiveMetadata`.
 *
 * `R3ComponentMetadata` is computed from `CompileDirectiveMetadata` and other statically reflected
 * information.
 */


function compileComponentFromRender2(outputCtx, component, render3Ast, reflector, bindingParser, directiveTypeBySel, pipeTypeByName) {
  var name = identifierName(component.type);
  name || error("Cannot resolver the name of ".concat(component.type));
  var definitionField = outputCtx.constantPool.propertyNameOf(2
  /* Component */
  );
  var summary = component.toSummary(); // Compute the R3ComponentMetadata from the CompileDirectiveMetadata

  var meta = Object.assign(Object.assign({}, directiveMetadataFromGlobalMetadata(component, outputCtx, reflector)), {
    selector: component.selector,
    template: {
      nodes: render3Ast.nodes,
      ngContentSelectors: render3Ast.ngContentSelectors
    },
    directives: [],
    pipes: typeMapToExpressionMap(pipeTypeByName, outputCtx),
    viewQueries: queriesFromGlobalMetadata(component.viewQueries, outputCtx),
    wrapDirectivesAndPipesInClosure: false,
    styles: summary.template && summary.template.styles || EMPTY_ARRAY,
    encapsulation: summary.template && summary.template.encapsulation || ViewEncapsulation.Emulated,
    interpolation: DEFAULT_INTERPOLATION_CONFIG,
    animations: null,
    viewProviders: component.viewProviders.length > 0 ? new WrappedNodeExpr(component.viewProviders) : null,
    relativeContextFilePath: '',
    i18nUseExternalIds: true
  });
  var res = compileComponentFromMetadata(meta, outputCtx.constantPool, bindingParser);
  var factoryRes = compileFactoryFunction(Object.assign(Object.assign({}, meta), {
    injectFn: Identifiers$1.directiveInject,
    target: R3FactoryTarget.Directive
  }));
  var ngFactoryDefStatement = new ClassStmt(name, null, [new ClassField('ɵfac', INFERRED_TYPE, [StmtModifier.Static], factoryRes.factory)], [], new ClassMethod(null, [], []), []);
  var componentDefStatement = new ClassStmt(name, null, [new ClassField(definitionField, INFERRED_TYPE, [StmtModifier.Static], res.expression)], [], new ClassMethod(null, [], []), []); // Create the partial class to be merged with the actual class.

  outputCtx.statements.push(ngFactoryDefStatement, componentDefStatement);
}
/**
 * Compute `R3DirectiveMetadata` given `CompileDirectiveMetadata` and a `CompileReflector`.
 */


function directiveMetadataFromGlobalMetadata(directive, outputCtx, reflector) {
  // The global-analysis based Ivy mode in ngc is no longer utilized/supported.
  throw new Error('unsupported');
}
/**
 * Convert `CompileQueryMetadata` into `R3QueryMetadata`.
 */


function queriesFromGlobalMetadata(queries, outputCtx) {
  return queries.map(function (query) {
    var read = null;

    if (query.read && query.read.identifier) {
      read = outputCtx.importExpr(query.read.identifier.reference);
    }

    return {
      propertyName: query.propertyName,
      first: query.first,
      predicate: selectorsFromGlobalMetadata(query.selectors, outputCtx),
      descendants: query.descendants,
      read: read,
      static: !!query.static
    };
  });
}
/**
 * Convert `CompileTokenMetadata` for query selectors into either an expression for a predicate
 * type, or a list of string predicates.
 */


function selectorsFromGlobalMetadata(selectors, outputCtx) {
  if (selectors.length > 1 || selectors.length == 1 && selectors[0].value) {
    var selectorStrings = selectors.map(function (value) {
      return value.value;
    });
    selectorStrings.some(function (value) {
      return !value;
    }) && error('Found a type among the string selectors expected');
    return outputCtx.constantPool.getConstLiteral(literalArr(selectorStrings.map(function (value) {
      return literal(value);
    })));
  }

  if (selectors.length == 1) {
    var first = selectors[0];

    if (first.identifier) {
      return outputCtx.importExpr(first.identifier.reference);
    }
  }

  error('Unexpected query form');
  return NULL_EXPR;
}

function prepareQueryParams(query, constantPool) {
  var parameters = [getQueryPredicate(query, constantPool), literal(query.descendants)];

  if (query.read) {
    parameters.push(query.read);
  }

  return parameters;
}

function convertAttributesToExpressions(attributes) {
  var values = [];

  var _iterator16 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(Object.getOwnPropertyNames(attributes)),
      _step16;

  try {
    for (_iterator16.s(); !(_step16 = _iterator16.n()).done;) {
      var key = _step16.value;
      var value = attributes[key];
      values.push(literal(key), value);
    }
  } catch (err) {
    _iterator16.e(err);
  } finally {
    _iterator16.f();
  }

  return values;
} // Define and update any content queries


function createContentQueriesFunction(queries, constantPool, name) {
  var createStatements = [];
  var updateStatements = [];
  var tempAllocator = temporaryAllocator(updateStatements, TEMPORARY_NAME);

  var _iterator17 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(queries),
      _step17;

  try {
    for (_iterator17.s(); !(_step17 = _iterator17.n()).done;) {
      var query = _step17.value;
      var queryInstruction = query.static ? Identifiers$1.staticContentQuery : Identifiers$1.contentQuery; // creation, e.g. r3.contentQuery(dirIndex, somePredicate, true, null);

      createStatements.push(importExpr(queryInstruction).callFn([variable('dirIndex')].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(prepareQueryParams(query, constantPool)))).toStmt()); // update, e.g. (r3.queryRefresh(tmp = r3.loadQuery()) && (ctx.someDir = tmp));

      var temporary = tempAllocator();
      var getQueryList = importExpr(Identifiers$1.loadQuery).callFn([]);
      var refresh = importExpr(Identifiers$1.queryRefresh).callFn([temporary.set(getQueryList)]);
      var updateDirective = variable(CONTEXT_NAME).prop(query.propertyName).set(query.first ? temporary.prop('first') : temporary);
      updateStatements.push(refresh.and(updateDirective).toStmt());
    }
  } catch (err) {
    _iterator17.e(err);
  } finally {
    _iterator17.f();
  }

  var contentQueriesFnName = name ? "".concat(name, "_ContentQueries") : null;
  return fn([new FnParam(RENDER_FLAGS, NUMBER_TYPE), new FnParam(CONTEXT_NAME, null), new FnParam('dirIndex', null)], [renderFlagCheckIfStmt(1
  /* Create */
  , createStatements), renderFlagCheckIfStmt(2
  /* Update */
  , updateStatements)], INFERRED_TYPE, null, contentQueriesFnName);
}

function stringAsType(str) {
  return expressionType(literal(str));
}

function stringMapAsType(map) {
  var mapValues = Object.keys(map).map(function (key) {
    var value = Array.isArray(map[key]) ? map[key][0] : map[key];
    return {
      key: key,
      value: literal(value),
      quoted: true
    };
  });
  return expressionType(literalMap(mapValues));
}

function stringArrayAsType(arr) {
  return arr.length > 0 ? expressionType(literalArr(arr.map(function (value) {
    return literal(value);
  }))) : NONE_TYPE;
}

function createDirectiveTypeParams(meta) {
  // On the type side, remove newlines from the selector as it will need to fit into a TypeScript
  // string literal, which must be on one line.
  var selectorForType = meta.selector !== null ? meta.selector.replace(/\n/g, '') : null;
  return [typeWithParameters(meta.type.type, meta.typeArgumentCount), selectorForType !== null ? stringAsType(selectorForType) : NONE_TYPE, meta.exportAs !== null ? stringArrayAsType(meta.exportAs) : NONE_TYPE, stringMapAsType(meta.inputs), stringMapAsType(meta.outputs), stringArrayAsType(meta.queries.map(function (q) {
    return q.propertyName;
  }))];
} // Define and update any view queries


function createViewQueriesFunction(viewQueries, constantPool, name) {
  var createStatements = [];
  var updateStatements = [];
  var tempAllocator = temporaryAllocator(updateStatements, TEMPORARY_NAME);
  viewQueries.forEach(function (query) {
    var queryInstruction = query.static ? Identifiers$1.staticViewQuery : Identifiers$1.viewQuery; // creation, e.g. r3.viewQuery(somePredicate, true);

    var queryDefinition = importExpr(queryInstruction).callFn(prepareQueryParams(query, constantPool));
    createStatements.push(queryDefinition.toStmt()); // update, e.g. (r3.queryRefresh(tmp = r3.loadQuery()) && (ctx.someDir = tmp));

    var temporary = tempAllocator();
    var getQueryList = importExpr(Identifiers$1.loadQuery).callFn([]);
    var refresh = importExpr(Identifiers$1.queryRefresh).callFn([temporary.set(getQueryList)]);
    var updateDirective = variable(CONTEXT_NAME).prop(query.propertyName).set(query.first ? temporary.prop('first') : temporary);
    updateStatements.push(refresh.and(updateDirective).toStmt());
  });
  var viewQueryFnName = name ? "".concat(name, "_Query") : null;
  return fn([new FnParam(RENDER_FLAGS, NUMBER_TYPE), new FnParam(CONTEXT_NAME, null)], [renderFlagCheckIfStmt(1
  /* Create */
  , createStatements), renderFlagCheckIfStmt(2
  /* Update */
  , updateStatements)], INFERRED_TYPE, null, viewQueryFnName);
} // Return a host binding function or null if one is not necessary.


function createHostBindingsFunction(hostBindingsMetadata, typeSourceSpan, bindingParser, constantPool, selector, name, definitionMap) {
  var bindingContext = variable(CONTEXT_NAME);
  var styleBuilder = new StylingBuilder(bindingContext);
  var _hostBindingsMetadata = hostBindingsMetadata.specialAttributes,
      styleAttr = _hostBindingsMetadata.styleAttr,
      classAttr = _hostBindingsMetadata.classAttr;

  if (styleAttr !== undefined) {
    styleBuilder.registerStyleAttr(styleAttr);
  }

  if (classAttr !== undefined) {
    styleBuilder.registerClassAttr(classAttr);
  }

  var createStatements = [];
  var updateStatements = [];
  var hostBindingSourceSpan = typeSourceSpan;
  var directiveSummary = metadataAsSummary(hostBindingsMetadata); // Calculate host event bindings

  var eventBindings = bindingParser.createDirectiveHostEventAsts(directiveSummary, hostBindingSourceSpan);

  if (eventBindings && eventBindings.length) {
    var listeners = createHostListeners(eventBindings, name);
    createStatements.push.apply(createStatements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(listeners));
  } // Calculate the host property bindings


  var bindings = bindingParser.createBoundHostProperties(directiveSummary, hostBindingSourceSpan);
  var allOtherBindings = []; // We need to calculate the total amount of binding slots required by
  // all the instructions together before any value conversions happen.
  // Value conversions may require additional slots for interpolation and
  // bindings with pipes. These calculates happen after this block.

  var totalHostVarsCount = 0;
  bindings && bindings.forEach(function (binding) {
    var name = binding.name;
    var stylingInputWasSet = styleBuilder.registerInputBasedOnName(name, binding.expression, binding.sourceSpan);

    if (stylingInputWasSet) {
      totalHostVarsCount += MIN_STYLING_BINDING_SLOTS_REQUIRED;
    } else {
      allOtherBindings.push(binding);
      totalHostVarsCount++;
    }
  });
  var valueConverter;

  var getValueConverter = function getValueConverter() {
    if (!valueConverter) {
      var hostVarsCountFn = function hostVarsCountFn(numSlots) {
        var originalVarsCount = totalHostVarsCount;
        totalHostVarsCount += numSlots;
        return originalVarsCount;
      };

      valueConverter = new ValueConverter(constantPool, function () {
        return error('Unexpected node');
      }, // new nodes are illegal here
      hostVarsCountFn, function () {
        return error('Unexpected pipe');
      }); // pipes are illegal here
    }

    return valueConverter;
  };

  var propertyBindings = [];
  var attributeBindings = [];
  var syntheticHostBindings = [];
  allOtherBindings.forEach(function (binding) {
    // resolve literal arrays and literal objects
    var value = binding.expression.visit(getValueConverter());
    var bindingExpr = bindingFn(bindingContext, value);

    var _getBindingNameAndIns = getBindingNameAndInstruction(binding),
        bindingName = _getBindingNameAndIns.bindingName,
        instruction = _getBindingNameAndIns.instruction,
        isAttribute = _getBindingNameAndIns.isAttribute;

    var securityContexts = bindingParser.calcPossibleSecurityContexts(selector, bindingName, isAttribute).filter(function (context) {
      return context !== SecurityContext.NONE;
    });
    var sanitizerFn = null;

    if (securityContexts.length) {
      if (securityContexts.length === 2 && securityContexts.indexOf(SecurityContext.URL) > -1 && securityContexts.indexOf(SecurityContext.RESOURCE_URL) > -1) {
        // Special case for some URL attributes (such as "src" and "href") that may be a part
        // of different security contexts. In this case we use special santitization function and
        // select the actual sanitizer at runtime based on a tag name that is provided while
        // invoking sanitization function.
        sanitizerFn = importExpr(Identifiers$1.sanitizeUrlOrResourceUrl);
      } else {
        sanitizerFn = resolveSanitizationFn(securityContexts[0], isAttribute);
      }
    }

    var instructionParams = [literal(bindingName), bindingExpr.currValExpr];

    if (sanitizerFn) {
      instructionParams.push(sanitizerFn);
    }

    updateStatements.push.apply(updateStatements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(bindingExpr.stmts));

    if (instruction === Identifiers$1.hostProperty) {
      propertyBindings.push(instructionParams);
    } else if (instruction === Identifiers$1.attribute) {
      attributeBindings.push(instructionParams);
    } else if (instruction === Identifiers$1.syntheticHostProperty) {
      syntheticHostBindings.push(instructionParams);
    } else {
      updateStatements.push(importExpr(instruction).callFn(instructionParams).toStmt());
    }
  });

  if (propertyBindings.length > 0) {
    updateStatements.push(chainedInstruction(Identifiers$1.hostProperty, propertyBindings).toStmt());
  }

  if (attributeBindings.length > 0) {
    updateStatements.push(chainedInstruction(Identifiers$1.attribute, attributeBindings).toStmt());
  }

  if (syntheticHostBindings.length > 0) {
    updateStatements.push(chainedInstruction(Identifiers$1.syntheticHostProperty, syntheticHostBindings).toStmt());
  } // since we're dealing with directives/components and both have hostBinding
  // functions, we need to generate a special hostAttrs instruction that deals
  // with both the assignment of styling as well as static attributes to the host
  // element. The instruction below will instruct all initial styling (styling
  // that is inside of a host binding within a directive/component) to be attached
  // to the host element alongside any of the provided host attributes that were
  // collected earlier.


  var hostAttrs = convertAttributesToExpressions(hostBindingsMetadata.attributes);
  styleBuilder.assignHostAttrs(hostAttrs, definitionMap);

  if (styleBuilder.hasBindings) {
    // finally each binding that was registered in the statement above will need to be added to
    // the update block of a component/directive templateFn/hostBindingsFn so that the bindings
    // are evaluated and updated for the element.
    styleBuilder.buildUpdateLevelInstructions(getValueConverter()).forEach(function (instruction) {
      if (instruction.calls.length > 0) {
        var calls = [];
        instruction.calls.forEach(function (call) {
          // we subtract a value of `1` here because the binding slot was already allocated
          // at the top of this method when all the input bindings were counted.
          totalHostVarsCount += Math.max(call.allocateBindingSlots - MIN_STYLING_BINDING_SLOTS_REQUIRED, 0);
          calls.push(convertStylingCall(call, bindingContext, bindingFn));
        });
        updateStatements.push(chainedInstruction(instruction.reference, calls).toStmt());
      }
    });
  }

  if (totalHostVarsCount) {
    definitionMap.set('hostVars', literal(totalHostVarsCount));
  }

  if (createStatements.length > 0 || updateStatements.length > 0) {
    var hostBindingsFnName = name ? "".concat(name, "_HostBindings") : null;
    var statements = [];

    if (createStatements.length > 0) {
      statements.push(renderFlagCheckIfStmt(1
      /* Create */
      , createStatements));
    }

    if (updateStatements.length > 0) {
      statements.push(renderFlagCheckIfStmt(2
      /* Update */
      , updateStatements));
    }

    return fn([new FnParam(RENDER_FLAGS, NUMBER_TYPE), new FnParam(CONTEXT_NAME, null)], statements, INFERRED_TYPE, null, hostBindingsFnName);
  }

  return null;
}

function bindingFn(implicit, value) {
  return _convertPropertyBinding(null, implicit, value, 'b', BindingForm.Expression, function () {
    return error('Unexpected interpolation');
  });
}

function convertStylingCall(call, bindingContext, bindingFn) {
  return call.params(function (value) {
    return bindingFn(bindingContext, value).currValExpr;
  });
}

function getBindingNameAndInstruction(binding) {
  var bindingName = binding.name;
  var instruction; // Check to see if this is an attr binding or a property binding

  var attrMatches = bindingName.match(ATTR_REGEX);

  if (attrMatches) {
    bindingName = attrMatches[1];
    instruction = Identifiers$1.attribute;
  } else {
    if (binding.isAnimation) {
      bindingName = prepareSyntheticPropertyName(bindingName); // host bindings that have a synthetic property (e.g. @foo) should always be rendered
      // in the context of the component and not the parent. Therefore there is a special
      // compatibility instruction available for this purpose.

      instruction = Identifiers$1.syntheticHostProperty;
    } else {
      instruction = Identifiers$1.hostProperty;
    }
  }

  return {
    bindingName: bindingName,
    instruction: instruction,
    isAttribute: !!attrMatches
  };
}

function createHostListeners(eventBindings, name) {
  var listeners = [];
  var syntheticListeners = [];
  var instructions = [];
  eventBindings.forEach(function (binding) {
    var bindingName = binding.name && sanitizeIdentifier(binding.name);
    var bindingFnName = binding.type === 1
    /* Animation */
    ? prepareSyntheticListenerFunctionName(bindingName, binding.targetOrPhase) : bindingName;
    var handlerName = name && bindingName ? "".concat(name, "_").concat(bindingFnName, "_HostBindingHandler") : null;
    var params = prepareEventListenerParameters(BoundEvent.fromParsedEvent(binding), handlerName);

    if (binding.type == 1
    /* Animation */
    ) {
        syntheticListeners.push(params);
      } else {
      listeners.push(params);
    }
  });

  if (syntheticListeners.length > 0) {
    instructions.push(chainedInstruction(Identifiers$1.syntheticHostListener, syntheticListeners).toStmt());
  }

  if (listeners.length > 0) {
    instructions.push(chainedInstruction(Identifiers$1.listener, listeners).toStmt());
  }

  return instructions;
}

function metadataAsSummary(meta) {
  // clang-format off
  return {
    // This is used by the BindingParser, which only deals with listeners and properties. There's no
    // need to pass attributes to it.
    hostAttributes: {},
    hostListeners: meta.listeners,
    hostProperties: meta.properties
  }; // clang-format on
}

function typeMapToExpressionMap(map, outputCtx) {
  // Convert each map entry into another entry where the value is an expression importing the type.
  var entries = Array.from(map).map(function (_ref19) {
    var _ref20 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_ref19, 2),
        key = _ref20[0],
        type = _ref20[1];

    return [key, outputCtx.importExpr(type)];
  });
  return new Map(entries);
}

var HOST_REG_EXP$1 = /^(?:\[([^\]]+)\])|(?:\(([^\)]+)\))$/;

function parseHostBindings(host) {
  var attributes = {};
  var listeners = {};
  var properties = {};
  var specialAttributes = {};

  for (var _i8 = 0, _Object$keys2 = Object.keys(host); _i8 < _Object$keys2.length; _i8++) {
    var key = _Object$keys2[_i8];
    var value = host[key];
    var matches = key.match(HOST_REG_EXP$1);

    if (matches === null) {
      switch (key) {
        case 'class':
          if (typeof value !== 'string') {
            // TODO(alxhub): make this a diagnostic.
            throw new Error("Class binding must be string");
          }

          specialAttributes.classAttr = value;
          break;

        case 'style':
          if (typeof value !== 'string') {
            // TODO(alxhub): make this a diagnostic.
            throw new Error("Style binding must be string");
          }

          specialAttributes.styleAttr = value;
          break;

        default:
          if (typeof value === 'string') {
            attributes[key] = literal(value);
          } else {
            attributes[key] = value;
          }

      }
    } else if (matches[1
    /* Binding */
    ] != null) {
      if (typeof value !== 'string') {
        // TODO(alxhub): make this a diagnostic.
        throw new Error("Property binding must be string");
      } // synthetic properties (the ones that have a `@` as a prefix)
      // are still treated the same as regular properties. Therefore
      // there is no point in storing them in a separate map.


      properties[matches[1
      /* Binding */
      ]] = value;
    } else if (matches[2
    /* Event */
    ] != null) {
      if (typeof value !== 'string') {
        // TODO(alxhub): make this a diagnostic.
        throw new Error("Event binding must be string");
      }

      listeners[matches[2
      /* Event */
      ]] = value;
    }
  }

  return {
    attributes: attributes,
    listeners: listeners,
    properties: properties,
    specialAttributes: specialAttributes
  };
}
/**
 * Verifies host bindings and returns the list of errors (if any). Empty array indicates that a
 * given set of host bindings has no errors.
 *
 * @param bindings set of host bindings to verify.
 * @param sourceSpan source span where host bindings were defined.
 * @returns array of errors associated with a given set of host bindings.
 */


function verifyHostBindings(bindings, sourceSpan) {
  var summary = metadataAsSummary(bindings); // TODO: abstract out host bindings verification logic and use it instead of
  // creating events and properties ASTs to detect errors (FW-996)

  var bindingParser = makeBindingParser();
  bindingParser.createDirectiveHostEventAsts(summary, sourceSpan);
  bindingParser.createBoundHostProperties(summary, sourceSpan);
  return bindingParser.errors;
}

function compileStyles(styles, selector, hostSelector) {
  var shadowCss = new ShadowCss();
  return styles.map(function (style) {
    return shadowCss.shimCssText(style, selector, hostSelector);
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An interface for retrieving documents by URL that the compiler uses
 * to load templates.
 */


var ResourceLoader = /*#__PURE__*/function () {
  function ResourceLoader() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ResourceLoader);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ResourceLoader, [{
    key: "get",
    value: function get(url) {
      return '';
    }
  }]);

  return ResourceLoader;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CompilerFacadeImpl = /*#__PURE__*/function () {
  function CompilerFacadeImpl() {
    var jitEvaluator = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new JitEvaluator();

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompilerFacadeImpl);

    this.jitEvaluator = jitEvaluator;
    this.R3ResolvedDependencyType = R3ResolvedDependencyType;
    this.R3FactoryTarget = R3FactoryTarget;
    this.ResourceLoader = ResourceLoader;
    this.elementSchemaRegistry = new DomElementSchemaRegistry();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompilerFacadeImpl, [{
    key: "compilePipe",
    value: function compilePipe(angularCoreEnv, sourceMapUrl, facade) {
      var metadata = {
        name: facade.name,
        type: wrapReference$1(facade.type),
        internalType: new WrappedNodeExpr(facade.type),
        typeArgumentCount: facade.typeArgumentCount,
        deps: convertR3DependencyMetadataArray(facade.deps),
        pipeName: facade.pipeName,
        pure: facade.pure
      };
      var res = compilePipeFromMetadata(metadata);
      return this.jitExpression(res.expression, angularCoreEnv, sourceMapUrl, []);
    }
  }, {
    key: "compileInjectable",
    value: function compileInjectable(angularCoreEnv, sourceMapUrl, facade) {
      var _compileInjectable2 = _compileInjectable({
        name: facade.name,
        type: wrapReference$1(facade.type),
        internalType: new WrappedNodeExpr(facade.type),
        typeArgumentCount: facade.typeArgumentCount,
        providedIn: computeProvidedIn(facade.providedIn),
        useClass: wrapExpression(facade, USE_CLASS),
        useFactory: wrapExpression(facade, USE_FACTORY),
        useValue: wrapExpression(facade, USE_VALUE),
        useExisting: wrapExpression(facade, USE_EXISTING),
        userDeps: convertR3DependencyMetadataArray(facade.userDeps) || undefined
      }),
          expression = _compileInjectable2.expression,
          statements = _compileInjectable2.statements;

      return this.jitExpression(expression, angularCoreEnv, sourceMapUrl, statements);
    }
  }, {
    key: "compileInjector",
    value: function compileInjector(angularCoreEnv, sourceMapUrl, facade) {
      var meta = {
        name: facade.name,
        type: wrapReference$1(facade.type),
        internalType: new WrappedNodeExpr(facade.type),
        deps: convertR3DependencyMetadataArray(facade.deps),
        providers: new WrappedNodeExpr(facade.providers),
        imports: facade.imports.map(function (i) {
          return new WrappedNodeExpr(i);
        })
      };

      var res = _compileInjector(meta);

      return this.jitExpression(res.expression, angularCoreEnv, sourceMapUrl, res.statements);
    }
  }, {
    key: "compileNgModule",
    value: function compileNgModule(angularCoreEnv, sourceMapUrl, facade) {
      var meta = {
        type: wrapReference$1(facade.type),
        internalType: new WrappedNodeExpr(facade.type),
        adjacentType: new WrappedNodeExpr(facade.type),
        bootstrap: facade.bootstrap.map(wrapReference$1),
        declarations: facade.declarations.map(wrapReference$1),
        imports: facade.imports.map(wrapReference$1),
        exports: facade.exports.map(wrapReference$1),
        emitInline: true,
        containsForwardDecls: false,
        schemas: facade.schemas ? facade.schemas.map(wrapReference$1) : null,
        id: facade.id ? new WrappedNodeExpr(facade.id) : null
      };

      var res = _compileNgModule(meta);

      return this.jitExpression(res.expression, angularCoreEnv, sourceMapUrl, []);
    }
  }, {
    key: "compileDirective",
    value: function compileDirective(angularCoreEnv, sourceMapUrl, facade) {
      var constantPool = new ConstantPool();
      var bindingParser = makeBindingParser();
      var meta = convertDirectiveFacadeToMetadata(facade);
      var res = compileDirectiveFromMetadata(meta, constantPool, bindingParser);
      return this.jitExpression(res.expression, angularCoreEnv, sourceMapUrl, constantPool.statements);
    }
  }, {
    key: "compileComponent",
    value: function compileComponent(angularCoreEnv, sourceMapUrl, facade) {
      // The ConstantPool is a requirement of the JIT'er.
      var constantPool = new ConstantPool();
      var interpolationConfig = facade.interpolation ? InterpolationConfig.fromArray(facade.interpolation) : DEFAULT_INTERPOLATION_CONFIG; // Parse the template and check for errors.

      var template = parseTemplate(facade.template, sourceMapUrl, {
        preserveWhitespaces: facade.preserveWhitespaces,
        interpolationConfig: interpolationConfig
      });

      if (template.errors !== undefined) {
        var errors = template.errors.map(function (err) {
          return err.toString();
        }).join(', ');
        throw new Error("Errors during JIT compilation of template for ".concat(facade.name, ": ").concat(errors));
      } // Compile the component metadata, including template, into an expression.
      // TODO(alxhub): implement inputs, outputs, queries, etc.


      var metadata = Object.assign(Object.assign(Object.assign({}, facade), convertDirectiveFacadeToMetadata(facade)), {
        selector: facade.selector || this.elementSchemaRegistry.getDefaultComponentElementName(),
        template: template,
        wrapDirectivesAndPipesInClosure: false,
        styles: [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(facade.styles), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(template.styles)),
        encapsulation: facade.encapsulation,
        interpolation: interpolationConfig,
        changeDetection: facade.changeDetection,
        animations: facade.animations != null ? new WrappedNodeExpr(facade.animations) : null,
        viewProviders: facade.viewProviders != null ? new WrappedNodeExpr(facade.viewProviders) : null,
        relativeContextFilePath: '',
        i18nUseExternalIds: true
      });
      var res = compileComponentFromMetadata(metadata, constantPool, makeBindingParser(interpolationConfig));
      var jitExpressionSourceMap = "ng:///".concat(facade.name, ".js");
      return this.jitExpression(res.expression, angularCoreEnv, jitExpressionSourceMap, constantPool.statements);
    }
  }, {
    key: "compileFactory",
    value: function compileFactory(angularCoreEnv, sourceMapUrl, meta) {
      var factoryRes = compileFactoryFunction({
        name: meta.name,
        type: wrapReference$1(meta.type),
        internalType: new WrappedNodeExpr(meta.type),
        typeArgumentCount: meta.typeArgumentCount,
        deps: convertR3DependencyMetadataArray(meta.deps),
        injectFn: meta.injectFn === 'directiveInject' ? Identifiers.directiveInject : Identifiers.inject,
        target: meta.target
      });
      return this.jitExpression(factoryRes.factory, angularCoreEnv, sourceMapUrl, factoryRes.statements);
    }
  }, {
    key: "createParseSourceSpan",
    value: function createParseSourceSpan(kind, typeName, sourceUrl) {
      return r3JitTypeSourceSpan(kind, typeName, sourceUrl);
    }
    /**
     * JIT compiles an expression and returns the result of executing that expression.
     *
     * @param def the definition which will be compiled and executed to get the value to patch
     * @param context an object map of @angular/core symbol names to symbols which will be available
     * in the context of the compiled expression
     * @param sourceUrl a URL to use for the source map of the compiled expression
     * @param preStatements a collection of statements that should be evaluated before the expression.
     */

  }, {
    key: "jitExpression",
    value: function jitExpression(def, context, sourceUrl, preStatements) {
      // The ConstantPool may contain Statements which declare variables used in the final expression.
      // Therefore, its statements need to precede the actual JIT operation. The final statement is a
      // declaration of $def which is set to the expression being compiled.
      var statements = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(preStatements), [new DeclareVarStmt('$def', def, undefined, [StmtModifier.Exported])]);
      var res = this.jitEvaluator.evaluateStatements(sourceUrl, statements, new R3JitReflector(context),
      /* enableSourceMaps */
      true);
      return res['$def'];
    }
  }]);

  return CompilerFacadeImpl;
}();

var USE_CLASS = Object.keys({
  useClass: null
})[0];
var USE_FACTORY = Object.keys({
  useFactory: null
})[0];
var USE_VALUE = Object.keys({
  useValue: null
})[0];
var USE_EXISTING = Object.keys({
  useExisting: null
})[0];

var wrapReference$1 = function wrapReference$1(value) {
  var wrapped = new WrappedNodeExpr(value);
  return {
    value: wrapped,
    type: wrapped
  };
};

function convertToR3QueryMetadata(facade) {
  return Object.assign(Object.assign({}, facade), {
    predicate: Array.isArray(facade.predicate) ? facade.predicate : new WrappedNodeExpr(facade.predicate),
    read: facade.read ? new WrappedNodeExpr(facade.read) : null,
    static: facade.static
  });
}

function convertDirectiveFacadeToMetadata(facade) {
  var inputsFromMetadata = parseInputOutputs(facade.inputs || []);
  var outputsFromMetadata = parseInputOutputs(facade.outputs || []);
  var propMetadata = facade.propMetadata;
  var inputsFromType = {};
  var outputsFromType = {};

  var _loop = function _loop(field) {
    if (propMetadata.hasOwnProperty(field)) {
      propMetadata[field].forEach(function (ann) {
        if (isInput(ann)) {
          inputsFromType[field] = ann.bindingPropertyName ? [ann.bindingPropertyName, field] : field;
        } else if (isOutput(ann)) {
          outputsFromType[field] = ann.bindingPropertyName || field;
        }
      });
    }
  };

  for (var field in propMetadata) {
    _loop(field);
  }

  return Object.assign(Object.assign({}, facade), {
    typeSourceSpan: facade.typeSourceSpan,
    type: wrapReference$1(facade.type),
    internalType: new WrappedNodeExpr(facade.type),
    deps: convertR3DependencyMetadataArray(facade.deps),
    host: extractHostBindings(facade.propMetadata, facade.typeSourceSpan, facade.host),
    inputs: Object.assign(Object.assign({}, inputsFromMetadata), inputsFromType),
    outputs: Object.assign(Object.assign({}, outputsFromMetadata), outputsFromType),
    queries: facade.queries.map(convertToR3QueryMetadata),
    providers: facade.providers != null ? new WrappedNodeExpr(facade.providers) : null,
    viewQueries: facade.viewQueries.map(convertToR3QueryMetadata),
    fullInheritance: false
  });
}

function wrapExpression(obj, property) {
  if (obj.hasOwnProperty(property)) {
    return new WrappedNodeExpr(obj[property]);
  } else {
    return undefined;
  }
}

function computeProvidedIn(providedIn) {
  if (providedIn == null || typeof providedIn === 'string') {
    return new LiteralExpr(providedIn);
  } else {
    return new WrappedNodeExpr(providedIn);
  }
}

function convertR3DependencyMetadata(facade) {
  var tokenExpr;

  if (facade.token === null) {
    tokenExpr = new LiteralExpr(null);
  } else if (facade.resolved === R3ResolvedDependencyType.Attribute) {
    tokenExpr = new LiteralExpr(facade.token);
  } else {
    tokenExpr = new WrappedNodeExpr(facade.token);
  }

  return {
    token: tokenExpr,
    attribute: null,
    resolved: facade.resolved,
    host: facade.host,
    optional: facade.optional,
    self: facade.self,
    skipSelf: facade.skipSelf
  };
}

function convertR3DependencyMetadataArray(facades) {
  return facades == null ? null : facades.map(convertR3DependencyMetadata);
}

function extractHostBindings(propMetadata, sourceSpan, host) {
  // First parse the declarations from the metadata.
  var bindings = parseHostBindings(host || {}); // After that check host bindings for errors

  var errors = verifyHostBindings(bindings, sourceSpan);

  if (errors.length) {
    throw new Error(errors.map(function (error) {
      return error.msg;
    }).join('\n'));
  } // Next, loop over the properties of the object, looking for @HostBinding and @HostListener.


  var _loop2 = function _loop2(field) {
    if (propMetadata.hasOwnProperty(field)) {
      propMetadata[field].forEach(function (ann) {
        if (isHostBinding(ann)) {
          bindings.properties[ann.hostPropertyName || field] = field;
        } else if (isHostListener(ann)) {
          bindings.listeners[ann.eventName || field] = "".concat(field, "(").concat((ann.args || []).join(','), ")");
        }
      });
    }
  };

  for (var field in propMetadata) {
    _loop2(field);
  }

  return bindings;
}

function isHostBinding(value) {
  return value.ngMetadataName === 'HostBinding';
}

function isHostListener(value) {
  return value.ngMetadataName === 'HostListener';
}

function isInput(value) {
  return value.ngMetadataName === 'Input';
}

function isOutput(value) {
  return value.ngMetadataName === 'Output';
}

function parseInputOutputs(values) {
  return values.reduce(function (map, value) {
    var _value$split$map = value.split(',').map(function (piece) {
      return piece.trim();
    }),
        _value$split$map2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_value$split$map, 2),
        field = _value$split$map2[0],
        property = _value$split$map2[1];

    map[field] = property || field;
    return map;
  }, {});
}

function publishFacade(global) {
  var ng = global.ng || (global.ng = {});
  ng.ɵcompilerFacade = new CompilerFacadeImpl();
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var VERSION$1 = new Version('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var CompilerConfig = function CompilerConfig() {
  var _ref21 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref21$defaultEncapsu = _ref21.defaultEncapsulation,
      defaultEncapsulation = _ref21$defaultEncapsu === void 0 ? ViewEncapsulation.Emulated : _ref21$defaultEncapsu,
      _ref21$useJit = _ref21.useJit,
      useJit = _ref21$useJit === void 0 ? true : _ref21$useJit,
      _ref21$jitDevMode = _ref21.jitDevMode,
      jitDevMode = _ref21$jitDevMode === void 0 ? false : _ref21$jitDevMode,
      _ref21$missingTransla = _ref21.missingTranslation,
      missingTranslation = _ref21$missingTransla === void 0 ? null : _ref21$missingTransla,
      preserveWhitespaces = _ref21.preserveWhitespaces,
      strictInjectionParameters = _ref21.strictInjectionParameters;

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompilerConfig);

  this.defaultEncapsulation = defaultEncapsulation;
  this.useJit = !!useJit;
  this.jitDevMode = !!jitDevMode;
  this.missingTranslation = missingTranslation;
  this.preserveWhitespaces = preserveWhitespacesDefault(noUndefined(preserveWhitespaces));
  this.strictInjectionParameters = strictInjectionParameters === true;
};

function preserveWhitespacesDefault(preserveWhitespacesOption) {
  var defaultSetting = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  return preserveWhitespacesOption === null ? defaultSetting : preserveWhitespacesOption;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var DirectiveNormalizer = /*#__PURE__*/function () {
  function DirectiveNormalizer(_resourceLoader, _urlResolver, _htmlParser, _config) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DirectiveNormalizer);

    this._resourceLoader = _resourceLoader;
    this._urlResolver = _urlResolver;
    this._htmlParser = _htmlParser;
    this._config = _config;
    this._resourceLoaderCache = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DirectiveNormalizer, [{
    key: "clearCache",
    value: function clearCache() {
      this._resourceLoaderCache.clear();
    }
  }, {
    key: "clearCacheFor",
    value: function clearCacheFor(normalizedDirective) {
      var _this190 = this;

      if (!normalizedDirective.isComponent) {
        return;
      }

      var template = normalizedDirective.template;

      this._resourceLoaderCache.delete(template.templateUrl);

      template.externalStylesheets.forEach(function (stylesheet) {
        _this190._resourceLoaderCache.delete(stylesheet.moduleUrl);
      });
    }
  }, {
    key: "_fetch",
    value: function _fetch(url) {
      var result = this._resourceLoaderCache.get(url);

      if (!result) {
        result = this._resourceLoader.get(url);

        this._resourceLoaderCache.set(url, result);
      }

      return result;
    }
  }, {
    key: "normalizeTemplate",
    value: function normalizeTemplate(prenormData) {
      var _this191 = this;

      if (isDefined(prenormData.template)) {
        if (isDefined(prenormData.templateUrl)) {
          throw syntaxError("'".concat(stringify(prenormData.componentType), "' component cannot define both template and templateUrl"));
        }

        if (typeof prenormData.template !== 'string') {
          throw syntaxError("The template specified for component ".concat(stringify(prenormData.componentType), " is not a string"));
        }
      } else if (isDefined(prenormData.templateUrl)) {
        if (typeof prenormData.templateUrl !== 'string') {
          throw syntaxError("The templateUrl specified for component ".concat(stringify(prenormData.componentType), " is not a string"));
        }
      } else {
        throw syntaxError("No template specified for component ".concat(stringify(prenormData.componentType)));
      }

      if (isDefined(prenormData.preserveWhitespaces) && typeof prenormData.preserveWhitespaces !== 'boolean') {
        throw syntaxError("The preserveWhitespaces option for component ".concat(stringify(prenormData.componentType), " must be a boolean"));
      }

      return SyncAsync.then(this._preParseTemplate(prenormData), function (preparsedTemplate) {
        return _this191._normalizeTemplateMetadata(prenormData, preparsedTemplate);
      });
    }
  }, {
    key: "_preParseTemplate",
    value: function _preParseTemplate(prenomData) {
      var _this192 = this;

      var template;
      var templateUrl;

      if (prenomData.template != null) {
        template = prenomData.template;
        templateUrl = prenomData.moduleUrl;
      } else {
        templateUrl = this._urlResolver.resolve(prenomData.moduleUrl, prenomData.templateUrl);
        template = this._fetch(templateUrl);
      }

      return SyncAsync.then(template, function (template) {
        return _this192._preparseLoadedTemplate(prenomData, template, templateUrl);
      });
    }
  }, {
    key: "_preparseLoadedTemplate",
    value: function _preparseLoadedTemplate(prenormData, template, templateAbsUrl) {
      var isInline = !!prenormData.template;
      var interpolationConfig = InterpolationConfig.fromArray(prenormData.interpolation);
      var templateUrl = templateSourceUrl({
        reference: prenormData.ngModuleType
      }, {
        type: {
          reference: prenormData.componentType
        }
      }, {
        isInline: isInline,
        templateUrl: templateAbsUrl
      });

      var rootNodesAndErrors = this._htmlParser.parse(template, templateUrl, {
        tokenizeExpansionForms: true,
        interpolationConfig: interpolationConfig
      });

      if (rootNodesAndErrors.errors.length > 0) {
        var errorString = rootNodesAndErrors.errors.join('\n');
        throw syntaxError("Template parse errors:\n".concat(errorString));
      }

      var templateMetadataStyles = this._normalizeStylesheet(new CompileStylesheetMetadata({
        styles: prenormData.styles,
        moduleUrl: prenormData.moduleUrl
      }));

      var visitor = new TemplatePreparseVisitor();
      visitAll$1(visitor, rootNodesAndErrors.rootNodes);

      var templateStyles = this._normalizeStylesheet(new CompileStylesheetMetadata({
        styles: visitor.styles,
        styleUrls: visitor.styleUrls,
        moduleUrl: templateAbsUrl
      }));

      var styles = templateMetadataStyles.styles.concat(templateStyles.styles);
      var inlineStyleUrls = templateMetadataStyles.styleUrls.concat(templateStyles.styleUrls);

      var styleUrls = this._normalizeStylesheet(new CompileStylesheetMetadata({
        styleUrls: prenormData.styleUrls,
        moduleUrl: prenormData.moduleUrl
      })).styleUrls;

      return {
        template: template,
        templateUrl: templateAbsUrl,
        isInline: isInline,
        htmlAst: rootNodesAndErrors,
        styles: styles,
        inlineStyleUrls: inlineStyleUrls,
        styleUrls: styleUrls,
        ngContentSelectors: visitor.ngContentSelectors
      };
    }
  }, {
    key: "_normalizeTemplateMetadata",
    value: function _normalizeTemplateMetadata(prenormData, preparsedTemplate) {
      var _this193 = this;

      return SyncAsync.then(this._loadMissingExternalStylesheets(preparsedTemplate.styleUrls.concat(preparsedTemplate.inlineStyleUrls)), function (externalStylesheets) {
        return _this193._normalizeLoadedTemplateMetadata(prenormData, preparsedTemplate, externalStylesheets);
      });
    }
  }, {
    key: "_normalizeLoadedTemplateMetadata",
    value: function _normalizeLoadedTemplateMetadata(prenormData, preparsedTemplate, stylesheets) {
      var _this194 = this;

      // Algorithm:
      // - produce exactly 1 entry per original styleUrl in
      // CompileTemplateMetadata.externalStylesheets with all styles inlined
      // - inline all styles that are referenced by the template into CompileTemplateMetadata.styles.
      // Reason: be able to determine how many stylesheets there are even without loading
      // the template nor the stylesheets, so we can create a stub for TypeScript always synchronously
      // (as resource loading may be async)
      var styles = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(preparsedTemplate.styles);

      this._inlineStyles(preparsedTemplate.inlineStyleUrls, stylesheets, styles);

      var styleUrls = preparsedTemplate.styleUrls;
      var externalStylesheets = styleUrls.map(function (styleUrl) {
        var stylesheet = stylesheets.get(styleUrl);

        var styles = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(stylesheet.styles);

        _this194._inlineStyles(stylesheet.styleUrls, stylesheets, styles);

        return new CompileStylesheetMetadata({
          moduleUrl: styleUrl,
          styles: styles
        });
      });
      var encapsulation = prenormData.encapsulation;

      if (encapsulation == null) {
        encapsulation = this._config.defaultEncapsulation;
      }

      if (encapsulation === ViewEncapsulation.Emulated && styles.length === 0 && styleUrls.length === 0) {
        encapsulation = ViewEncapsulation.None;
      }

      return new CompileTemplateMetadata({
        encapsulation: encapsulation,
        template: preparsedTemplate.template,
        templateUrl: preparsedTemplate.templateUrl,
        htmlAst: preparsedTemplate.htmlAst,
        styles: styles,
        styleUrls: styleUrls,
        ngContentSelectors: preparsedTemplate.ngContentSelectors,
        animations: prenormData.animations,
        interpolation: prenormData.interpolation,
        isInline: preparsedTemplate.isInline,
        externalStylesheets: externalStylesheets,
        preserveWhitespaces: preserveWhitespacesDefault(prenormData.preserveWhitespaces, this._config.preserveWhitespaces)
      });
    }
  }, {
    key: "_inlineStyles",
    value: function _inlineStyles(styleUrls, stylesheets, targetStyles) {
      var _this195 = this;

      styleUrls.forEach(function (styleUrl) {
        var stylesheet = stylesheets.get(styleUrl);
        stylesheet.styles.forEach(function (style) {
          return targetStyles.push(style);
        });

        _this195._inlineStyles(stylesheet.styleUrls, stylesheets, targetStyles);
      });
    }
  }, {
    key: "_loadMissingExternalStylesheets",
    value: function _loadMissingExternalStylesheets(styleUrls) {
      var _this196 = this;

      var loadedStylesheets = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Map();
      return SyncAsync.then(SyncAsync.all(styleUrls.filter(function (styleUrl) {
        return !loadedStylesheets.has(styleUrl);
      }).map(function (styleUrl) {
        return SyncAsync.then(_this196._fetch(styleUrl), function (loadedStyle) {
          var stylesheet = _this196._normalizeStylesheet(new CompileStylesheetMetadata({
            styles: [loadedStyle],
            moduleUrl: styleUrl
          }));

          loadedStylesheets.set(styleUrl, stylesheet);
          return _this196._loadMissingExternalStylesheets(stylesheet.styleUrls, loadedStylesheets);
        });
      })), function (_) {
        return loadedStylesheets;
      });
    }
  }, {
    key: "_normalizeStylesheet",
    value: function _normalizeStylesheet(stylesheet) {
      var _this197 = this;

      var moduleUrl = stylesheet.moduleUrl;
      var allStyleUrls = stylesheet.styleUrls.filter(isStyleUrlResolvable).map(function (url) {
        return _this197._urlResolver.resolve(moduleUrl, url);
      });
      var allStyles = stylesheet.styles.map(function (style) {
        var styleWithImports = extractStyleUrls(_this197._urlResolver, moduleUrl, style);
        allStyleUrls.push.apply(allStyleUrls, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(styleWithImports.styleUrls));
        return styleWithImports.style;
      });
      return new CompileStylesheetMetadata({
        styles: allStyles,
        styleUrls: allStyleUrls,
        moduleUrl: moduleUrl
      });
    }
  }]);

  return DirectiveNormalizer;
}();

var TemplatePreparseVisitor = /*#__PURE__*/function () {
  function TemplatePreparseVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplatePreparseVisitor);

    this.ngContentSelectors = [];
    this.styles = [];
    this.styleUrls = [];
    this.ngNonBindableStackCount = 0;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TemplatePreparseVisitor, [{
    key: "visitElement",
    value: function visitElement(ast, context) {
      var preparsedElement = preparseElement(ast);

      switch (preparsedElement.type) {
        case PreparsedElementType.NG_CONTENT:
          if (this.ngNonBindableStackCount === 0) {
            this.ngContentSelectors.push(preparsedElement.selectAttr);
          }

          break;

        case PreparsedElementType.STYLE:
          var textContent = '';
          ast.children.forEach(function (child) {
            if (child instanceof Text$3) {
              textContent += child.value;
            }
          });
          this.styles.push(textContent);
          break;

        case PreparsedElementType.STYLESHEET:
          this.styleUrls.push(preparsedElement.hrefAttr);
          break;

        default:
          break;
      }

      if (preparsedElement.nonBindable) {
        this.ngNonBindableStackCount++;
      }

      visitAll$1(this, ast.children);

      if (preparsedElement.nonBindable) {
        this.ngNonBindableStackCount--;
      }

      return null;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(ast, context) {
      visitAll$1(this, ast.cases);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(ast, context) {
      visitAll$1(this, ast.expression);
    }
  }, {
    key: "visitComment",
    value: function visitComment(ast, context) {
      return null;
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(ast, context) {
      return null;
    }
  }, {
    key: "visitText",
    value: function visitText(ast, context) {
      return null;
    }
  }]);

  return TemplatePreparseVisitor;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var QUERY_METADATA_IDENTIFIERS = [createViewChild, createViewChildren, createContentChild, createContentChildren];
/*
 * Resolve a `Type` for {@link Directive}.
 *
 * This interface can be overridden by the application developer to create custom behavior.
 *
 * See {@link Compiler}
 */

var DirectiveResolver = /*#__PURE__*/function () {
  function DirectiveResolver(_reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DirectiveResolver);

    this._reflector = _reflector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DirectiveResolver, [{
    key: "isDirective",
    value: function isDirective(type) {
      var typeMetadata = this._reflector.annotations(resolveForwardRef(type));

      return typeMetadata && typeMetadata.some(isDirectiveMetadata);
    }
  }, {
    key: "resolve",
    value: function resolve(type) {
      var throwIfNotFound = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

      var typeMetadata = this._reflector.annotations(resolveForwardRef(type));

      if (typeMetadata) {
        var metadata = findLast(typeMetadata, isDirectiveMetadata);

        if (metadata) {
          var propertyMetadata = this._reflector.propMetadata(type);

          var guards = this._reflector.guards(type);

          return this._mergeWithPropertyMetadata(metadata, propertyMetadata, guards, type);
        }
      }

      if (throwIfNotFound) {
        throw new Error("No Directive annotation found on ".concat(stringify(type)));
      }

      return null;
    }
  }, {
    key: "_mergeWithPropertyMetadata",
    value: function _mergeWithPropertyMetadata(dm, propertyMetadata, guards, directiveType) {
      var inputs = [];
      var outputs = [];
      var host = {};
      var queries = {};
      Object.keys(propertyMetadata).forEach(function (propName) {
        var input = findLast(propertyMetadata[propName], function (a) {
          return createInput.isTypeOf(a);
        });

        if (input) {
          if (input.bindingPropertyName) {
            inputs.push("".concat(propName, ": ").concat(input.bindingPropertyName));
          } else {
            inputs.push(propName);
          }
        }

        var output = findLast(propertyMetadata[propName], function (a) {
          return createOutput.isTypeOf(a);
        });

        if (output) {
          if (output.bindingPropertyName) {
            outputs.push("".concat(propName, ": ").concat(output.bindingPropertyName));
          } else {
            outputs.push(propName);
          }
        }

        var hostBindings = propertyMetadata[propName].filter(function (a) {
          return createHostBinding.isTypeOf(a);
        });
        hostBindings.forEach(function (hostBinding) {
          if (hostBinding.hostPropertyName) {
            var startWith = hostBinding.hostPropertyName[0];

            if (startWith === '(') {
              throw new Error("@HostBinding can not bind to events. Use @HostListener instead.");
            } else if (startWith === '[') {
              throw new Error("@HostBinding parameter should be a property name, 'class.<name>', or 'attr.<name>'.");
            }

            host["[".concat(hostBinding.hostPropertyName, "]")] = propName;
          } else {
            host["[".concat(propName, "]")] = propName;
          }
        });
        var hostListeners = propertyMetadata[propName].filter(function (a) {
          return createHostListener.isTypeOf(a);
        });
        hostListeners.forEach(function (hostListener) {
          var args = hostListener.args || [];
          host["(".concat(hostListener.eventName, ")")] = "".concat(propName, "(").concat(args.join(','), ")");
        });
        var query = findLast(propertyMetadata[propName], function (a) {
          return QUERY_METADATA_IDENTIFIERS.some(function (i) {
            return i.isTypeOf(a);
          });
        });

        if (query) {
          queries[propName] = query;
        }
      });
      return this._merge(dm, inputs, outputs, host, queries, guards, directiveType);
    }
  }, {
    key: "_extractPublicName",
    value: function _extractPublicName(def) {
      return splitAtColon(def, [null, def])[1].trim();
    }
  }, {
    key: "_dedupeBindings",
    value: function _dedupeBindings(bindings) {
      var names = new Set();
      var publicNames = new Set();
      var reversedResult = []; // go last to first to allow later entries to overwrite previous entries

      for (var i = bindings.length - 1; i >= 0; i--) {
        var binding = bindings[i];

        var name = this._extractPublicName(binding);

        publicNames.add(name);

        if (!names.has(name)) {
          names.add(name);
          reversedResult.push(binding);
        }
      }

      return reversedResult.reverse();
    }
  }, {
    key: "_merge",
    value: function _merge(directive, inputs, outputs, host, queries, guards, directiveType) {
      var mergedInputs = this._dedupeBindings(directive.inputs ? directive.inputs.concat(inputs) : inputs);

      var mergedOutputs = this._dedupeBindings(directive.outputs ? directive.outputs.concat(outputs) : outputs);

      var mergedHost = directive.host ? Object.assign(Object.assign({}, directive.host), host) : host;
      var mergedQueries = directive.queries ? Object.assign(Object.assign({}, directive.queries), queries) : queries;

      if (createComponent.isTypeOf(directive)) {
        var comp = directive;
        return createComponent({
          selector: comp.selector,
          inputs: mergedInputs,
          outputs: mergedOutputs,
          host: mergedHost,
          exportAs: comp.exportAs,
          moduleId: comp.moduleId,
          queries: mergedQueries,
          changeDetection: comp.changeDetection,
          providers: comp.providers,
          viewProviders: comp.viewProviders,
          entryComponents: comp.entryComponents,
          template: comp.template,
          templateUrl: comp.templateUrl,
          styles: comp.styles,
          styleUrls: comp.styleUrls,
          encapsulation: comp.encapsulation,
          animations: comp.animations,
          interpolation: comp.interpolation,
          preserveWhitespaces: directive.preserveWhitespaces
        });
      } else {
        return createDirective({
          selector: directive.selector,
          inputs: mergedInputs,
          outputs: mergedOutputs,
          host: mergedHost,
          exportAs: directive.exportAs,
          queries: mergedQueries,
          providers: directive.providers,
          guards: guards
        });
      }
    }
  }]);

  return DirectiveResolver;
}();

function isDirectiveMetadata(type) {
  return createDirective.isTypeOf(type) || createComponent.isTypeOf(type);
}

function findLast(arr, condition) {
  for (var i = arr.length - 1; i >= 0; i--) {
    if (condition(arr[i])) {
      return arr[i];
    }
  }

  return null;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An i18n error.
 */


var I18nError = /*#__PURE__*/function (_ParseError6) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(I18nError, _ParseError6);

  var _super97 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(I18nError);

  function I18nError(span, msg) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, I18nError);

    return _super97.call(this, span, msg);
  }

  return I18nError;
}(ParseError);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _I18N_ATTR = 'i18n';
var _I18N_ATTR_PREFIX = 'i18n-';
var _I18N_COMMENT_PREFIX_REGEXP = /^i18n:?/;
var MEANING_SEPARATOR = '|';
var ID_SEPARATOR = '@@';
var i18nCommentsWarned = false;
/**
 * Extract translatable messages from an html AST
 */

function extractMessages(nodes, interpolationConfig, implicitTags, implicitAttrs) {
  var visitor = new _Visitor$2(implicitTags, implicitAttrs);
  return visitor.extract(nodes, interpolationConfig);
}

function mergeTranslations(nodes, translations, interpolationConfig, implicitTags, implicitAttrs) {
  var visitor = new _Visitor$2(implicitTags, implicitAttrs);
  return visitor.merge(nodes, translations, interpolationConfig);
}

var ExtractionResult = function ExtractionResult(messages, errors) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ExtractionResult);

  this.messages = messages;
  this.errors = errors;
};

var _VisitorMode;

(function (_VisitorMode) {
  _VisitorMode[_VisitorMode["Extract"] = 0] = "Extract";
  _VisitorMode[_VisitorMode["Merge"] = 1] = "Merge";
})(_VisitorMode || (_VisitorMode = {}));
/**
 * This Visitor is used:
 * 1. to extract all the translatable strings from an html AST (see `extract()`),
 * 2. to replace the translatable strings with the actual translations (see `merge()`)
 *
 * @internal
 */


var _Visitor$2 = /*#__PURE__*/function () {
  function _Visitor$2(_implicitTags, _implicitAttrs) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _Visitor$2);

    this._implicitTags = _implicitTags;
    this._implicitAttrs = _implicitAttrs;
  }
  /**
   * Extracts the messages from the tree
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_Visitor$2, [{
    key: "extract",
    value: function extract(nodes, interpolationConfig) {
      var _this198 = this;

      this._init(_VisitorMode.Extract, interpolationConfig);

      nodes.forEach(function (node) {
        return node.visit(_this198, null);
      });

      if (this._inI18nBlock) {
        this._reportError(nodes[nodes.length - 1], 'Unclosed block');
      }

      return new ExtractionResult(this._messages, this._errors);
    }
    /**
     * Returns a tree where all translatable nodes are translated
     */

  }, {
    key: "merge",
    value: function merge(nodes, translations, interpolationConfig) {
      this._init(_VisitorMode.Merge, interpolationConfig);

      this._translations = translations; // Construct a single fake root element

      var wrapper = new Element$1('wrapper', [], nodes, undefined, undefined, undefined);
      var translatedNode = wrapper.visit(this, null);

      if (this._inI18nBlock) {
        this._reportError(nodes[nodes.length - 1], 'Unclosed block');
      }

      return new ParseTreeResult(translatedNode.children, this._errors);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(icuCase, context) {
      // Parse cases for translatable html attributes
      var expression = visitAll$1(this, icuCase.expression, context);

      if (this._mode === _VisitorMode.Merge) {
        return new ExpansionCase(icuCase.value, expression, icuCase.sourceSpan, icuCase.valueSourceSpan, icuCase.expSourceSpan);
      }
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(icu, context) {
      this._mayBeAddBlockChildren(icu);

      var wasInIcu = this._inIcu;

      if (!this._inIcu) {
        // nested ICU messages should not be extracted but top-level translated as a whole
        if (this._isInTranslatableSection) {
          this._addMessage([icu]);
        }

        this._inIcu = true;
      }

      var cases = visitAll$1(this, icu.cases, context);

      if (this._mode === _VisitorMode.Merge) {
        icu = new Expansion(icu.switchValue, icu.type, cases, icu.sourceSpan, icu.switchValueSourceSpan);
      }

      this._inIcu = wasInIcu;
      return icu;
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {
      var isOpening = _isOpeningComment(comment);

      if (isOpening && this._isInTranslatableSection) {
        this._reportError(comment, 'Could not start a block inside a translatable section');

        return;
      }

      var isClosing = _isClosingComment(comment);

      if (isClosing && !this._inI18nBlock) {
        this._reportError(comment, 'Trying to close an unopened block');

        return;
      }

      if (!this._inI18nNode && !this._inIcu) {
        if (!this._inI18nBlock) {
          if (isOpening) {
            // deprecated from v5 you should use <ng-container i18n> instead of i18n comments
            if (!i18nCommentsWarned && console && console.warn) {
              i18nCommentsWarned = true;
              var details = comment.sourceSpan.details ? ", ".concat(comment.sourceSpan.details) : ''; // TODO(ocombe): use a log service once there is a public one available

              console.warn("I18n comments are deprecated, use an <ng-container> element instead (".concat(comment.sourceSpan.start).concat(details, ")"));
            }

            this._inI18nBlock = true;
            this._blockStartDepth = this._depth;
            this._blockChildren = [];
            this._blockMeaningAndDesc = comment.value.replace(_I18N_COMMENT_PREFIX_REGEXP, '').trim();

            this._openTranslatableSection(comment);
          }
        } else {
          if (isClosing) {
            if (this._depth == this._blockStartDepth) {
              this._closeTranslatableSection(comment, this._blockChildren);

              this._inI18nBlock = false;

              var message = this._addMessage(this._blockChildren, this._blockMeaningAndDesc); // merge attributes in sections


              var nodes = this._translateMessage(comment, message);

              return visitAll$1(this, nodes);
            } else {
              this._reportError(comment, 'I18N blocks should not cross element boundaries');

              return;
            }
          }
        }
      }
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      if (this._isInTranslatableSection) {
        this._mayBeAddBlockChildren(text);
      }

      return text;
    }
  }, {
    key: "visitElement",
    value: function visitElement(el, context) {
      var _this199 = this;

      this._mayBeAddBlockChildren(el);

      this._depth++;
      var wasInI18nNode = this._inI18nNode;
      var wasInImplicitNode = this._inImplicitNode;
      var childNodes = [];
      var translatedChildNodes = undefined; // Extract:
      // - top level nodes with the (implicit) "i18n" attribute if not already in a section
      // - ICU messages

      var i18nAttr = _getI18nAttr(el);

      var i18nMeta = i18nAttr ? i18nAttr.value : '';
      var isImplicit = this._implicitTags.some(function (tag) {
        return el.name === tag;
      }) && !this._inIcu && !this._isInTranslatableSection;
      var isTopLevelImplicit = !wasInImplicitNode && isImplicit;
      this._inImplicitNode = wasInImplicitNode || isImplicit;

      if (!this._isInTranslatableSection && !this._inIcu) {
        if (i18nAttr || isTopLevelImplicit) {
          this._inI18nNode = true;

          var message = this._addMessage(el.children, i18nMeta);

          translatedChildNodes = this._translateMessage(el, message);
        }

        if (this._mode == _VisitorMode.Extract) {
          var isTranslatable = i18nAttr || isTopLevelImplicit;
          if (isTranslatable) this._openTranslatableSection(el);
          visitAll$1(this, el.children);
          if (isTranslatable) this._closeTranslatableSection(el, el.children);
        }
      } else {
        if (i18nAttr || isTopLevelImplicit) {
          this._reportError(el, 'Could not mark an element as translatable inside a translatable section');
        }

        if (this._mode == _VisitorMode.Extract) {
          // Descend into child nodes for extraction
          visitAll$1(this, el.children);
        }
      }

      if (this._mode === _VisitorMode.Merge) {
        var visitNodes = translatedChildNodes || el.children;
        visitNodes.forEach(function (child) {
          var visited = child.visit(_this199, context);

          if (visited && !_this199._isInTranslatableSection) {
            // Do not add the children from translatable sections (= i18n blocks here)
            // They will be added later in this loop when the block closes (i.e. on `<!-- /i18n -->`)
            childNodes = childNodes.concat(visited);
          }
        });
      }

      this._visitAttributesOf(el);

      this._depth--;
      this._inI18nNode = wasInI18nNode;
      this._inImplicitNode = wasInImplicitNode;

      if (this._mode === _VisitorMode.Merge) {
        var translatedAttrs = this._translateAttributes(el);

        return new Element$1(el.name, translatedAttrs, childNodes, el.sourceSpan, el.startSourceSpan, el.endSourceSpan);
      }

      return null;
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {
      throw new Error('unreachable code');
    }
  }, {
    key: "_init",
    value: function _init(mode, interpolationConfig) {
      this._mode = mode;
      this._inI18nBlock = false;
      this._inI18nNode = false;
      this._depth = 0;
      this._inIcu = false;
      this._msgCountAtSectionStart = undefined;
      this._errors = [];
      this._messages = [];
      this._inImplicitNode = false;
      this._createI18nMessage = createI18nMessageFactory(interpolationConfig);
    } // looks for translatable attributes

  }, {
    key: "_visitAttributesOf",
    value: function _visitAttributesOf(el) {
      var _this200 = this;

      var explicitAttrNameToValue = {};
      var implicitAttrNames = this._implicitAttrs[el.name] || [];
      el.attrs.filter(function (attr) {
        return attr.name.startsWith(_I18N_ATTR_PREFIX);
      }).forEach(function (attr) {
        return explicitAttrNameToValue[attr.name.slice(_I18N_ATTR_PREFIX.length)] = attr.value;
      });
      el.attrs.forEach(function (attr) {
        if (attr.name in explicitAttrNameToValue) {
          _this200._addMessage([attr], explicitAttrNameToValue[attr.name]);
        } else if (implicitAttrNames.some(function (name) {
          return attr.name === name;
        })) {
          _this200._addMessage([attr]);
        }
      });
    } // add a translatable message

  }, {
    key: "_addMessage",
    value: function _addMessage(ast, msgMeta) {
      if (ast.length == 0 || ast.length == 1 && ast[0] instanceof Attribute && !ast[0].value) {
        // Do not create empty messages
        return null;
      }

      var _parseMessageMeta2 = _parseMessageMeta(msgMeta),
          meaning = _parseMessageMeta2.meaning,
          description = _parseMessageMeta2.description,
          id = _parseMessageMeta2.id;

      var message = this._createI18nMessage(ast, meaning, description, id);

      this._messages.push(message);

      return message;
    } // Translates the given message given the `TranslationBundle`
    // This is used for translating elements / blocks - see `_translateAttributes` for attributes
    // no-op when called in extraction mode (returns [])

  }, {
    key: "_translateMessage",
    value: function _translateMessage(el, message) {
      if (message && this._mode === _VisitorMode.Merge) {
        var nodes = this._translations.get(message);

        if (nodes) {
          return nodes;
        }

        this._reportError(el, "Translation unavailable for message id=\"".concat(this._translations.digest(message), "\""));
      }

      return [];
    } // translate the attributes of an element and remove i18n specific attributes

  }, {
    key: "_translateAttributes",
    value: function _translateAttributes(el) {
      var _this201 = this;

      var attributes = el.attrs;
      var i18nParsedMessageMeta = {};
      attributes.forEach(function (attr) {
        if (attr.name.startsWith(_I18N_ATTR_PREFIX)) {
          i18nParsedMessageMeta[attr.name.slice(_I18N_ATTR_PREFIX.length)] = _parseMessageMeta(attr.value);
        }
      });
      var translatedAttributes = [];
      attributes.forEach(function (attr) {
        if (attr.name === _I18N_ATTR || attr.name.startsWith(_I18N_ATTR_PREFIX)) {
          // strip i18n specific attributes
          return;
        }

        if (attr.value && attr.value != '' && i18nParsedMessageMeta.hasOwnProperty(attr.name)) {
          var _i18nParsedMessageMet = i18nParsedMessageMeta[attr.name],
              meaning = _i18nParsedMessageMet.meaning,
              description = _i18nParsedMessageMet.description,
              id = _i18nParsedMessageMet.id;

          var message = _this201._createI18nMessage([attr], meaning, description, id);

          var nodes = _this201._translations.get(message);

          if (nodes) {
            if (nodes.length == 0) {
              translatedAttributes.push(new Attribute(attr.name, '', attr.sourceSpan));
            } else if (nodes[0] instanceof Text$3) {
              var value = nodes[0].value;
              translatedAttributes.push(new Attribute(attr.name, value, attr.sourceSpan));
            } else {
              _this201._reportError(el, "Unexpected translation for attribute \"".concat(attr.name, "\" (id=\"").concat(id || _this201._translations.digest(message), "\")"));
            }
          } else {
            _this201._reportError(el, "Translation unavailable for attribute \"".concat(attr.name, "\" (id=\"").concat(id || _this201._translations.digest(message), "\")"));
          }
        } else {
          translatedAttributes.push(attr);
        }
      });
      return translatedAttributes;
    }
    /**
     * Add the node as a child of the block when:
     * - we are in a block,
     * - we are not inside a ICU message (those are handled separately),
     * - the node is a "direct child" of the block
     */

  }, {
    key: "_mayBeAddBlockChildren",
    value: function _mayBeAddBlockChildren(node) {
      if (this._inI18nBlock && !this._inIcu && this._depth == this._blockStartDepth) {
        this._blockChildren.push(node);
      }
    }
    /**
     * Marks the start of a section, see `_closeTranslatableSection`
     */

  }, {
    key: "_openTranslatableSection",
    value: function _openTranslatableSection(node) {
      if (this._isInTranslatableSection) {
        this._reportError(node, 'Unexpected section start');
      } else {
        this._msgCountAtSectionStart = this._messages.length;
      }
    }
    /**
     * A translatable section could be:
     * - the content of translatable element,
     * - nodes between `<!-- i18n -->` and `<!-- /i18n -->` comments
     */

  }, {
    key: "_closeTranslatableSection",

    /**
     * Terminates a section.
     *
     * If a section has only one significant children (comments not significant) then we should not
     * keep the message from this children:
     *
     * `<p i18n="meaning|description">{ICU message}</p>` would produce two messages:
     * - one for the <p> content with meaning and description,
     * - another one for the ICU message.
     *
     * In this case the last message is discarded as it contains less information (the AST is
     * otherwise identical).
     *
     * Note that we should still keep messages extracted from attributes inside the section (ie in the
     * ICU message here)
     */
    value: function _closeTranslatableSection(node, directChildren) {
      if (!this._isInTranslatableSection) {
        this._reportError(node, 'Unexpected section end');

        return;
      }

      var startIndex = this._msgCountAtSectionStart;
      var significantChildren = directChildren.reduce(function (count, node) {
        return count + (node instanceof Comment ? 0 : 1);
      }, 0);

      if (significantChildren == 1) {
        for (var i = this._messages.length - 1; i >= startIndex; i--) {
          var ast = this._messages[i].nodes;

          if (!(ast.length == 1 && ast[0] instanceof Text$1)) {
            this._messages.splice(i, 1);

            break;
          }
        }
      }

      this._msgCountAtSectionStart = undefined;
    }
  }, {
    key: "_reportError",
    value: function _reportError(node, msg) {
      this._errors.push(new I18nError(node.sourceSpan, msg));
    }
  }, {
    key: "_isInTranslatableSection",
    get: function get() {
      return this._msgCountAtSectionStart !== void 0;
    }
  }]);

  return _Visitor$2;
}();

function _isOpeningComment(n) {
  return !!(n instanceof Comment && n.value && n.value.startsWith('i18n'));
}

function _isClosingComment(n) {
  return !!(n instanceof Comment && n.value && n.value === '/i18n');
}

function _getI18nAttr(p) {
  return p.attrs.find(function (attr) {
    return attr.name === _I18N_ATTR;
  }) || null;
}

function _parseMessageMeta(i18n) {
  if (!i18n) return {
    meaning: '',
    description: '',
    id: ''
  };
  var idIndex = i18n.indexOf(ID_SEPARATOR);
  var descIndex = i18n.indexOf(MEANING_SEPARATOR);

  var _ref22 = idIndex > -1 ? [i18n.slice(0, idIndex), i18n.slice(idIndex + 2)] : [i18n, ''],
      _ref23 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_ref22, 2),
      meaningAndDesc = _ref23[0],
      id = _ref23[1];

  var _ref24 = descIndex > -1 ? [meaningAndDesc.slice(0, descIndex), meaningAndDesc.slice(descIndex + 1)] : ['', meaningAndDesc],
      _ref25 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_ref24, 2),
      meaning = _ref25[0],
      description = _ref25[1];

  return {
    meaning: meaning,
    description: description,
    id: id.trim()
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var XmlTagDefinition = /*#__PURE__*/function () {
  function XmlTagDefinition() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XmlTagDefinition);

    this.closedByParent = false;
    this.contentType = TagContentType.PARSABLE_DATA;
    this.isVoid = false;
    this.ignoreFirstLf = false;
    this.canSelfClose = true;
    this.preventNamespaceInheritance = false;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XmlTagDefinition, [{
    key: "requireExtraParent",
    value: function requireExtraParent(currentParent) {
      return false;
    }
  }, {
    key: "isClosedByChild",
    value: function isClosedByChild(name) {
      return false;
    }
  }]);

  return XmlTagDefinition;
}();

var _TAG_DEFINITION = new XmlTagDefinition();

function getXmlTagDefinition(tagName) {
  return _TAG_DEFINITION;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var XmlParser = /*#__PURE__*/function (_Parser2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(XmlParser, _Parser2);

  var _super98 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(XmlParser);

  function XmlParser() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XmlParser);

    return _super98.call(this, getXmlTagDefinition);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XmlParser, [{
    key: "parse",
    value: function parse(source, url, options) {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(XmlParser.prototype), "parse", this).call(this, source, url, options);
    }
  }]);

  return XmlParser;
}(Parser);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _VERSION = '1.2';
var _XMLNS = 'urn:oasis:names:tc:xliff:document:1.2'; // TODO(vicb): make this a param (s/_/-/)

var _DEFAULT_SOURCE_LANG = 'en';
var _PLACEHOLDER_TAG$1 = 'x';
var _MARKER_TAG = 'mrk';
var _FILE_TAG = 'file';
var _SOURCE_TAG$1 = 'source';
var _SEGMENT_SOURCE_TAG = 'seg-source';
var _ALT_TRANS_TAG = 'alt-trans';
var _TARGET_TAG = 'target';
var _UNIT_TAG = 'trans-unit';
var _CONTEXT_GROUP_TAG = 'context-group';
var _CONTEXT_TAG = 'context'; // http://docs.oasis-open.org/xliff/v1.2/os/xliff-core.html
// http://docs.oasis-open.org/xliff/v1.2/xliff-profile-html/xliff-profile-html-1.2.html

var Xliff = /*#__PURE__*/function (_Serializer2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Xliff, _Serializer2);

  var _super99 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Xliff);

  function Xliff() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Xliff);

    return _super99.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Xliff, [{
    key: "write",
    value: function write(messages, locale) {
      var visitor = new _WriteVisitor();
      var transUnits = [];
      messages.forEach(function (message) {
        var _transUnit$children;

        var contextTags = [];
        message.sources.forEach(function (source) {
          var contextGroupTag = new Tag(_CONTEXT_GROUP_TAG, {
            purpose: 'location'
          });
          contextGroupTag.children.push(new CR(10), new Tag(_CONTEXT_TAG, {
            'context-type': 'sourcefile'
          }, [new Text$2(source.filePath)]), new CR(10), new Tag(_CONTEXT_TAG, {
            'context-type': 'linenumber'
          }, [new Text$2("".concat(source.startLine))]), new CR(8));
          contextTags.push(new CR(8), contextGroupTag);
        });
        var transUnit = new Tag(_UNIT_TAG, {
          id: message.id,
          datatype: 'html'
        });

        (_transUnit$children = transUnit.children).push.apply(_transUnit$children, [new CR(8), new Tag(_SOURCE_TAG$1, {}, visitor.serialize(message.nodes))].concat(contextTags));

        if (message.description) {
          transUnit.children.push(new CR(8), new Tag('note', {
            priority: '1',
            from: 'description'
          }, [new Text$2(message.description)]));
        }

        if (message.meaning) {
          transUnit.children.push(new CR(8), new Tag('note', {
            priority: '1',
            from: 'meaning'
          }, [new Text$2(message.meaning)]));
        }

        transUnit.children.push(new CR(6));
        transUnits.push(new CR(6), transUnit);
      });
      var body = new Tag('body', {}, [].concat(transUnits, [new CR(4)]));
      var file = new Tag('file', {
        'source-language': locale || _DEFAULT_SOURCE_LANG,
        datatype: 'plaintext',
        original: 'ng2.template'
      }, [new CR(4), body, new CR(2)]);
      var xliff = new Tag('xliff', {
        version: _VERSION,
        xmlns: _XMLNS
      }, [new CR(2), file, new CR()]);
      return serialize([new Declaration({
        version: '1.0',
        encoding: 'UTF-8'
      }), new CR(), xliff, new CR()]);
    }
  }, {
    key: "load",
    value: function load(content, url) {
      // xliff to xml nodes
      var xliffParser = new XliffParser();

      var _xliffParser$parse = xliffParser.parse(content, url),
          locale = _xliffParser$parse.locale,
          msgIdToHtml = _xliffParser$parse.msgIdToHtml,
          errors = _xliffParser$parse.errors; // xml nodes to i18n nodes


      var i18nNodesByMsgId = {};
      var converter = new XmlToI18n();
      Object.keys(msgIdToHtml).forEach(function (msgId) {
        var _converter$convert = converter.convert(msgIdToHtml[msgId], url),
            i18nNodes = _converter$convert.i18nNodes,
            e = _converter$convert.errors;

        errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(e));
        i18nNodesByMsgId[msgId] = i18nNodes;
      });

      if (errors.length) {
        throw new Error("xliff parse errors:\n".concat(errors.join('\n')));
      }

      return {
        locale: locale,
        i18nNodesByMsgId: i18nNodesByMsgId
      };
    }
  }, {
    key: "digest",
    value: function digest(message) {
      return _digest2(message);
    }
  }]);

  return Xliff;
}(Serializer);

var _WriteVisitor = /*#__PURE__*/function () {
  function _WriteVisitor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _WriteVisitor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_WriteVisitor, [{
    key: "visitText",
    value: function visitText(text, context) {
      return [new Text$2(text.value)];
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this202 = this;

      var nodes = [];
      container.children.forEach(function (node) {
        return nodes.push.apply(nodes, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(node.visit(_this202)));
      });
      return nodes;
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this203 = this;

      var nodes = [new Text$2("{".concat(icu.expressionPlaceholder, ", ").concat(icu.type, ", "))];
      Object.keys(icu.cases).forEach(function (c) {
        nodes.push.apply(nodes, [new Text$2("".concat(c, " {"))].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(icu.cases[c].visit(_this203)), [new Text$2("} ")]));
      });
      nodes.push(new Text$2("}"));
      return nodes;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var ctype = getCtypeForTag(ph.tag);

      if (ph.isVoid) {
        // void tags have no children nor closing tags
        return [new Tag(_PLACEHOLDER_TAG$1, {
          id: ph.startName,
          ctype: ctype,
          'equiv-text': "<".concat(ph.tag, "/>")
        })];
      }

      var startTagPh = new Tag(_PLACEHOLDER_TAG$1, {
        id: ph.startName,
        ctype: ctype,
        'equiv-text': "<".concat(ph.tag, ">")
      });
      var closeTagPh = new Tag(_PLACEHOLDER_TAG$1, {
        id: ph.closeName,
        ctype: ctype,
        'equiv-text': "</".concat(ph.tag, ">")
      });
      return [startTagPh].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this.serialize(ph.children)), [closeTagPh]);
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      return [new Tag(_PLACEHOLDER_TAG$1, {
        id: ph.name,
        'equiv-text': "{{".concat(ph.value, "}}")
      })];
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      var equivText = "{".concat(ph.value.expression, ", ").concat(ph.value.type, ", ").concat(Object.keys(ph.value.cases).map(function (value) {
        return value + ' {...}';
      }).join(' '), "}");
      return [new Tag(_PLACEHOLDER_TAG$1, {
        id: ph.name,
        'equiv-text': equivText
      })];
    }
  }, {
    key: "serialize",
    value: function serialize(nodes) {
      var _ref26,
          _this204 = this;

      return (_ref26 = []).concat.apply(_ref26, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(nodes.map(function (node) {
        return node.visit(_this204);
      })));
    }
  }]);

  return _WriteVisitor;
}(); // TODO(vicb): add error management (structure)
// Extract messages as xml nodes from the xliff file


var XliffParser = /*#__PURE__*/function () {
  function XliffParser() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XliffParser);

    this._locale = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XliffParser, [{
    key: "parse",
    value: function parse(xliff, url) {
      this._unitMlString = null;
      this._msgIdToHtml = {};
      var xml = new XmlParser().parse(xliff, url);
      this._errors = xml.errors;
      visitAll$1(this, xml.rootNodes, null);
      return {
        msgIdToHtml: this._msgIdToHtml,
        errors: this._errors,
        locale: this._locale
      };
    }
  }, {
    key: "visitElement",
    value: function visitElement(element, context) {
      switch (element.name) {
        case _UNIT_TAG:
          this._unitMlString = null;
          var idAttr = element.attrs.find(function (attr) {
            return attr.name === 'id';
          });

          if (!idAttr) {
            this._addError(element, "<".concat(_UNIT_TAG, "> misses the \"id\" attribute"));
          } else {
            var id = idAttr.value;

            if (this._msgIdToHtml.hasOwnProperty(id)) {
              this._addError(element, "Duplicated translations for msg ".concat(id));
            } else {
              visitAll$1(this, element.children, null);

              if (typeof this._unitMlString === 'string') {
                this._msgIdToHtml[id] = this._unitMlString;
              } else {
                this._addError(element, "Message ".concat(id, " misses a translation"));
              }
            }
          }

          break;
        // ignore those tags

        case _SOURCE_TAG$1:
        case _SEGMENT_SOURCE_TAG:
        case _ALT_TRANS_TAG:
          break;

        case _TARGET_TAG:
          var innerTextStart = element.startSourceSpan.end.offset;
          var innerTextEnd = element.endSourceSpan.start.offset;
          var content = element.startSourceSpan.start.file.content;
          var innerText = content.slice(innerTextStart, innerTextEnd);
          this._unitMlString = innerText;
          break;

        case _FILE_TAG:
          var localeAttr = element.attrs.find(function (attr) {
            return attr.name === 'target-language';
          });

          if (localeAttr) {
            this._locale = localeAttr.value;
          }

          visitAll$1(this, element.children, null);
          break;

        default:
          // TODO(vicb): assert file structure, xliff version
          // For now only recurse on unhandled nodes
          visitAll$1(this, element.children, null);
      }
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {}
  }, {
    key: "visitText",
    value: function visitText(text, context) {}
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {}
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion, context) {}
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase, context) {}
  }, {
    key: "_addError",
    value: function _addError(node, message) {
      this._errors.push(new I18nError(node.sourceSpan, message));
    }
  }]);

  return XliffParser;
}(); // Convert ml nodes (xliff syntax) to i18n nodes


var XmlToI18n = /*#__PURE__*/function () {
  function XmlToI18n() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XmlToI18n);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XmlToI18n, [{
    key: "convert",
    value: function convert(message, url) {
      var _ref27;

      var xmlIcu = new XmlParser().parse(message, url, {
        tokenizeExpansionForms: true
      });
      this._errors = xmlIcu.errors;
      var i18nNodes = this._errors.length > 0 || xmlIcu.rootNodes.length == 0 ? [] : (_ref27 = []).concat.apply(_ref27, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitAll$1(this, xmlIcu.rootNodes)));
      return {
        i18nNodes: i18nNodes,
        errors: this._errors
      };
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      return new Text$1(text.value, text.sourceSpan);
    }
  }, {
    key: "visitElement",
    value: function visitElement(el, context) {
      if (el.name === _PLACEHOLDER_TAG$1) {
        var nameAttr = el.attrs.find(function (attr) {
          return attr.name === 'id';
        });

        if (nameAttr) {
          return new Placeholder('', nameAttr.value, el.sourceSpan);
        }

        this._addError(el, "<".concat(_PLACEHOLDER_TAG$1, "> misses the \"id\" attribute"));

        return null;
      }

      if (el.name === _MARKER_TAG) {
        var _ref28;

        return (_ref28 = []).concat.apply(_ref28, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitAll$1(this, el.children)));
      }

      this._addError(el, "Unexpected tag");

      return null;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(icu, context) {
      var caseMap = {};
      visitAll$1(this, icu.cases).forEach(function (c) {
        caseMap[c.value] = new Container(c.nodes, icu.sourceSpan);
      });
      return new Icu$1(icu.switchValue, icu.type, caseMap, icu.sourceSpan);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(icuCase, context) {
      return {
        value: icuCase.value,
        nodes: visitAll$1(this, icuCase.expression)
      };
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {}
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {}
  }, {
    key: "_addError",
    value: function _addError(node, message) {
      this._errors.push(new I18nError(node.sourceSpan, message));
    }
  }]);

  return XmlToI18n;
}();

function getCtypeForTag(tag) {
  switch (tag.toLowerCase()) {
    case 'br':
      return 'lb';

    case 'img':
      return 'image';

    default:
      return "x-".concat(tag);
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _VERSION$1 = '2.0';
var _XMLNS$1 = 'urn:oasis:names:tc:xliff:document:2.0'; // TODO(vicb): make this a param (s/_/-/)

var _DEFAULT_SOURCE_LANG$1 = 'en';
var _PLACEHOLDER_TAG$2 = 'ph';
var _PLACEHOLDER_SPANNING_TAG = 'pc';
var _MARKER_TAG$1 = 'mrk';
var _XLIFF_TAG = 'xliff';
var _SOURCE_TAG$2 = 'source';
var _TARGET_TAG$1 = 'target';
var _UNIT_TAG$1 = 'unit'; // http://docs.oasis-open.org/xliff/xliff-core/v2.0/os/xliff-core-v2.0-os.html

var Xliff2 = /*#__PURE__*/function (_Serializer3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Xliff2, _Serializer3);

  var _super100 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Xliff2);

  function Xliff2() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Xliff2);

    return _super100.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Xliff2, [{
    key: "write",
    value: function write(messages, locale) {
      var visitor = new _WriteVisitor$1();
      var units = [];
      messages.forEach(function (message) {
        var unit = new Tag(_UNIT_TAG$1, {
          id: message.id
        });
        var notes = new Tag('notes');

        if (message.description || message.meaning) {
          if (message.description) {
            notes.children.push(new CR(8), new Tag('note', {
              category: 'description'
            }, [new Text$2(message.description)]));
          }

          if (message.meaning) {
            notes.children.push(new CR(8), new Tag('note', {
              category: 'meaning'
            }, [new Text$2(message.meaning)]));
          }
        }

        message.sources.forEach(function (source) {
          notes.children.push(new CR(8), new Tag('note', {
            category: 'location'
          }, [new Text$2("".concat(source.filePath, ":").concat(source.startLine).concat(source.endLine !== source.startLine ? ',' + source.endLine : ''))]));
        });
        notes.children.push(new CR(6));
        unit.children.push(new CR(6), notes);
        var segment = new Tag('segment');
        segment.children.push(new CR(8), new Tag(_SOURCE_TAG$2, {}, visitor.serialize(message.nodes)), new CR(6));
        unit.children.push(new CR(6), segment, new CR(4));
        units.push(new CR(4), unit);
      });
      var file = new Tag('file', {
        'original': 'ng.template',
        id: 'ngi18n'
      }, [].concat(units, [new CR(2)]));
      var xliff = new Tag(_XLIFF_TAG, {
        version: _VERSION$1,
        xmlns: _XMLNS$1,
        srcLang: locale || _DEFAULT_SOURCE_LANG$1
      }, [new CR(2), file, new CR()]);
      return serialize([new Declaration({
        version: '1.0',
        encoding: 'UTF-8'
      }), new CR(), xliff, new CR()]);
    }
  }, {
    key: "load",
    value: function load(content, url) {
      // xliff to xml nodes
      var xliff2Parser = new Xliff2Parser();

      var _xliff2Parser$parse = xliff2Parser.parse(content, url),
          locale = _xliff2Parser$parse.locale,
          msgIdToHtml = _xliff2Parser$parse.msgIdToHtml,
          errors = _xliff2Parser$parse.errors; // xml nodes to i18n nodes


      var i18nNodesByMsgId = {};
      var converter = new XmlToI18n$1();
      Object.keys(msgIdToHtml).forEach(function (msgId) {
        var _converter$convert2 = converter.convert(msgIdToHtml[msgId], url),
            i18nNodes = _converter$convert2.i18nNodes,
            e = _converter$convert2.errors;

        errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(e));
        i18nNodesByMsgId[msgId] = i18nNodes;
      });

      if (errors.length) {
        throw new Error("xliff2 parse errors:\n".concat(errors.join('\n')));
      }

      return {
        locale: locale,
        i18nNodesByMsgId: i18nNodesByMsgId
      };
    }
  }, {
    key: "digest",
    value: function digest(message) {
      return decimalDigest(message);
    }
  }]);

  return Xliff2;
}(Serializer);

var _WriteVisitor$1 = /*#__PURE__*/function () {
  function _WriteVisitor$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _WriteVisitor$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_WriteVisitor$1, [{
    key: "visitText",
    value: function visitText(text, context) {
      return [new Text$2(text.value)];
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this205 = this;

      var nodes = [];
      container.children.forEach(function (node) {
        return nodes.push.apply(nodes, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(node.visit(_this205)));
      });
      return nodes;
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this206 = this;

      var nodes = [new Text$2("{".concat(icu.expressionPlaceholder, ", ").concat(icu.type, ", "))];
      Object.keys(icu.cases).forEach(function (c) {
        nodes.push.apply(nodes, [new Text$2("".concat(c, " {"))].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(icu.cases[c].visit(_this206)), [new Text$2("} ")]));
      });
      nodes.push(new Text$2("}"));
      return nodes;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var _ref29,
          _this207 = this;

      var type = getTypeForTag(ph.tag);

      if (ph.isVoid) {
        var tagPh = new Tag(_PLACEHOLDER_TAG$2, {
          id: (this._nextPlaceholderId++).toString(),
          equiv: ph.startName,
          type: type,
          disp: "<".concat(ph.tag, "/>")
        });
        return [tagPh];
      }

      var tagPc = new Tag(_PLACEHOLDER_SPANNING_TAG, {
        id: (this._nextPlaceholderId++).toString(),
        equivStart: ph.startName,
        equivEnd: ph.closeName,
        type: type,
        dispStart: "<".concat(ph.tag, ">"),
        dispEnd: "</".concat(ph.tag, ">")
      });

      var nodes = (_ref29 = []).concat.apply(_ref29, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ph.children.map(function (node) {
        return node.visit(_this207);
      })));

      if (nodes.length) {
        nodes.forEach(function (node) {
          return tagPc.children.push(node);
        });
      } else {
        tagPc.children.push(new Text$2(''));
      }

      return [tagPc];
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      var idStr = (this._nextPlaceholderId++).toString();
      return [new Tag(_PLACEHOLDER_TAG$2, {
        id: idStr,
        equiv: ph.name,
        disp: "{{".concat(ph.value, "}}")
      })];
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      var cases = Object.keys(ph.value.cases).map(function (value) {
        return value + ' {...}';
      }).join(' ');
      var idStr = (this._nextPlaceholderId++).toString();
      return [new Tag(_PLACEHOLDER_TAG$2, {
        id: idStr,
        equiv: ph.name,
        disp: "{".concat(ph.value.expression, ", ").concat(ph.value.type, ", ").concat(cases, "}")
      })];
    }
  }, {
    key: "serialize",
    value: function serialize(nodes) {
      var _ref30,
          _this208 = this;

      this._nextPlaceholderId = 0;
      return (_ref30 = []).concat.apply(_ref30, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(nodes.map(function (node) {
        return node.visit(_this208);
      })));
    }
  }]);

  return _WriteVisitor$1;
}(); // Extract messages as xml nodes from the xliff file


var Xliff2Parser = /*#__PURE__*/function () {
  function Xliff2Parser() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Xliff2Parser);

    this._locale = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Xliff2Parser, [{
    key: "parse",
    value: function parse(xliff, url) {
      this._unitMlString = null;
      this._msgIdToHtml = {};
      var xml = new XmlParser().parse(xliff, url);
      this._errors = xml.errors;
      visitAll$1(this, xml.rootNodes, null);
      return {
        msgIdToHtml: this._msgIdToHtml,
        errors: this._errors,
        locale: this._locale
      };
    }
  }, {
    key: "visitElement",
    value: function visitElement(element, context) {
      switch (element.name) {
        case _UNIT_TAG$1:
          this._unitMlString = null;
          var idAttr = element.attrs.find(function (attr) {
            return attr.name === 'id';
          });

          if (!idAttr) {
            this._addError(element, "<".concat(_UNIT_TAG$1, "> misses the \"id\" attribute"));
          } else {
            var id = idAttr.value;

            if (this._msgIdToHtml.hasOwnProperty(id)) {
              this._addError(element, "Duplicated translations for msg ".concat(id));
            } else {
              visitAll$1(this, element.children, null);

              if (typeof this._unitMlString === 'string') {
                this._msgIdToHtml[id] = this._unitMlString;
              } else {
                this._addError(element, "Message ".concat(id, " misses a translation"));
              }
            }
          }

          break;

        case _SOURCE_TAG$2:
          // ignore source message
          break;

        case _TARGET_TAG$1:
          var innerTextStart = element.startSourceSpan.end.offset;
          var innerTextEnd = element.endSourceSpan.start.offset;
          var content = element.startSourceSpan.start.file.content;
          var innerText = content.slice(innerTextStart, innerTextEnd);
          this._unitMlString = innerText;
          break;

        case _XLIFF_TAG:
          var localeAttr = element.attrs.find(function (attr) {
            return attr.name === 'trgLang';
          });

          if (localeAttr) {
            this._locale = localeAttr.value;
          }

          var versionAttr = element.attrs.find(function (attr) {
            return attr.name === 'version';
          });

          if (versionAttr) {
            var version = versionAttr.value;

            if (version !== '2.0') {
              this._addError(element, "The XLIFF file version ".concat(version, " is not compatible with XLIFF 2.0 serializer"));
            } else {
              visitAll$1(this, element.children, null);
            }
          }

          break;

        default:
          visitAll$1(this, element.children, null);
      }
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {}
  }, {
    key: "visitText",
    value: function visitText(text, context) {}
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {}
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion, context) {}
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase, context) {}
  }, {
    key: "_addError",
    value: function _addError(node, message) {
      this._errors.push(new I18nError(node.sourceSpan, message));
    }
  }]);

  return Xliff2Parser;
}(); // Convert ml nodes (xliff syntax) to i18n nodes


var XmlToI18n$1 = /*#__PURE__*/function () {
  function XmlToI18n$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XmlToI18n$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XmlToI18n$1, [{
    key: "convert",
    value: function convert(message, url) {
      var _ref31;

      var xmlIcu = new XmlParser().parse(message, url, {
        tokenizeExpansionForms: true
      });
      this._errors = xmlIcu.errors;
      var i18nNodes = this._errors.length > 0 || xmlIcu.rootNodes.length == 0 ? [] : (_ref31 = []).concat.apply(_ref31, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitAll$1(this, xmlIcu.rootNodes)));
      return {
        i18nNodes: i18nNodes,
        errors: this._errors
      };
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      return new Text$1(text.value, text.sourceSpan);
    }
  }, {
    key: "visitElement",
    value: function visitElement(el, context) {
      var _this209 = this,
          _ref32;

      switch (el.name) {
        case _PLACEHOLDER_TAG$2:
          var nameAttr = el.attrs.find(function (attr) {
            return attr.name === 'equiv';
          });

          if (nameAttr) {
            return [new Placeholder('', nameAttr.value, el.sourceSpan)];
          }

          this._addError(el, "<".concat(_PLACEHOLDER_TAG$2, "> misses the \"equiv\" attribute"));

          break;

        case _PLACEHOLDER_SPANNING_TAG:
          var startAttr = el.attrs.find(function (attr) {
            return attr.name === 'equivStart';
          });
          var endAttr = el.attrs.find(function (attr) {
            return attr.name === 'equivEnd';
          });

          if (!startAttr) {
            this._addError(el, "<".concat(_PLACEHOLDER_TAG$2, "> misses the \"equivStart\" attribute"));
          } else if (!endAttr) {
            this._addError(el, "<".concat(_PLACEHOLDER_TAG$2, "> misses the \"equivEnd\" attribute"));
          } else {
            var startId = startAttr.value;
            var endId = endAttr.value;
            var nodes = [];
            return nodes.concat.apply(nodes, [new Placeholder('', startId, el.sourceSpan)].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(el.children.map(function (node) {
              return node.visit(_this209, null);
            })), [new Placeholder('', endId, el.sourceSpan)]));
          }

          break;

        case _MARKER_TAG$1:
          return (_ref32 = []).concat.apply(_ref32, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitAll$1(this, el.children)));

        default:
          this._addError(el, "Unexpected tag");

      }

      return null;
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(icu, context) {
      var caseMap = {};
      visitAll$1(this, icu.cases).forEach(function (c) {
        caseMap[c.value] = new Container(c.nodes, icu.sourceSpan);
      });
      return new Icu$1(icu.switchValue, icu.type, caseMap, icu.sourceSpan);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(icuCase, context) {
      var _ref33;

      return {
        value: icuCase.value,
        nodes: (_ref33 = []).concat.apply(_ref33, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitAll$1(this, icuCase.expression)))
      };
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {}
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {}
  }, {
    key: "_addError",
    value: function _addError(node, message) {
      this._errors.push(new I18nError(node.sourceSpan, message));
    }
  }]);

  return XmlToI18n$1;
}();

function getTypeForTag(tag) {
  switch (tag.toLowerCase()) {
    case 'br':
    case 'b':
    case 'i':
    case 'u':
      return 'fmt';

    case 'img':
      return 'image';

    case 'a':
      return 'link';

    default:
      return 'other';
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _TRANSLATIONS_TAG = 'translationbundle';
var _TRANSLATION_TAG = 'translation';
var _PLACEHOLDER_TAG$3 = 'ph';

var Xtb = /*#__PURE__*/function (_Serializer4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(Xtb, _Serializer4);

  var _super101 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(Xtb);

  function Xtb() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Xtb);

    return _super101.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Xtb, [{
    key: "write",
    value: function write(messages, locale) {
      throw new Error('Unsupported');
    }
  }, {
    key: "load",
    value: function load(content, url) {
      // xtb to xml nodes
      var xtbParser = new XtbParser();

      var _xtbParser$parse = xtbParser.parse(content, url),
          locale = _xtbParser$parse.locale,
          msgIdToHtml = _xtbParser$parse.msgIdToHtml,
          errors = _xtbParser$parse.errors; // xml nodes to i18n nodes


      var i18nNodesByMsgId = {};
      var converter = new XmlToI18n$2(); // Because we should be able to load xtb files that rely on features not supported by angular,
      // we need to delay the conversion of html to i18n nodes so that non angular messages are not
      // converted

      Object.keys(msgIdToHtml).forEach(function (msgId) {
        var valueFn = function valueFn() {
          var _converter$convert3 = converter.convert(msgIdToHtml[msgId], url),
              i18nNodes = _converter$convert3.i18nNodes,
              errors = _converter$convert3.errors;

          if (errors.length) {
            throw new Error("xtb parse errors:\n".concat(errors.join('\n')));
          }

          return i18nNodes;
        };

        createLazyProperty(i18nNodesByMsgId, msgId, valueFn);
      });

      if (errors.length) {
        throw new Error("xtb parse errors:\n".concat(errors.join('\n')));
      }

      return {
        locale: locale,
        i18nNodesByMsgId: i18nNodesByMsgId
      };
    }
  }, {
    key: "digest",
    value: function digest(message) {
      return digest$1(message);
    }
  }, {
    key: "createNameMapper",
    value: function createNameMapper(message) {
      return new SimplePlaceholderMapper(message, toPublicName);
    }
  }]);

  return Xtb;
}(Serializer);

function createLazyProperty(messages, id, valueFn) {
  Object.defineProperty(messages, id, {
    configurable: true,
    enumerable: true,
    get: function get() {
      var value = valueFn();
      Object.defineProperty(messages, id, {
        enumerable: true,
        value: value
      });
      return value;
    },
    set: function set(_) {
      throw new Error('Could not overwrite an XTB translation');
    }
  });
} // Extract messages as xml nodes from the xtb file


var XtbParser = /*#__PURE__*/function () {
  function XtbParser() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XtbParser);

    this._locale = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XtbParser, [{
    key: "parse",
    value: function parse(xtb, url) {
      this._bundleDepth = 0;
      this._msgIdToHtml = {}; // We can not parse the ICU messages at this point as some messages might not originate
      // from Angular that could not be lex'd.

      var xml = new XmlParser().parse(xtb, url);
      this._errors = xml.errors;
      visitAll$1(this, xml.rootNodes);
      return {
        msgIdToHtml: this._msgIdToHtml,
        errors: this._errors,
        locale: this._locale
      };
    }
  }, {
    key: "visitElement",
    value: function visitElement(element, context) {
      switch (element.name) {
        case _TRANSLATIONS_TAG:
          this._bundleDepth++;

          if (this._bundleDepth > 1) {
            this._addError(element, "<".concat(_TRANSLATIONS_TAG, "> elements can not be nested"));
          }

          var langAttr = element.attrs.find(function (attr) {
            return attr.name === 'lang';
          });

          if (langAttr) {
            this._locale = langAttr.value;
          }

          visitAll$1(this, element.children, null);
          this._bundleDepth--;
          break;

        case _TRANSLATION_TAG:
          var idAttr = element.attrs.find(function (attr) {
            return attr.name === 'id';
          });

          if (!idAttr) {
            this._addError(element, "<".concat(_TRANSLATION_TAG, "> misses the \"id\" attribute"));
          } else {
            var id = idAttr.value;

            if (this._msgIdToHtml.hasOwnProperty(id)) {
              this._addError(element, "Duplicated translations for msg ".concat(id));
            } else {
              var innerTextStart = element.startSourceSpan.end.offset;
              var innerTextEnd = element.endSourceSpan.start.offset;
              var content = element.startSourceSpan.start.file.content;
              var innerText = content.slice(innerTextStart, innerTextEnd);
              this._msgIdToHtml[id] = innerText;
            }
          }

          break;

        default:
          this._addError(element, 'Unexpected tag');

      }
    }
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {}
  }, {
    key: "visitText",
    value: function visitText(text, context) {}
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {}
  }, {
    key: "visitExpansion",
    value: function visitExpansion(expansion, context) {}
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(expansionCase, context) {}
  }, {
    key: "_addError",
    value: function _addError(node, message) {
      this._errors.push(new I18nError(node.sourceSpan, message));
    }
  }]);

  return XtbParser;
}(); // Convert ml nodes (xtb syntax) to i18n nodes


var XmlToI18n$2 = /*#__PURE__*/function () {
  function XmlToI18n$2() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, XmlToI18n$2);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(XmlToI18n$2, [{
    key: "convert",
    value: function convert(message, url) {
      var xmlIcu = new XmlParser().parse(message, url, {
        tokenizeExpansionForms: true
      });
      this._errors = xmlIcu.errors;
      var i18nNodes = this._errors.length > 0 || xmlIcu.rootNodes.length == 0 ? [] : visitAll$1(this, xmlIcu.rootNodes);
      return {
        i18nNodes: i18nNodes,
        errors: this._errors
      };
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      return new Text$1(text.value, text.sourceSpan);
    }
  }, {
    key: "visitExpansion",
    value: function visitExpansion(icu, context) {
      var caseMap = {};
      visitAll$1(this, icu.cases).forEach(function (c) {
        caseMap[c.value] = new Container(c.nodes, icu.sourceSpan);
      });
      return new Icu$1(icu.switchValue, icu.type, caseMap, icu.sourceSpan);
    }
  }, {
    key: "visitExpansionCase",
    value: function visitExpansionCase(icuCase, context) {
      return {
        value: icuCase.value,
        nodes: visitAll$1(this, icuCase.expression)
      };
    }
  }, {
    key: "visitElement",
    value: function visitElement(el, context) {
      if (el.name === _PLACEHOLDER_TAG$3) {
        var nameAttr = el.attrs.find(function (attr) {
          return attr.name === 'name';
        });

        if (nameAttr) {
          return new Placeholder('', nameAttr.value, el.sourceSpan);
        }

        this._addError(el, "<".concat(_PLACEHOLDER_TAG$3, "> misses the \"name\" attribute"));
      } else {
        this._addError(el, "Unexpected tag");
      }

      return null;
    }
  }, {
    key: "visitComment",
    value: function visitComment(comment, context) {}
  }, {
    key: "visitAttribute",
    value: function visitAttribute(attribute, context) {}
  }, {
    key: "_addError",
    value: function _addError(node, message) {
      this._errors.push(new I18nError(node.sourceSpan, message));
    }
  }]);

  return XmlToI18n$2;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A container for translated messages
 */


var TranslationBundle = /*#__PURE__*/function () {
  function TranslationBundle() {
    var _i18nNodesByMsgId = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var locale = arguments.length > 1 ? arguments[1] : undefined;
    var digest = arguments.length > 2 ? arguments[2] : undefined;
    var mapperFactory = arguments.length > 3 ? arguments[3] : undefined;
    var missingTranslationStrategy = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : MissingTranslationStrategy.Warning;
    var console = arguments.length > 5 ? arguments[5] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TranslationBundle);

    this._i18nNodesByMsgId = _i18nNodesByMsgId;
    this.digest = digest;
    this.mapperFactory = mapperFactory;
    this._i18nToHtml = new I18nToHtmlVisitor(_i18nNodesByMsgId, locale, digest, mapperFactory, missingTranslationStrategy, console);
  } // Creates a `TranslationBundle` by parsing the given `content` with the `serializer`.


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TranslationBundle, [{
    key: "get",
    // Returns the translation as HTML nodes from the given source message.
    value: function get(srcMsg) {
      var html = this._i18nToHtml.convert(srcMsg);

      if (html.errors.length) {
        throw new Error(html.errors.join('\n'));
      }

      return html.nodes;
    }
  }, {
    key: "has",
    value: function has(srcMsg) {
      return this.digest(srcMsg) in this._i18nNodesByMsgId;
    }
  }], [{
    key: "load",
    value: function load(content, url, serializer, missingTranslationStrategy, console) {
      var _serializer$load = serializer.load(content, url),
          locale = _serializer$load.locale,
          i18nNodesByMsgId = _serializer$load.i18nNodesByMsgId;

      var digestFn = function digestFn(m) {
        return serializer.digest(m);
      };

      var mapperFactory = function mapperFactory(m) {
        return serializer.createNameMapper(m);
      };

      return new TranslationBundle(i18nNodesByMsgId, locale, digestFn, mapperFactory, missingTranslationStrategy, console);
    }
  }]);

  return TranslationBundle;
}();

var I18nToHtmlVisitor = /*#__PURE__*/function () {
  function I18nToHtmlVisitor() {
    var _i18nNodesByMsgId = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var _locale = arguments.length > 1 ? arguments[1] : undefined;

    var _digest = arguments.length > 2 ? arguments[2] : undefined;

    var _mapperFactory = arguments.length > 3 ? arguments[3] : undefined;

    var _missingTranslationStrategy = arguments.length > 4 ? arguments[4] : undefined;

    var _console = arguments.length > 5 ? arguments[5] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, I18nToHtmlVisitor);

    this._i18nNodesByMsgId = _i18nNodesByMsgId;
    this._locale = _locale;
    this._digest = _digest;
    this._mapperFactory = _mapperFactory;
    this._missingTranslationStrategy = _missingTranslationStrategy;
    this._console = _console;
    this._contextStack = [];
    this._errors = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(I18nToHtmlVisitor, [{
    key: "convert",
    value: function convert(srcMsg) {
      this._contextStack.length = 0;
      this._errors.length = 0; // i18n to text

      var text = this._convertToText(srcMsg); // text to html


      var url = srcMsg.nodes[0].sourceSpan.start.file.url;
      var html = new HtmlParser().parse(text, url, {
        tokenizeExpansionForms: true
      });
      return {
        nodes: html.rootNodes,
        errors: [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._errors), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(html.errors))
      };
    }
  }, {
    key: "visitText",
    value: function visitText(text, context) {
      // `convert()` uses an `HtmlParser` to return `html.Node`s
      // we should then make sure that any special characters are escaped
      return escapeXml(text.value);
    }
  }, {
    key: "visitContainer",
    value: function visitContainer(container, context) {
      var _this210 = this;

      return container.children.map(function (n) {
        return n.visit(_this210);
      }).join('');
    }
  }, {
    key: "visitIcu",
    value: function visitIcu(icu, context) {
      var _this211 = this;

      var cases = Object.keys(icu.cases).map(function (k) {
        return "".concat(k, " {").concat(icu.cases[k].visit(_this211), "}");
      }); // TODO(vicb): Once all format switch to using expression placeholders
      // we should throw when the placeholder is not in the source message

      var exp = this._srcMsg.placeholders.hasOwnProperty(icu.expression) ? this._srcMsg.placeholders[icu.expression] : icu.expression;
      return "{".concat(exp, ", ").concat(icu.type, ", ").concat(cases.join(' '), "}");
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, context) {
      var phName = this._mapper(ph.name);

      if (this._srcMsg.placeholders.hasOwnProperty(phName)) {
        return this._srcMsg.placeholders[phName];
      }

      if (this._srcMsg.placeholderToMessage.hasOwnProperty(phName)) {
        return this._convertToText(this._srcMsg.placeholderToMessage[phName]);
      }

      this._addError(ph, "Unknown placeholder \"".concat(ph.name, "\""));

      return '';
    } // Loaded message contains only placeholders (vs tag and icu placeholders).
    // However when a translation can not be found, we need to serialize the source message
    // which can contain tag placeholders

  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, context) {
      var _this212 = this;

      var tag = "".concat(ph.tag);
      var attrs = Object.keys(ph.attrs).map(function (name) {
        return "".concat(name, "=\"").concat(ph.attrs[name], "\"");
      }).join(' ');

      if (ph.isVoid) {
        return "<".concat(tag, " ").concat(attrs, "/>");
      }

      var children = ph.children.map(function (c) {
        return c.visit(_this212);
      }).join('');
      return "<".concat(tag, " ").concat(attrs, ">").concat(children, "</").concat(tag, ">");
    } // Loaded message contains only placeholders (vs tag and icu placeholders).
    // However when a translation can not be found, we need to serialize the source message
    // which can contain tag placeholders

  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, context) {
      // An ICU placeholder references the source message to be serialized
      return this._convertToText(this._srcMsg.placeholderToMessage[ph.name]);
    }
    /**
     * Convert a source message to a translated text string:
     * - text nodes are replaced with their translation,
     * - placeholders are replaced with their content,
     * - ICU nodes are converted to ICU expressions.
     */

  }, {
    key: "_convertToText",
    value: function _convertToText(srcMsg) {
      var _this213 = this;

      var id = this._digest(srcMsg);

      var mapper = this._mapperFactory ? this._mapperFactory(srcMsg) : null;
      var nodes;

      this._contextStack.push({
        msg: this._srcMsg,
        mapper: this._mapper
      });

      this._srcMsg = srcMsg;

      if (this._i18nNodesByMsgId.hasOwnProperty(id)) {
        // When there is a translation use its nodes as the source
        // And create a mapper to convert serialized placeholder names to internal names
        nodes = this._i18nNodesByMsgId[id];

        this._mapper = function (name) {
          return mapper ? mapper.toInternalName(name) : name;
        };
      } else {
        // When no translation has been found
        // - report an error / a warning / nothing,
        // - use the nodes from the original message
        // - placeholders are already internal and need no mapper
        if (this._missingTranslationStrategy === MissingTranslationStrategy.Error) {
          var ctx = this._locale ? " for locale \"".concat(this._locale, "\"") : '';

          this._addError(srcMsg.nodes[0], "Missing translation for message \"".concat(id, "\"").concat(ctx));
        } else if (this._console && this._missingTranslationStrategy === MissingTranslationStrategy.Warning) {
          var _ctx2 = this._locale ? " for locale \"".concat(this._locale, "\"") : '';

          this._console.warn("Missing translation for message \"".concat(id, "\"").concat(_ctx2));
        }

        nodes = srcMsg.nodes;

        this._mapper = function (name) {
          return name;
        };
      }

      var text = nodes.map(function (node) {
        return node.visit(_this213);
      }).join('');

      var context = this._contextStack.pop();

      this._srcMsg = context.msg;
      this._mapper = context.mapper;
      return text;
    }
  }, {
    key: "_addError",
    value: function _addError(el, msg) {
      this._errors.push(new I18nError(el.sourceSpan, msg));
    }
  }]);

  return I18nToHtmlVisitor;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var I18NHtmlParser = /*#__PURE__*/function () {
  function I18NHtmlParser(_htmlParser, translations, translationsFormat) {
    var missingTranslation = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : MissingTranslationStrategy.Warning;
    var console = arguments.length > 4 ? arguments[4] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, I18NHtmlParser);

    this._htmlParser = _htmlParser;

    if (translations) {
      var _serializer = createSerializer(translationsFormat);

      this._translationBundle = TranslationBundle.load(translations, 'i18n', _serializer, missingTranslation, console);
    } else {
      this._translationBundle = new TranslationBundle({}, null, _digest2, undefined, missingTranslation, console);
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(I18NHtmlParser, [{
    key: "parse",
    value: function parse(source, url) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var interpolationConfig = options.interpolationConfig || DEFAULT_INTERPOLATION_CONFIG;

      var parseResult = this._htmlParser.parse(source, url, Object.assign({
        interpolationConfig: interpolationConfig
      }, options));

      if (parseResult.errors.length) {
        return new ParseTreeResult(parseResult.rootNodes, parseResult.errors);
      }

      return mergeTranslations(parseResult.rootNodes, this._translationBundle, interpolationConfig, [], {});
    }
  }]);

  return I18NHtmlParser;
}();

function createSerializer(format) {
  format = (format || 'xlf').toLowerCase();

  switch (format) {
    case 'xmb':
      return new Xmb();

    case 'xtb':
      return new Xtb();

    case 'xliff2':
    case 'xlf2':
      return new Xliff2();

    case 'xliff':
    case 'xlf':
    default:
      return new Xliff();
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var QUOTED_KEYS = '$quoted$';

function convertValueToOutputAst(ctx, value) {
  var type = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  return visitValue(value, new _ValueOutputAstTransformer(ctx), type);
}

var _ValueOutputAstTransformer = /*#__PURE__*/function () {
  function _ValueOutputAstTransformer(ctx) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _ValueOutputAstTransformer);

    this.ctx = ctx;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_ValueOutputAstTransformer, [{
    key: "visitArray",
    value: function visitArray(arr, type) {
      var values = []; // Note Array.map() must not be used to convert the values because it will
      // skip over empty elements in arrays constructed using `new Array(length)`,
      // resulting in `undefined` elements. This breaks the type guarantee that
      // all values in `o.LiteralArrayExpr` are of type `o.Expression`.
      // See test case in `value_util_spec.ts`.

      for (var i = 0; i < arr.length; ++i) {
        values.push(visitValue(arr[i], this, null
        /* context */
        ));
      }

      return literalArr(values, type);
    }
  }, {
    key: "visitStringMap",
    value: function visitStringMap(map, type) {
      var _this214 = this;

      var entries = [];
      var quotedSet = new Set(map && map[QUOTED_KEYS]);
      Object.keys(map).forEach(function (key) {
        entries.push(new LiteralMapEntry(key, visitValue(map[key], _this214, null), quotedSet.has(key)));
      });
      return new LiteralMapExpr(entries, type);
    }
  }, {
    key: "visitPrimitive",
    value: function visitPrimitive(value, type) {
      return literal(value, type);
    }
  }, {
    key: "visitOther",
    value: function visitOther(value, type) {
      if (value instanceof Expression) {
        return value;
      } else {
        return this.ctx.importExpr(value);
      }
    }
  }]);

  return _ValueOutputAstTransformer;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function mapEntry$1(key, value) {
  return {
    key: key,
    value: value,
    quoted: false
  };
}

var InjectableCompiler = /*#__PURE__*/function () {
  function InjectableCompiler(reflector, alwaysGenerateDef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, InjectableCompiler);

    this.reflector = reflector;
    this.alwaysGenerateDef = alwaysGenerateDef;
    this.tokenInjector = reflector.resolveExternalReference(Identifiers.Injector);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(InjectableCompiler, [{
    key: "depsArray",
    value: function depsArray(deps, ctx) {
      var _this215 = this;

      return deps.map(function (dep) {
        var token = dep;
        var args = [token];
        var flags = 0
        /* Default */
        ;

        if (Array.isArray(dep)) {
          for (var i = 0; i < dep.length; i++) {
            var v = dep[i];

            if (v) {
              if (v.ngMetadataName === 'Optional') {
                flags |= 8
                /* Optional */
                ;
              } else if (v.ngMetadataName === 'SkipSelf') {
                flags |= 4
                /* SkipSelf */
                ;
              } else if (v.ngMetadataName === 'Self') {
                flags |= 2
                /* Self */
                ;
              } else if (v.ngMetadataName === 'Inject') {
                token = v.token;
              } else {
                token = v;
              }
            }
          }
        }

        var tokenExpr;

        if (typeof token === 'string') {
          tokenExpr = literal(token);
        } else if (token === _this215.tokenInjector) {
          tokenExpr = importExpr(Identifiers.INJECTOR);
        } else {
          tokenExpr = ctx.importExpr(token);
        }

        if (flags !== 0
        /* Default */
        ) {
            args = [tokenExpr, literal(flags)];
          } else {
          args = [tokenExpr];
        }

        return importExpr(Identifiers.inject).callFn(args);
      });
    }
  }, {
    key: "factoryFor",
    value: function factoryFor(injectable, ctx) {
      var retValue;

      if (injectable.useExisting) {
        retValue = importExpr(Identifiers.inject).callFn([ctx.importExpr(injectable.useExisting)]);
      } else if (injectable.useFactory) {
        var deps = injectable.deps || [];

        if (deps.length > 0) {
          retValue = ctx.importExpr(injectable.useFactory).callFn(this.depsArray(deps, ctx));
        } else {
          return ctx.importExpr(injectable.useFactory);
        }
      } else if (injectable.useValue) {
        retValue = convertValueToOutputAst(ctx, injectable.useValue);
      } else {
        var clazz = injectable.useClass || injectable.symbol;
        var depArgs = this.depsArray(this.reflector.parameters(clazz), ctx);
        retValue = new InstantiateExpr(ctx.importExpr(clazz), depArgs);
      }

      return fn([], [new ReturnStatement(retValue)], undefined, undefined, injectable.symbol.name + '_Factory');
    }
  }, {
    key: "injectableDef",
    value: function injectableDef(injectable, ctx) {
      var providedIn = NULL_EXPR;

      if (injectable.providedIn !== undefined) {
        if (injectable.providedIn === null) {
          providedIn = NULL_EXPR;
        } else if (typeof injectable.providedIn === 'string') {
          providedIn = literal(injectable.providedIn);
        } else {
          providedIn = ctx.importExpr(injectable.providedIn);
        }
      }

      var def = [mapEntry$1('factory', this.factoryFor(injectable, ctx)), mapEntry$1('token', ctx.importExpr(injectable.type.reference)), mapEntry$1('providedIn', providedIn)];
      return importExpr(Identifiers.ɵɵdefineInjectable).callFn([literalMap(def)]);
    }
  }, {
    key: "compile",
    value: function compile(injectable, ctx) {
      if (this.alwaysGenerateDef || injectable.providedIn !== undefined) {
        var className = identifierName(injectable.type);
        var clazz = new ClassStmt(className, null, [new ClassField('ɵprov', INFERRED_TYPE, [StmtModifier.Static], this.injectableDef(injectable, ctx))], [], new ClassMethod(null, [], []), []);
        ctx.statements.push(clazz);
      }
    }
  }]);

  return InjectableCompiler;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var STRIP_SRC_FILE_SUFFIXES = /(\.ts|\.d\.ts|\.js|\.jsx|\.tsx)$/;
var GENERATED_FILE = /\.ngfactory\.|\.ngsummary\./;
var JIT_SUMMARY_FILE = /\.ngsummary\./;
var JIT_SUMMARY_NAME = /NgSummary$/;

function ngfactoryFilePath(filePath) {
  var forceSourceFile = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var urlWithSuffix = splitTypescriptSuffix(filePath, forceSourceFile);
  return "".concat(urlWithSuffix[0], ".ngfactory").concat(normalizeGenFileSuffix(urlWithSuffix[1]));
}

function stripGeneratedFileSuffix(filePath) {
  return filePath.replace(GENERATED_FILE, '.');
}

function isGeneratedFile(filePath) {
  return GENERATED_FILE.test(filePath);
}

function splitTypescriptSuffix(path) {
  var forceSourceFile = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  if (path.endsWith('.d.ts')) {
    return [path.slice(0, -5), forceSourceFile ? '.ts' : '.d.ts'];
  }

  var lastDot = path.lastIndexOf('.');

  if (lastDot !== -1) {
    return [path.substring(0, lastDot), path.substring(lastDot)];
  }

  return [path, ''];
}

function normalizeGenFileSuffix(srcFileSuffix) {
  return srcFileSuffix === '.tsx' ? '.ts' : srcFileSuffix;
}

function summaryFileName(fileName) {
  var fileNameWithoutSuffix = fileName.replace(STRIP_SRC_FILE_SUFFIXES, '');
  return "".concat(fileNameWithoutSuffix, ".ngsummary.json");
}

function summaryForJitFileName(fileName) {
  var forceSourceFile = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var urlWithSuffix = splitTypescriptSuffix(stripGeneratedFileSuffix(fileName), forceSourceFile);
  return "".concat(urlWithSuffix[0], ".ngsummary").concat(urlWithSuffix[1]);
}

function stripSummaryForJitFileSuffix(filePath) {
  return filePath.replace(JIT_SUMMARY_FILE, '.');
}

function summaryForJitName(symbolName) {
  return "".concat(symbolName, "NgSummary");
}

function stripSummaryForJitNameSuffix(symbolName) {
  return symbolName.replace(JIT_SUMMARY_NAME, '');
}

var LOWERED_SYMBOL = /\u0275\d+/;

function isLoweredSymbol(name) {
  return LOWERED_SYMBOL.test(name);
}

function createLoweredSymbol(id) {
  return "\u0275".concat(id);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var LifecycleHooks;

(function (LifecycleHooks) {
  LifecycleHooks[LifecycleHooks["OnInit"] = 0] = "OnInit";
  LifecycleHooks[LifecycleHooks["OnDestroy"] = 1] = "OnDestroy";
  LifecycleHooks[LifecycleHooks["DoCheck"] = 2] = "DoCheck";
  LifecycleHooks[LifecycleHooks["OnChanges"] = 3] = "OnChanges";
  LifecycleHooks[LifecycleHooks["AfterContentInit"] = 4] = "AfterContentInit";
  LifecycleHooks[LifecycleHooks["AfterContentChecked"] = 5] = "AfterContentChecked";
  LifecycleHooks[LifecycleHooks["AfterViewInit"] = 6] = "AfterViewInit";
  LifecycleHooks[LifecycleHooks["AfterViewChecked"] = 7] = "AfterViewChecked";
})(LifecycleHooks || (LifecycleHooks = {}));

var LIFECYCLE_HOOKS_VALUES = [LifecycleHooks.OnInit, LifecycleHooks.OnDestroy, LifecycleHooks.DoCheck, LifecycleHooks.OnChanges, LifecycleHooks.AfterContentInit, LifecycleHooks.AfterContentChecked, LifecycleHooks.AfterViewInit, LifecycleHooks.AfterViewChecked];

function hasLifecycleHook(reflector, hook, token) {
  return reflector.hasLifecycleHook(token, getHookName(hook));
}

function getAllLifecycleHooks(reflector, token) {
  return LIFECYCLE_HOOKS_VALUES.filter(function (hook) {
    return hasLifecycleHook(reflector, hook, token);
  });
}

function getHookName(hook) {
  switch (hook) {
    case LifecycleHooks.OnInit:
      return 'ngOnInit';

    case LifecycleHooks.OnDestroy:
      return 'ngOnDestroy';

    case LifecycleHooks.DoCheck:
      return 'ngDoCheck';

    case LifecycleHooks.OnChanges:
      return 'ngOnChanges';

    case LifecycleHooks.AfterContentInit:
      return 'ngAfterContentInit';

    case LifecycleHooks.AfterContentChecked:
      return 'ngAfterContentChecked';

    case LifecycleHooks.AfterViewInit:
      return 'ngAfterViewInit';

    case LifecycleHooks.AfterViewChecked:
      return 'ngAfterViewChecked';

    default:
      // This default case is not needed by TypeScript compiler, as the switch is exhaustive.
      // However Closure Compiler does not understand that and reports an error in typed mode.
      // The `throw new Error` below works around the problem, and the unexpected: never variable
      // makes sure tsc still checks this code is unreachable.
      var unexpected = hook;
      throw new Error("unexpected ".concat(unexpected));
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ERROR_COMPONENT_TYPE = 'ngComponentType'; // Design notes:
// - don't lazily create metadata:
//   For some metadata, we need to do async work sometimes,
//   so the user has to kick off this loading.
//   But we want to report errors even when the async work is
//   not required to check that the user would have been able
//   to wait correctly.

var CompileMetadataResolver = /*#__PURE__*/function () {
  function CompileMetadataResolver(_config, _htmlParser, _ngModuleResolver, _directiveResolver, _pipeResolver, _summaryResolver, _schemaRegistry, _directiveNormalizer, _console, _staticSymbolCache, _reflector, _errorCollector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileMetadataResolver);

    this._config = _config;
    this._htmlParser = _htmlParser;
    this._ngModuleResolver = _ngModuleResolver;
    this._directiveResolver = _directiveResolver;
    this._pipeResolver = _pipeResolver;
    this._summaryResolver = _summaryResolver;
    this._schemaRegistry = _schemaRegistry;
    this._directiveNormalizer = _directiveNormalizer;
    this._console = _console;
    this._staticSymbolCache = _staticSymbolCache;
    this._reflector = _reflector;
    this._errorCollector = _errorCollector;
    this._nonNormalizedDirectiveCache = new Map();
    this._directiveCache = new Map();
    this._summaryCache = new Map();
    this._pipeCache = new Map();
    this._ngModuleCache = new Map();
    this._ngModuleOfTypes = new Map();
    this._shallowModuleCache = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompileMetadataResolver, [{
    key: "getReflector",
    value: function getReflector() {
      return this._reflector;
    }
  }, {
    key: "clearCacheFor",
    value: function clearCacheFor(type) {
      var dirMeta = this._directiveCache.get(type);

      this._directiveCache.delete(type);

      this._nonNormalizedDirectiveCache.delete(type);

      this._summaryCache.delete(type);

      this._pipeCache.delete(type);

      this._ngModuleOfTypes.delete(type); // Clear all of the NgModule as they contain transitive information!


      this._ngModuleCache.clear();

      if (dirMeta) {
        this._directiveNormalizer.clearCacheFor(dirMeta);
      }
    }
  }, {
    key: "clearCache",
    value: function clearCache() {
      this._directiveCache.clear();

      this._nonNormalizedDirectiveCache.clear();

      this._summaryCache.clear();

      this._pipeCache.clear();

      this._ngModuleCache.clear();

      this._ngModuleOfTypes.clear();

      this._directiveNormalizer.clearCache();
    }
  }, {
    key: "_createProxyClass",
    value: function _createProxyClass(baseType, name) {
      var delegate = null;

      var proxyClass = function proxyClass() {
        if (!delegate) {
          throw new Error("Illegal state: Class ".concat(name, " for type ").concat(stringify(baseType), " is not compiled yet!"));
        }

        return delegate.apply(this, arguments);
      };

      proxyClass.setDelegate = function (d) {
        delegate = d;
        proxyClass.prototype = d.prototype;
      }; // Make stringify work correctly


      proxyClass.overriddenName = name;
      return proxyClass;
    }
  }, {
    key: "getGeneratedClass",
    value: function getGeneratedClass(dirType, name) {
      if (dirType instanceof StaticSymbol) {
        return this._staticSymbolCache.get(ngfactoryFilePath(dirType.filePath), name);
      } else {
        return this._createProxyClass(dirType, name);
      }
    }
  }, {
    key: "getComponentViewClass",
    value: function getComponentViewClass(dirType) {
      return this.getGeneratedClass(dirType, viewClassName(dirType, 0));
    }
  }, {
    key: "getHostComponentViewClass",
    value: function getHostComponentViewClass(dirType) {
      return this.getGeneratedClass(dirType, hostViewClassName(dirType));
    }
  }, {
    key: "getHostComponentType",
    value: function getHostComponentType(dirType) {
      var name = "".concat(identifierName({
        reference: dirType
      }), "_Host");

      if (dirType instanceof StaticSymbol) {
        return this._staticSymbolCache.get(dirType.filePath, name);
      }

      return this._createProxyClass(dirType, name);
    }
  }, {
    key: "getRendererType",
    value: function getRendererType(dirType) {
      if (dirType instanceof StaticSymbol) {
        return this._staticSymbolCache.get(ngfactoryFilePath(dirType.filePath), rendererTypeName(dirType));
      } else {
        // returning an object as proxy,
        // that we fill later during runtime compilation.
        return {};
      }
    }
  }, {
    key: "getComponentFactory",
    value: function getComponentFactory(selector, dirType, inputs, outputs) {
      if (dirType instanceof StaticSymbol) {
        return this._staticSymbolCache.get(ngfactoryFilePath(dirType.filePath), componentFactoryName(dirType));
      } else {
        var hostView = this.getHostComponentViewClass(dirType); // Note: ngContentSelectors will be filled later once the template is
        // loaded.

        var createComponentFactory = this._reflector.resolveExternalReference(Identifiers.createComponentFactory);

        return createComponentFactory(selector, dirType, hostView, inputs, outputs, []);
      }
    }
  }, {
    key: "initComponentFactory",
    value: function initComponentFactory(factory, ngContentSelectors) {
      if (!(factory instanceof StaticSymbol)) {
        var _factory$ngContentSel;

        (_factory$ngContentSel = factory.ngContentSelectors).push.apply(_factory$ngContentSel, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ngContentSelectors));
      }
    }
  }, {
    key: "_loadSummary",
    value: function _loadSummary(type, kind) {
      var typeSummary = this._summaryCache.get(type);

      if (!typeSummary) {
        var summary = this._summaryResolver.resolveSummary(type);

        typeSummary = summary ? summary.type : null;

        this._summaryCache.set(type, typeSummary || null);
      }

      return typeSummary && typeSummary.summaryKind === kind ? typeSummary : null;
    }
  }, {
    key: "getHostComponentMetadata",
    value: function getHostComponentMetadata(compMeta, hostViewType) {
      var hostType = this.getHostComponentType(compMeta.type.reference);

      if (!hostViewType) {
        hostViewType = this.getHostComponentViewClass(hostType);
      } // Note: ! is ok here as this method should only be called with normalized directive
      // metadata, which always fills in the selector.


      var template = CssSelector.parse(compMeta.selector)[0].getMatchingElementTemplate();
      var templateUrl = '';

      var htmlAst = this._htmlParser.parse(template, templateUrl);

      return CompileDirectiveMetadata.create({
        isHost: true,
        type: {
          reference: hostType,
          diDeps: [],
          lifecycleHooks: []
        },
        template: new CompileTemplateMetadata({
          encapsulation: ViewEncapsulation.None,
          template: template,
          templateUrl: templateUrl,
          htmlAst: htmlAst,
          styles: [],
          styleUrls: [],
          ngContentSelectors: [],
          animations: [],
          isInline: true,
          externalStylesheets: [],
          interpolation: null,
          preserveWhitespaces: false
        }),
        exportAs: null,
        changeDetection: ChangeDetectionStrategy.Default,
        inputs: [],
        outputs: [],
        host: {},
        isComponent: true,
        selector: '*',
        providers: [],
        viewProviders: [],
        queries: [],
        guards: {},
        viewQueries: [],
        componentViewType: hostViewType,
        rendererType: {
          id: '__Host__',
          encapsulation: ViewEncapsulation.None,
          styles: [],
          data: {}
        },
        entryComponents: [],
        componentFactory: null
      });
    }
  }, {
    key: "loadDirectiveMetadata",
    value: function loadDirectiveMetadata(ngModuleType, directiveType, isSync) {
      var _this216 = this;

      if (this._directiveCache.has(directiveType)) {
        return null;
      }

      directiveType = resolveForwardRef(directiveType);

      var _this$getNonNormalize = this.getNonNormalizedDirectiveMetadata(directiveType),
          annotation = _this$getNonNormalize.annotation,
          metadata = _this$getNonNormalize.metadata;

      var createDirectiveMetadata = function createDirectiveMetadata(templateMetadata) {
        var normalizedDirMeta = new CompileDirectiveMetadata({
          isHost: false,
          type: metadata.type,
          isComponent: metadata.isComponent,
          selector: metadata.selector,
          exportAs: metadata.exportAs,
          changeDetection: metadata.changeDetection,
          inputs: metadata.inputs,
          outputs: metadata.outputs,
          hostListeners: metadata.hostListeners,
          hostProperties: metadata.hostProperties,
          hostAttributes: metadata.hostAttributes,
          providers: metadata.providers,
          viewProviders: metadata.viewProviders,
          queries: metadata.queries,
          guards: metadata.guards,
          viewQueries: metadata.viewQueries,
          entryComponents: metadata.entryComponents,
          componentViewType: metadata.componentViewType,
          rendererType: metadata.rendererType,
          componentFactory: metadata.componentFactory,
          template: templateMetadata
        });

        if (templateMetadata) {
          _this216.initComponentFactory(metadata.componentFactory, templateMetadata.ngContentSelectors);
        }

        _this216._directiveCache.set(directiveType, normalizedDirMeta);

        _this216._summaryCache.set(directiveType, normalizedDirMeta.toSummary());

        return null;
      };

      if (metadata.isComponent) {
        var template = metadata.template;

        var templateMeta = this._directiveNormalizer.normalizeTemplate({
          ngModuleType: ngModuleType,
          componentType: directiveType,
          moduleUrl: this._reflector.componentModuleUrl(directiveType, annotation),
          encapsulation: template.encapsulation,
          template: template.template,
          templateUrl: template.templateUrl,
          styles: template.styles,
          styleUrls: template.styleUrls,
          animations: template.animations,
          interpolation: template.interpolation,
          preserveWhitespaces: template.preserveWhitespaces
        });

        if (isPromise(templateMeta) && isSync) {
          this._reportError(componentStillLoadingError(directiveType), directiveType);

          return null;
        }

        return SyncAsync.then(templateMeta, createDirectiveMetadata);
      } else {
        // directive
        createDirectiveMetadata(null);
        return null;
      }
    }
  }, {
    key: "getNonNormalizedDirectiveMetadata",
    value: function getNonNormalizedDirectiveMetadata(directiveType) {
      var _this217 = this;

      directiveType = resolveForwardRef(directiveType);

      if (!directiveType) {
        return null;
      }

      var cacheEntry = this._nonNormalizedDirectiveCache.get(directiveType);

      if (cacheEntry) {
        return cacheEntry;
      }

      var dirMeta = this._directiveResolver.resolve(directiveType, false);

      if (!dirMeta) {
        return null;
      }

      var nonNormalizedTemplateMetadata = undefined;

      if (createComponent.isTypeOf(dirMeta)) {
        // component
        var compMeta = dirMeta;
        assertArrayOfStrings('styles', compMeta.styles);
        assertArrayOfStrings('styleUrls', compMeta.styleUrls);
        assertInterpolationSymbols('interpolation', compMeta.interpolation);
        var animations = compMeta.animations;
        nonNormalizedTemplateMetadata = new CompileTemplateMetadata({
          encapsulation: noUndefined(compMeta.encapsulation),
          template: noUndefined(compMeta.template),
          templateUrl: noUndefined(compMeta.templateUrl),
          htmlAst: null,
          styles: compMeta.styles || [],
          styleUrls: compMeta.styleUrls || [],
          animations: animations || [],
          interpolation: noUndefined(compMeta.interpolation),
          isInline: !!compMeta.template,
          externalStylesheets: [],
          ngContentSelectors: [],
          preserveWhitespaces: noUndefined(dirMeta.preserveWhitespaces)
        });
      }

      var changeDetectionStrategy = null;
      var viewProviders = [];
      var entryComponentMetadata = [];
      var selector = dirMeta.selector;

      if (createComponent.isTypeOf(dirMeta)) {
        // Component
        var _compMeta = dirMeta;
        changeDetectionStrategy = _compMeta.changeDetection;

        if (_compMeta.viewProviders) {
          viewProviders = this._getProvidersMetadata(_compMeta.viewProviders, entryComponentMetadata, "viewProviders for \"".concat(stringifyType(directiveType), "\""), [], directiveType);
        }

        if (_compMeta.entryComponents) {
          entryComponentMetadata = flattenAndDedupeArray(_compMeta.entryComponents).map(function (type) {
            return _this217._getEntryComponentMetadata(type);
          }).concat(entryComponentMetadata);
        }

        if (!selector) {
          selector = this._schemaRegistry.getDefaultComponentElementName();
        }
      } else {
        // Directive
        if (!selector) {
          selector = null;
        }
      }

      var providers = [];

      if (dirMeta.providers != null) {
        providers = this._getProvidersMetadata(dirMeta.providers, entryComponentMetadata, "providers for \"".concat(stringifyType(directiveType), "\""), [], directiveType);
      }

      var queries = [];
      var viewQueries = [];

      if (dirMeta.queries != null) {
        queries = this._getQueriesMetadata(dirMeta.queries, false, directiveType);
        viewQueries = this._getQueriesMetadata(dirMeta.queries, true, directiveType);
      }

      var metadata = CompileDirectiveMetadata.create({
        isHost: false,
        selector: selector,
        exportAs: noUndefined(dirMeta.exportAs),
        isComponent: !!nonNormalizedTemplateMetadata,
        type: this._getTypeMetadata(directiveType),
        template: nonNormalizedTemplateMetadata,
        changeDetection: changeDetectionStrategy,
        inputs: dirMeta.inputs || [],
        outputs: dirMeta.outputs || [],
        host: dirMeta.host || {},
        providers: providers || [],
        viewProviders: viewProviders || [],
        queries: queries || [],
        guards: dirMeta.guards || {},
        viewQueries: viewQueries || [],
        entryComponents: entryComponentMetadata,
        componentViewType: nonNormalizedTemplateMetadata ? this.getComponentViewClass(directiveType) : null,
        rendererType: nonNormalizedTemplateMetadata ? this.getRendererType(directiveType) : null,
        componentFactory: null
      });

      if (nonNormalizedTemplateMetadata) {
        metadata.componentFactory = this.getComponentFactory(selector, directiveType, metadata.inputs, metadata.outputs);
      }

      cacheEntry = {
        metadata: metadata,
        annotation: dirMeta
      };

      this._nonNormalizedDirectiveCache.set(directiveType, cacheEntry);

      return cacheEntry;
    }
    /**
     * Gets the metadata for the given directive.
     * This assumes `loadNgModuleDirectiveAndPipeMetadata` has been called first.
     */

  }, {
    key: "getDirectiveMetadata",
    value: function getDirectiveMetadata(directiveType) {
      var dirMeta = this._directiveCache.get(directiveType);

      if (!dirMeta) {
        this._reportError(syntaxError("Illegal state: getDirectiveMetadata can only be called after loadNgModuleDirectiveAndPipeMetadata for a module that declares it. Directive ".concat(stringifyType(directiveType), ".")), directiveType);
      }

      return dirMeta;
    }
  }, {
    key: "getDirectiveSummary",
    value: function getDirectiveSummary(dirType) {
      var dirSummary = this._loadSummary(dirType, CompileSummaryKind.Directive);

      if (!dirSummary) {
        this._reportError(syntaxError("Illegal state: Could not load the summary for directive ".concat(stringifyType(dirType), ".")), dirType);
      }

      return dirSummary;
    }
  }, {
    key: "isDirective",
    value: function isDirective(type) {
      return !!this._loadSummary(type, CompileSummaryKind.Directive) || this._directiveResolver.isDirective(type);
    }
  }, {
    key: "isAbstractDirective",
    value: function isAbstractDirective(type) {
      var summary = this._loadSummary(type, CompileSummaryKind.Directive);

      if (summary && !summary.isComponent) {
        return !summary.selector;
      }

      var meta = this._directiveResolver.resolve(type, false);

      if (meta && !createComponent.isTypeOf(meta)) {
        return !meta.selector;
      }

      return false;
    }
  }, {
    key: "isPipe",
    value: function isPipe(type) {
      return !!this._loadSummary(type, CompileSummaryKind.Pipe) || this._pipeResolver.isPipe(type);
    }
  }, {
    key: "isNgModule",
    value: function isNgModule(type) {
      return !!this._loadSummary(type, CompileSummaryKind.NgModule) || this._ngModuleResolver.isNgModule(type);
    }
  }, {
    key: "getNgModuleSummary",
    value: function getNgModuleSummary(moduleType) {
      var alreadyCollecting = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      var moduleSummary = this._loadSummary(moduleType, CompileSummaryKind.NgModule);

      if (!moduleSummary) {
        var moduleMeta = this.getNgModuleMetadata(moduleType, false, alreadyCollecting);
        moduleSummary = moduleMeta ? moduleMeta.toSummary() : null;

        if (moduleSummary) {
          this._summaryCache.set(moduleType, moduleSummary);
        }
      }

      return moduleSummary;
    }
    /**
     * Loads the declared directives and pipes of an NgModule.
     */

  }, {
    key: "loadNgModuleDirectiveAndPipeMetadata",
    value: function loadNgModuleDirectiveAndPipeMetadata(moduleType, isSync) {
      var _this218 = this;

      var throwIfNotFound = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
      var ngModule = this.getNgModuleMetadata(moduleType, throwIfNotFound);
      var loading = [];

      if (ngModule) {
        ngModule.declaredDirectives.forEach(function (id) {
          var promise = _this218.loadDirectiveMetadata(moduleType, id.reference, isSync);

          if (promise) {
            loading.push(promise);
          }
        });
        ngModule.declaredPipes.forEach(function (id) {
          return _this218._loadPipeMetadata(id.reference);
        });
      }

      return Promise.all(loading);
    }
  }, {
    key: "getShallowModuleMetadata",
    value: function getShallowModuleMetadata(moduleType) {
      var compileMeta = this._shallowModuleCache.get(moduleType);

      if (compileMeta) {
        return compileMeta;
      }

      var ngModuleMeta = findLast(this._reflector.shallowAnnotations(moduleType), createNgModule.isTypeOf);
      compileMeta = {
        type: this._getTypeMetadata(moduleType),
        rawExports: ngModuleMeta.exports,
        rawImports: ngModuleMeta.imports,
        rawProviders: ngModuleMeta.providers
      };

      this._shallowModuleCache.set(moduleType, compileMeta);

      return compileMeta;
    }
  }, {
    key: "getNgModuleMetadata",
    value: function getNgModuleMetadata(moduleType) {
      var _this219 = this;

      var throwIfNotFound = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var alreadyCollecting = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
      moduleType = resolveForwardRef(moduleType);

      var compileMeta = this._ngModuleCache.get(moduleType);

      if (compileMeta) {
        return compileMeta;
      }

      var meta = this._ngModuleResolver.resolve(moduleType, throwIfNotFound);

      if (!meta) {
        return null;
      }

      var declaredDirectives = [];
      var exportedNonModuleIdentifiers = [];
      var declaredPipes = [];
      var importedModules = [];
      var exportedModules = [];
      var providers = [];
      var entryComponents = [];
      var bootstrapComponents = [];
      var schemas = [];

      if (meta.imports) {
        flattenAndDedupeArray(meta.imports).forEach(function (importedType) {
          var importedModuleType = undefined;

          if (isValidType(importedType)) {
            importedModuleType = importedType;
          } else if (importedType && importedType.ngModule) {
            var moduleWithProviders = importedType;
            importedModuleType = moduleWithProviders.ngModule;

            if (moduleWithProviders.providers) {
              providers.push.apply(providers, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this219._getProvidersMetadata(moduleWithProviders.providers, entryComponents, "provider for the NgModule '".concat(stringifyType(importedModuleType), "'"), [], importedType)));
            }
          }

          if (importedModuleType) {
            if (_this219._checkSelfImport(moduleType, importedModuleType)) return;
            if (!alreadyCollecting) alreadyCollecting = new Set();

            if (alreadyCollecting.has(importedModuleType)) {
              _this219._reportError(syntaxError("".concat(_this219._getTypeDescriptor(importedModuleType), " '").concat(stringifyType(importedType), "' is imported recursively by the module '").concat(stringifyType(moduleType), "'.")), moduleType);

              return;
            }

            alreadyCollecting.add(importedModuleType);

            var importedModuleSummary = _this219.getNgModuleSummary(importedModuleType, alreadyCollecting);

            alreadyCollecting.delete(importedModuleType);

            if (!importedModuleSummary) {
              _this219._reportError(syntaxError("Unexpected ".concat(_this219._getTypeDescriptor(importedType), " '").concat(stringifyType(importedType), "' imported by the module '").concat(stringifyType(moduleType), "'. Please add a @NgModule annotation.")), moduleType);

              return;
            }

            importedModules.push(importedModuleSummary);
          } else {
            _this219._reportError(syntaxError("Unexpected value '".concat(stringifyType(importedType), "' imported by the module '").concat(stringifyType(moduleType), "'")), moduleType);

            return;
          }
        });
      }

      if (meta.exports) {
        flattenAndDedupeArray(meta.exports).forEach(function (exportedType) {
          if (!isValidType(exportedType)) {
            _this219._reportError(syntaxError("Unexpected value '".concat(stringifyType(exportedType), "' exported by the module '").concat(stringifyType(moduleType), "'")), moduleType);

            return;
          }

          if (!alreadyCollecting) alreadyCollecting = new Set();

          if (alreadyCollecting.has(exportedType)) {
            _this219._reportError(syntaxError("".concat(_this219._getTypeDescriptor(exportedType), " '").concat(stringify(exportedType), "' is exported recursively by the module '").concat(stringifyType(moduleType), "'")), moduleType);

            return;
          }

          alreadyCollecting.add(exportedType);

          var exportedModuleSummary = _this219.getNgModuleSummary(exportedType, alreadyCollecting);

          alreadyCollecting.delete(exportedType);

          if (exportedModuleSummary) {
            exportedModules.push(exportedModuleSummary);
          } else {
            exportedNonModuleIdentifiers.push(_this219._getIdentifierMetadata(exportedType));
          }
        });
      } // Note: This will be modified later, so we rely on
      // getting a new instance every time!


      var transitiveModule = this._getTransitiveNgModuleMetadata(importedModules, exportedModules);

      if (meta.declarations) {
        flattenAndDedupeArray(meta.declarations).forEach(function (declaredType) {
          if (!isValidType(declaredType)) {
            _this219._reportError(syntaxError("Unexpected value '".concat(stringifyType(declaredType), "' declared by the module '").concat(stringifyType(moduleType), "'")), moduleType);

            return;
          }

          var declaredIdentifier = _this219._getIdentifierMetadata(declaredType);

          if (_this219.isDirective(declaredType)) {
            if (_this219.isAbstractDirective(declaredType)) {
              _this219._reportError(syntaxError("Directive ".concat(stringifyType(declaredType), " has no selector, please add it!")), declaredType);
            }

            transitiveModule.addDirective(declaredIdentifier);
            declaredDirectives.push(declaredIdentifier);

            _this219._addTypeToModule(declaredType, moduleType);
          } else if (_this219.isPipe(declaredType)) {
            transitiveModule.addPipe(declaredIdentifier);
            transitiveModule.pipes.push(declaredIdentifier);
            declaredPipes.push(declaredIdentifier);

            _this219._addTypeToModule(declaredType, moduleType);
          } else {
            _this219._reportError(syntaxError("Unexpected ".concat(_this219._getTypeDescriptor(declaredType), " '").concat(stringifyType(declaredType), "' declared by the module '").concat(stringifyType(moduleType), "'. Please add a @Pipe/@Directive/@Component annotation.")), moduleType);

            return;
          }
        });
      }

      var exportedDirectives = [];
      var exportedPipes = [];
      exportedNonModuleIdentifiers.forEach(function (exportedId) {
        if (transitiveModule.directivesSet.has(exportedId.reference)) {
          exportedDirectives.push(exportedId);
          transitiveModule.addExportedDirective(exportedId);
        } else if (transitiveModule.pipesSet.has(exportedId.reference)) {
          exportedPipes.push(exportedId);
          transitiveModule.addExportedPipe(exportedId);
        } else {
          _this219._reportError(syntaxError("Can't export ".concat(_this219._getTypeDescriptor(exportedId.reference), " ").concat(stringifyType(exportedId.reference), " from ").concat(stringifyType(moduleType), " as it was neither declared nor imported!")), moduleType);

          return;
        }
      }); // The providers of the module have to go last
      // so that they overwrite any other provider we already added.

      if (meta.providers) {
        providers.push.apply(providers, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._getProvidersMetadata(meta.providers, entryComponents, "provider for the NgModule '".concat(stringifyType(moduleType), "'"), [], moduleType)));
      }

      if (meta.entryComponents) {
        entryComponents.push.apply(entryComponents, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(flattenAndDedupeArray(meta.entryComponents).map(function (type) {
          return _this219._getEntryComponentMetadata(type);
        })));
      }

      if (meta.bootstrap) {
        flattenAndDedupeArray(meta.bootstrap).forEach(function (type) {
          if (!isValidType(type)) {
            _this219._reportError(syntaxError("Unexpected value '".concat(stringifyType(type), "' used in the bootstrap property of module '").concat(stringifyType(moduleType), "'")), moduleType);

            return;
          }

          bootstrapComponents.push(_this219._getIdentifierMetadata(type));
        });
      }

      entryComponents.push.apply(entryComponents, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(bootstrapComponents.map(function (type) {
        return _this219._getEntryComponentMetadata(type.reference);
      })));

      if (meta.schemas) {
        schemas.push.apply(schemas, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(flattenAndDedupeArray(meta.schemas)));
      }

      compileMeta = new CompileNgModuleMetadata({
        type: this._getTypeMetadata(moduleType),
        providers: providers,
        entryComponents: entryComponents,
        bootstrapComponents: bootstrapComponents,
        schemas: schemas,
        declaredDirectives: declaredDirectives,
        exportedDirectives: exportedDirectives,
        declaredPipes: declaredPipes,
        exportedPipes: exportedPipes,
        importedModules: importedModules,
        exportedModules: exportedModules,
        transitiveModule: transitiveModule,
        id: meta.id || null
      });
      entryComponents.forEach(function (id) {
        return transitiveModule.addEntryComponent(id);
      });
      providers.forEach(function (provider) {
        return transitiveModule.addProvider(provider, compileMeta.type);
      });
      transitiveModule.addModule(compileMeta.type);

      this._ngModuleCache.set(moduleType, compileMeta);

      return compileMeta;
    }
  }, {
    key: "_checkSelfImport",
    value: function _checkSelfImport(moduleType, importedModuleType) {
      if (moduleType === importedModuleType) {
        this._reportError(syntaxError("'".concat(stringifyType(moduleType), "' module can't import itself")), moduleType);

        return true;
      }

      return false;
    }
  }, {
    key: "_getTypeDescriptor",
    value: function _getTypeDescriptor(type) {
      if (isValidType(type)) {
        if (this.isDirective(type)) {
          return 'directive';
        }

        if (this.isPipe(type)) {
          return 'pipe';
        }

        if (this.isNgModule(type)) {
          return 'module';
        }
      }

      if (type.provide) {
        return 'provider';
      }

      return 'value';
    }
  }, {
    key: "_addTypeToModule",
    value: function _addTypeToModule(type, moduleType) {
      var oldModule = this._ngModuleOfTypes.get(type);

      if (oldModule && oldModule !== moduleType) {
        this._reportError(syntaxError("Type ".concat(stringifyType(type), " is part of the declarations of 2 modules: ").concat(stringifyType(oldModule), " and ").concat(stringifyType(moduleType), "! ") + "Please consider moving ".concat(stringifyType(type), " to a higher module that imports ").concat(stringifyType(oldModule), " and ").concat(stringifyType(moduleType), ". ") + "You can also create a new NgModule that exports and includes ".concat(stringifyType(type), " then import that NgModule in ").concat(stringifyType(oldModule), " and ").concat(stringifyType(moduleType), ".")), moduleType);

        return;
      }

      this._ngModuleOfTypes.set(type, moduleType);
    }
  }, {
    key: "_getTransitiveNgModuleMetadata",
    value: function _getTransitiveNgModuleMetadata(importedModules, exportedModules) {
      // collect `providers` / `entryComponents` from all imported and all exported modules
      var result = new TransitiveCompileNgModuleMetadata();
      var modulesByToken = new Map();
      importedModules.concat(exportedModules).forEach(function (modSummary) {
        modSummary.modules.forEach(function (mod) {
          return result.addModule(mod);
        });
        modSummary.entryComponents.forEach(function (comp) {
          return result.addEntryComponent(comp);
        });
        var addedTokens = new Set();
        modSummary.providers.forEach(function (entry) {
          var tokenRef = tokenReference(entry.provider.token);
          var prevModules = modulesByToken.get(tokenRef);

          if (!prevModules) {
            prevModules = new Set();
            modulesByToken.set(tokenRef, prevModules);
          }

          var moduleRef = entry.module.reference; // Note: the providers of one module may still contain multiple providers
          // per token (e.g. for multi providers), and we need to preserve these.

          if (addedTokens.has(tokenRef) || !prevModules.has(moduleRef)) {
            prevModules.add(moduleRef);
            addedTokens.add(tokenRef);
            result.addProvider(entry.provider, entry.module);
          }
        });
      });
      exportedModules.forEach(function (modSummary) {
        modSummary.exportedDirectives.forEach(function (id) {
          return result.addExportedDirective(id);
        });
        modSummary.exportedPipes.forEach(function (id) {
          return result.addExportedPipe(id);
        });
      });
      importedModules.forEach(function (modSummary) {
        modSummary.exportedDirectives.forEach(function (id) {
          return result.addDirective(id);
        });
        modSummary.exportedPipes.forEach(function (id) {
          return result.addPipe(id);
        });
      });
      return result;
    }
  }, {
    key: "_getIdentifierMetadata",
    value: function _getIdentifierMetadata(type) {
      type = resolveForwardRef(type);
      return {
        reference: type
      };
    }
  }, {
    key: "isInjectable",
    value: function isInjectable(type) {
      var annotations = this._reflector.tryAnnotations(type);

      return annotations.some(function (ann) {
        return createInjectable.isTypeOf(ann);
      });
    }
  }, {
    key: "getInjectableSummary",
    value: function getInjectableSummary(type) {
      return {
        summaryKind: CompileSummaryKind.Injectable,
        type: this._getTypeMetadata(type, null, false)
      };
    }
  }, {
    key: "getInjectableMetadata",
    value: function getInjectableMetadata(type) {
      var dependencies = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      var throwOnUnknownDeps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      var typeSummary = this._loadSummary(type, CompileSummaryKind.Injectable);

      var typeMetadata = typeSummary ? typeSummary.type : this._getTypeMetadata(type, dependencies, throwOnUnknownDeps);

      var annotations = this._reflector.annotations(type).filter(function (ann) {
        return createInjectable.isTypeOf(ann);
      });

      if (annotations.length === 0) {
        return null;
      }

      var meta = annotations[annotations.length - 1];
      return {
        symbol: type,
        type: typeMetadata,
        providedIn: meta.providedIn,
        useValue: meta.useValue,
        useClass: meta.useClass,
        useExisting: meta.useExisting,
        useFactory: meta.useFactory,
        deps: meta.deps
      };
    }
  }, {
    key: "_getTypeMetadata",
    value: function _getTypeMetadata(type) {
      var dependencies = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      var throwOnUnknownDeps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      var identifier = this._getIdentifierMetadata(type);

      return {
        reference: identifier.reference,
        diDeps: this._getDependenciesMetadata(identifier.reference, dependencies, throwOnUnknownDeps),
        lifecycleHooks: getAllLifecycleHooks(this._reflector, identifier.reference)
      };
    }
  }, {
    key: "_getFactoryMetadata",
    value: function _getFactoryMetadata(factory) {
      var dependencies = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      factory = resolveForwardRef(factory);
      return {
        reference: factory,
        diDeps: this._getDependenciesMetadata(factory, dependencies)
      };
    }
    /**
     * Gets the metadata for the given pipe.
     * This assumes `loadNgModuleDirectiveAndPipeMetadata` has been called first.
     */

  }, {
    key: "getPipeMetadata",
    value: function getPipeMetadata(pipeType) {
      var pipeMeta = this._pipeCache.get(pipeType);

      if (!pipeMeta) {
        this._reportError(syntaxError("Illegal state: getPipeMetadata can only be called after loadNgModuleDirectiveAndPipeMetadata for a module that declares it. Pipe ".concat(stringifyType(pipeType), ".")), pipeType);
      }

      return pipeMeta || null;
    }
  }, {
    key: "getPipeSummary",
    value: function getPipeSummary(pipeType) {
      var pipeSummary = this._loadSummary(pipeType, CompileSummaryKind.Pipe);

      if (!pipeSummary) {
        this._reportError(syntaxError("Illegal state: Could not load the summary for pipe ".concat(stringifyType(pipeType), ".")), pipeType);
      }

      return pipeSummary;
    }
  }, {
    key: "getOrLoadPipeMetadata",
    value: function getOrLoadPipeMetadata(pipeType) {
      var pipeMeta = this._pipeCache.get(pipeType);

      if (!pipeMeta) {
        pipeMeta = this._loadPipeMetadata(pipeType);
      }

      return pipeMeta;
    }
  }, {
    key: "_loadPipeMetadata",
    value: function _loadPipeMetadata(pipeType) {
      pipeType = resolveForwardRef(pipeType);

      var pipeAnnotation = this._pipeResolver.resolve(pipeType);

      var pipeMeta = new CompilePipeMetadata({
        type: this._getTypeMetadata(pipeType),
        name: pipeAnnotation.name,
        pure: !!pipeAnnotation.pure
      });

      this._pipeCache.set(pipeType, pipeMeta);

      this._summaryCache.set(pipeType, pipeMeta.toSummary());

      return pipeMeta;
    }
  }, {
    key: "_getDependenciesMetadata",
    value: function _getDependenciesMetadata(typeOrFunc, dependencies) {
      var _this220 = this;

      var throwOnUnknownDeps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
      var hasUnknownDeps = false;
      var params = dependencies || this._reflector.parameters(typeOrFunc) || [];
      var dependenciesMetadata = params.map(function (param) {
        var isAttribute = false;
        var isHost = false;
        var isSelf = false;
        var isSkipSelf = false;
        var isOptional = false;
        var token = null;

        if (Array.isArray(param)) {
          param.forEach(function (paramEntry) {
            if (createHost.isTypeOf(paramEntry)) {
              isHost = true;
            } else if (createSelf.isTypeOf(paramEntry)) {
              isSelf = true;
            } else if (createSkipSelf.isTypeOf(paramEntry)) {
              isSkipSelf = true;
            } else if (createOptional.isTypeOf(paramEntry)) {
              isOptional = true;
            } else if (createAttribute.isTypeOf(paramEntry)) {
              isAttribute = true;
              token = paramEntry.attributeName;
            } else if (createInject.isTypeOf(paramEntry)) {
              token = paramEntry.token;
            } else if (createInjectionToken.isTypeOf(paramEntry) || paramEntry instanceof StaticSymbol) {
              token = paramEntry;
            } else if (isValidType(paramEntry) && token == null) {
              token = paramEntry;
            }
          });
        } else {
          token = param;
        }

        if (token == null) {
          hasUnknownDeps = true;
          return {};
        }

        return {
          isAttribute: isAttribute,
          isHost: isHost,
          isSelf: isSelf,
          isSkipSelf: isSkipSelf,
          isOptional: isOptional,
          token: _this220._getTokenMetadata(token)
        };
      });

      if (hasUnknownDeps) {
        var depsTokens = dependenciesMetadata.map(function (dep) {
          return dep.token ? stringifyType(dep.token) : '?';
        }).join(', ');
        var message = "Can't resolve all parameters for ".concat(stringifyType(typeOrFunc), ": (").concat(depsTokens, ").");

        if (throwOnUnknownDeps || this._config.strictInjectionParameters) {
          this._reportError(syntaxError(message), typeOrFunc);
        }
      }

      return dependenciesMetadata;
    }
  }, {
    key: "_getTokenMetadata",
    value: function _getTokenMetadata(token) {
      token = resolveForwardRef(token);
      var compileToken;

      if (typeof token === 'string') {
        compileToken = {
          value: token
        };
      } else {
        compileToken = {
          identifier: {
            reference: token
          }
        };
      }

      return compileToken;
    }
  }, {
    key: "_getProvidersMetadata",
    value: function _getProvidersMetadata(providers, targetEntryComponents, debugInfo) {
      var _this221 = this;

      var compileProviders = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
      var type = arguments.length > 4 ? arguments[4] : undefined;
      providers.forEach(function (provider, providerIdx) {
        if (Array.isArray(provider)) {
          _this221._getProvidersMetadata(provider, targetEntryComponents, debugInfo, compileProviders);
        } else {
          provider = resolveForwardRef(provider);
          var providerMeta = undefined;

          if (provider && typeof provider === 'object' && provider.hasOwnProperty('provide')) {
            _this221._validateProvider(provider);

            providerMeta = new ProviderMeta(provider.provide, provider);
          } else if (isValidType(provider)) {
            providerMeta = new ProviderMeta(provider, {
              useClass: provider
            });
          } else if (provider === void 0) {
            _this221._reportError(syntaxError("Encountered undefined provider! Usually this means you have a circular dependencies. This might be caused by using 'barrel' index.ts files."));

            return;
          } else {
            var providersInfo = providers.reduce(function (soFar, seenProvider, seenProviderIdx) {
              if (seenProviderIdx < providerIdx) {
                soFar.push("".concat(stringifyType(seenProvider)));
              } else if (seenProviderIdx == providerIdx) {
                soFar.push("?".concat(stringifyType(seenProvider), "?"));
              } else if (seenProviderIdx == providerIdx + 1) {
                soFar.push('...');
              }

              return soFar;
            }, []).join(', ');

            _this221._reportError(syntaxError("Invalid ".concat(debugInfo ? debugInfo : 'provider', " - only instances of Provider and Type are allowed, got: [").concat(providersInfo, "]")), type);

            return;
          }

          if (providerMeta.token === _this221._reflector.resolveExternalReference(Identifiers.ANALYZE_FOR_ENTRY_COMPONENTS)) {
            targetEntryComponents.push.apply(targetEntryComponents, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this221._getEntryComponentsFromProvider(providerMeta, type)));
          } else {
            compileProviders.push(_this221.getProviderMetadata(providerMeta));
          }
        }
      });
      return compileProviders;
    }
  }, {
    key: "_validateProvider",
    value: function _validateProvider(provider) {
      if (provider.hasOwnProperty('useClass') && provider.useClass == null) {
        this._reportError(syntaxError("Invalid provider for ".concat(stringifyType(provider.provide), ". useClass cannot be ").concat(provider.useClass, ".\n           Usually it happens when:\n           1. There's a circular dependency (might be caused by using index.ts (barrel) files).\n           2. Class was used before it was declared. Use forwardRef in this case.")));
      }
    }
  }, {
    key: "_getEntryComponentsFromProvider",
    value: function _getEntryComponentsFromProvider(provider, type) {
      var _this222 = this;

      var components = [];
      var collectedIdentifiers = [];

      if (provider.useFactory || provider.useExisting || provider.useClass) {
        this._reportError(syntaxError("The ANALYZE_FOR_ENTRY_COMPONENTS token only supports useValue!"), type);

        return [];
      }

      if (!provider.multi) {
        this._reportError(syntaxError("The ANALYZE_FOR_ENTRY_COMPONENTS token only supports 'multi = true'!"), type);

        return [];
      }

      extractIdentifiers(provider.useValue, collectedIdentifiers);
      collectedIdentifiers.forEach(function (identifier) {
        var entry = _this222._getEntryComponentMetadata(identifier.reference, false);

        if (entry) {
          components.push(entry);
        }
      });
      return components;
    }
  }, {
    key: "_getEntryComponentMetadata",
    value: function _getEntryComponentMetadata(dirType) {
      var throwIfNotFound = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var dirMeta = this.getNonNormalizedDirectiveMetadata(dirType);

      if (dirMeta && dirMeta.metadata.isComponent) {
        return {
          componentType: dirType,
          componentFactory: dirMeta.metadata.componentFactory
        };
      }

      var dirSummary = this._loadSummary(dirType, CompileSummaryKind.Directive);

      if (dirSummary && dirSummary.isComponent) {
        return {
          componentType: dirType,
          componentFactory: dirSummary.componentFactory
        };
      }

      if (throwIfNotFound) {
        throw syntaxError("".concat(dirType.name, " cannot be used as an entry component."));
      }

      return null;
    }
  }, {
    key: "_getInjectableTypeMetadata",
    value: function _getInjectableTypeMetadata(type) {
      var dependencies = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      var typeSummary = this._loadSummary(type, CompileSummaryKind.Injectable);

      if (typeSummary) {
        return typeSummary.type;
      }

      return this._getTypeMetadata(type, dependencies);
    }
  }, {
    key: "getProviderMetadata",
    value: function getProviderMetadata(provider) {
      var compileDeps = undefined;
      var compileTypeMetadata = null;
      var compileFactoryMetadata = null;

      var token = this._getTokenMetadata(provider.token);

      if (provider.useClass) {
        compileTypeMetadata = this._getInjectableTypeMetadata(provider.useClass, provider.dependencies);
        compileDeps = compileTypeMetadata.diDeps;

        if (provider.token === provider.useClass) {
          // use the compileTypeMetadata as it contains information about lifecycleHooks...
          token = {
            identifier: compileTypeMetadata
          };
        }
      } else if (provider.useFactory) {
        compileFactoryMetadata = this._getFactoryMetadata(provider.useFactory, provider.dependencies);
        compileDeps = compileFactoryMetadata.diDeps;
      }

      return {
        token: token,
        useClass: compileTypeMetadata,
        useValue: provider.useValue,
        useFactory: compileFactoryMetadata,
        useExisting: provider.useExisting ? this._getTokenMetadata(provider.useExisting) : undefined,
        deps: compileDeps,
        multi: provider.multi
      };
    }
  }, {
    key: "_getQueriesMetadata",
    value: function _getQueriesMetadata(queries, isViewQuery, directiveType) {
      var _this223 = this;

      var res = [];
      Object.keys(queries).forEach(function (propertyName) {
        var query = queries[propertyName];

        if (query.isViewQuery === isViewQuery) {
          res.push(_this223._getQueryMetadata(query, propertyName, directiveType));
        }
      });
      return res;
    }
  }, {
    key: "_queryVarBindings",
    value: function _queryVarBindings(selector) {
      return selector.split(/\s*,\s*/);
    }
  }, {
    key: "_getQueryMetadata",
    value: function _getQueryMetadata(q, propertyName, typeOrFunc) {
      var _this224 = this;

      var selectors;

      if (typeof q.selector === 'string') {
        selectors = this._queryVarBindings(q.selector).map(function (varName) {
          return _this224._getTokenMetadata(varName);
        });
      } else {
        if (!q.selector) {
          this._reportError(syntaxError("Can't construct a query for the property \"".concat(propertyName, "\" of \"").concat(stringifyType(typeOrFunc), "\" since the query selector wasn't defined.")), typeOrFunc);

          selectors = [];
        } else {
          selectors = [this._getTokenMetadata(q.selector)];
        }
      }

      return {
        selectors: selectors,
        first: q.first,
        descendants: q.descendants,
        propertyName: propertyName,
        read: q.read ? this._getTokenMetadata(q.read) : null,
        static: q.static
      };
    }
  }, {
    key: "_reportError",
    value: function _reportError(error, type, otherType) {
      if (this._errorCollector) {
        this._errorCollector(error, type);

        if (otherType) {
          this._errorCollector(error, otherType);
        }
      } else {
        throw error;
      }
    }
  }]);

  return CompileMetadataResolver;
}();

function flattenArray(tree) {
  var out = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  if (tree) {
    for (var i = 0; i < tree.length; i++) {
      var item = resolveForwardRef(tree[i]);

      if (Array.isArray(item)) {
        flattenArray(item, out);
      } else {
        out.push(item);
      }
    }
  }

  return out;
}

function dedupeArray(array) {
  if (array) {
    return Array.from(new Set(array));
  }

  return [];
}

function flattenAndDedupeArray(tree) {
  return dedupeArray(flattenArray(tree));
}

function isValidType(value) {
  return value instanceof StaticSymbol || value instanceof Type;
}

function extractIdentifiers(value, targetIdentifiers) {
  visitValue(value, new _CompileValueConverter(), targetIdentifiers);
}

var _CompileValueConverter = /*#__PURE__*/function (_ValueTransformer) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_CompileValueConverter, _ValueTransformer);

  var _super102 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_CompileValueConverter);

  function _CompileValueConverter() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _CompileValueConverter);

    return _super102.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_CompileValueConverter, [{
    key: "visitOther",
    value: function visitOther(value, targetIdentifiers) {
      targetIdentifiers.push({
        reference: value
      });
    }
  }]);

  return _CompileValueConverter;
}(ValueTransformer);

function stringifyType(type) {
  if (type instanceof StaticSymbol) {
    return "".concat(type.name, " in ").concat(type.filePath);
  } else {
    return stringify(type);
  }
}
/**
 * Indicates that a component is still being loaded in a synchronous compile.
 */


function componentStillLoadingError(compType) {
  var error = Error("Can't compile synchronously as ".concat(stringify(compType), " is still being loaded!"));
  error[ERROR_COMPONENT_TYPE] = compType;
  return error;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function providerDef(ctx, providerAst) {
  var flags = 0
  /* None */
  ;

  if (!providerAst.eager) {
    flags |= 4096
    /* LazyProvider */
    ;
  }

  if (providerAst.providerType === ProviderAstType.PrivateService) {
    flags |= 8192
    /* PrivateProvider */
    ;
  }

  if (providerAst.isModule) {
    flags |= 1073741824
    /* TypeModuleProvider */
    ;
  }

  providerAst.lifecycleHooks.forEach(function (lifecycleHook) {
    // for regular providers, we only support ngOnDestroy
    if (lifecycleHook === LifecycleHooks.OnDestroy || providerAst.providerType === ProviderAstType.Directive || providerAst.providerType === ProviderAstType.Component) {
      flags |= lifecycleHookToNodeFlag(lifecycleHook);
    }
  });

  var _ref34 = providerAst.multiProvider ? multiProviderDef(ctx, flags, providerAst.providers) : singleProviderDef(ctx, flags, providerAst.providerType, providerAst.providers[0]),
      providerExpr = _ref34.providerExpr,
      providerFlags = _ref34.flags,
      depsExpr = _ref34.depsExpr;

  return {
    providerExpr: providerExpr,
    flags: providerFlags,
    depsExpr: depsExpr,
    tokenExpr: tokenExpr(ctx, providerAst.token)
  };
}

function multiProviderDef(ctx, flags, providers) {
  var allDepDefs = [];
  var allParams = [];
  var exprs = providers.map(function (provider, providerIndex) {
    var expr;

    if (provider.useClass) {
      var depExprs = convertDeps(providerIndex, provider.deps || provider.useClass.diDeps);
      expr = ctx.importExpr(provider.useClass.reference).instantiate(depExprs);
    } else if (provider.useFactory) {
      var _depExprs = convertDeps(providerIndex, provider.deps || provider.useFactory.diDeps);

      expr = ctx.importExpr(provider.useFactory.reference).callFn(_depExprs);
    } else if (provider.useExisting) {
      var _depExprs2 = convertDeps(providerIndex, [{
        token: provider.useExisting
      }]);

      expr = _depExprs2[0];
    } else {
      expr = convertValueToOutputAst(ctx, provider.useValue);
    }

    return expr;
  });
  var providerExpr = fn(allParams, [new ReturnStatement(literalArr(exprs))], INFERRED_TYPE);
  return {
    providerExpr: providerExpr,
    flags: flags | 1024
    /* TypeFactoryProvider */
    ,
    depsExpr: literalArr(allDepDefs)
  };

  function convertDeps(providerIndex, deps) {
    return deps.map(function (dep, depIndex) {
      var paramName = "p".concat(providerIndex, "_").concat(depIndex);
      allParams.push(new FnParam(paramName, DYNAMIC_TYPE));
      allDepDefs.push(depDef(ctx, dep));
      return variable(paramName);
    });
  }
}

function singleProviderDef(ctx, flags, providerType, providerMeta) {
  var providerExpr;
  var deps;

  if (providerType === ProviderAstType.Directive || providerType === ProviderAstType.Component) {
    providerExpr = ctx.importExpr(providerMeta.useClass.reference);
    flags |= 16384
    /* TypeDirective */
    ;
    deps = providerMeta.deps || providerMeta.useClass.diDeps;
  } else {
    if (providerMeta.useClass) {
      providerExpr = ctx.importExpr(providerMeta.useClass.reference);
      flags |= 512
      /* TypeClassProvider */
      ;
      deps = providerMeta.deps || providerMeta.useClass.diDeps;
    } else if (providerMeta.useFactory) {
      providerExpr = ctx.importExpr(providerMeta.useFactory.reference);
      flags |= 1024
      /* TypeFactoryProvider */
      ;
      deps = providerMeta.deps || providerMeta.useFactory.diDeps;
    } else if (providerMeta.useExisting) {
      providerExpr = NULL_EXPR;
      flags |= 2048
      /* TypeUseExistingProvider */
      ;
      deps = [{
        token: providerMeta.useExisting
      }];
    } else {
      providerExpr = convertValueToOutputAst(ctx, providerMeta.useValue);
      flags |= 256
      /* TypeValueProvider */
      ;
      deps = [];
    }
  }

  var depsExpr = literalArr(deps.map(function (dep) {
    return depDef(ctx, dep);
  }));
  return {
    providerExpr: providerExpr,
    flags: flags,
    depsExpr: depsExpr
  };
}

function tokenExpr(ctx, tokenMeta) {
  return tokenMeta.identifier ? ctx.importExpr(tokenMeta.identifier.reference) : literal(tokenMeta.value);
}

function depDef(ctx, dep) {
  // Note: the following fields have already been normalized out by provider_analyzer:
  // - isAttribute, isHost
  var expr = dep.isValue ? convertValueToOutputAst(ctx, dep.value) : tokenExpr(ctx, dep.token);
  var flags = 0
  /* None */
  ;

  if (dep.isSkipSelf) {
    flags |= 1
    /* SkipSelf */
    ;
  }

  if (dep.isOptional) {
    flags |= 2
    /* Optional */
    ;
  }

  if (dep.isSelf) {
    flags |= 4
    /* Self */
    ;
  }

  if (dep.isValue) {
    flags |= 8
    /* Value */
    ;
  }

  return flags === 0
  /* None */
  ? expr : literalArr([literal(flags), expr]);
}

function lifecycleHookToNodeFlag(lifecycleHook) {
  var nodeFlag = 0
  /* None */
  ;

  switch (lifecycleHook) {
    case LifecycleHooks.AfterContentChecked:
      nodeFlag = 2097152
      /* AfterContentChecked */
      ;
      break;

    case LifecycleHooks.AfterContentInit:
      nodeFlag = 1048576
      /* AfterContentInit */
      ;
      break;

    case LifecycleHooks.AfterViewChecked:
      nodeFlag = 8388608
      /* AfterViewChecked */
      ;
      break;

    case LifecycleHooks.AfterViewInit:
      nodeFlag = 4194304
      /* AfterViewInit */
      ;
      break;

    case LifecycleHooks.DoCheck:
      nodeFlag = 262144
      /* DoCheck */
      ;
      break;

    case LifecycleHooks.OnChanges:
      nodeFlag = 524288
      /* OnChanges */
      ;
      break;

    case LifecycleHooks.OnDestroy:
      nodeFlag = 131072
      /* OnDestroy */
      ;
      break;

    case LifecycleHooks.OnInit:
      nodeFlag = 65536
      /* OnInit */
      ;
      break;
  }

  return nodeFlag;
}

function componentFactoryResolverProviderDef(reflector, ctx, flags, entryComponents) {
  var entryComponentFactories = entryComponents.map(function (entryComponent) {
    return ctx.importExpr(entryComponent.componentFactory);
  });
  var token = createTokenForExternalReference(reflector, Identifiers.ComponentFactoryResolver);
  var classMeta = {
    diDeps: [{
      isValue: true,
      value: literalArr(entryComponentFactories)
    }, {
      token: token,
      isSkipSelf: true,
      isOptional: true
    }, {
      token: createTokenForExternalReference(reflector, Identifiers.NgModuleRef)
    }],
    lifecycleHooks: [],
    reference: reflector.resolveExternalReference(Identifiers.CodegenComponentFactoryResolver)
  };

  var _singleProviderDef = singleProviderDef(ctx, flags, ProviderAstType.PrivateService, {
    token: token,
    multi: false,
    useClass: classMeta
  }),
      providerExpr = _singleProviderDef.providerExpr,
      providerFlags = _singleProviderDef.flags,
      depsExpr = _singleProviderDef.depsExpr;

  return {
    providerExpr: providerExpr,
    flags: providerFlags,
    depsExpr: depsExpr,
    tokenExpr: tokenExpr(ctx, token)
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NgModuleCompileResult = function NgModuleCompileResult(ngModuleFactoryVar) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NgModuleCompileResult);

  this.ngModuleFactoryVar = ngModuleFactoryVar;
};

var LOG_VAR = variable('_l');

var NgModuleCompiler = /*#__PURE__*/function () {
  function NgModuleCompiler(reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NgModuleCompiler);

    this.reflector = reflector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NgModuleCompiler, [{
    key: "compile",
    value: function compile(ctx, ngModuleMeta, extraProviders) {
      var sourceSpan = typeSourceSpan('NgModule', ngModuleMeta.type);
      var entryComponentFactories = ngModuleMeta.transitiveModule.entryComponents;
      var bootstrapComponents = ngModuleMeta.bootstrapComponents;
      var providerParser = new NgModuleProviderAnalyzer(this.reflector, ngModuleMeta, extraProviders, sourceSpan);
      var providerDefs = [componentFactoryResolverProviderDef(this.reflector, ctx, 0
      /* None */
      , entryComponentFactories)].concat(providerParser.parse().map(function (provider) {
        return providerDef(ctx, provider);
      })).map(function (_ref35) {
        var providerExpr = _ref35.providerExpr,
            depsExpr = _ref35.depsExpr,
            flags = _ref35.flags,
            tokenExpr = _ref35.tokenExpr;
        return importExpr(Identifiers.moduleProviderDef).callFn([literal(flags), tokenExpr, providerExpr, depsExpr]);
      });
      var ngModuleDef = importExpr(Identifiers.moduleDef).callFn([literalArr(providerDefs)]);
      var ngModuleDefFactory = fn([new FnParam(LOG_VAR.name)], [new ReturnStatement(ngModuleDef)], INFERRED_TYPE);
      var ngModuleFactoryVar = "".concat(identifierName(ngModuleMeta.type), "NgFactory");

      this._createNgModuleFactory(ctx, ngModuleMeta.type.reference, importExpr(Identifiers.createModuleFactory).callFn([ctx.importExpr(ngModuleMeta.type.reference), literalArr(bootstrapComponents.map(function (id) {
        return ctx.importExpr(id.reference);
      })), ngModuleDefFactory]));

      if (ngModuleMeta.id) {
        var id = typeof ngModuleMeta.id === 'string' ? literal(ngModuleMeta.id) : ctx.importExpr(ngModuleMeta.id);
        var registerFactoryStmt = importExpr(Identifiers.RegisterModuleFactoryFn).callFn([id, variable(ngModuleFactoryVar)]).toStmt();
        ctx.statements.push(registerFactoryStmt);
      }

      return new NgModuleCompileResult(ngModuleFactoryVar);
    }
  }, {
    key: "createStub",
    value: function createStub(ctx, ngModuleReference) {
      this._createNgModuleFactory(ctx, ngModuleReference, NULL_EXPR);
    }
  }, {
    key: "_createNgModuleFactory",
    value: function _createNgModuleFactory(ctx, reference, value) {
      var ngModuleFactoryVar = "".concat(identifierName({
        reference: reference
      }), "NgFactory");
      var ngModuleFactoryStmt = variable(ngModuleFactoryVar).set(value).toDeclStmt(importType(Identifiers.NgModuleFactory, [expressionType(ctx.importExpr(reference))], [TypeModifier.Const]), [StmtModifier.Final, StmtModifier.Exported]);
      ctx.statements.push(ngModuleFactoryStmt);
    }
  }]);

  return NgModuleCompiler;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Resolves types to {@link NgModule}.
 */


var NgModuleResolver = /*#__PURE__*/function () {
  function NgModuleResolver(_reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, NgModuleResolver);

    this._reflector = _reflector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(NgModuleResolver, [{
    key: "isNgModule",
    value: function isNgModule(type) {
      return this._reflector.annotations(type).some(createNgModule.isTypeOf);
    }
  }, {
    key: "resolve",
    value: function resolve(type) {
      var throwIfNotFound = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var ngModuleMeta = findLast(this._reflector.annotations(type), createNgModule.isTypeOf);

      if (ngModuleMeta) {
        return ngModuleMeta;
      } else {
        if (throwIfNotFound) {
          throw new Error("No NgModule metadata found for '".concat(stringify(type), "'."));
        }

        return null;
      }
    }
  }]);

  return NgModuleResolver;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function debugOutputAstAsTypeScript(ast) {
  var converter = new _TsEmitterVisitor();
  var ctx = EmitterVisitorContext.createRoot();
  var asts = Array.isArray(ast) ? ast : [ast];
  asts.forEach(function (ast) {
    if (ast instanceof Statement) {
      ast.visitStatement(converter, ctx);
    } else if (ast instanceof Expression) {
      ast.visitExpression(converter, ctx);
    } else if (ast instanceof Type$1) {
      ast.visitType(converter, ctx);
    } else {
      throw new Error("Don't know how to print debug info for ".concat(ast));
    }
  });
  return ctx.toSource();
}

var TypeScriptEmitter = /*#__PURE__*/function () {
  function TypeScriptEmitter() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TypeScriptEmitter);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TypeScriptEmitter, [{
    key: "emitStatementsAndContext",
    value: function emitStatementsAndContext(genFilePath, stmts) {
      var preamble = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
      var emitSourceMaps = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
      var referenceFilter = arguments.length > 4 ? arguments[4] : undefined;
      var importFilter = arguments.length > 5 ? arguments[5] : undefined;
      var converter = new _TsEmitterVisitor(referenceFilter, importFilter);
      var ctx = EmitterVisitorContext.createRoot();
      converter.visitAllStatements(stmts, ctx);
      var preambleLines = preamble ? preamble.split('\n') : [];
      converter.reexports.forEach(function (reexports, exportedModuleName) {
        var reexportsCode = reexports.map(function (reexport) {
          return "".concat(reexport.name, " as ").concat(reexport.as);
        }).join(',');
        preambleLines.push("export {".concat(reexportsCode, "} from '").concat(exportedModuleName, "';"));
      });
      converter.importsWithPrefixes.forEach(function (prefix, importedModuleName) {
        // Note: can't write the real word for import as it screws up system.js auto detection...
        preambleLines.push("imp" + "ort * as ".concat(prefix, " from '").concat(importedModuleName, "';"));
      });
      var sm = emitSourceMaps ? ctx.toSourceMapGenerator(genFilePath, preambleLines.length).toJsComment() : '';
      var lines = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(preambleLines), [ctx.toSource(), sm]);

      if (sm) {
        // always add a newline at the end, as some tools have bugs without it.
        lines.push('');
      }

      ctx.setPreambleLineCount(preambleLines.length);
      return {
        sourceText: lines.join('\n'),
        context: ctx
      };
    }
  }, {
    key: "emitStatements",
    value: function emitStatements(genFilePath, stmts) {
      var preamble = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
      return this.emitStatementsAndContext(genFilePath, stmts, preamble).sourceText;
    }
  }]);

  return TypeScriptEmitter;
}();

var _TsEmitterVisitor = /*#__PURE__*/function (_AbstractEmitterVisit2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(_TsEmitterVisitor, _AbstractEmitterVisit2);

  var _super103 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(_TsEmitterVisitor);

  function _TsEmitterVisitor(referenceFilter, importFilter) {
    var _this225;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _TsEmitterVisitor);

    _this225 = _super103.call(this, false);
    _this225.referenceFilter = referenceFilter;
    _this225.importFilter = importFilter;
    _this225.typeExpression = 0;
    _this225.importsWithPrefixes = new Map();
    _this225.reexports = new Map();
    return _this225;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_TsEmitterVisitor, [{
    key: "visitType",
    value: function visitType(t, ctx) {
      var defaultType = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'any';

      if (t) {
        this.typeExpression++;
        t.visitType(this, ctx);
        this.typeExpression--;
      } else {
        ctx.print(null, defaultType);
      }
    }
  }, {
    key: "visitLiteralExpr",
    value: function visitLiteralExpr(ast, ctx) {
      var value = ast.value;

      if (value == null && ast.type != INFERRED_TYPE) {
        ctx.print(ast, "(".concat(value, " as any)"));
        return null;
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(_TsEmitterVisitor.prototype), "visitLiteralExpr", this).call(this, ast, ctx);
    } // Temporary workaround to support strictNullCheck enabled consumers of ngc emit.
    // In SNC mode, [] have the type never[], so we cast here to any[].
    // TODO: narrow the cast to a more explicit type, or use a pattern that does not
    // start with [].concat. see https://github.com/angular/angular/pull/11846

  }, {
    key: "visitLiteralArrayExpr",
    value: function visitLiteralArrayExpr(ast, ctx) {
      if (ast.entries.length === 0) {
        ctx.print(ast, '(');
      }

      var result = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(_TsEmitterVisitor.prototype), "visitLiteralArrayExpr", this).call(this, ast, ctx);

      if (ast.entries.length === 0) {
        ctx.print(ast, ' as any[])');
      }

      return result;
    }
  }, {
    key: "visitExternalExpr",
    value: function visitExternalExpr(ast, ctx) {
      this._visitIdentifier(ast.value, ast.typeParams, ctx);

      return null;
    }
  }, {
    key: "visitAssertNotNullExpr",
    value: function visitAssertNotNullExpr(ast, ctx) {
      var result = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(_TsEmitterVisitor.prototype), "visitAssertNotNullExpr", this).call(this, ast, ctx);

      ctx.print(ast, '!');
      return result;
    }
  }, {
    key: "visitDeclareVarStmt",
    value: function visitDeclareVarStmt(stmt, ctx) {
      if (stmt.hasModifier(StmtModifier.Exported) && stmt.value instanceof ExternalExpr && !stmt.type) {
        // check for a reexport
        var _stmt$value$value = stmt.value.value,
            name = _stmt$value$value.name,
            moduleName = _stmt$value$value.moduleName;

        if (moduleName) {
          var reexports = this.reexports.get(moduleName);

          if (!reexports) {
            reexports = [];
            this.reexports.set(moduleName, reexports);
          }

          reexports.push({
            name: name,
            as: stmt.name
          });
          return null;
        }
      }

      if (stmt.hasModifier(StmtModifier.Exported)) {
        ctx.print(stmt, "export ");
      }

      if (stmt.hasModifier(StmtModifier.Final)) {
        ctx.print(stmt, "const");
      } else {
        ctx.print(stmt, "var");
      }

      ctx.print(stmt, " ".concat(stmt.name));

      this._printColonType(stmt.type, ctx);

      if (stmt.value) {
        ctx.print(stmt, " = ");
        stmt.value.visitExpression(this, ctx);
      }

      ctx.println(stmt, ";");
      return null;
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, ctx) {
      throw new Error('Cannot visit a WrappedNodeExpr when outputting Typescript.');
    }
  }, {
    key: "visitCastExpr",
    value: function visitCastExpr(ast, ctx) {
      ctx.print(ast, "(<");
      ast.type.visitType(this, ctx);
      ctx.print(ast, ">");
      ast.value.visitExpression(this, ctx);
      ctx.print(ast, ")");
      return null;
    }
  }, {
    key: "visitInstantiateExpr",
    value: function visitInstantiateExpr(ast, ctx) {
      ctx.print(ast, "new ");
      this.typeExpression++;
      ast.classExpr.visitExpression(this, ctx);
      this.typeExpression--;
      ctx.print(ast, "(");
      this.visitAllExpressions(ast.args, ctx, ',');
      ctx.print(ast, ")");
      return null;
    }
  }, {
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, ctx) {
      var _this226 = this;

      ctx.pushClass(stmt);

      if (stmt.hasModifier(StmtModifier.Exported)) {
        ctx.print(stmt, "export ");
      }

      ctx.print(stmt, "class ".concat(stmt.name));

      if (stmt.parent != null) {
        ctx.print(stmt, " extends ");
        this.typeExpression++;
        stmt.parent.visitExpression(this, ctx);
        this.typeExpression--;
      }

      ctx.println(stmt, " {");
      ctx.incIndent();
      stmt.fields.forEach(function (field) {
        return _this226._visitClassField(field, ctx);
      });

      if (stmt.constructorMethod != null) {
        this._visitClassConstructor(stmt, ctx);
      }

      stmt.getters.forEach(function (getter) {
        return _this226._visitClassGetter(getter, ctx);
      });
      stmt.methods.forEach(function (method) {
        return _this226._visitClassMethod(method, ctx);
      });
      ctx.decIndent();
      ctx.println(stmt, "}");
      ctx.popClass();
      return null;
    }
  }, {
    key: "_visitClassField",
    value: function _visitClassField(field, ctx) {
      if (field.hasModifier(StmtModifier.Private)) {
        // comment out as a workaround for #10967
        ctx.print(null, "/*private*/ ");
      }

      if (field.hasModifier(StmtModifier.Static)) {
        ctx.print(null, 'static ');
      }

      ctx.print(null, field.name);

      this._printColonType(field.type, ctx);

      if (field.initializer) {
        ctx.print(null, ' = ');
        field.initializer.visitExpression(this, ctx);
      }

      ctx.println(null, ";");
    }
  }, {
    key: "_visitClassGetter",
    value: function _visitClassGetter(getter, ctx) {
      if (getter.hasModifier(StmtModifier.Private)) {
        ctx.print(null, "private ");
      }

      ctx.print(null, "get ".concat(getter.name, "()"));

      this._printColonType(getter.type, ctx);

      ctx.println(null, " {");
      ctx.incIndent();
      this.visitAllStatements(getter.body, ctx);
      ctx.decIndent();
      ctx.println(null, "}");
    }
  }, {
    key: "_visitClassConstructor",
    value: function _visitClassConstructor(stmt, ctx) {
      ctx.print(stmt, "constructor(");

      this._visitParams(stmt.constructorMethod.params, ctx);

      ctx.println(stmt, ") {");
      ctx.incIndent();
      this.visitAllStatements(stmt.constructorMethod.body, ctx);
      ctx.decIndent();
      ctx.println(stmt, "}");
    }
  }, {
    key: "_visitClassMethod",
    value: function _visitClassMethod(method, ctx) {
      if (method.hasModifier(StmtModifier.Private)) {
        ctx.print(null, "private ");
      }

      ctx.print(null, "".concat(method.name, "("));

      this._visitParams(method.params, ctx);

      ctx.print(null, ")");

      this._printColonType(method.type, ctx, 'void');

      ctx.println(null, " {");
      ctx.incIndent();
      this.visitAllStatements(method.body, ctx);
      ctx.decIndent();
      ctx.println(null, "}");
    }
  }, {
    key: "visitFunctionExpr",
    value: function visitFunctionExpr(ast, ctx) {
      if (ast.name) {
        ctx.print(ast, 'function ');
        ctx.print(ast, ast.name);
      }

      ctx.print(ast, "(");

      this._visitParams(ast.params, ctx);

      ctx.print(ast, ")");

      this._printColonType(ast.type, ctx, 'void');

      if (!ast.name) {
        ctx.print(ast, " => ");
      }

      ctx.println(ast, '{');
      ctx.incIndent();
      this.visitAllStatements(ast.statements, ctx);
      ctx.decIndent();
      ctx.print(ast, "}");
      return null;
    }
  }, {
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, ctx) {
      if (stmt.hasModifier(StmtModifier.Exported)) {
        ctx.print(stmt, "export ");
      }

      ctx.print(stmt, "function ".concat(stmt.name, "("));

      this._visitParams(stmt.params, ctx);

      ctx.print(stmt, ")");

      this._printColonType(stmt.type, ctx, 'void');

      ctx.println(stmt, " {");
      ctx.incIndent();
      this.visitAllStatements(stmt.statements, ctx);
      ctx.decIndent();
      ctx.println(stmt, "}");
      return null;
    }
  }, {
    key: "visitTryCatchStmt",
    value: function visitTryCatchStmt(stmt, ctx) {
      ctx.println(stmt, "try {");
      ctx.incIndent();
      this.visitAllStatements(stmt.bodyStmts, ctx);
      ctx.decIndent();
      ctx.println(stmt, "} catch (".concat(CATCH_ERROR_VAR$1.name, ") {"));
      ctx.incIndent();
      var catchStmts = [CATCH_STACK_VAR$1.set(CATCH_ERROR_VAR$1.prop('stack', null)).toDeclStmt(null, [StmtModifier.Final])].concat(stmt.catchStmts);
      this.visitAllStatements(catchStmts, ctx);
      ctx.decIndent();
      ctx.println(stmt, "}");
      return null;
    }
  }, {
    key: "visitBuiltinType",
    value: function visitBuiltinType(type, ctx) {
      var typeStr;

      switch (type.name) {
        case BuiltinTypeName.Bool:
          typeStr = 'boolean';
          break;

        case BuiltinTypeName.Dynamic:
          typeStr = 'any';
          break;

        case BuiltinTypeName.Function:
          typeStr = 'Function';
          break;

        case BuiltinTypeName.Number:
          typeStr = 'number';
          break;

        case BuiltinTypeName.Int:
          typeStr = 'number';
          break;

        case BuiltinTypeName.String:
          typeStr = 'string';
          break;

        case BuiltinTypeName.None:
          typeStr = 'never';
          break;

        default:
          throw new Error("Unsupported builtin type ".concat(type.name));
      }

      ctx.print(null, typeStr);
      return null;
    }
  }, {
    key: "visitExpressionType",
    value: function visitExpressionType(ast, ctx) {
      var _this227 = this;

      ast.value.visitExpression(this, ctx);

      if (ast.typeParams !== null) {
        ctx.print(null, '<');
        this.visitAllObjects(function (type) {
          return _this227.visitType(type, ctx);
        }, ast.typeParams, ctx, ',');
        ctx.print(null, '>');
      }

      return null;
    }
  }, {
    key: "visitArrayType",
    value: function visitArrayType(type, ctx) {
      this.visitType(type.of, ctx);
      ctx.print(null, "[]");
      return null;
    }
  }, {
    key: "visitMapType",
    value: function visitMapType(type, ctx) {
      ctx.print(null, "{[key: string]:");
      this.visitType(type.valueType, ctx);
      ctx.print(null, "}");
      return null;
    }
  }, {
    key: "getBuiltinMethodName",
    value: function getBuiltinMethodName(method) {
      var name;

      switch (method) {
        case BuiltinMethod.ConcatArray:
          name = 'concat';
          break;

        case BuiltinMethod.SubscribeObservable:
          name = 'subscribe';
          break;

        case BuiltinMethod.Bind:
          name = 'bind';
          break;

        default:
          throw new Error("Unknown builtin method: ".concat(method));
      }

      return name;
    }
  }, {
    key: "_visitParams",
    value: function _visitParams(params, ctx) {
      var _this228 = this;

      this.visitAllObjects(function (param) {
        ctx.print(null, param.name);

        _this228._printColonType(param.type, ctx);
      }, params, ctx, ',');
    }
  }, {
    key: "_visitIdentifier",
    value: function _visitIdentifier(value, typeParams, ctx) {
      var _this229 = this;

      var name = value.name,
          moduleName = value.moduleName;

      if (this.referenceFilter && this.referenceFilter(value)) {
        ctx.print(null, '(null as any)');
        return;
      }

      if (moduleName && (!this.importFilter || !this.importFilter(value))) {
        var prefix = this.importsWithPrefixes.get(moduleName);

        if (prefix == null) {
          prefix = "i".concat(this.importsWithPrefixes.size);
          this.importsWithPrefixes.set(moduleName, prefix);
        }

        ctx.print(null, "".concat(prefix, "."));
      }

      ctx.print(null, name);

      if (this.typeExpression > 0) {
        // If we are in a type expression that refers to a generic type then supply
        // the required type parameters. If there were not enough type parameters
        // supplied, supply any as the type. Outside a type expression the reference
        // should not supply type parameters and be treated as a simple value reference
        // to the constructor function itself.
        var suppliedParameters = typeParams || [];

        if (suppliedParameters.length > 0) {
          ctx.print(null, "<");
          this.visitAllObjects(function (type) {
            return type.visitType(_this229, ctx);
          }, typeParams, ctx, ',');
          ctx.print(null, ">");
        }
      }
    }
  }, {
    key: "_printColonType",
    value: function _printColonType(type, ctx, defaultType) {
      if (type !== INFERRED_TYPE) {
        ctx.print(null, ':');
        this.visitType(type, ctx, defaultType);
      }
    }
  }]);

  return _TsEmitterVisitor;
}(AbstractEmitterVisitor);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Resolve a `Type` for {@link Pipe}.
 *
 * This interface can be overridden by the application developer to create custom behavior.
 *
 * See {@link Compiler}
 */


var PipeResolver = /*#__PURE__*/function () {
  function PipeResolver(_reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PipeResolver);

    this._reflector = _reflector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PipeResolver, [{
    key: "isPipe",
    value: function isPipe(type) {
      var typeMetadata = this._reflector.annotations(resolveForwardRef(type));

      return typeMetadata && typeMetadata.some(createPipe.isTypeOf);
    }
    /**
     * Return {@link Pipe} for a given `Type`.
     */

  }, {
    key: "resolve",
    value: function resolve(type) {
      var throwIfNotFound = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

      var metas = this._reflector.annotations(resolveForwardRef(type));

      if (metas) {
        var annotation = findLast(metas, createPipe.isTypeOf);

        if (annotation) {
          return annotation;
        }
      }

      if (throwIfNotFound) {
        throw new Error("No Pipe decorator found on ".concat(stringify(type)));
      }

      return null;
    }
  }]);

  return PipeResolver;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generates code that is used to type check templates.
 */


var TypeCheckCompiler = /*#__PURE__*/function () {
  function TypeCheckCompiler(options, reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TypeCheckCompiler);

    this.options = options;
    this.reflector = reflector;
  }
  /**
   * Important notes:
   * - This must not produce new `import` statements, but only refer to types outside
   *   of the file via the variables provided via externalReferenceVars.
   *   This allows Typescript to reuse the old program's structure as no imports have changed.
   * - This must not produce any exports, as this would pollute the .d.ts file
   *   and also violate the point above.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TypeCheckCompiler, [{
    key: "compileComponent",
    value: function compileComponent(componentId, component, template, usedPipes, externalReferenceVars, ctx) {
      var _this230 = this;

      var pipes = new Map();
      usedPipes.forEach(function (p) {
        return pipes.set(p.name, p.type.reference);
      });
      var embeddedViewCount = 0;

      var viewBuilderFactory = function viewBuilderFactory(parent, guards) {
        var embeddedViewIndex = embeddedViewCount++;
        return new ViewBuilder(_this230.options, _this230.reflector, externalReferenceVars, parent, component.type.reference, component.isHost, embeddedViewIndex, pipes, guards, ctx, viewBuilderFactory);
      };

      var visitor = viewBuilderFactory(null, []);
      visitor.visitAll([], template);
      return visitor.build(componentId);
    }
  }]);

  return TypeCheckCompiler;
}();

var DYNAMIC_VAR_NAME = '_any';

var TypeCheckLocalResolver = /*#__PURE__*/function () {
  function TypeCheckLocalResolver() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TypeCheckLocalResolver);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TypeCheckLocalResolver, [{
    key: "notifyImplicitReceiverUse",
    value: function notifyImplicitReceiverUse() {}
  }, {
    key: "getLocal",
    value: function getLocal(name) {
      if (name === EventHandlerVars.event.name) {
        // References to the event should not be type-checked.
        // TODO(chuckj): determine a better type for the event.
        return variable(DYNAMIC_VAR_NAME);
      }

      return null;
    }
  }]);

  return TypeCheckLocalResolver;
}();

var defaultResolver = new TypeCheckLocalResolver();

var ViewBuilder = /*#__PURE__*/function () {
  function ViewBuilder(options, reflector, externalReferenceVars, parent, component, isHostComponent, embeddedViewIndex, pipes, guards, ctx, viewBuilderFactory) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ViewBuilder);

    this.options = options;
    this.reflector = reflector;
    this.externalReferenceVars = externalReferenceVars;
    this.parent = parent;
    this.component = component;
    this.isHostComponent = isHostComponent;
    this.embeddedViewIndex = embeddedViewIndex;
    this.pipes = pipes;
    this.guards = guards;
    this.ctx = ctx;
    this.viewBuilderFactory = viewBuilderFactory;
    this.refOutputVars = new Map();
    this.variables = [];
    this.children = [];
    this.updates = [];
    this.actions = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ViewBuilder, [{
    key: "getOutputVar",
    value: function getOutputVar(type) {
      var varName;

      if (type === this.component && this.isHostComponent) {
        varName = DYNAMIC_VAR_NAME;
      } else if (type instanceof StaticSymbol) {
        varName = this.externalReferenceVars.get(type);
      } else {
        varName = DYNAMIC_VAR_NAME;
      }

      if (!varName) {
        throw new Error("Illegal State: referring to a type without a variable ".concat(JSON.stringify(type)));
      }

      return varName;
    }
  }, {
    key: "getTypeGuardExpressions",
    value: function getTypeGuardExpressions(ast) {
      var result = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this.guards);

      var _iterator18 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(ast.directives),
          _step18;

      try {
        for (_iterator18.s(); !(_step18 = _iterator18.n()).done;) {
          var directive = _step18.value;

          var _iterator19 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(directive.inputs),
              _step19;

          try {
            for (_iterator19.s(); !(_step19 = _iterator19.n()).done;) {
              var input = _step19.value;
              var guard = directive.directive.guards[input.directiveName];

              if (guard) {
                var useIf = guard === 'UseIf';
                result.push({
                  guard: guard,
                  useIf: useIf,
                  expression: {
                    context: this.component,
                    value: input.value,
                    sourceSpan: input.sourceSpan
                  }
                });
              }
            }
          } catch (err) {
            _iterator19.e(err);
          } finally {
            _iterator19.f();
          }
        }
      } catch (err) {
        _iterator18.e(err);
      } finally {
        _iterator18.f();
      }

      return result;
    }
  }, {
    key: "visitAll",
    value: function visitAll(variables, astNodes) {
      this.variables = variables;
      templateVisitAll(this, astNodes);
    }
  }, {
    key: "build",
    value: function build(componentId) {
      var _this231 = this;

      var targetStatements = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
      this.children.forEach(function (child) {
        return child.build(componentId, targetStatements);
      });
      var viewStmts = [variable(DYNAMIC_VAR_NAME).set(NULL_EXPR).toDeclStmt(DYNAMIC_TYPE)];
      var bindingCount = 0;
      this.updates.forEach(function (expression) {
        var _viewStmts;

        var _this231$preprocessUp = _this231.preprocessUpdateExpression(expression),
            sourceSpan = _this231$preprocessUp.sourceSpan,
            context = _this231$preprocessUp.context,
            value = _this231$preprocessUp.value;

        var bindingId = "".concat(bindingCount++);
        var nameResolver = context === _this231.component ? _this231 : defaultResolver;

        var _convertPropertyBindi = _convertPropertyBinding(nameResolver, variable(_this231.getOutputVar(context)), value, bindingId, BindingForm.General),
            stmts = _convertPropertyBindi.stmts,
            currValExpr = _convertPropertyBindi.currValExpr;

        stmts.push(new ExpressionStatement(currValExpr));

        (_viewStmts = viewStmts).push.apply(_viewStmts, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(stmts.map(function (stmt) {
          return applySourceSpanToStatementIfNeeded(stmt, sourceSpan);
        })));
      });
      this.actions.forEach(function (_ref36) {
        var _viewStmts2;

        var sourceSpan = _ref36.sourceSpan,
            context = _ref36.context,
            value = _ref36.value;
        var bindingId = "".concat(bindingCount++);
        var nameResolver = context === _this231.component ? _this231 : defaultResolver;

        var _convertActionBinding = convertActionBinding(nameResolver, variable(_this231.getOutputVar(context)), value, bindingId),
            stmts = _convertActionBinding.stmts;

        (_viewStmts2 = viewStmts).push.apply(_viewStmts2, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(stmts.map(function (stmt) {
          return applySourceSpanToStatementIfNeeded(stmt, sourceSpan);
        })));
      });

      if (this.guards.length) {
        var guardExpression = undefined;

        var _iterator20 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(this.guards),
            _step20;

        try {
          for (_iterator20.s(); !(_step20 = _iterator20.n()).done;) {
            var guard = _step20.value;

            var _this$preprocessUpdat = this.preprocessUpdateExpression(guard.expression),
                context = _this$preprocessUpdat.context,
                value = _this$preprocessUpdat.value;

            var bindingId = "".concat(bindingCount++);
            var nameResolver = context === this.component ? this : defaultResolver; // We only support support simple expressions and ignore others as they
            // are unlikely to affect type narrowing.

            var _convertPropertyBindi2 = _convertPropertyBinding(nameResolver, variable(this.getOutputVar(context)), value, bindingId, BindingForm.TrySimple),
                stmts = _convertPropertyBindi2.stmts,
                currValExpr = _convertPropertyBindi2.currValExpr;

            if (stmts.length == 0) {
              var guardClause = guard.useIf ? currValExpr : this.ctx.importExpr(guard.guard).callFn([currValExpr]);
              guardExpression = guardExpression ? guardExpression.and(guardClause) : guardClause;
            }
          }
        } catch (err) {
          _iterator20.e(err);
        } finally {
          _iterator20.f();
        }

        if (guardExpression) {
          viewStmts = [new IfStmt(guardExpression, viewStmts)];
        }
      }

      var viewName = "_View_".concat(componentId, "_").concat(this.embeddedViewIndex);
      var viewFactory = new DeclareFunctionStmt(viewName, [], viewStmts);
      targetStatements.push(viewFactory);
      return targetStatements;
    }
  }, {
    key: "visitBoundText",
    value: function visitBoundText(ast, context) {
      var _this232 = this;

      var astWithSource = ast.value;
      var inter = astWithSource.ast;
      inter.expressions.forEach(function (expr) {
        return _this232.updates.push({
          context: _this232.component,
          value: expr,
          sourceSpan: ast.sourceSpan
        });
      });
    }
  }, {
    key: "visitEmbeddedTemplate",
    value: function visitEmbeddedTemplate(ast, context) {
      this.visitElementOrTemplate(ast); // Note: The old view compiler used to use an `any` type
      // for the context in any embedded view.
      // We keep this behaivor behind a flag for now.

      if (this.options.fullTemplateTypeCheck) {
        // Find any applicable type guards. For example, NgIf has a type guard on ngIf
        // (see NgIf.ngIfTypeGuard) that can be used to indicate that a template is only
        // stamped out if ngIf is truthy so any bindings in the template can assume that,
        // if a nullable type is used for ngIf, that expression is not null or undefined.
        var guards = this.getTypeGuardExpressions(ast);
        var childVisitor = this.viewBuilderFactory(this, guards);
        this.children.push(childVisitor);
        childVisitor.visitAll(ast.variables, ast.children);
      }
    }
  }, {
    key: "visitElement",
    value: function visitElement(ast, context) {
      var _this233 = this;

      this.visitElementOrTemplate(ast);
      var inputDefs = [];
      var updateRendererExpressions = [];
      var outputDefs = [];
      ast.inputs.forEach(function (inputAst) {
        _this233.updates.push({
          context: _this233.component,
          value: inputAst.value,
          sourceSpan: inputAst.sourceSpan
        });
      });
      templateVisitAll(this, ast.children);
    }
  }, {
    key: "visitElementOrTemplate",
    value: function visitElementOrTemplate(ast) {
      var _this234 = this;

      ast.directives.forEach(function (dirAst) {
        _this234.visitDirective(dirAst);
      });
      ast.references.forEach(function (ref) {
        var outputVarType = null; // Note: The old view compiler used to use an `any` type
        // for directives exposed via `exportAs`.
        // We keep this behaivor behind a flag for now.

        if (ref.value && ref.value.identifier && _this234.options.fullTemplateTypeCheck) {
          outputVarType = ref.value.identifier.reference;
        } else {
          outputVarType = BuiltinTypeName.Dynamic;
        }

        _this234.refOutputVars.set(ref.name, outputVarType);
      });
      ast.outputs.forEach(function (outputAst) {
        _this234.actions.push({
          context: _this234.component,
          value: outputAst.handler,
          sourceSpan: outputAst.sourceSpan
        });
      });
    }
  }, {
    key: "visitDirective",
    value: function visitDirective(dirAst) {
      var _this235 = this;

      var dirType = dirAst.directive.type.reference;
      dirAst.inputs.forEach(function (input) {
        return _this235.updates.push({
          context: _this235.component,
          value: input.value,
          sourceSpan: input.sourceSpan
        });
      }); // Note: The old view compiler used to use an `any` type
      // for expressions in host properties / events.
      // We keep this behaivor behind a flag for now.

      if (this.options.fullTemplateTypeCheck) {
        dirAst.hostProperties.forEach(function (inputAst) {
          return _this235.updates.push({
            context: dirType,
            value: inputAst.value,
            sourceSpan: inputAst.sourceSpan
          });
        });
        dirAst.hostEvents.forEach(function (hostEventAst) {
          return _this235.actions.push({
            context: dirType,
            value: hostEventAst.handler,
            sourceSpan: hostEventAst.sourceSpan
          });
        });
      }
    }
  }, {
    key: "notifyImplicitReceiverUse",
    value: function notifyImplicitReceiverUse() {}
  }, {
    key: "getLocal",
    value: function getLocal(name) {
      if (name == EventHandlerVars.event.name) {
        return variable(this.getOutputVar(BuiltinTypeName.Dynamic));
      }

      for (var currBuilder = this; currBuilder; currBuilder = currBuilder.parent) {
        var outputVarType = void 0; // check references

        outputVarType = currBuilder.refOutputVars.get(name);

        if (outputVarType == null) {
          // check variables
          var varAst = currBuilder.variables.find(function (varAst) {
            return varAst.name === name;
          });

          if (varAst) {
            outputVarType = BuiltinTypeName.Dynamic;
          }
        }

        if (outputVarType != null) {
          return variable(this.getOutputVar(outputVarType));
        }
      }

      return null;
    }
  }, {
    key: "pipeOutputVar",
    value: function pipeOutputVar(name) {
      var pipe = this.pipes.get(name);

      if (!pipe) {
        throw new Error("Illegal State: Could not find pipe ".concat(name, " in template of ").concat(this.component));
      }

      return this.getOutputVar(pipe);
    }
  }, {
    key: "preprocessUpdateExpression",
    value: function preprocessUpdateExpression(expression) {
      var _this236 = this;

      return {
        sourceSpan: expression.sourceSpan,
        context: expression.context,
        value: convertPropertyBindingBuiltins({
          createLiteralArrayConverter: function createLiteralArrayConverter(argCount) {
            return function (args) {
              var arr = literalArr(args); // Note: The old view compiler used to use an `any` type
              // for arrays.

              return _this236.options.fullTemplateTypeCheck ? arr : arr.cast(DYNAMIC_TYPE);
            };
          },
          createLiteralMapConverter: function createLiteralMapConverter(keys) {
            return function (values) {
              var entries = keys.map(function (k, i) {
                return {
                  key: k.key,
                  value: values[i],
                  quoted: k.quoted
                };
              });
              var map = literalMap(entries); // Note: The old view compiler used to use an `any` type
              // for maps.

              return _this236.options.fullTemplateTypeCheck ? map : map.cast(DYNAMIC_TYPE);
            };
          },
          createPipeConverter: function createPipeConverter(name, argCount) {
            return function (args) {
              // Note: The old view compiler used to use an `any` type
              // for pipes.
              var pipeExpr = _this236.options.fullTemplateTypeCheck ? variable(_this236.pipeOutputVar(name)) : variable(_this236.getOutputVar(BuiltinTypeName.Dynamic));
              return pipeExpr.callMethod('transform', args);
            };
          }
        }, expression.value)
      };
    }
  }, {
    key: "visitNgContent",
    value: function visitNgContent(ast, context) {}
  }, {
    key: "visitText",
    value: function visitText(ast, context) {}
  }, {
    key: "visitDirectiveProperty",
    value: function visitDirectiveProperty(ast, context) {}
  }, {
    key: "visitReference",
    value: function visitReference(ast, context) {}
  }, {
    key: "visitVariable",
    value: function visitVariable(ast, context) {}
  }, {
    key: "visitEvent",
    value: function visitEvent(ast, context) {}
  }, {
    key: "visitElementProperty",
    value: function visitElementProperty(ast, context) {}
  }, {
    key: "visitAttr",
    value: function visitAttr(ast, context) {}
  }]);

  return ViewBuilder;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CLASS_ATTR$1 = 'class';
var STYLE_ATTR = 'style';
var IMPLICIT_TEMPLATE_VAR = '\$implicit';

var ViewCompileResult = function ViewCompileResult(viewClassVar, rendererTypeVar) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ViewCompileResult);

  this.viewClassVar = viewClassVar;
  this.rendererTypeVar = rendererTypeVar;
};

var ViewCompiler = /*#__PURE__*/function () {
  function ViewCompiler(_reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ViewCompiler);

    this._reflector = _reflector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ViewCompiler, [{
    key: "compileComponent",
    value: function compileComponent(outputCtx, component, template, styles, usedPipes) {
      var _this237 = this,
          _outputCtx$statements;

      var embeddedViewCount = 0;
      var renderComponentVarName = undefined;

      if (!component.isHost) {
        var _template = component.template;
        var customRenderData = [];

        if (_template.animations && _template.animations.length) {
          customRenderData.push(new LiteralMapEntry('animation', convertValueToOutputAst(outputCtx, _template.animations), true));
        }

        var renderComponentVar = variable(rendererTypeName(component.type.reference));
        renderComponentVarName = renderComponentVar.name;
        outputCtx.statements.push(renderComponentVar.set(importExpr(Identifiers.createRendererType2).callFn([new LiteralMapExpr([new LiteralMapEntry('encapsulation', literal(_template.encapsulation), false), new LiteralMapEntry('styles', styles, false), new LiteralMapEntry('data', new LiteralMapExpr(customRenderData), false)])])).toDeclStmt(importType(Identifiers.RendererType2), [StmtModifier.Final, StmtModifier.Exported]));
      }

      var viewBuilderFactory = function viewBuilderFactory(parent) {
        var embeddedViewIndex = embeddedViewCount++;
        return new ViewBuilder$1(_this237._reflector, outputCtx, parent, component, embeddedViewIndex, usedPipes, viewBuilderFactory);
      };

      var visitor = viewBuilderFactory(null);
      visitor.visitAll([], template);

      (_outputCtx$statements = outputCtx.statements).push.apply(_outputCtx$statements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(visitor.build()));

      return new ViewCompileResult(visitor.viewName, renderComponentVarName);
    }
  }]);

  return ViewCompiler;
}();

var LOG_VAR$1 = variable('_l');
var VIEW_VAR = variable('_v');
var CHECK_VAR = variable('_ck');
var COMP_VAR = variable('_co');
var EVENT_NAME_VAR = variable('en');
var ALLOW_DEFAULT_VAR = variable("ad");

var ViewBuilder$1 = /*#__PURE__*/function () {
  function ViewBuilder$1(reflector, outputCtx, parent, component, embeddedViewIndex, usedPipes, viewBuilderFactory) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ViewBuilder$1);

    this.reflector = reflector;
    this.outputCtx = outputCtx;
    this.parent = parent;
    this.component = component;
    this.embeddedViewIndex = embeddedViewIndex;
    this.usedPipes = usedPipes;
    this.viewBuilderFactory = viewBuilderFactory;
    this.nodes = [];
    this.purePipeNodeIndices = Object.create(null); // Need Object.create so that we don't have builtin values...

    this.refNodeIndices = Object.create(null);
    this.variables = [];
    this.children = []; // TODO(tbosch): The old view compiler used to use an `any` type
    // for the context in any embedded view. We keep this behaivor for now
    // to be able to introduce the new view compiler without too many errors.

    this.compType = this.embeddedViewIndex > 0 ? DYNAMIC_TYPE : expressionType(outputCtx.importExpr(this.component.type.reference));
    this.viewName = viewClassName(this.component.type.reference, this.embeddedViewIndex);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ViewBuilder$1, [{
    key: "visitAll",
    value: function visitAll(variables, astNodes) {
      var _this238 = this;

      this.variables = variables; // create the pipes for the pure pipes immediately, so that we know their indices.

      if (!this.parent) {
        this.usedPipes.forEach(function (pipe) {
          if (pipe.pure) {
            _this238.purePipeNodeIndices[pipe.name] = _this238._createPipe(null, pipe);
          }
        });
      }

      if (!this.parent) {
        this.component.viewQueries.forEach(function (query, queryIndex) {
          // Note: queries start with id 1 so we can use the number in a Bloom filter!
          var queryId = queryIndex + 1;
          var bindingType = query.first ? 0
          /* First */
          : 1
          /* All */
          ;
          var flags = 134217728
          /* TypeViewQuery */
          | calcStaticDynamicQueryFlags(query);

          _this238.nodes.push(function () {
            return {
              sourceSpan: null,
              nodeFlags: flags,
              nodeDef: importExpr(Identifiers.queryDef).callFn([literal(flags), literal(queryId), new LiteralMapExpr([new LiteralMapEntry(query.propertyName, literal(bindingType), false)])])
            };
          });
        });
      }

      templateVisitAll(this, astNodes);

      if (this.parent && (astNodes.length === 0 || needsAdditionalRootNode(astNodes))) {
        // if the view is an embedded view, then we need to add an additional root node in some cases
        this.nodes.push(function () {
          return {
            sourceSpan: null,
            nodeFlags: 1
            /* TypeElement */
            ,
            nodeDef: importExpr(Identifiers.anchorDef).callFn([literal(0
            /* None */
            ), NULL_EXPR, NULL_EXPR, literal(0)])
          };
        });
      }
    }
  }, {
    key: "build",
    value: function build() {
      var targetStatements = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
      this.children.forEach(function (child) {
        return child.build(targetStatements);
      });

      var _this$_createNodeExpr = this._createNodeExpressions(),
          updateRendererStmts = _this$_createNodeExpr.updateRendererStmts,
          updateDirectivesStmts = _this$_createNodeExpr.updateDirectivesStmts,
          nodeDefExprs = _this$_createNodeExpr.nodeDefExprs;

      var updateRendererFn = this._createUpdateFn(updateRendererStmts);

      var updateDirectivesFn = this._createUpdateFn(updateDirectivesStmts);

      var viewFlags = 0
      /* None */
      ;

      if (!this.parent && this.component.changeDetection === ChangeDetectionStrategy.OnPush) {
        viewFlags |= 2
        /* OnPush */
        ;
      }

      var viewFactory = new DeclareFunctionStmt(this.viewName, [new FnParam(LOG_VAR$1.name)], [new ReturnStatement(importExpr(Identifiers.viewDef).callFn([literal(viewFlags), literalArr(nodeDefExprs), updateDirectivesFn, updateRendererFn]))], importType(Identifiers.ViewDefinition), this.embeddedViewIndex === 0 ? [StmtModifier.Exported] : []);
      targetStatements.push(viewFactory);
      return targetStatements;
    }
  }, {
    key: "_createUpdateFn",
    value: function _createUpdateFn(updateStmts) {
      var updateFn;

      if (updateStmts.length > 0) {
        var preStmts = [];

        if (!this.component.isHost && findReadVarNames(updateStmts).has(COMP_VAR.name)) {
          preStmts.push(COMP_VAR.set(VIEW_VAR.prop('component')).toDeclStmt(this.compType));
        }

        updateFn = fn([new FnParam(CHECK_VAR.name, INFERRED_TYPE), new FnParam(VIEW_VAR.name, INFERRED_TYPE)], [].concat(preStmts, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(updateStmts)), INFERRED_TYPE);
      } else {
        updateFn = NULL_EXPR;
      }

      return updateFn;
    }
  }, {
    key: "visitNgContent",
    value: function visitNgContent(ast, context) {
      // ngContentDef(ngContentIndex: number, index: number): NodeDef;
      this.nodes.push(function () {
        return {
          sourceSpan: ast.sourceSpan,
          nodeFlags: 8
          /* TypeNgContent */
          ,
          nodeDef: importExpr(Identifiers.ngContentDef).callFn([literal(ast.ngContentIndex), literal(ast.index)])
        };
      });
    }
  }, {
    key: "visitText",
    value: function visitText(ast, context) {
      // Static text nodes have no check function
      var checkIndex = -1;
      this.nodes.push(function () {
        return {
          sourceSpan: ast.sourceSpan,
          nodeFlags: 2
          /* TypeText */
          ,
          nodeDef: importExpr(Identifiers.textDef).callFn([literal(checkIndex), literal(ast.ngContentIndex), literalArr([literal(ast.value)])])
        };
      });
    }
  }, {
    key: "visitBoundText",
    value: function visitBoundText(ast, context) {
      var _this239 = this;

      var nodeIndex = this.nodes.length; // reserve the space in the nodeDefs array

      this.nodes.push(null);
      var astWithSource = ast.value;
      var inter = astWithSource.ast;
      var updateRendererExpressions = inter.expressions.map(function (expr, bindingIndex) {
        return _this239._preprocessUpdateExpression({
          nodeIndex: nodeIndex,
          bindingIndex: bindingIndex,
          sourceSpan: ast.sourceSpan,
          context: COMP_VAR,
          value: expr
        });
      }); // Check index is the same as the node index during compilation
      // They might only differ at runtime

      var checkIndex = nodeIndex;

      this.nodes[nodeIndex] = function () {
        return {
          sourceSpan: ast.sourceSpan,
          nodeFlags: 2
          /* TypeText */
          ,
          nodeDef: importExpr(Identifiers.textDef).callFn([literal(checkIndex), literal(ast.ngContentIndex), literalArr(inter.strings.map(function (s) {
            return literal(s);
          }))]),
          updateRenderer: updateRendererExpressions
        };
      };
    }
  }, {
    key: "visitEmbeddedTemplate",
    value: function visitEmbeddedTemplate(ast, context) {
      var _this240 = this;

      var nodeIndex = this.nodes.length; // reserve the space in the nodeDefs array

      this.nodes.push(null);

      var _this$_visitElementOr = this._visitElementOrTemplate(nodeIndex, ast),
          flags = _this$_visitElementOr.flags,
          queryMatchesExpr = _this$_visitElementOr.queryMatchesExpr,
          hostEvents = _this$_visitElementOr.hostEvents;

      var childVisitor = this.viewBuilderFactory(this);
      this.children.push(childVisitor);
      childVisitor.visitAll(ast.variables, ast.children);
      var childCount = this.nodes.length - nodeIndex - 1; // anchorDef(
      //   flags: NodeFlags, matchedQueries: [string, QueryValueType][], ngContentIndex: number,
      //   childCount: number, handleEventFn?: ElementHandleEventFn, templateFactory?:
      //   ViewDefinitionFactory): NodeDef;

      this.nodes[nodeIndex] = function () {
        return {
          sourceSpan: ast.sourceSpan,
          nodeFlags: 1
          /* TypeElement */
          | flags,
          nodeDef: importExpr(Identifiers.anchorDef).callFn([literal(flags), queryMatchesExpr, literal(ast.ngContentIndex), literal(childCount), _this240._createElementHandleEventFn(nodeIndex, hostEvents), variable(childVisitor.viewName)])
        };
      };
    }
  }, {
    key: "visitElement",
    value: function visitElement(ast, context) {
      var _this241 = this;

      var nodeIndex = this.nodes.length; // reserve the space in the nodeDefs array so we can add children

      this.nodes.push(null); // Using a null element name creates an anchor.

      var elName = isNgContainer(ast.name) ? null : ast.name;

      var _this$_visitElementOr2 = this._visitElementOrTemplate(nodeIndex, ast),
          flags = _this$_visitElementOr2.flags,
          usedEvents = _this$_visitElementOr2.usedEvents,
          queryMatchesExpr = _this$_visitElementOr2.queryMatchesExpr,
          dirHostBindings = _this$_visitElementOr2.hostBindings,
          hostEvents = _this$_visitElementOr2.hostEvents;

      var inputDefs = [];
      var updateRendererExpressions = [];
      var outputDefs = [];

      if (elName) {
        var hostBindings = ast.inputs.map(function (inputAst) {
          return {
            context: COMP_VAR,
            inputAst: inputAst,
            dirAst: null
          };
        }).concat(dirHostBindings);

        if (hostBindings.length) {
          updateRendererExpressions = hostBindings.map(function (hostBinding, bindingIndex) {
            return _this241._preprocessUpdateExpression({
              context: hostBinding.context,
              nodeIndex: nodeIndex,
              bindingIndex: bindingIndex,
              sourceSpan: hostBinding.inputAst.sourceSpan,
              value: hostBinding.inputAst.value
            });
          });
          inputDefs = hostBindings.map(function (hostBinding) {
            return elementBindingDef(hostBinding.inputAst, hostBinding.dirAst);
          });
        }

        outputDefs = usedEvents.map(function (_ref37) {
          var _ref38 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_ref37, 2),
              target = _ref38[0],
              eventName = _ref38[1];

          return literalArr([literal(target), literal(eventName)]);
        });
      }

      templateVisitAll(this, ast.children);
      var childCount = this.nodes.length - nodeIndex - 1;
      var compAst = ast.directives.find(function (dirAst) {
        return dirAst.directive.isComponent;
      });
      var compRendererType = NULL_EXPR;
      var compView = NULL_EXPR;

      if (compAst) {
        compView = this.outputCtx.importExpr(compAst.directive.componentViewType);
        compRendererType = this.outputCtx.importExpr(compAst.directive.rendererType);
      } // Check index is the same as the node index during compilation
      // They might only differ at runtime


      var checkIndex = nodeIndex;

      this.nodes[nodeIndex] = function () {
        return {
          sourceSpan: ast.sourceSpan,
          nodeFlags: 1
          /* TypeElement */
          | flags,
          nodeDef: importExpr(Identifiers.elementDef).callFn([literal(checkIndex), literal(flags), queryMatchesExpr, literal(ast.ngContentIndex), literal(childCount), literal(elName), elName ? fixedAttrsDef(ast) : NULL_EXPR, inputDefs.length ? literalArr(inputDefs) : NULL_EXPR, outputDefs.length ? literalArr(outputDefs) : NULL_EXPR, _this241._createElementHandleEventFn(nodeIndex, hostEvents), compView, compRendererType]),
          updateRenderer: updateRendererExpressions
        };
      };
    }
  }, {
    key: "_visitElementOrTemplate",
    value: function _visitElementOrTemplate(nodeIndex, ast) {
      var _this242 = this;

      var flags = 0
      /* None */
      ;

      if (ast.hasViewContainer) {
        flags |= 16777216
        /* EmbeddedViews */
        ;
      }

      var usedEvents = new Map();
      ast.outputs.forEach(function (event) {
        var _elementEventNameAndT = elementEventNameAndTarget(event, null),
            name = _elementEventNameAndT.name,
            target = _elementEventNameAndT.target;

        usedEvents.set(elementEventFullName(target, name), [target, name]);
      });
      ast.directives.forEach(function (dirAst) {
        dirAst.hostEvents.forEach(function (event) {
          var _elementEventNameAndT2 = elementEventNameAndTarget(event, dirAst),
              name = _elementEventNameAndT2.name,
              target = _elementEventNameAndT2.target;

          usedEvents.set(elementEventFullName(target, name), [target, name]);
        });
      });
      var hostBindings = [];
      var hostEvents = [];

      this._visitComponentFactoryResolverProvider(ast.directives);

      ast.providers.forEach(function (providerAst) {
        var dirAst = undefined;
        ast.directives.forEach(function (localDirAst) {
          if (localDirAst.directive.type.reference === tokenReference(providerAst.token)) {
            dirAst = localDirAst;
          }
        });

        if (dirAst) {
          var _this242$_visitDirect = _this242._visitDirective(providerAst, dirAst, ast.references, ast.queryMatches, usedEvents),
              dirHostBindings = _this242$_visitDirect.hostBindings,
              dirHostEvents = _this242$_visitDirect.hostEvents;

          hostBindings.push.apply(hostBindings, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(dirHostBindings));
          hostEvents.push.apply(hostEvents, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(dirHostEvents));
        } else {
          _this242._visitProvider(providerAst, ast.queryMatches);
        }
      });
      var queryMatchExprs = [];
      ast.queryMatches.forEach(function (match) {
        var valueType = undefined;

        if (tokenReference(match.value) === _this242.reflector.resolveExternalReference(Identifiers.ElementRef)) {
          valueType = 0
          /* ElementRef */
          ;
        } else if (tokenReference(match.value) === _this242.reflector.resolveExternalReference(Identifiers.ViewContainerRef)) {
          valueType = 3
          /* ViewContainerRef */
          ;
        } else if (tokenReference(match.value) === _this242.reflector.resolveExternalReference(Identifiers.TemplateRef)) {
          valueType = 2
          /* TemplateRef */
          ;
        }

        if (valueType != null) {
          queryMatchExprs.push(literalArr([literal(match.queryId), literal(valueType)]));
        }
      });
      ast.references.forEach(function (ref) {
        var valueType = undefined;

        if (!ref.value) {
          valueType = 1
          /* RenderElement */
          ;
        } else if (tokenReference(ref.value) === _this242.reflector.resolveExternalReference(Identifiers.TemplateRef)) {
          valueType = 2
          /* TemplateRef */
          ;
        }

        if (valueType != null) {
          _this242.refNodeIndices[ref.name] = nodeIndex;
          queryMatchExprs.push(literalArr([literal(ref.name), literal(valueType)]));
        }
      });
      ast.outputs.forEach(function (outputAst) {
        hostEvents.push({
          context: COMP_VAR,
          eventAst: outputAst,
          dirAst: null
        });
      });
      return {
        flags: flags,
        usedEvents: Array.from(usedEvents.values()),
        queryMatchesExpr: queryMatchExprs.length ? literalArr(queryMatchExprs) : NULL_EXPR,
        hostBindings: hostBindings,
        hostEvents: hostEvents
      };
    }
  }, {
    key: "_visitDirective",
    value: function _visitDirective(providerAst, dirAst, refs, queryMatches, usedEvents) {
      var _this243 = this;

      var nodeIndex = this.nodes.length; // reserve the space in the nodeDefs array so we can add children

      this.nodes.push(null);
      dirAst.directive.queries.forEach(function (query, queryIndex) {
        var queryId = dirAst.contentQueryStartId + queryIndex;
        var flags = 67108864
        /* TypeContentQuery */
        | calcStaticDynamicQueryFlags(query);
        var bindingType = query.first ? 0
        /* First */
        : 1
        /* All */
        ;

        _this243.nodes.push(function () {
          return {
            sourceSpan: dirAst.sourceSpan,
            nodeFlags: flags,
            nodeDef: importExpr(Identifiers.queryDef).callFn([literal(flags), literal(queryId), new LiteralMapExpr([new LiteralMapEntry(query.propertyName, literal(bindingType), false)])])
          };
        });
      }); // Note: the operation below might also create new nodeDefs,
      // but we don't want them to be a child of a directive,
      // as they might be a provider/pipe on their own.
      // I.e. we only allow queries as children of directives nodes.

      var childCount = this.nodes.length - nodeIndex - 1;

      var _this$_visitProviderO = this._visitProviderOrDirective(providerAst, queryMatches),
          flags = _this$_visitProviderO.flags,
          queryMatchExprs = _this$_visitProviderO.queryMatchExprs,
          providerExpr = _this$_visitProviderO.providerExpr,
          depsExpr = _this$_visitProviderO.depsExpr;

      refs.forEach(function (ref) {
        if (ref.value && tokenReference(ref.value) === tokenReference(providerAst.token)) {
          _this243.refNodeIndices[ref.name] = nodeIndex;
          queryMatchExprs.push(literalArr([literal(ref.name), literal(4
          /* Provider */
          )]));
        }
      });

      if (dirAst.directive.isComponent) {
        flags |= 32768
        /* Component */
        ;
      }

      var inputDefs = dirAst.inputs.map(function (inputAst, inputIndex) {
        var mapValue = literalArr([literal(inputIndex), literal(inputAst.directiveName)]); // Note: it's important to not quote the key so that we can capture renames by minifiers!

        return new LiteralMapEntry(inputAst.directiveName, mapValue, false);
      });
      var outputDefs = [];
      var dirMeta = dirAst.directive;
      Object.keys(dirMeta.outputs).forEach(function (propName) {
        var eventName = dirMeta.outputs[propName];

        if (usedEvents.has(eventName)) {
          // Note: it's important to not quote the key so that we can capture renames by minifiers!
          outputDefs.push(new LiteralMapEntry(propName, literal(eventName), false));
        }
      });
      var updateDirectiveExpressions = [];

      if (dirAst.inputs.length || (flags & (262144
      /* DoCheck */
      | 65536
      /* OnInit */
      )) > 0) {
        updateDirectiveExpressions = dirAst.inputs.map(function (input, bindingIndex) {
          return _this243._preprocessUpdateExpression({
            nodeIndex: nodeIndex,
            bindingIndex: bindingIndex,
            sourceSpan: input.sourceSpan,
            context: COMP_VAR,
            value: input.value
          });
        });
      }

      var dirContextExpr = importExpr(Identifiers.nodeValue).callFn([VIEW_VAR, literal(nodeIndex)]);
      var hostBindings = dirAst.hostProperties.map(function (inputAst) {
        return {
          context: dirContextExpr,
          dirAst: dirAst,
          inputAst: inputAst
        };
      });
      var hostEvents = dirAst.hostEvents.map(function (hostEventAst) {
        return {
          context: dirContextExpr,
          eventAst: hostEventAst,
          dirAst: dirAst
        };
      }); // Check index is the same as the node index during compilation
      // They might only differ at runtime

      var checkIndex = nodeIndex;

      this.nodes[nodeIndex] = function () {
        return {
          sourceSpan: dirAst.sourceSpan,
          nodeFlags: 16384
          /* TypeDirective */
          | flags,
          nodeDef: importExpr(Identifiers.directiveDef).callFn([literal(checkIndex), literal(flags), queryMatchExprs.length ? literalArr(queryMatchExprs) : NULL_EXPR, literal(childCount), providerExpr, depsExpr, inputDefs.length ? new LiteralMapExpr(inputDefs) : NULL_EXPR, outputDefs.length ? new LiteralMapExpr(outputDefs) : NULL_EXPR]),
          updateDirectives: updateDirectiveExpressions,
          directive: dirAst.directive.type
        };
      };

      return {
        hostBindings: hostBindings,
        hostEvents: hostEvents
      };
    }
  }, {
    key: "_visitProvider",
    value: function _visitProvider(providerAst, queryMatches) {
      this._addProviderNode(this._visitProviderOrDirective(providerAst, queryMatches));
    }
  }, {
    key: "_visitComponentFactoryResolverProvider",
    value: function _visitComponentFactoryResolverProvider(directives) {
      var componentDirMeta = directives.find(function (dirAst) {
        return dirAst.directive.isComponent;
      });

      if (componentDirMeta && componentDirMeta.directive.entryComponents.length) {
        var _componentFactoryReso = componentFactoryResolverProviderDef(this.reflector, this.outputCtx, 8192
        /* PrivateProvider */
        , componentDirMeta.directive.entryComponents),
            providerExpr = _componentFactoryReso.providerExpr,
            depsExpr = _componentFactoryReso.depsExpr,
            flags = _componentFactoryReso.flags,
            _tokenExpr = _componentFactoryReso.tokenExpr;

        this._addProviderNode({
          providerExpr: providerExpr,
          depsExpr: depsExpr,
          flags: flags,
          tokenExpr: _tokenExpr,
          queryMatchExprs: [],
          sourceSpan: componentDirMeta.sourceSpan
        });
      }
    }
  }, {
    key: "_addProviderNode",
    value: function _addProviderNode(data) {
      // providerDef(
      //   flags: NodeFlags, matchedQueries: [string, QueryValueType][], token:any,
      //   value: any, deps: ([DepFlags, any] | any)[]): NodeDef;
      this.nodes.push(function () {
        return {
          sourceSpan: data.sourceSpan,
          nodeFlags: data.flags,
          nodeDef: importExpr(Identifiers.providerDef).callFn([literal(data.flags), data.queryMatchExprs.length ? literalArr(data.queryMatchExprs) : NULL_EXPR, data.tokenExpr, data.providerExpr, data.depsExpr])
        };
      });
    }
  }, {
    key: "_visitProviderOrDirective",
    value: function _visitProviderOrDirective(providerAst, queryMatches) {
      var flags = 0
      /* None */
      ;
      var queryMatchExprs = [];
      queryMatches.forEach(function (match) {
        if (tokenReference(match.value) === tokenReference(providerAst.token)) {
          queryMatchExprs.push(literalArr([literal(match.queryId), literal(4
          /* Provider */
          )]));
        }
      });

      var _providerDef = providerDef(this.outputCtx, providerAst),
          providerExpr = _providerDef.providerExpr,
          depsExpr = _providerDef.depsExpr,
          providerFlags = _providerDef.flags,
          tokenExpr = _providerDef.tokenExpr;

      return {
        flags: flags | providerFlags,
        queryMatchExprs: queryMatchExprs,
        providerExpr: providerExpr,
        depsExpr: depsExpr,
        tokenExpr: tokenExpr,
        sourceSpan: providerAst.sourceSpan
      };
    }
  }, {
    key: "getLocal",
    value: function getLocal(name) {
      if (name == EventHandlerVars.event.name) {
        return EventHandlerVars.event;
      }

      var currViewExpr = VIEW_VAR;

      for (var currBuilder = this; currBuilder; currBuilder = currBuilder.parent, currViewExpr = currViewExpr.prop('parent').cast(DYNAMIC_TYPE)) {
        // check references
        var refNodeIndex = currBuilder.refNodeIndices[name];

        if (refNodeIndex != null) {
          return importExpr(Identifiers.nodeValue).callFn([currViewExpr, literal(refNodeIndex)]);
        } // check variables


        var varAst = currBuilder.variables.find(function (varAst) {
          return varAst.name === name;
        });

        if (varAst) {
          var varValue = varAst.value || IMPLICIT_TEMPLATE_VAR;
          return currViewExpr.prop('context').prop(varValue);
        }
      }

      return null;
    }
  }, {
    key: "notifyImplicitReceiverUse",
    value: function notifyImplicitReceiverUse() {// Not needed in View Engine as View Engine walks through the generated
      // expressions to figure out if the implicit receiver is used and needs
      // to be generated as part of the pre-update statements.
    }
  }, {
    key: "_createLiteralArrayConverter",
    value: function _createLiteralArrayConverter(sourceSpan, argCount) {
      if (argCount === 0) {
        var valueExpr = importExpr(Identifiers.EMPTY_ARRAY);
        return function () {
          return valueExpr;
        };
      }

      var checkIndex = this.nodes.length;
      this.nodes.push(function () {
        return {
          sourceSpan: sourceSpan,
          nodeFlags: 32
          /* TypePureArray */
          ,
          nodeDef: importExpr(Identifiers.pureArrayDef).callFn([literal(checkIndex), literal(argCount)])
        };
      });
      return function (args) {
        return callCheckStmt(checkIndex, args);
      };
    }
  }, {
    key: "_createLiteralMapConverter",
    value: function _createLiteralMapConverter(sourceSpan, keys) {
      if (keys.length === 0) {
        var valueExpr = importExpr(Identifiers.EMPTY_MAP);
        return function () {
          return valueExpr;
        };
      }

      var map = literalMap(keys.map(function (e, i) {
        return Object.assign(Object.assign({}, e), {
          value: literal(i)
        });
      }));
      var checkIndex = this.nodes.length;
      this.nodes.push(function () {
        return {
          sourceSpan: sourceSpan,
          nodeFlags: 64
          /* TypePureObject */
          ,
          nodeDef: importExpr(Identifiers.pureObjectDef).callFn([literal(checkIndex), map])
        };
      });
      return function (args) {
        return callCheckStmt(checkIndex, args);
      };
    }
  }, {
    key: "_createPipeConverter",
    value: function _createPipeConverter(expression, name, argCount) {
      var pipe = this.usedPipes.find(function (pipeSummary) {
        return pipeSummary.name === name;
      });

      if (pipe.pure) {
        var checkIndex = this.nodes.length;
        this.nodes.push(function () {
          return {
            sourceSpan: expression.sourceSpan,
            nodeFlags: 128
            /* TypePurePipe */
            ,
            nodeDef: importExpr(Identifiers.purePipeDef).callFn([literal(checkIndex), literal(argCount)])
          };
        }); // find underlying pipe in the component view

        var compViewExpr = VIEW_VAR;
        var compBuilder = this;

        while (compBuilder.parent) {
          compBuilder = compBuilder.parent;
          compViewExpr = compViewExpr.prop('parent').cast(DYNAMIC_TYPE);
        }

        var pipeNodeIndex = compBuilder.purePipeNodeIndices[name];
        var pipeValueExpr = importExpr(Identifiers.nodeValue).callFn([compViewExpr, literal(pipeNodeIndex)]);
        return function (args) {
          return callUnwrapValue(expression.nodeIndex, expression.bindingIndex, callCheckStmt(checkIndex, [pipeValueExpr].concat(args)));
        };
      } else {
        var nodeIndex = this._createPipe(expression.sourceSpan, pipe);

        var nodeValueExpr = importExpr(Identifiers.nodeValue).callFn([VIEW_VAR, literal(nodeIndex)]);
        return function (args) {
          return callUnwrapValue(expression.nodeIndex, expression.bindingIndex, nodeValueExpr.callMethod('transform', args));
        };
      }
    }
  }, {
    key: "_createPipe",
    value: function _createPipe(sourceSpan, pipe) {
      var _this244 = this;

      var nodeIndex = this.nodes.length;
      var flags = 0
      /* None */
      ;
      pipe.type.lifecycleHooks.forEach(function (lifecycleHook) {
        // for pipes, we only support ngOnDestroy
        if (lifecycleHook === LifecycleHooks.OnDestroy) {
          flags |= lifecycleHookToNodeFlag(lifecycleHook);
        }
      });
      var depExprs = pipe.type.diDeps.map(function (diDep) {
        return depDef(_this244.outputCtx, diDep);
      }); // function pipeDef(
      //   flags: NodeFlags, ctor: any, deps: ([DepFlags, any] | any)[]): NodeDef

      this.nodes.push(function () {
        return {
          sourceSpan: sourceSpan,
          nodeFlags: 16
          /* TypePipe */
          ,
          nodeDef: importExpr(Identifiers.pipeDef).callFn([literal(flags), _this244.outputCtx.importExpr(pipe.type.reference), literalArr(depExprs)])
        };
      });
      return nodeIndex;
    }
    /**
     * For the AST in `UpdateExpression.value`:
     * - create nodes for pipes, literal arrays and, literal maps,
     * - update the AST to replace pipes, literal arrays and, literal maps with calls to check fn.
     *
     * WARNING: This might create new nodeDefs (for pipes and literal arrays and literal maps)!
     */

  }, {
    key: "_preprocessUpdateExpression",
    value: function _preprocessUpdateExpression(expression) {
      var _this245 = this;

      return {
        nodeIndex: expression.nodeIndex,
        bindingIndex: expression.bindingIndex,
        sourceSpan: expression.sourceSpan,
        context: expression.context,
        value: convertPropertyBindingBuiltins({
          createLiteralArrayConverter: function createLiteralArrayConverter(argCount) {
            return _this245._createLiteralArrayConverter(expression.sourceSpan, argCount);
          },
          createLiteralMapConverter: function createLiteralMapConverter(keys) {
            return _this245._createLiteralMapConverter(expression.sourceSpan, keys);
          },
          createPipeConverter: function createPipeConverter(name, argCount) {
            return _this245._createPipeConverter(expression, name, argCount);
          }
        }, expression.value)
      };
    }
  }, {
    key: "_createNodeExpressions",
    value: function _createNodeExpressions() {
      var self = this;
      var updateBindingCount = 0;
      var updateRendererStmts = [];
      var updateDirectivesStmts = [];
      var nodeDefExprs = this.nodes.map(function (factory, nodeIndex) {
        var _factory = factory(),
            nodeDef = _factory.nodeDef,
            nodeFlags = _factory.nodeFlags,
            updateDirectives = _factory.updateDirectives,
            updateRenderer = _factory.updateRenderer,
            sourceSpan = _factory.sourceSpan;

        if (updateRenderer) {
          updateRendererStmts.push.apply(updateRendererStmts, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(createUpdateStatements(nodeIndex, sourceSpan, updateRenderer, false)));
        }

        if (updateDirectives) {
          updateDirectivesStmts.push.apply(updateDirectivesStmts, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(createUpdateStatements(nodeIndex, sourceSpan, updateDirectives, (nodeFlags & (262144
          /* DoCheck */
          | 65536
          /* OnInit */
          )) > 0)));
        } // We use a comma expression to call the log function before
        // the nodeDef function, but still use the result of the nodeDef function
        // as the value.
        // Note: We only add the logger to elements / text nodes,
        // so we don't generate too much code.


        var logWithNodeDef = nodeFlags & 3
        /* CatRenderNode */
        ? new CommaExpr([LOG_VAR$1.callFn([]).callFn([]), nodeDef]) : nodeDef;
        return applySourceSpanToExpressionIfNeeded(logWithNodeDef, sourceSpan);
      });
      return {
        updateRendererStmts: updateRendererStmts,
        updateDirectivesStmts: updateDirectivesStmts,
        nodeDefExprs: nodeDefExprs
      };

      function createUpdateStatements(nodeIndex, sourceSpan, expressions, allowEmptyExprs) {
        var updateStmts = [];
        var exprs = expressions.map(function (_ref39) {
          var sourceSpan = _ref39.sourceSpan,
              context = _ref39.context,
              value = _ref39.value;
          var bindingId = "".concat(updateBindingCount++);
          var nameResolver = context === COMP_VAR ? self : null;

          var _convertPropertyBindi3 = _convertPropertyBinding(nameResolver, context, value, bindingId, BindingForm.General),
              stmts = _convertPropertyBindi3.stmts,
              currValExpr = _convertPropertyBindi3.currValExpr;

          updateStmts.push.apply(updateStmts, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(stmts.map(function (stmt) {
            return applySourceSpanToStatementIfNeeded(stmt, sourceSpan);
          })));
          return applySourceSpanToExpressionIfNeeded(currValExpr, sourceSpan);
        });

        if (expressions.length || allowEmptyExprs) {
          updateStmts.push(applySourceSpanToStatementIfNeeded(callCheckStmt(nodeIndex, exprs).toStmt(), sourceSpan));
        }

        return updateStmts;
      }
    }
  }, {
    key: "_createElementHandleEventFn",
    value: function _createElementHandleEventFn(nodeIndex, handlers) {
      var _this246 = this;

      var handleEventStmts = [];
      var handleEventBindingCount = 0;
      handlers.forEach(function (_ref40) {
        var context = _ref40.context,
            eventAst = _ref40.eventAst,
            dirAst = _ref40.dirAst;
        var bindingId = "".concat(handleEventBindingCount++);
        var nameResolver = context === COMP_VAR ? _this246 : null;

        var _convertActionBinding2 = convertActionBinding(nameResolver, context, eventAst.handler, bindingId),
            stmts = _convertActionBinding2.stmts,
            allowDefault = _convertActionBinding2.allowDefault;

        var trueStmts = stmts;

        if (allowDefault) {
          trueStmts.push(ALLOW_DEFAULT_VAR.set(allowDefault.and(ALLOW_DEFAULT_VAR)).toStmt());
        }

        var _elementEventNameAndT3 = elementEventNameAndTarget(eventAst, dirAst),
            eventTarget = _elementEventNameAndT3.target,
            eventName = _elementEventNameAndT3.name;

        var fullEventName = elementEventFullName(eventTarget, eventName);
        handleEventStmts.push(applySourceSpanToStatementIfNeeded(new IfStmt(literal(fullEventName).identical(EVENT_NAME_VAR), trueStmts), eventAst.sourceSpan));
      });
      var handleEventFn;

      if (handleEventStmts.length > 0) {
        var preStmts = [ALLOW_DEFAULT_VAR.set(literal(true)).toDeclStmt(BOOL_TYPE)];

        if (!this.component.isHost && findReadVarNames(handleEventStmts).has(COMP_VAR.name)) {
          preStmts.push(COMP_VAR.set(VIEW_VAR.prop('component')).toDeclStmt(this.compType));
        }

        handleEventFn = fn([new FnParam(VIEW_VAR.name, INFERRED_TYPE), new FnParam(EVENT_NAME_VAR.name, INFERRED_TYPE), new FnParam(EventHandlerVars.event.name, INFERRED_TYPE)], [].concat(preStmts, handleEventStmts, [new ReturnStatement(ALLOW_DEFAULT_VAR)]), INFERRED_TYPE);
      } else {
        handleEventFn = NULL_EXPR;
      }

      return handleEventFn;
    }
  }, {
    key: "visitDirective",
    value: function visitDirective(ast, context) {}
  }, {
    key: "visitDirectiveProperty",
    value: function visitDirectiveProperty(ast, context) {}
  }, {
    key: "visitReference",
    value: function visitReference(ast, context) {}
  }, {
    key: "visitVariable",
    value: function visitVariable(ast, context) {}
  }, {
    key: "visitEvent",
    value: function visitEvent(ast, context) {}
  }, {
    key: "visitElementProperty",
    value: function visitElementProperty(ast, context) {}
  }, {
    key: "visitAttr",
    value: function visitAttr(ast, context) {}
  }]);

  return ViewBuilder$1;
}();

function needsAdditionalRootNode(astNodes) {
  var lastAstNode = astNodes[astNodes.length - 1];

  if (lastAstNode instanceof EmbeddedTemplateAst) {
    return lastAstNode.hasViewContainer;
  }

  if (lastAstNode instanceof ElementAst) {
    if (isNgContainer(lastAstNode.name) && lastAstNode.children.length) {
      return needsAdditionalRootNode(lastAstNode.children);
    }

    return lastAstNode.hasViewContainer;
  }

  return lastAstNode instanceof NgContentAst;
}

function elementBindingDef(inputAst, dirAst) {
  var inputType = inputAst.type;

  switch (inputType) {
    case 1
    /* Attribute */
    :
      return literalArr([literal(1
      /* TypeElementAttribute */
      ), literal(inputAst.name), literal(inputAst.securityContext)]);

    case 0
    /* Property */
    :
      return literalArr([literal(8
      /* TypeProperty */
      ), literal(inputAst.name), literal(inputAst.securityContext)]);

    case 4
    /* Animation */
    :
      var bindingType = 8
      /* TypeProperty */
      | (dirAst && dirAst.directive.isComponent ? 32
      /* SyntheticHostProperty */
      : 16
      /* SyntheticProperty */
      );
      return literalArr([literal(bindingType), literal('@' + inputAst.name), literal(inputAst.securityContext)]);

    case 2
    /* Class */
    :
      return literalArr([literal(2
      /* TypeElementClass */
      ), literal(inputAst.name), NULL_EXPR]);

    case 3
    /* Style */
    :
      return literalArr([literal(4
      /* TypeElementStyle */
      ), literal(inputAst.name), literal(inputAst.unit)]);

    default:
      // This default case is not needed by TypeScript compiler, as the switch is exhaustive.
      // However Closure Compiler does not understand that and reports an error in typed mode.
      // The `throw new Error` below works around the problem, and the unexpected: never variable
      // makes sure tsc still checks this code is unreachable.
      var unexpected = inputType;
      throw new Error("unexpected ".concat(unexpected));
  }
}

function fixedAttrsDef(elementAst) {
  var mapResult = Object.create(null);
  elementAst.attrs.forEach(function (attrAst) {
    mapResult[attrAst.name] = attrAst.value;
  });
  elementAst.directives.forEach(function (dirAst) {
    Object.keys(dirAst.directive.hostAttributes).forEach(function (name) {
      var value = dirAst.directive.hostAttributes[name];
      var prevValue = mapResult[name];
      mapResult[name] = prevValue != null ? mergeAttributeValue(name, prevValue, value) : value;
    });
  }); // Note: We need to sort to get a defined output order
  // for tests and for caching generated artifacts...

  return literalArr(Object.keys(mapResult).sort().map(function (attrName) {
    return literalArr([literal(attrName), literal(mapResult[attrName])]);
  }));
}

function mergeAttributeValue(attrName, attrValue1, attrValue2) {
  if (attrName == CLASS_ATTR$1 || attrName == STYLE_ATTR) {
    return "".concat(attrValue1, " ").concat(attrValue2);
  } else {
    return attrValue2;
  }
}

function callCheckStmt(nodeIndex, exprs) {
  if (exprs.length > 10) {
    return CHECK_VAR.callFn([VIEW_VAR, literal(nodeIndex), literal(1
    /* Dynamic */
    ), literalArr(exprs)]);
  } else {
    return CHECK_VAR.callFn([VIEW_VAR, literal(nodeIndex), literal(0
    /* Inline */
    )].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(exprs)));
  }
}

function callUnwrapValue(nodeIndex, bindingIdx, expr) {
  return importExpr(Identifiers.unwrapValue).callFn([VIEW_VAR, literal(nodeIndex), literal(bindingIdx), expr]);
}

function elementEventNameAndTarget(eventAst, dirAst) {
  if (eventAst.isAnimation) {
    return {
      name: "@".concat(eventAst.name, ".").concat(eventAst.phase),
      target: dirAst && dirAst.directive.isComponent ? 'component' : null
    };
  } else {
    return eventAst;
  }
}

function calcStaticDynamicQueryFlags(query) {
  var flags = 0
  /* None */
  ; // Note: We only make queries static that query for a single item and the user specifically
  // set the to be static. This is because of backwards compatibility with the old view compiler...

  if (query.first && query.static) {
    flags |= 268435456
    /* StaticQuery */
    ;
  } else {
    flags |= 536870912
    /* DynamicQuery */
    ;
  }

  return flags;
}

function elementEventFullName(target, name) {
  return target ? "".concat(target, ":").concat(name) : name;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A container for message extracted from the templates.
 */


var MessageBundle = /*#__PURE__*/function () {
  function MessageBundle(_htmlParser, _implicitTags, _implicitAttrs) {
    var _locale = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, MessageBundle);

    this._htmlParser = _htmlParser;
    this._implicitTags = _implicitTags;
    this._implicitAttrs = _implicitAttrs;
    this._locale = _locale;
    this._messages = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(MessageBundle, [{
    key: "updateFromTemplate",
    value: function updateFromTemplate(html, url, interpolationConfig) {
      var _this$_messages;

      var htmlParserResult = this._htmlParser.parse(html, url, {
        tokenizeExpansionForms: true,
        interpolationConfig: interpolationConfig
      });

      if (htmlParserResult.errors.length) {
        return htmlParserResult.errors;
      }

      var i18nParserResult = extractMessages(htmlParserResult.rootNodes, interpolationConfig, this._implicitTags, this._implicitAttrs);

      if (i18nParserResult.errors.length) {
        return i18nParserResult.errors;
      }

      (_this$_messages = this._messages).push.apply(_this$_messages, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(i18nParserResult.messages));

      return [];
    } // Return the message in the internal format
    // The public (serialized) format might be different, see the `write` method.

  }, {
    key: "getMessages",
    value: function getMessages() {
      return this._messages;
    }
  }, {
    key: "write",
    value: function write(serializer, filterSources) {
      var messages = {};
      var mapperVisitor = new MapPlaceholderNames(); // Deduplicate messages based on their ID

      this._messages.forEach(function (message) {
        var id = serializer.digest(message);

        if (!messages.hasOwnProperty(id)) {
          messages[id] = message;
        } else {
          var _messages$id$sources;

          (_messages$id$sources = messages[id].sources).push.apply(_messages$id$sources, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(message.sources));
        }
      }); // Transform placeholder names using the serializer mapping


      var msgList = Object.keys(messages).map(function (id) {
        var mapper = serializer.createNameMapper(messages[id]);
        var src = messages[id];
        var nodes = mapper ? mapperVisitor.convert(src.nodes, mapper) : src.nodes;
        var transformedMessage = new Message(nodes, {}, {}, src.meaning, src.description, id);
        transformedMessage.sources = src.sources;

        if (filterSources) {
          transformedMessage.sources.forEach(function (source) {
            return source.filePath = filterSources(source.filePath);
          });
        }

        return transformedMessage;
      });
      return serializer.write(msgList, this._locale);
    }
  }]);

  return MessageBundle;
}(); // Transform an i18n AST by renaming the placeholder nodes with the given mapper


var MapPlaceholderNames = /*#__PURE__*/function (_CloneVisitor) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(MapPlaceholderNames, _CloneVisitor);

  var _super104 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(MapPlaceholderNames);

  function MapPlaceholderNames() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, MapPlaceholderNames);

    return _super104.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(MapPlaceholderNames, [{
    key: "convert",
    value: function convert(nodes, mapper) {
      var _this247 = this;

      return mapper ? nodes.map(function (n) {
        return n.visit(_this247, mapper);
      }) : nodes;
    }
  }, {
    key: "visitTagPlaceholder",
    value: function visitTagPlaceholder(ph, mapper) {
      var _this248 = this;

      var startName = mapper.toPublicName(ph.startName);
      var closeName = ph.closeName ? mapper.toPublicName(ph.closeName) : ph.closeName;
      var children = ph.children.map(function (n) {
        return n.visit(_this248, mapper);
      });
      return new TagPlaceholder(ph.tag, ph.attrs, startName, closeName, children, ph.isVoid, ph.sourceSpan, ph.startSourceSpan, ph.endSourceSpan);
    }
  }, {
    key: "visitPlaceholder",
    value: function visitPlaceholder(ph, mapper) {
      return new Placeholder(ph.value, mapper.toPublicName(ph.name), ph.sourceSpan);
    }
  }, {
    key: "visitIcuPlaceholder",
    value: function visitIcuPlaceholder(ph, mapper) {
      return new IcuPlaceholder(ph.value, mapper.toPublicName(ph.name), ph.sourceSpan);
    }
  }]);

  return MapPlaceholderNames;
}(CloneVisitor);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var GeneratedFile = /*#__PURE__*/function () {
  function GeneratedFile(srcFileUrl, genFileUrl, sourceOrStmts) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, GeneratedFile);

    this.srcFileUrl = srcFileUrl;
    this.genFileUrl = genFileUrl;

    if (typeof sourceOrStmts === 'string') {
      this.source = sourceOrStmts;
      this.stmts = null;
    } else {
      this.source = null;
      this.stmts = sourceOrStmts;
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(GeneratedFile, [{
    key: "isEquivalent",
    value: function isEquivalent(other) {
      if (this.genFileUrl !== other.genFileUrl) {
        return false;
      }

      if (this.source) {
        return this.source === other.source;
      }

      if (other.stmts == null) {
        return false;
      } // Note: the constructor guarantees that if this.source is not filled,
      // then this.stmts is.


      return areAllEquivalent(this.stmts, other.stmts);
    }
  }]);

  return GeneratedFile;
}();

function toTypeScript(file) {
  var preamble = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';

  if (!file.stmts) {
    throw new Error("Illegal state: No stmts present on GeneratedFile ".concat(file.genFileUrl));
  }

  return new TypeScriptEmitter().emitStatements(file.genFileUrl, file.stmts, preamble);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function _listLazyRoutes(moduleMeta, reflector) {
  var allLazyRoutes = [];

  var _iterator21 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(moduleMeta.transitiveModule.providers),
      _step21;

  try {
    for (_iterator21.s(); !(_step21 = _iterator21.n()).done;) {
      var _step21$value = _step21.value,
          provider = _step21$value.provider,
          module = _step21$value.module;

      if (tokenReference(provider.token) === reflector.ROUTES) {
        var loadChildren = _collectLoadChildren(provider.useValue);

        var _iterator22 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(loadChildren),
            _step22;

        try {
          for (_iterator22.s(); !(_step22 = _iterator22.n()).done;) {
            var route = _step22.value;
            allLazyRoutes.push(parseLazyRoute(route, reflector, module.reference));
          }
        } catch (err) {
          _iterator22.e(err);
        } finally {
          _iterator22.f();
        }
      }
    }
  } catch (err) {
    _iterator21.e(err);
  } finally {
    _iterator21.f();
  }

  return allLazyRoutes;
}

function _collectLoadChildren(routes) {
  var target = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  if (typeof routes === 'string') {
    target.push(routes);
  } else if (Array.isArray(routes)) {
    var _iterator23 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(routes),
        _step23;

    try {
      for (_iterator23.s(); !(_step23 = _iterator23.n()).done;) {
        var route = _step23.value;

        _collectLoadChildren(route, target);
      }
    } catch (err) {
      _iterator23.e(err);
    } finally {
      _iterator23.f();
    }
  } else if (routes.loadChildren) {
    _collectLoadChildren(routes.loadChildren, target);
  } else if (routes.children) {
    _collectLoadChildren(routes.children, target);
  }

  return target;
}

function parseLazyRoute(route, reflector, module) {
  var _route$split = route.split('#'),
      _route$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_4__["default"])(_route$split, 2),
      routePath = _route$split2[0],
      routeName = _route$split2[1];

  var referencedModule = reflector.resolveExternalReference({
    moduleName: routePath,
    name: routeName
  }, module ? module.filePath : undefined);
  return {
    route: route,
    module: module || referencedModule,
    referencedModule: referencedModule
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TS = /^(?!.*\.d\.ts$).*\.ts$/;

var ResolvedStaticSymbol = function ResolvedStaticSymbol(symbol, metadata) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ResolvedStaticSymbol);

  this.symbol = symbol;
  this.metadata = metadata;
};

var SUPPORTED_SCHEMA_VERSION = 4;
/**
 * This class is responsible for loading metadata per symbol,
 * and normalizing references between symbols.
 *
 * Internally, it only uses symbols without members,
 * and deduces the values for symbols with members based
 * on these symbols.
 */

var StaticSymbolResolver = /*#__PURE__*/function () {
  function StaticSymbolResolver(host, staticSymbolCache, summaryResolver, errorRecorder) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StaticSymbolResolver);

    this.host = host;
    this.staticSymbolCache = staticSymbolCache;
    this.summaryResolver = summaryResolver;
    this.errorRecorder = errorRecorder;
    this.metadataCache = new Map(); // Note: this will only contain StaticSymbols without members!

    this.resolvedSymbols = new Map(); // Note: this will only contain StaticSymbols without members!

    this.importAs = new Map();
    this.symbolResourcePaths = new Map();
    this.symbolFromFile = new Map();
    this.knownFileNameToModuleNames = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StaticSymbolResolver, [{
    key: "resolveSymbol",
    value: function resolveSymbol(staticSymbol) {
      if (staticSymbol.members.length > 0) {
        return this._resolveSymbolMembers(staticSymbol);
      } // Note: always ask for a summary first,
      // as we might have read shallow metadata via a .d.ts file
      // for the symbol.


      var resultFromSummary = this._resolveSymbolFromSummary(staticSymbol);

      if (resultFromSummary) {
        return resultFromSummary;
      }

      var resultFromCache = this.resolvedSymbols.get(staticSymbol);

      if (resultFromCache) {
        return resultFromCache;
      } // Note: Some users use libraries that were not compiled with ngc, i.e. they don't
      // have summaries, only .d.ts files. So we always need to check both, the summary
      // and metadata.


      this._createSymbolsOf(staticSymbol.filePath);

      return this.resolvedSymbols.get(staticSymbol);
    }
    /**
     * getImportAs produces a symbol that can be used to import the given symbol.
     * The import might be different than the symbol if the symbol is exported from
     * a library with a summary; in which case we want to import the symbol from the
     * ngfactory re-export instead of directly to avoid introducing a direct dependency
     * on an otherwise indirect dependency.
     *
     * @param staticSymbol the symbol for which to generate a import symbol
     */

  }, {
    key: "getImportAs",
    value: function getImportAs(staticSymbol) {
      var useSummaries = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

      if (staticSymbol.members.length) {
        var baseSymbol = this.getStaticSymbol(staticSymbol.filePath, staticSymbol.name);
        var baseImportAs = this.getImportAs(baseSymbol, useSummaries);
        return baseImportAs ? this.getStaticSymbol(baseImportAs.filePath, baseImportAs.name, staticSymbol.members) : null;
      }

      var summarizedFileName = stripSummaryForJitFileSuffix(staticSymbol.filePath);

      if (summarizedFileName !== staticSymbol.filePath) {
        var summarizedName = stripSummaryForJitNameSuffix(staticSymbol.name);

        var _baseSymbol = this.getStaticSymbol(summarizedFileName, summarizedName, staticSymbol.members);

        var _baseImportAs = this.getImportAs(_baseSymbol, useSummaries);

        return _baseImportAs ? this.getStaticSymbol(summaryForJitFileName(_baseImportAs.filePath), summaryForJitName(_baseImportAs.name), _baseSymbol.members) : null;
      }

      var result = useSummaries && this.summaryResolver.getImportAs(staticSymbol) || null;

      if (!result) {
        result = this.importAs.get(staticSymbol);
      }

      return result;
    }
    /**
     * getResourcePath produces the path to the original location of the symbol and should
     * be used to determine the relative location of resource references recorded in
     * symbol metadata.
     */

  }, {
    key: "getResourcePath",
    value: function getResourcePath(staticSymbol) {
      return this.symbolResourcePaths.get(staticSymbol) || staticSymbol.filePath;
    }
    /**
     * getTypeArity returns the number of generic type parameters the given symbol
     * has. If the symbol is not a type the result is null.
     */

  }, {
    key: "getTypeArity",
    value: function getTypeArity(staticSymbol) {
      // If the file is a factory/ngsummary file, don't resolve the symbol as doing so would
      // cause the metadata for an factory/ngsummary file to be loaded which doesn't exist.
      // All references to generated classes must include the correct arity whenever
      // generating code.
      if (isGeneratedFile(staticSymbol.filePath)) {
        return null;
      }

      var resolvedSymbol = unwrapResolvedMetadata(this.resolveSymbol(staticSymbol));

      while (resolvedSymbol && resolvedSymbol.metadata instanceof StaticSymbol) {
        resolvedSymbol = unwrapResolvedMetadata(this.resolveSymbol(resolvedSymbol.metadata));
      }

      return resolvedSymbol && resolvedSymbol.metadata && resolvedSymbol.metadata.arity || null;
    }
  }, {
    key: "getKnownModuleName",
    value: function getKnownModuleName(filePath) {
      return this.knownFileNameToModuleNames.get(filePath) || null;
    }
  }, {
    key: "recordImportAs",
    value: function recordImportAs(sourceSymbol, targetSymbol) {
      sourceSymbol.assertNoMembers();
      targetSymbol.assertNoMembers();
      this.importAs.set(sourceSymbol, targetSymbol);
    }
  }, {
    key: "recordModuleNameForFileName",
    value: function recordModuleNameForFileName(fileName, moduleName) {
      this.knownFileNameToModuleNames.set(fileName, moduleName);
    }
    /**
     * Invalidate all information derived from the given file and return the
     * static symbols contained in the file.
     *
     * @param fileName the file to invalidate
     */

  }, {
    key: "invalidateFile",
    value: function invalidateFile(fileName) {
      this.metadataCache.delete(fileName);
      var symbols = this.symbolFromFile.get(fileName);

      if (!symbols) {
        return [];
      }

      this.symbolFromFile.delete(fileName);

      var _iterator24 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(symbols),
          _step24;

      try {
        for (_iterator24.s(); !(_step24 = _iterator24.n()).done;) {
          var symbol = _step24.value;
          this.resolvedSymbols.delete(symbol);
          this.importAs.delete(symbol);
          this.symbolResourcePaths.delete(symbol);
        }
      } catch (err) {
        _iterator24.e(err);
      } finally {
        _iterator24.f();
      }

      return symbols;
    }
    /** @internal */

  }, {
    key: "ignoreErrorsFor",
    value: function ignoreErrorsFor(cb) {
      var recorder = this.errorRecorder;

      this.errorRecorder = function () {};

      try {
        return cb();
      } finally {
        this.errorRecorder = recorder;
      }
    }
  }, {
    key: "_resolveSymbolMembers",
    value: function _resolveSymbolMembers(staticSymbol) {
      var members = staticSymbol.members;
      var baseResolvedSymbol = this.resolveSymbol(this.getStaticSymbol(staticSymbol.filePath, staticSymbol.name));

      if (!baseResolvedSymbol) {
        return null;
      }

      var baseMetadata = unwrapResolvedMetadata(baseResolvedSymbol.metadata);

      if (baseMetadata instanceof StaticSymbol) {
        return new ResolvedStaticSymbol(staticSymbol, this.getStaticSymbol(baseMetadata.filePath, baseMetadata.name, members));
      } else if (baseMetadata && baseMetadata.__symbolic === 'class') {
        if (baseMetadata.statics && members.length === 1) {
          return new ResolvedStaticSymbol(staticSymbol, baseMetadata.statics[members[0]]);
        }
      } else {
        var value = baseMetadata;

        for (var i = 0; i < members.length && value; i++) {
          value = value[members[i]];
        }

        return new ResolvedStaticSymbol(staticSymbol, value);
      }

      return null;
    }
  }, {
    key: "_resolveSymbolFromSummary",
    value: function _resolveSymbolFromSummary(staticSymbol) {
      var summary = this.summaryResolver.resolveSummary(staticSymbol);
      return summary ? new ResolvedStaticSymbol(staticSymbol, summary.metadata) : null;
    }
    /**
     * getStaticSymbol produces a Type whose metadata is known but whose implementation is not loaded.
     * All types passed to the StaticResolver should be pseudo-types returned by this method.
     *
     * @param declarationFile the absolute path of the file where the symbol is declared
     * @param name the name of the type.
     * @param members a symbol for a static member of the named type
     */

  }, {
    key: "getStaticSymbol",
    value: function getStaticSymbol(declarationFile, name, members) {
      return this.staticSymbolCache.get(declarationFile, name, members);
    }
    /**
     * hasDecorators checks a file's metadata for the presence of decorators without evaluating the
     * metadata.
     *
     * @param filePath the absolute path to examine for decorators.
     * @returns true if any class in the file has a decorator.
     */

  }, {
    key: "hasDecorators",
    value: function hasDecorators(filePath) {
      var metadata = this.getModuleMetadata(filePath);

      if (metadata['metadata']) {
        return Object.keys(metadata['metadata']).some(function (metadataKey) {
          var entry = metadata['metadata'][metadataKey];
          return entry && entry.__symbolic === 'class' && entry.decorators;
        });
      }

      return false;
    }
  }, {
    key: "getSymbolsOf",
    value: function getSymbolsOf(filePath) {
      var summarySymbols = this.summaryResolver.getSymbolsOf(filePath);

      if (summarySymbols) {
        return summarySymbols;
      } // Note: Some users use libraries that were not compiled with ngc, i.e. they don't
      // have summaries, only .d.ts files, but `summaryResolver.isLibraryFile` returns true.


      this._createSymbolsOf(filePath);

      return this.symbolFromFile.get(filePath) || [];
    }
  }, {
    key: "_createSymbolsOf",
    value: function _createSymbolsOf(filePath) {
      var _this249 = this;

      if (this.symbolFromFile.has(filePath)) {
        return;
      }

      var resolvedSymbols = [];
      var metadata = this.getModuleMetadata(filePath);

      if (metadata['importAs']) {
        // Index bundle indices should use the importAs module name defined
        // in the bundle.
        this.knownFileNameToModuleNames.set(filePath, metadata['importAs']);
      } // handle the symbols in one of the re-export location


      if (metadata['exports']) {
        var _iterator25 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(metadata['exports']),
            _step25;

        try {
          var _loop3 = function _loop3() {
            var moduleExport = _step25.value;

            // handle the symbols in the list of explicitly re-exported symbols.
            if (moduleExport.export) {
              moduleExport.export.forEach(function (exportSymbol) {
                var symbolName;

                if (typeof exportSymbol === 'string') {
                  symbolName = exportSymbol;
                } else {
                  symbolName = exportSymbol.as;
                }

                symbolName = unescapeIdentifier(symbolName);
                var symName = symbolName;

                if (typeof exportSymbol !== 'string') {
                  symName = unescapeIdentifier(exportSymbol.name);
                }

                var resolvedModule = _this249.resolveModule(moduleExport.from, filePath);

                if (resolvedModule) {
                  var targetSymbol = _this249.getStaticSymbol(resolvedModule, symName);

                  var sourceSymbol = _this249.getStaticSymbol(filePath, symbolName);

                  resolvedSymbols.push(_this249.createExport(sourceSymbol, targetSymbol));
                }
              });
            } else {
              // Handle the symbols loaded by 'export *' directives.
              var resolvedModule = _this249.resolveModule(moduleExport.from, filePath);

              if (resolvedModule && resolvedModule !== filePath) {
                var nestedExports = _this249.getSymbolsOf(resolvedModule);

                nestedExports.forEach(function (targetSymbol) {
                  var sourceSymbol = _this249.getStaticSymbol(filePath, targetSymbol.name);

                  resolvedSymbols.push(_this249.createExport(sourceSymbol, targetSymbol));
                });
              }
            }
          };

          for (_iterator25.s(); !(_step25 = _iterator25.n()).done;) {
            _loop3();
          }
        } catch (err) {
          _iterator25.e(err);
        } finally {
          _iterator25.f();
        }
      } // handle the actual metadata. Has to be after the exports
      // as there might be collisions in the names, and we want the symbols
      // of the current module to win ofter reexports.


      if (metadata['metadata']) {
        // handle direct declarations of the symbol
        var topLevelSymbolNames = new Set(Object.keys(metadata['metadata']).map(unescapeIdentifier));
        var origins = metadata['origins'] || {};
        Object.keys(metadata['metadata']).forEach(function (metadataKey) {
          var symbolMeta = metadata['metadata'][metadataKey];
          var name = unescapeIdentifier(metadataKey);

          var symbol = _this249.getStaticSymbol(filePath, name);

          var origin = origins.hasOwnProperty(metadataKey) && origins[metadataKey];

          if (origin) {
            // If the symbol is from a bundled index, use the declaration location of the
            // symbol so relative references (such as './my.html') will be calculated
            // correctly.
            var originFilePath = _this249.resolveModule(origin, filePath);

            if (!originFilePath) {
              _this249.reportError(new Error("Couldn't resolve original symbol for ".concat(origin, " from ").concat(_this249.host.getOutputName(filePath))));
            } else {
              _this249.symbolResourcePaths.set(symbol, originFilePath);
            }
          }

          resolvedSymbols.push(_this249.createResolvedSymbol(symbol, filePath, topLevelSymbolNames, symbolMeta));
        });
      }

      var uniqueSymbols = new Set();

      for (var _i9 = 0, _resolvedSymbols = resolvedSymbols; _i9 < _resolvedSymbols.length; _i9++) {
        var resolvedSymbol = _resolvedSymbols[_i9];
        this.resolvedSymbols.set(resolvedSymbol.symbol, resolvedSymbol);
        uniqueSymbols.add(resolvedSymbol.symbol);
      }

      this.symbolFromFile.set(filePath, Array.from(uniqueSymbols));
    }
  }, {
    key: "createResolvedSymbol",
    value: function createResolvedSymbol(sourceSymbol, topLevelPath, topLevelSymbolNames, metadata) {
      var _this250 = this;

      // For classes that don't have Angular summaries / metadata,
      // we only keep their arity, but nothing else
      // (e.g. their constructor parameters).
      // We do this to prevent introducing deep imports
      // as we didn't generate .ngfactory.ts files with proper reexports.
      var isTsFile = TS.test(sourceSymbol.filePath);

      if (this.summaryResolver.isLibraryFile(sourceSymbol.filePath) && !isTsFile && metadata && metadata['__symbolic'] === 'class') {
        var _transformedMeta = {
          __symbolic: 'class',
          arity: metadata.arity
        };
        return new ResolvedStaticSymbol(sourceSymbol, _transformedMeta);
      }

      var _originalFileMemo;

      var getOriginalName = function getOriginalName() {
        if (!_originalFileMemo) {
          // Guess what the original file name is from the reference. If it has a `.d.ts` extension
          // replace it with `.ts`. If it already has `.ts` just leave it in place. If it doesn't have
          // .ts or .d.ts, append `.ts'. Also, if it is in `node_modules`, trim the `node_module`
          // location as it is not important to finding the file.
          _originalFileMemo = _this250.host.getOutputName(topLevelPath.replace(/((\.ts)|(\.d\.ts)|)$/, '.ts').replace(/^.*node_modules[/\\]/, ''));
        }

        return _originalFileMemo;
      };

      var self = this;

      var ReferenceTransformer = /*#__PURE__*/function (_ValueTransformer2) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ReferenceTransformer, _ValueTransformer2);

        var _super105 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ReferenceTransformer);

        function ReferenceTransformer() {
          Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReferenceTransformer);

          return _super105.apply(this, arguments);
        }

        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ReferenceTransformer, [{
          key: "visitStringMap",
          value: function visitStringMap(map, functionParams) {
            var symbolic = map['__symbolic'];

            if (symbolic === 'function') {
              var oldLen = functionParams.length;
              functionParams.push.apply(functionParams, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(map['parameters'] || []));

              var result = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(ReferenceTransformer.prototype), "visitStringMap", this).call(this, map, functionParams);

              functionParams.length = oldLen;
              return result;
            } else if (symbolic === 'reference') {
              var module = map['module'];
              var name = map['name'] ? unescapeIdentifier(map['name']) : map['name'];

              if (!name) {
                return null;
              }

              var filePath;

              if (module) {
                filePath = self.resolveModule(module, sourceSymbol.filePath);

                if (!filePath) {
                  return {
                    __symbolic: 'error',
                    message: "Could not resolve ".concat(module, " relative to ").concat(self.host.getMetadataFor(sourceSymbol.filePath), "."),
                    line: map['line'],
                    character: map['character'],
                    fileName: getOriginalName()
                  };
                }

                return {
                  __symbolic: 'resolved',
                  symbol: self.getStaticSymbol(filePath, name),
                  line: map['line'],
                  character: map['character'],
                  fileName: getOriginalName()
                };
              } else if (functionParams.indexOf(name) >= 0) {
                // reference to a function parameter
                return {
                  __symbolic: 'reference',
                  name: name
                };
              } else {
                if (topLevelSymbolNames.has(name)) {
                  return self.getStaticSymbol(topLevelPath, name);
                } // ambient value


                null;
              }
            } else if (symbolic === 'error') {
              return Object.assign(Object.assign({}, map), {
                fileName: getOriginalName()
              });
            } else {
              return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(ReferenceTransformer.prototype), "visitStringMap", this).call(this, map, functionParams);
            }
          }
        }]);

        return ReferenceTransformer;
      }(ValueTransformer);

      var transformedMeta = visitValue(metadata, new ReferenceTransformer(), []);
      var unwrappedTransformedMeta = unwrapResolvedMetadata(transformedMeta);

      if (unwrappedTransformedMeta instanceof StaticSymbol) {
        return this.createExport(sourceSymbol, unwrappedTransformedMeta);
      }

      return new ResolvedStaticSymbol(sourceSymbol, transformedMeta);
    }
  }, {
    key: "createExport",
    value: function createExport(sourceSymbol, targetSymbol) {
      sourceSymbol.assertNoMembers();
      targetSymbol.assertNoMembers();

      if (this.summaryResolver.isLibraryFile(sourceSymbol.filePath) && this.summaryResolver.isLibraryFile(targetSymbol.filePath)) {
        // This case is for an ng library importing symbols from a plain ts library
        // transitively.
        // Note: We rely on the fact that we discover symbols in the direction
        // from source files to library files
        this.importAs.set(targetSymbol, this.getImportAs(sourceSymbol) || sourceSymbol);
      }

      return new ResolvedStaticSymbol(sourceSymbol, targetSymbol);
    }
  }, {
    key: "reportError",
    value: function reportError(error, context, path) {
      if (this.errorRecorder) {
        this.errorRecorder(error, context && context.filePath || path);
      } else {
        throw error;
      }
    }
    /**
     * @param module an absolute path to a module file.
     */

  }, {
    key: "getModuleMetadata",
    value: function getModuleMetadata(module) {
      var moduleMetadata = this.metadataCache.get(module);

      if (!moduleMetadata) {
        var moduleMetadatas = this.host.getMetadataFor(module);

        if (moduleMetadatas) {
          var maxVersion = -1;
          moduleMetadatas.forEach(function (md) {
            if (md && md['version'] > maxVersion) {
              maxVersion = md['version'];
              moduleMetadata = md;
            }
          });
        }

        if (!moduleMetadata) {
          moduleMetadata = {
            __symbolic: 'module',
            version: SUPPORTED_SCHEMA_VERSION,
            module: module,
            metadata: {}
          };
        }

        if (moduleMetadata['version'] != SUPPORTED_SCHEMA_VERSION) {
          var errorMessage = moduleMetadata['version'] == 2 ? "Unsupported metadata version ".concat(moduleMetadata['version'], " for module ").concat(module, ". This module should be compiled with a newer version of ngc") : "Metadata version mismatch for module ".concat(this.host.getOutputName(module), ", found version ").concat(moduleMetadata['version'], ", expected ").concat(SUPPORTED_SCHEMA_VERSION);
          this.reportError(new Error(errorMessage));
        }

        this.metadataCache.set(module, moduleMetadata);
      }

      return moduleMetadata;
    }
  }, {
    key: "getSymbolByModule",
    value: function getSymbolByModule(module, symbolName, containingFile) {
      var filePath = this.resolveModule(module, containingFile);

      if (!filePath) {
        this.reportError(new Error("Could not resolve module ".concat(module).concat(containingFile ? ' relative to ' + this.host.getOutputName(containingFile) : '')));
        return this.getStaticSymbol("ERROR:".concat(module), symbolName);
      }

      return this.getStaticSymbol(filePath, symbolName);
    }
  }, {
    key: "resolveModule",
    value: function resolveModule(module, containingFile) {
      try {
        return this.host.moduleNameToFileName(module, containingFile);
      } catch (e) {
        console.error("Could not resolve module '".concat(module, "' relative to file ").concat(containingFile));
        this.reportError(e, undefined, containingFile);
      }

      return null;
    }
  }]);

  return StaticSymbolResolver;
}(); // Remove extra underscore from escaped identifier.
// See https://github.com/Microsoft/TypeScript/blob/master/src/compiler/utilities.ts


function unescapeIdentifier(identifier) {
  return identifier.startsWith('___') ? identifier.substr(1) : identifier;
}

function unwrapResolvedMetadata(metadata) {
  if (metadata && metadata.__symbolic === 'resolved') {
    return metadata.symbol;
  }

  return metadata;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function serializeSummaries(srcFileName, forJitCtx, summaryResolver, symbolResolver, symbols, types) {
  var createExternalSymbolReexports = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;
  var toJsonSerializer = new ToJsonSerializer(symbolResolver, summaryResolver, srcFileName); // for symbols, we use everything except for the class metadata itself
  // (we keep the statics though), as the class metadata is contained in the
  // CompileTypeSummary.

  symbols.forEach(function (resolvedSymbol) {
    return toJsonSerializer.addSummary({
      symbol: resolvedSymbol.symbol,
      metadata: resolvedSymbol.metadata
    });
  }); // Add type summaries.

  types.forEach(function (_ref41) {
    var summary = _ref41.summary,
        metadata = _ref41.metadata;
    toJsonSerializer.addSummary({
      symbol: summary.type.reference,
      metadata: undefined,
      type: summary
    });
  });

  var _toJsonSerializer$ser = toJsonSerializer.serialize(createExternalSymbolReexports),
      json = _toJsonSerializer$ser.json,
      exportAs = _toJsonSerializer$ser.exportAs;

  if (forJitCtx) {
    var forJitSerializer = new ForJitSerializer(forJitCtx, symbolResolver, summaryResolver);
    types.forEach(function (_ref42) {
      var summary = _ref42.summary,
          metadata = _ref42.metadata;
      forJitSerializer.addSourceType(summary, metadata);
    });
    toJsonSerializer.unprocessedSymbolSummariesBySymbol.forEach(function (summary) {
      if (summaryResolver.isLibraryFile(summary.symbol.filePath) && summary.type) {
        forJitSerializer.addLibType(summary.type);
      }
    });
    forJitSerializer.serialize(exportAs);
  }

  return {
    json: json,
    exportAs: exportAs
  };
}

function deserializeSummaries(symbolCache, summaryResolver, libraryFileName, json) {
  var deserializer = new FromJsonDeserializer(symbolCache, summaryResolver);
  return deserializer.deserialize(libraryFileName, json);
}

function createForJitStub(outputCtx, reference) {
  return createSummaryForJitFunction(outputCtx, reference, NULL_EXPR);
}

function createSummaryForJitFunction(outputCtx, reference, value) {
  var fnName = summaryForJitName(reference.name);
  outputCtx.statements.push(fn([], [new ReturnStatement(value)], new ArrayType(DYNAMIC_TYPE)).toDeclStmt(fnName, [StmtModifier.Final, StmtModifier.Exported]));
}

var ToJsonSerializer = /*#__PURE__*/function (_ValueTransformer3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(ToJsonSerializer, _ValueTransformer3);

  var _super106 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(ToJsonSerializer);

  function ToJsonSerializer(symbolResolver, summaryResolver, srcFileName) {
    var _this251;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ToJsonSerializer);

    _this251 = _super106.call(this);
    _this251.symbolResolver = symbolResolver;
    _this251.summaryResolver = summaryResolver;
    _this251.srcFileName = srcFileName; // Note: This only contains symbols without members.

    _this251.symbols = [];
    _this251.indexBySymbol = new Map();
    _this251.reexportedBy = new Map(); // This now contains a `__symbol: number` in the place of
    // StaticSymbols, but otherwise has the same shape as the original objects.

    _this251.processedSummaryBySymbol = new Map();
    _this251.processedSummaries = [];
    _this251.unprocessedSymbolSummariesBySymbol = new Map();
    _this251.moduleName = symbolResolver.getKnownModuleName(srcFileName);
    return _this251;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ToJsonSerializer, [{
    key: "addSummary",
    value: function addSummary(summary) {
      var _this252 = this;

      var unprocessedSummary = this.unprocessedSymbolSummariesBySymbol.get(summary.symbol);
      var processedSummary = this.processedSummaryBySymbol.get(summary.symbol);

      if (!unprocessedSummary) {
        unprocessedSummary = {
          symbol: summary.symbol,
          metadata: undefined
        };
        this.unprocessedSymbolSummariesBySymbol.set(summary.symbol, unprocessedSummary);
        processedSummary = {
          symbol: this.processValue(summary.symbol, 0
          /* None */
          )
        };
        this.processedSummaries.push(processedSummary);
        this.processedSummaryBySymbol.set(summary.symbol, processedSummary);
      }

      if (!unprocessedSummary.metadata && summary.metadata) {
        var metadata = summary.metadata || {};

        if (metadata.__symbolic === 'class') {
          // For classes, we keep everything except their class decorators.
          // We need to keep e.g. the ctor args, method names, method decorators
          // so that the class can be extended in another compilation unit.
          // We don't keep the class decorators as
          // 1) they refer to data
          //   that should not cause a rebuild of downstream compilation units
          //   (e.g. inline templates of @Component, or @NgModule.declarations)
          // 2) their data is already captured in TypeSummaries, e.g. DirectiveSummary.
          var clone = {};
          Object.keys(metadata).forEach(function (propName) {
            if (propName !== 'decorators') {
              clone[propName] = metadata[propName];
            }
          });
          metadata = clone;
        } else if (isCall(metadata)) {
          if (!isFunctionCall(metadata) && !isMethodCallOnVariable(metadata)) {
            // Don't store complex calls as we won't be able to simplify them anyways later on.
            metadata = {
              __symbolic: 'error',
              message: 'Complex function calls are not supported.'
            };
          }
        } // Note: We need to keep storing ctor calls for e.g.
        // `export const x = new InjectionToken(...)`


        unprocessedSummary.metadata = metadata;
        processedSummary.metadata = this.processValue(metadata, 1
        /* ResolveValue */
        );

        if (metadata instanceof StaticSymbol && this.summaryResolver.isLibraryFile(metadata.filePath)) {
          var declarationSymbol = this.symbols[this.indexBySymbol.get(metadata)];

          if (!isLoweredSymbol(declarationSymbol.name)) {
            // Note: symbols that were introduced during codegen in the user file can have a reexport
            // if a user used `export *`. However, we can't rely on this as tsickle will change
            // `export *` into named exports, using only the information from the typechecker.
            // As we introduce the new symbols after typecheck, Tsickle does not know about them,
            // and omits them when expanding `export *`.
            // So we have to keep reexporting these symbols manually via .ngfactory files.
            this.reexportedBy.set(declarationSymbol, summary.symbol);
          }
        }
      }

      if (!unprocessedSummary.type && summary.type) {
        unprocessedSummary.type = summary.type; // Note: We don't add the summaries of all referenced symbols as for the ResolvedSymbols,
        // as the type summaries already contain the transitive data that they require
        // (in a minimal way).

        processedSummary.type = this.processValue(summary.type, 0
        /* None */
        ); // except for reexported directives / pipes, so we need to store
        // their summaries explicitly.

        if (summary.type.summaryKind === CompileSummaryKind.NgModule) {
          var ngModuleSummary = summary.type;
          ngModuleSummary.exportedDirectives.concat(ngModuleSummary.exportedPipes).forEach(function (id) {
            var symbol = id.reference;

            if (_this252.summaryResolver.isLibraryFile(symbol.filePath) && !_this252.unprocessedSymbolSummariesBySymbol.has(symbol)) {
              var _summary = _this252.summaryResolver.resolveSummary(symbol);

              if (_summary) {
                _this252.addSummary(_summary);
              }
            }
          });
        }
      }
    }
    /**
     * @param createExternalSymbolReexports Whether external static symbols should be re-exported.
     * This can be enabled if external symbols should be re-exported by the current module in
     * order to avoid dynamically generated module dependencies which can break strict dependency
     * enforcements (as in Google3). Read more here: https://github.com/angular/angular/issues/25644
     */

  }, {
    key: "serialize",
    value: function serialize(createExternalSymbolReexports) {
      var _this253 = this;

      var exportAs = [];
      var json = JSON.stringify({
        moduleName: this.moduleName,
        summaries: this.processedSummaries,
        symbols: this.symbols.map(function (symbol, index) {
          symbol.assertNoMembers();
          var importAs = undefined;

          if (_this253.summaryResolver.isLibraryFile(symbol.filePath)) {
            var reexportSymbol = _this253.reexportedBy.get(symbol);

            if (reexportSymbol) {
              // In case the given external static symbol is already manually exported by the
              // user, we just proxy the external static symbol reference to the manual export.
              // This ensures that the AOT compiler imports the external symbol through the
              // user export and does not introduce another dependency which is not needed.
              importAs = _this253.indexBySymbol.get(reexportSymbol);
            } else if (createExternalSymbolReexports) {
              // In this case, the given external static symbol is *not* manually exported by
              // the user, and we manually create a re-export in the factory file so that we
              // don't introduce another module dependency. This is useful when running within
              // Bazel so that the AOT compiler does not introduce any module dependencies
              // which can break the strict dependency enforcement. (e.g. as in Google3)
              // Read more about this here: https://github.com/angular/angular/issues/25644
              var summary = _this253.unprocessedSymbolSummariesBySymbol.get(symbol);

              if (!summary || !summary.metadata || summary.metadata.__symbolic !== 'interface') {
                importAs = "".concat(symbol.name, "_").concat(index);
                exportAs.push({
                  symbol: symbol,
                  exportAs: importAs
                });
              }
            }
          }

          return {
            __symbol: index,
            name: symbol.name,
            filePath: _this253.summaryResolver.toSummaryFileName(symbol.filePath, _this253.srcFileName),
            importAs: importAs
          };
        })
      });
      return {
        json: json,
        exportAs: exportAs
      };
    }
  }, {
    key: "processValue",
    value: function processValue(value, flags) {
      return visitValue(value, this, flags);
    }
  }, {
    key: "visitOther",
    value: function visitOther(value, context) {
      if (value instanceof StaticSymbol) {
        var baseSymbol = this.symbolResolver.getStaticSymbol(value.filePath, value.name);
        var index = this.visitStaticSymbol(baseSymbol, context);
        return {
          __symbol: index,
          members: value.members
        };
      }
    }
    /**
     * Strip line and character numbers from ngsummaries.
     * Emitting them causes white spaces changes to retrigger upstream
     * recompilations in bazel.
     * TODO: find out a way to have line and character numbers in errors without
     * excessive recompilation in bazel.
     */

  }, {
    key: "visitStringMap",
    value: function visitStringMap(map, context) {
      if (map['__symbolic'] === 'resolved') {
        return visitValue(map['symbol'], this, context);
      }

      if (map['__symbolic'] === 'error') {
        delete map['line'];
        delete map['character'];
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(ToJsonSerializer.prototype), "visitStringMap", this).call(this, map, context);
    }
    /**
     * Returns null if the options.resolveValue is true, and the summary for the symbol
     * resolved to a type or could not be resolved.
     */

  }, {
    key: "visitStaticSymbol",
    value: function visitStaticSymbol(baseSymbol, flags) {
      var index = this.indexBySymbol.get(baseSymbol);
      var summary = null;

      if (flags & 1
      /* ResolveValue */
      && this.summaryResolver.isLibraryFile(baseSymbol.filePath)) {
        if (this.unprocessedSymbolSummariesBySymbol.has(baseSymbol)) {
          // the summary for this symbol was already added
          // -> nothing to do.
          return index;
        }

        summary = this.loadSummary(baseSymbol);

        if (summary && summary.metadata instanceof StaticSymbol) {
          // The summary is a reexport
          index = this.visitStaticSymbol(summary.metadata, flags); // reset the summary as it is just a reexport, so we don't want to store it.

          summary = null;
        }
      } else if (index != null) {
        // Note: == on purpose to compare with undefined!
        // No summary and the symbol is already added -> nothing to do.
        return index;
      } // Note: == on purpose to compare with undefined!


      if (index == null) {
        index = this.symbols.length;
        this.symbols.push(baseSymbol);
      }

      this.indexBySymbol.set(baseSymbol, index);

      if (summary) {
        this.addSummary(summary);
      }

      return index;
    }
  }, {
    key: "loadSummary",
    value: function loadSummary(symbol) {
      var summary = this.summaryResolver.resolveSummary(symbol);

      if (!summary) {
        // some symbols might originate from a plain typescript library
        // that just exported .d.ts and .metadata.json files, i.e. where no summary
        // files were created.
        var resolvedSymbol = this.symbolResolver.resolveSymbol(symbol);

        if (resolvedSymbol) {
          summary = {
            symbol: resolvedSymbol.symbol,
            metadata: resolvedSymbol.metadata
          };
        }
      }

      return summary;
    }
  }]);

  return ToJsonSerializer;
}(ValueTransformer);

var ForJitSerializer = /*#__PURE__*/function () {
  function ForJitSerializer(outputCtx, symbolResolver, summaryResolver) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ForJitSerializer);

    this.outputCtx = outputCtx;
    this.symbolResolver = symbolResolver;
    this.summaryResolver = summaryResolver;
    this.data = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(ForJitSerializer, [{
    key: "addSourceType",
    value: function addSourceType(summary, metadata) {
      this.data.push({
        summary: summary,
        metadata: metadata,
        isLibrary: false
      });
    }
  }, {
    key: "addLibType",
    value: function addLibType(summary) {
      this.data.push({
        summary: summary,
        metadata: null,
        isLibrary: true
      });
    }
  }, {
    key: "serialize",
    value: function serialize(exportAsArr) {
      var _this254 = this;

      var exportAsBySymbol = new Map();

      var _iterator26 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(exportAsArr),
          _step26;

      try {
        for (_iterator26.s(); !(_step26 = _iterator26.n()).done;) {
          var _step26$value = _step26.value,
              symbol = _step26$value.symbol,
              exportAs = _step26$value.exportAs;
          exportAsBySymbol.set(symbol, exportAs);
        }
      } catch (err) {
        _iterator26.e(err);
      } finally {
        _iterator26.f();
      }

      var ngModuleSymbols = new Set();

      var _iterator27 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(this.data),
          _step27;

      try {
        for (_iterator27.s(); !(_step27 = _iterator27.n()).done;) {
          var _step27$value = _step27.value,
              summary = _step27$value.summary,
              metadata = _step27$value.metadata,
              isLibrary = _step27$value.isLibrary;

          if (summary.summaryKind === CompileSummaryKind.NgModule) {
            // collect the symbols that refer to NgModule classes.
            // Note: we can't just rely on `summary.type.summaryKind` to determine this as
            // we don't add the summaries of all referenced symbols when we serialize type summaries.
            // See serializeSummaries for details.
            ngModuleSymbols.add(summary.type.reference);
            var modSummary = summary;

            var _iterator28 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(modSummary.modules),
                _step28;

            try {
              for (_iterator28.s(); !(_step28 = _iterator28.n()).done;) {
                var mod = _step28.value;
                ngModuleSymbols.add(mod.reference);
              }
            } catch (err) {
              _iterator28.e(err);
            } finally {
              _iterator28.f();
            }
          }

          if (!isLibrary) {
            var fnName = summaryForJitName(summary.type.reference.name);
            createSummaryForJitFunction(this.outputCtx, summary.type.reference, this.serializeSummaryWithDeps(summary, metadata));
          }
        }
      } catch (err) {
        _iterator27.e(err);
      } finally {
        _iterator27.f();
      }

      ngModuleSymbols.forEach(function (ngModuleSymbol) {
        if (_this254.summaryResolver.isLibraryFile(ngModuleSymbol.filePath)) {
          var exportAs = exportAsBySymbol.get(ngModuleSymbol) || ngModuleSymbol.name;
          var jitExportAsName = summaryForJitName(exportAs);

          _this254.outputCtx.statements.push(variable(jitExportAsName).set(_this254.serializeSummaryRef(ngModuleSymbol)).toDeclStmt(null, [StmtModifier.Exported]));
        }
      });
    }
  }, {
    key: "serializeSummaryWithDeps",
    value: function serializeSummaryWithDeps(summary, metadata) {
      var _this255 = this;

      var expressions = [this.serializeSummary(summary)];
      var providers = [];

      if (metadata instanceof CompileNgModuleMetadata) {
        expressions.push.apply(expressions, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])( // For directives / pipes, we only add the declared ones,
        // and rely on transitively importing NgModules to get the transitive
        // summaries.
        metadata.declaredDirectives.concat(metadata.declaredPipes).map(function (type) {
          return type.reference;
        }) // For modules,
        // we also add the summaries for modules
        // from libraries.
        // This is ok as we produce reexports for all transitive modules.
        .concat(metadata.transitiveModule.modules.map(function (type) {
          return type.reference;
        }).filter(function (ref) {
          return ref !== metadata.type.reference;
        })).map(function (ref) {
          return _this255.serializeSummaryRef(ref);
        }))); // Note: We don't use `NgModuleSummary.providers`, as that one is transitive,
        // and we already have transitive modules.

        providers = metadata.providers;
      } else if (summary.summaryKind === CompileSummaryKind.Directive) {
        var dirSummary = summary;
        providers = dirSummary.providers.concat(dirSummary.viewProviders);
      } // Note: We can't just refer to the `ngsummary.ts` files for `useClass` providers (as we do for
      // declaredDirectives / declaredPipes), as we allow
      // providers without ctor arguments to skip the `@Injectable` decorator,
      // i.e. we didn't generate .ngsummary.ts files for these.


      expressions.push.apply(expressions, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(providers.filter(function (provider) {
        return !!provider.useClass;
      }).map(function (provider) {
        return _this255.serializeSummary({
          summaryKind: CompileSummaryKind.Injectable,
          type: provider.useClass
        });
      })));
      return literalArr(expressions);
    }
  }, {
    key: "serializeSummaryRef",
    value: function serializeSummaryRef(typeSymbol) {
      var jitImportedSymbol = this.symbolResolver.getStaticSymbol(summaryForJitFileName(typeSymbol.filePath), summaryForJitName(typeSymbol.name));
      return this.outputCtx.importExpr(jitImportedSymbol);
    }
  }, {
    key: "serializeSummary",
    value: function serializeSummary(data) {
      var outputCtx = this.outputCtx;

      var Transformer = /*#__PURE__*/function () {
        function Transformer() {
          Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Transformer);
        }

        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Transformer, [{
          key: "visitArray",
          value: function visitArray(arr, context) {
            var _this256 = this;

            return literalArr(arr.map(function (entry) {
              return visitValue(entry, _this256, context);
            }));
          }
        }, {
          key: "visitStringMap",
          value: function visitStringMap(map, context) {
            var _this257 = this;

            return new LiteralMapExpr(Object.keys(map).map(function (key) {
              return new LiteralMapEntry(key, visitValue(map[key], _this257, context), false);
            }));
          }
        }, {
          key: "visitPrimitive",
          value: function visitPrimitive(value, context) {
            return literal(value);
          }
        }, {
          key: "visitOther",
          value: function visitOther(value, context) {
            if (value instanceof StaticSymbol) {
              return outputCtx.importExpr(value);
            } else {
              throw new Error("Illegal State: Encountered value ".concat(value));
            }
          }
        }]);

        return Transformer;
      }();

      return visitValue(data, new Transformer(), null);
    }
  }]);

  return ForJitSerializer;
}();

var FromJsonDeserializer = /*#__PURE__*/function (_ValueTransformer4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(FromJsonDeserializer, _ValueTransformer4);

  var _super107 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(FromJsonDeserializer);

  function FromJsonDeserializer(symbolCache, summaryResolver) {
    var _this258;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, FromJsonDeserializer);

    _this258 = _super107.call(this);
    _this258.symbolCache = symbolCache;
    _this258.summaryResolver = summaryResolver;
    return _this258;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(FromJsonDeserializer, [{
    key: "deserialize",
    value: function deserialize(libraryFileName, json) {
      var _this259 = this;

      var data = JSON.parse(json);
      var allImportAs = [];
      this.symbols = data.symbols.map(function (serializedSymbol) {
        return _this259.symbolCache.get(_this259.summaryResolver.fromSummaryFileName(serializedSymbol.filePath, libraryFileName), serializedSymbol.name);
      });
      data.symbols.forEach(function (serializedSymbol, index) {
        var symbol = _this259.symbols[index];
        var importAs = serializedSymbol.importAs;

        if (typeof importAs === 'number') {
          allImportAs.push({
            symbol: symbol,
            importAs: _this259.symbols[importAs]
          });
        } else if (typeof importAs === 'string') {
          allImportAs.push({
            symbol: symbol,
            importAs: _this259.symbolCache.get(ngfactoryFilePath(libraryFileName), importAs)
          });
        }
      });
      var summaries = visitValue(data.summaries, this, null);
      return {
        moduleName: data.moduleName,
        summaries: summaries,
        importAs: allImportAs
      };
    }
  }, {
    key: "visitStringMap",
    value: function visitStringMap(map, context) {
      if ('__symbol' in map) {
        var baseSymbol = this.symbols[map['__symbol']];
        var members = map['members'];
        return members.length ? this.symbolCache.get(baseSymbol.filePath, baseSymbol.name, members) : baseSymbol;
      } else {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(FromJsonDeserializer.prototype), "visitStringMap", this).call(this, map, context);
      }
    }
  }]);

  return FromJsonDeserializer;
}(ValueTransformer);

function isCall(metadata) {
  return metadata && metadata.__symbolic === 'call';
}

function isFunctionCall(metadata) {
  return isCall(metadata) && unwrapResolvedMetadata(metadata.expression) instanceof StaticSymbol;
}

function isMethodCallOnVariable(metadata) {
  return isCall(metadata) && metadata.expression && metadata.expression.__symbolic === 'select' && unwrapResolvedMetadata(metadata.expression.expression) instanceof StaticSymbol;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var AotCompiler = /*#__PURE__*/function () {
  function AotCompiler(_config, _options, _host, reflector, _metadataResolver, _templateParser, _styleCompiler, _viewCompiler, _typeCheckCompiler, _ngModuleCompiler, _injectableCompiler, _outputEmitter, _summaryResolver, _symbolResolver) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AotCompiler);

    this._config = _config;
    this._options = _options;
    this._host = _host;
    this.reflector = reflector;
    this._metadataResolver = _metadataResolver;
    this._templateParser = _templateParser;
    this._styleCompiler = _styleCompiler;
    this._viewCompiler = _viewCompiler;
    this._typeCheckCompiler = _typeCheckCompiler;
    this._ngModuleCompiler = _ngModuleCompiler;
    this._injectableCompiler = _injectableCompiler;
    this._outputEmitter = _outputEmitter;
    this._summaryResolver = _summaryResolver;
    this._symbolResolver = _symbolResolver;
    this._templateAstCache = new Map();
    this._analyzedFiles = new Map();
    this._analyzedFilesForInjectables = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AotCompiler, [{
    key: "clearCache",
    value: function clearCache() {
      this._metadataResolver.clearCache();
    }
  }, {
    key: "analyzeModulesSync",
    value: function analyzeModulesSync(rootFiles) {
      var _this260 = this;

      var analyzeResult = analyzeAndValidateNgModules(rootFiles, this._host, this._symbolResolver, this._metadataResolver);
      analyzeResult.ngModules.forEach(function (ngModule) {
        return _this260._metadataResolver.loadNgModuleDirectiveAndPipeMetadata(ngModule.type.reference, true);
      });
      return analyzeResult;
    }
  }, {
    key: "analyzeModulesAsync",
    value: function analyzeModulesAsync(rootFiles) {
      var _this261 = this;

      var analyzeResult = analyzeAndValidateNgModules(rootFiles, this._host, this._symbolResolver, this._metadataResolver);
      return Promise.all(analyzeResult.ngModules.map(function (ngModule) {
        return _this261._metadataResolver.loadNgModuleDirectiveAndPipeMetadata(ngModule.type.reference, false);
      })).then(function () {
        return analyzeResult;
      });
    }
  }, {
    key: "_analyzeFile",
    value: function _analyzeFile(fileName) {
      var analyzedFile = this._analyzedFiles.get(fileName);

      if (!analyzedFile) {
        analyzedFile = analyzeFile(this._host, this._symbolResolver, this._metadataResolver, fileName);

        this._analyzedFiles.set(fileName, analyzedFile);
      }

      return analyzedFile;
    }
  }, {
    key: "_analyzeFileForInjectables",
    value: function _analyzeFileForInjectables(fileName) {
      var analyzedFile = this._analyzedFilesForInjectables.get(fileName);

      if (!analyzedFile) {
        analyzedFile = analyzeFileForInjectables(this._host, this._symbolResolver, this._metadataResolver, fileName);

        this._analyzedFilesForInjectables.set(fileName, analyzedFile);
      }

      return analyzedFile;
    }
  }, {
    key: "findGeneratedFileNames",
    value: function findGeneratedFileNames(fileName) {
      var _this262 = this;

      var genFileNames = [];

      var file = this._analyzeFile(fileName); // Make sure we create a .ngfactory if we have a injectable/directive/pipe/NgModule
      // or a reference to a non source file.
      // Note: This is overestimating the required .ngfactory files as the real calculation is harder.
      // Only do this for StubEmitFlags.Basic, as adding a type check block
      // does not change this file (as we generate type check blocks based on NgModules).


      if (this._options.allowEmptyCodegenFiles || file.directives.length || file.pipes.length || file.injectables.length || file.ngModules.length || file.exportsNonSourceFiles) {
        genFileNames.push(ngfactoryFilePath(file.fileName, true));

        if (this._options.enableSummariesForJit) {
          genFileNames.push(summaryForJitFileName(file.fileName, true));
        }
      }

      var fileSuffix = normalizeGenFileSuffix(splitTypescriptSuffix(file.fileName, true)[1]);
      file.directives.forEach(function (dirSymbol) {
        var compMeta = _this262._metadataResolver.getNonNormalizedDirectiveMetadata(dirSymbol).metadata;

        if (!compMeta.isComponent) {
          return;
        } // Note: compMeta is a component and therefore template is non null.


        compMeta.template.styleUrls.forEach(function (styleUrl) {
          var normalizedUrl = _this262._host.resourceNameToFileName(styleUrl, file.fileName);

          if (!normalizedUrl) {
            throw syntaxError("Couldn't resolve resource ".concat(styleUrl, " relative to ").concat(file.fileName));
          }

          var needsShim = (compMeta.template.encapsulation || _this262._config.defaultEncapsulation) === ViewEncapsulation.Emulated;
          genFileNames.push(_stylesModuleUrl(normalizedUrl, needsShim, fileSuffix));

          if (_this262._options.allowEmptyCodegenFiles) {
            genFileNames.push(_stylesModuleUrl(normalizedUrl, !needsShim, fileSuffix));
          }
        });
      });
      return genFileNames;
    }
  }, {
    key: "emitBasicStub",
    value: function emitBasicStub(genFileName, originalFileName) {
      var outputCtx = this._createOutputContext(genFileName);

      if (genFileName.endsWith('.ngfactory.ts')) {
        if (!originalFileName) {
          throw new Error("Assertion error: require the original file for .ngfactory.ts stubs. File: ".concat(genFileName));
        }

        var originalFile = this._analyzeFile(originalFileName);

        this._createNgFactoryStub(outputCtx, originalFile, 1
        /* Basic */
        );
      } else if (genFileName.endsWith('.ngsummary.ts')) {
        if (this._options.enableSummariesForJit) {
          if (!originalFileName) {
            throw new Error("Assertion error: require the original file for .ngsummary.ts stubs. File: ".concat(genFileName));
          }

          var _originalFile = this._analyzeFile(originalFileName);

          _createEmptyStub(outputCtx);

          _originalFile.ngModules.forEach(function (ngModule) {
            // create exports that user code can reference
            createForJitStub(outputCtx, ngModule.type.reference);
          });
        }
      } else if (genFileName.endsWith('.ngstyle.ts')) {
        _createEmptyStub(outputCtx);
      } // Note: for the stubs, we don't need a property srcFileUrl,
      // as later on in emitAllImpls we will create the proper GeneratedFiles with the
      // correct srcFileUrl.
      // This is good as e.g. for .ngstyle.ts files we can't derive
      // the url of components based on the genFileUrl.


      return this._codegenSourceModule('unknown', outputCtx);
    }
  }, {
    key: "emitTypeCheckStub",
    value: function emitTypeCheckStub(genFileName, originalFileName) {
      var originalFile = this._analyzeFile(originalFileName);

      var outputCtx = this._createOutputContext(genFileName);

      if (genFileName.endsWith('.ngfactory.ts')) {
        this._createNgFactoryStub(outputCtx, originalFile, 2
        /* TypeCheck */
        );
      }

      return outputCtx.statements.length > 0 ? this._codegenSourceModule(originalFile.fileName, outputCtx) : null;
    }
  }, {
    key: "loadFilesAsync",
    value: function loadFilesAsync(fileNames, tsFiles) {
      var _this263 = this;

      var files = fileNames.map(function (fileName) {
        return _this263._analyzeFile(fileName);
      });
      var loadingPromises = [];
      files.forEach(function (file) {
        return file.ngModules.forEach(function (ngModule) {
          return loadingPromises.push(_this263._metadataResolver.loadNgModuleDirectiveAndPipeMetadata(ngModule.type.reference, false));
        });
      });
      var analyzedInjectables = tsFiles.map(function (tsFile) {
        return _this263._analyzeFileForInjectables(tsFile);
      });
      return Promise.all(loadingPromises).then(function (_) {
        return {
          analyzedModules: mergeAndValidateNgFiles(files),
          analyzedInjectables: analyzedInjectables
        };
      });
    }
  }, {
    key: "loadFilesSync",
    value: function loadFilesSync(fileNames, tsFiles) {
      var _this264 = this;

      var files = fileNames.map(function (fileName) {
        return _this264._analyzeFile(fileName);
      });
      files.forEach(function (file) {
        return file.ngModules.forEach(function (ngModule) {
          return _this264._metadataResolver.loadNgModuleDirectiveAndPipeMetadata(ngModule.type.reference, true);
        });
      });
      var analyzedInjectables = tsFiles.map(function (tsFile) {
        return _this264._analyzeFileForInjectables(tsFile);
      });
      return {
        analyzedModules: mergeAndValidateNgFiles(files),
        analyzedInjectables: analyzedInjectables
      };
    }
  }, {
    key: "_createNgFactoryStub",
    value: function _createNgFactoryStub(outputCtx, file, emitFlags) {
      var _this265 = this;

      var componentId = 0;
      file.ngModules.forEach(function (ngModuleMeta, ngModuleIndex) {
        // Note: the code below needs to executed for StubEmitFlags.Basic and StubEmitFlags.TypeCheck,
        // so we don't change the .ngfactory file too much when adding the type-check block.
        // create exports that user code can reference
        _this265._ngModuleCompiler.createStub(outputCtx, ngModuleMeta.type.reference); // add references to the symbols from the metadata.
        // These can be used by the type check block for components,
        // and they also cause TypeScript to include these files into the program too,
        // which will make them part of the analyzedFiles.


        var externalReferences = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ngModuleMeta.transitiveModule.directives.map(function (d) {
          return d.reference;
        })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ngModuleMeta.transitiveModule.pipes.map(function (d) {
          return d.reference;
        })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ngModuleMeta.importedModules.map(function (m) {
          return m.type.reference;
        })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ngModuleMeta.exportedModules.map(function (m) {
          return m.type.reference;
        })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this265._externalIdentifierReferences([Identifiers.TemplateRef, Identifiers.ElementRef])));
        var externalReferenceVars = new Map();
        externalReferences.forEach(function (ref, typeIndex) {
          externalReferenceVars.set(ref, "_decl".concat(ngModuleIndex, "_").concat(typeIndex));
        });
        externalReferenceVars.forEach(function (varName, reference) {
          outputCtx.statements.push(variable(varName).set(NULL_EXPR.cast(DYNAMIC_TYPE)).toDeclStmt(expressionType(outputCtx.importExpr(reference,
          /* typeParams */
          null,
          /* useSummaries */
          false))));
        });

        if (emitFlags & 2
        /* TypeCheck */
        ) {
            // add the type-check block for all components of the NgModule
            ngModuleMeta.declaredDirectives.forEach(function (dirId) {
              var compMeta = _this265._metadataResolver.getDirectiveMetadata(dirId.reference);

              if (!compMeta.isComponent) {
                return;
              }

              componentId++;

              _this265._createTypeCheckBlock(outputCtx, "".concat(compMeta.type.reference.name, "_Host_").concat(componentId), ngModuleMeta, _this265._metadataResolver.getHostComponentMetadata(compMeta), [compMeta.type], externalReferenceVars);

              _this265._createTypeCheckBlock(outputCtx, "".concat(compMeta.type.reference.name, "_").concat(componentId), ngModuleMeta, compMeta, ngModuleMeta.transitiveModule.directives, externalReferenceVars);
            });
          }
      });

      if (outputCtx.statements.length === 0) {
        _createEmptyStub(outputCtx);
      }
    }
  }, {
    key: "_externalIdentifierReferences",
    value: function _externalIdentifierReferences(references) {
      var result = [];

      var _iterator29 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(references),
          _step29;

      try {
        for (_iterator29.s(); !(_step29 = _iterator29.n()).done;) {
          var reference = _step29.value;
          var token = createTokenForExternalReference(this.reflector, reference);

          if (token.identifier) {
            result.push(token.identifier.reference);
          }
        }
      } catch (err) {
        _iterator29.e(err);
      } finally {
        _iterator29.f();
      }

      return result;
    }
  }, {
    key: "_createTypeCheckBlock",
    value: function _createTypeCheckBlock(ctx, componentId, moduleMeta, compMeta, directives, externalReferenceVars) {
      var _ctx$statements;

      var _this$_parseTemplate = this._parseTemplate(compMeta, moduleMeta, directives),
          parsedTemplate = _this$_parseTemplate.template,
          usedPipes = _this$_parseTemplate.pipes;

      (_ctx$statements = ctx.statements).push.apply(_ctx$statements, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._typeCheckCompiler.compileComponent(componentId, compMeta, parsedTemplate, usedPipes, externalReferenceVars, ctx)));
    }
  }, {
    key: "emitMessageBundle",
    value: function emitMessageBundle(analyzeResult, locale) {
      var _this266 = this;

      var errors = [];
      var htmlParser = new HtmlParser(); // TODO(vicb): implicit tags & attributes

      var messageBundle = new MessageBundle(htmlParser, [], {}, locale);
      analyzeResult.files.forEach(function (file) {
        var compMetas = [];
        file.directives.forEach(function (directiveType) {
          var dirMeta = _this266._metadataResolver.getDirectiveMetadata(directiveType);

          if (dirMeta && dirMeta.isComponent) {
            compMetas.push(dirMeta);
          }
        });
        compMetas.forEach(function (compMeta) {
          var html = compMeta.template.template; // Template URL points to either an HTML or TS file depending on whether
          // the file is used with `templateUrl:` or `template:`, respectively.

          var templateUrl = compMeta.template.templateUrl;
          var interpolationConfig = InterpolationConfig.fromArray(compMeta.template.interpolation);
          errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(messageBundle.updateFromTemplate(html, templateUrl, interpolationConfig)));
        });
      });

      if (errors.length) {
        throw new Error(errors.map(function (e) {
          return e.toString();
        }).join('\n'));
      }

      return messageBundle;
    }
  }, {
    key: "emitAllPartialModules",
    value: function emitAllPartialModules(_ref43, r3Files) {
      var _this267 = this;

      var ngModuleByPipeOrDirective = _ref43.ngModuleByPipeOrDirective,
          files = _ref43.files;
      var contextMap = new Map();

      var getContext = function getContext(fileName) {
        if (!contextMap.has(fileName)) {
          contextMap.set(fileName, _this267._createOutputContext(fileName));
        }

        return contextMap.get(fileName);
      };

      files.forEach(function (file) {
        return _this267._compilePartialModule(file.fileName, ngModuleByPipeOrDirective, file.directives, file.pipes, file.ngModules, file.injectables, getContext(file.fileName));
      });
      r3Files.forEach(function (file) {
        return _this267._compileShallowModules(file.fileName, file.shallowModules, getContext(file.fileName));
      });
      return Array.from(contextMap.values()).map(function (context) {
        return {
          fileName: context.genFilePath,
          statements: [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(context.constantPool.statements), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(context.statements))
        };
      });
    }
  }, {
    key: "_compileShallowModules",
    value: function _compileShallowModules(fileName, shallowModules, context) {
      var _this268 = this;

      shallowModules.forEach(function (module) {
        return compileNgModuleFromRender2(context, module, _this268._injectableCompiler);
      });
    }
  }, {
    key: "_compilePartialModule",
    value: function _compilePartialModule(fileName, ngModuleByPipeOrDirective, directives, pipes, ngModules, injectables, context) {
      var _this269 = this;

      var errors = [];
      var schemaRegistry = new DomElementSchemaRegistry();
      var hostBindingParser = new BindingParser(this._templateParser.expressionParser, DEFAULT_INTERPOLATION_CONFIG, schemaRegistry, [], errors); // Process all components and directives

      directives.forEach(function (directiveType) {
        var directiveMetadata = _this269._metadataResolver.getDirectiveMetadata(directiveType);

        if (directiveMetadata.isComponent) {
          var module = ngModuleByPipeOrDirective.get(directiveType);
          module || error("Cannot determine the module for component '".concat(identifierName(directiveMetadata.type), "'"));
          var htmlAst = directiveMetadata.template.htmlAst;
          var preserveWhitespaces = directiveMetadata.template.preserveWhitespaces;

          if (!preserveWhitespaces) {
            htmlAst = removeWhitespaces(htmlAst);
          }

          var render3Ast = htmlAstToRender3Ast(htmlAst.rootNodes, hostBindingParser); // Map of StaticType by directive selectors

          var directiveTypeBySel = new Map();

          var _directives = module.transitiveModule.directives.map(function (dir) {
            return _this269._metadataResolver.getDirectiveSummary(dir.reference);
          });

          _directives.forEach(function (directive) {
            if (directive.selector) {
              directiveTypeBySel.set(directive.selector, directive.type.reference);
            }
          }); // Map of StaticType by pipe names


          var pipeTypeByName = new Map();

          var _pipes = module.transitiveModule.pipes.map(function (pipe) {
            return _this269._metadataResolver.getPipeSummary(pipe.reference);
          });

          _pipes.forEach(function (pipe) {
            pipeTypeByName.set(pipe.name, pipe.type.reference);
          });

          compileComponentFromRender2(context, directiveMetadata, render3Ast, _this269.reflector, hostBindingParser, directiveTypeBySel, pipeTypeByName);
        } else {
          compileDirectiveFromRender2(context, directiveMetadata, _this269.reflector, hostBindingParser);
        }
      });
      pipes.forEach(function (pipeType) {
        var pipeMetadata = _this269._metadataResolver.getPipeMetadata(pipeType);

        if (pipeMetadata) {
          compilePipeFromRender2(context, pipeMetadata, _this269.reflector);
        }
      });
      injectables.forEach(function (injectable) {
        return _this269._injectableCompiler.compile(injectable, context);
      });
    }
  }, {
    key: "emitAllPartialModules2",
    value: function emitAllPartialModules2(files) {
      var _this270 = this;

      // Using reduce like this is a select many pattern (where map is a select pattern)
      return files.reduce(function (r, file) {
        r.push.apply(r, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this270._emitPartialModule2(file.fileName, file.injectables)));
        return r;
      }, []);
    }
  }, {
    key: "_emitPartialModule2",
    value: function _emitPartialModule2(fileName, injectables) {
      var _this271 = this;

      var context = this._createOutputContext(fileName);

      injectables.forEach(function (injectable) {
        return _this271._injectableCompiler.compile(injectable, context);
      });

      if (context.statements && context.statements.length > 0) {
        return [{
          fileName: fileName,
          statements: [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(context.constantPool.statements), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(context.statements))
        }];
      }

      return [];
    }
  }, {
    key: "emitAllImpls",
    value: function emitAllImpls(analyzeResult) {
      var _this272 = this;

      var ngModuleByPipeOrDirective = analyzeResult.ngModuleByPipeOrDirective,
          files = analyzeResult.files;
      var sourceModules = files.map(function (file) {
        return _this272._compileImplFile(file.fileName, ngModuleByPipeOrDirective, file.directives, file.pipes, file.ngModules, file.injectables);
      });
      return flatten(sourceModules);
    }
  }, {
    key: "_compileImplFile",
    value: function _compileImplFile(srcFileUrl, ngModuleByPipeOrDirective, directives, pipes, ngModules, injectables) {
      var _this273 = this;

      var fileSuffix = normalizeGenFileSuffix(splitTypescriptSuffix(srcFileUrl, true)[1]);
      var generatedFiles = [];

      var outputCtx = this._createOutputContext(ngfactoryFilePath(srcFileUrl, true));

      generatedFiles.push.apply(generatedFiles, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(this._createSummary(srcFileUrl, directives, pipes, ngModules, injectables, outputCtx))); // compile all ng modules

      ngModules.forEach(function (ngModuleMeta) {
        return _this273._compileModule(outputCtx, ngModuleMeta);
      }); // compile components

      directives.forEach(function (dirType) {
        var compMeta = _this273._metadataResolver.getDirectiveMetadata(dirType);

        if (!compMeta.isComponent) {
          return;
        }

        var ngModule = ngModuleByPipeOrDirective.get(dirType);

        if (!ngModule) {
          throw new Error("Internal Error: cannot determine the module for component ".concat(identifierName(compMeta.type), "!"));
        } // compile styles


        var componentStylesheet = _this273._styleCompiler.compileComponent(outputCtx, compMeta); // Note: compMeta is a component and therefore template is non null.


        compMeta.template.externalStylesheets.forEach(function (stylesheetMeta) {
          // Note: fill non shim and shim style files as they might
          // be shared by component with and without ViewEncapsulation.
          var shim = _this273._styleCompiler.needsStyleShim(compMeta);

          generatedFiles.push(_this273._codegenStyles(srcFileUrl, compMeta, stylesheetMeta, shim, fileSuffix));

          if (_this273._options.allowEmptyCodegenFiles) {
            generatedFiles.push(_this273._codegenStyles(srcFileUrl, compMeta, stylesheetMeta, !shim, fileSuffix));
          }
        }); // compile components

        var compViewVars = _this273._compileComponent(outputCtx, compMeta, ngModule, ngModule.transitiveModule.directives, componentStylesheet, fileSuffix);

        _this273._compileComponentFactory(outputCtx, compMeta, ngModule, fileSuffix);
      });

      if (outputCtx.statements.length > 0 || this._options.allowEmptyCodegenFiles) {
        var srcModule = this._codegenSourceModule(srcFileUrl, outputCtx);

        generatedFiles.unshift(srcModule);
      }

      return generatedFiles;
    }
  }, {
    key: "_createSummary",
    value: function _createSummary(srcFileName, directives, pipes, ngModules, injectables, ngFactoryCtx) {
      var _this274 = this;

      var symbolSummaries = this._symbolResolver.getSymbolsOf(srcFileName).map(function (symbol) {
        return _this274._symbolResolver.resolveSymbol(symbol);
      });

      var typeData = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ngModules.map(function (meta) {
        return {
          summary: _this274._metadataResolver.getNgModuleSummary(meta.type.reference),
          metadata: _this274._metadataResolver.getNgModuleMetadata(meta.type.reference)
        };
      })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(directives.map(function (ref) {
        return {
          summary: _this274._metadataResolver.getDirectiveSummary(ref),
          metadata: _this274._metadataResolver.getDirectiveMetadata(ref)
        };
      })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(pipes.map(function (ref) {
        return {
          summary: _this274._metadataResolver.getPipeSummary(ref),
          metadata: _this274._metadataResolver.getPipeMetadata(ref)
        };
      })), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(injectables.map(function (ref) {
        return {
          summary: _this274._metadataResolver.getInjectableSummary(ref.symbol),
          metadata: _this274._metadataResolver.getInjectableSummary(ref.symbol).type
        };
      })));
      var forJitOutputCtx = this._options.enableSummariesForJit ? this._createOutputContext(summaryForJitFileName(srcFileName, true)) : null;

      var _serializeSummaries = serializeSummaries(srcFileName, forJitOutputCtx, this._summaryResolver, this._symbolResolver, symbolSummaries, typeData, this._options.createExternalSymbolFactoryReexports),
          json = _serializeSummaries.json,
          exportAs = _serializeSummaries.exportAs;

      exportAs.forEach(function (entry) {
        ngFactoryCtx.statements.push(variable(entry.exportAs).set(ngFactoryCtx.importExpr(entry.symbol)).toDeclStmt(null, [StmtModifier.Exported]));
      });
      var summaryJson = new GeneratedFile(srcFileName, summaryFileName(srcFileName), json);
      var result = [summaryJson];

      if (forJitOutputCtx) {
        result.push(this._codegenSourceModule(srcFileName, forJitOutputCtx));
      }

      return result;
    }
  }, {
    key: "_compileModule",
    value: function _compileModule(outputCtx, ngModule) {
      var providers = [];

      if (this._options.locale) {
        var normalizedLocale = this._options.locale.replace(/_/g, '-');

        providers.push({
          token: createTokenForExternalReference(this.reflector, Identifiers.LOCALE_ID),
          useValue: normalizedLocale
        });
      }

      if (this._options.i18nFormat) {
        providers.push({
          token: createTokenForExternalReference(this.reflector, Identifiers.TRANSLATIONS_FORMAT),
          useValue: this._options.i18nFormat
        });
      }

      this._ngModuleCompiler.compile(outputCtx, ngModule, providers);
    }
  }, {
    key: "_compileComponentFactory",
    value: function _compileComponentFactory(outputCtx, compMeta, ngModule, fileSuffix) {
      var hostMeta = this._metadataResolver.getHostComponentMetadata(compMeta);

      var hostViewFactoryVar = this._compileComponent(outputCtx, hostMeta, ngModule, [compMeta.type], null, fileSuffix).viewClassVar;

      var compFactoryVar = componentFactoryName(compMeta.type.reference);
      var inputsExprs = [];

      for (var propName in compMeta.inputs) {
        var templateName = compMeta.inputs[propName]; // Don't quote so that the key gets minified...

        inputsExprs.push(new LiteralMapEntry(propName, literal(templateName), false));
      }

      var outputsExprs = [];

      for (var _propName in compMeta.outputs) {
        var _templateName = compMeta.outputs[_propName]; // Don't quote so that the key gets minified...

        outputsExprs.push(new LiteralMapEntry(_propName, literal(_templateName), false));
      }

      outputCtx.statements.push(variable(compFactoryVar).set(importExpr(Identifiers.createComponentFactory).callFn([literal(compMeta.selector), outputCtx.importExpr(compMeta.type.reference), variable(hostViewFactoryVar), new LiteralMapExpr(inputsExprs), new LiteralMapExpr(outputsExprs), literalArr(compMeta.template.ngContentSelectors.map(function (selector) {
        return literal(selector);
      }))])).toDeclStmt(importType(Identifiers.ComponentFactory, [expressionType(outputCtx.importExpr(compMeta.type.reference))], [TypeModifier.Const]), [StmtModifier.Final, StmtModifier.Exported]));
    }
  }, {
    key: "_compileComponent",
    value: function _compileComponent(outputCtx, compMeta, ngModule, directiveIdentifiers, componentStyles, fileSuffix) {
      var _this$_parseTemplate2 = this._parseTemplate(compMeta, ngModule, directiveIdentifiers),
          parsedTemplate = _this$_parseTemplate2.template,
          usedPipes = _this$_parseTemplate2.pipes;

      var stylesExpr = componentStyles ? variable(componentStyles.stylesVar) : literalArr([]);

      var viewResult = this._viewCompiler.compileComponent(outputCtx, compMeta, parsedTemplate, stylesExpr, usedPipes);

      if (componentStyles) {
        _resolveStyleStatements(this._symbolResolver, componentStyles, this._styleCompiler.needsStyleShim(compMeta), fileSuffix);
      }

      return viewResult;
    }
  }, {
    key: "_parseTemplate",
    value: function _parseTemplate(compMeta, ngModule, directiveIdentifiers) {
      var _this275 = this;

      if (this._templateAstCache.has(compMeta.type.reference)) {
        return this._templateAstCache.get(compMeta.type.reference);
      }

      var preserveWhitespaces = compMeta.template.preserveWhitespaces;
      var directives = directiveIdentifiers.map(function (dir) {
        return _this275._metadataResolver.getDirectiveSummary(dir.reference);
      });
      var pipes = ngModule.transitiveModule.pipes.map(function (pipe) {
        return _this275._metadataResolver.getPipeSummary(pipe.reference);
      });

      var result = this._templateParser.parse(compMeta, compMeta.template.htmlAst, directives, pipes, ngModule.schemas, templateSourceUrl(ngModule.type, compMeta, compMeta.template), preserveWhitespaces);

      this._templateAstCache.set(compMeta.type.reference, result);

      return result;
    }
  }, {
    key: "_createOutputContext",
    value: function _createOutputContext(genFilePath) {
      var _this276 = this;

      var importExpr$1 = function importExpr$1(symbol) {
        var typeParams = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
        var useSummaries = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

        if (!(symbol instanceof StaticSymbol)) {
          throw new Error("Internal error: unknown identifier ".concat(JSON.stringify(symbol)));
        }

        var arity = _this276._symbolResolver.getTypeArity(symbol) || 0;

        var _ref44 = _this276._symbolResolver.getImportAs(symbol, useSummaries) || symbol,
            filePath = _ref44.filePath,
            name = _ref44.name,
            members = _ref44.members;

        var importModule = _this276._fileNameToModuleName(filePath, genFilePath); // It should be good enough to compare filePath to genFilePath and if they are equal
        // there is a self reference. However, ngfactory files generate to .ts but their
        // symbols have .d.ts so a simple compare is insufficient. They should be canonical
        // and is tracked by #17705.


        var selfReference = _this276._fileNameToModuleName(genFilePath, genFilePath);

        var moduleName = importModule === selfReference ? null : importModule; // If we are in a type expression that refers to a generic type then supply
        // the required type parameters. If there were not enough type parameters
        // supplied, supply any as the type. Outside a type expression the reference
        // should not supply type parameters and be treated as a simple value reference
        // to the constructor function itself.

        var suppliedTypeParams = typeParams || [];
        var missingTypeParamsCount = arity - suppliedTypeParams.length;
        var allTypeParams = suppliedTypeParams.concat(newArray(missingTypeParamsCount, DYNAMIC_TYPE));
        return members.reduce(function (expr, memberName) {
          return expr.prop(memberName);
        }, importExpr(new ExternalReference(moduleName, name, null), allTypeParams));
      };

      return {
        statements: [],
        genFilePath: genFilePath,
        importExpr: importExpr$1,
        constantPool: new ConstantPool()
      };
    }
  }, {
    key: "_fileNameToModuleName",
    value: function _fileNameToModuleName(importedFilePath, containingFilePath) {
      return this._summaryResolver.getKnownModuleName(importedFilePath) || this._symbolResolver.getKnownModuleName(importedFilePath) || this._host.fileNameToModuleName(importedFilePath, containingFilePath);
    }
  }, {
    key: "_codegenStyles",
    value: function _codegenStyles(srcFileUrl, compMeta, stylesheetMetadata, isShimmed, fileSuffix) {
      var outputCtx = this._createOutputContext(_stylesModuleUrl(stylesheetMetadata.moduleUrl, isShimmed, fileSuffix));

      var compiledStylesheet = this._styleCompiler.compileStyles(outputCtx, compMeta, stylesheetMetadata, isShimmed);

      _resolveStyleStatements(this._symbolResolver, compiledStylesheet, isShimmed, fileSuffix);

      return this._codegenSourceModule(srcFileUrl, outputCtx);
    }
  }, {
    key: "_codegenSourceModule",
    value: function _codegenSourceModule(srcFileUrl, ctx) {
      return new GeneratedFile(srcFileUrl, ctx.genFilePath, ctx.statements);
    }
  }, {
    key: "listLazyRoutes",
    value: function listLazyRoutes(entryRoute, analyzedModules) {
      var self = this;

      if (entryRoute) {
        var symbol = parseLazyRoute(entryRoute, this.reflector).referencedModule;
        return visitLazyRoute(symbol);
      } else if (analyzedModules) {
        var allLazyRoutes = [];

        var _iterator30 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(analyzedModules.ngModules),
            _step30;

        try {
          for (_iterator30.s(); !(_step30 = _iterator30.n()).done;) {
            var ngModule = _step30.value;

            var lazyRoutes = _listLazyRoutes(ngModule, this.reflector);

            var _iterator31 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(lazyRoutes),
                _step31;

            try {
              for (_iterator31.s(); !(_step31 = _iterator31.n()).done;) {
                var lazyRoute = _step31.value;
                allLazyRoutes.push(lazyRoute);
              }
            } catch (err) {
              _iterator31.e(err);
            } finally {
              _iterator31.f();
            }
          }
        } catch (err) {
          _iterator30.e(err);
        } finally {
          _iterator30.f();
        }

        return allLazyRoutes;
      } else {
        throw new Error("Either route or analyzedModules has to be specified!");
      }

      function visitLazyRoute(symbol) {
        var seenRoutes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Set();
        var allLazyRoutes = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

        // Support pointing to default exports, but stop recursing there,
        // as the StaticReflector does not yet support default exports.
        if (seenRoutes.has(symbol) || !symbol.name) {
          return allLazyRoutes;
        }

        seenRoutes.add(symbol);

        var lazyRoutes = _listLazyRoutes(self._metadataResolver.getNgModuleMetadata(symbol, true), self.reflector);

        var _iterator32 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(lazyRoutes),
            _step32;

        try {
          for (_iterator32.s(); !(_step32 = _iterator32.n()).done;) {
            var _lazyRoute = _step32.value;
            allLazyRoutes.push(_lazyRoute);
            visitLazyRoute(_lazyRoute.referencedModule, seenRoutes, allLazyRoutes);
          }
        } catch (err) {
          _iterator32.e(err);
        } finally {
          _iterator32.f();
        }

        return allLazyRoutes;
      }
    }
  }]);

  return AotCompiler;
}();

function _createEmptyStub(outputCtx) {
  // Note: We need to produce at least one import statement so that
  // TypeScript knows that the file is an es6 module. Otherwise our generated
  // exports / imports won't be emitted properly by TypeScript.
  outputCtx.statements.push(importExpr(Identifiers.ComponentFactory).toStmt());
}

function _resolveStyleStatements(symbolResolver, compileResult, needsShim, fileSuffix) {
  compileResult.dependencies.forEach(function (dep) {
    dep.setValue(symbolResolver.getStaticSymbol(_stylesModuleUrl(dep.moduleUrl, needsShim, fileSuffix), dep.name));
  });
}

function _stylesModuleUrl(stylesheetUrl, shim, suffix) {
  return "".concat(stylesheetUrl).concat(shim ? '.shim' : '', ".ngstyle").concat(suffix);
}

function analyzeNgModules(fileNames, host, staticSymbolResolver, metadataResolver) {
  var files = _analyzeFilesIncludingNonProgramFiles(fileNames, host, staticSymbolResolver, metadataResolver);

  return mergeAnalyzedFiles(files);
}

function analyzeAndValidateNgModules(fileNames, host, staticSymbolResolver, metadataResolver) {
  return validateAnalyzedModules(analyzeNgModules(fileNames, host, staticSymbolResolver, metadataResolver));
}

function validateAnalyzedModules(analyzedModules) {
  if (analyzedModules.symbolsMissingModule && analyzedModules.symbolsMissingModule.length) {
    var messages = analyzedModules.symbolsMissingModule.map(function (s) {
      return "Cannot determine the module for class ".concat(s.name, " in ").concat(s.filePath, "! Add ").concat(s.name, " to the NgModule to fix it.");
    });
    throw syntaxError(messages.join('\n'));
  }

  return analyzedModules;
} // Analyzes all of the program files,
// including files that are not part of the program
// but are referenced by an NgModule.


function _analyzeFilesIncludingNonProgramFiles(fileNames, host, staticSymbolResolver, metadataResolver) {
  var seenFiles = new Set();
  var files = [];

  var visitFile = function visitFile(fileName) {
    if (seenFiles.has(fileName) || !host.isSourceFile(fileName)) {
      return false;
    }

    seenFiles.add(fileName);
    var analyzedFile = analyzeFile(host, staticSymbolResolver, metadataResolver, fileName);
    files.push(analyzedFile);
    analyzedFile.ngModules.forEach(function (ngModule) {
      ngModule.transitiveModule.modules.forEach(function (modMeta) {
        return visitFile(modMeta.reference.filePath);
      });
    });
  };

  fileNames.forEach(function (fileName) {
    return visitFile(fileName);
  });
  return files;
}

function analyzeFile(host, staticSymbolResolver, metadataResolver, fileName) {
  var abstractDirectives = [];
  var directives = [];
  var pipes = [];
  var injectables = [];
  var ngModules = [];
  var hasDecorators = staticSymbolResolver.hasDecorators(fileName);
  var exportsNonSourceFiles = false;
  var isDeclarationFile = fileName.endsWith('.d.ts'); // Don't analyze .d.ts files that have no decorators as a shortcut
  // to speed up the analysis. This prevents us from
  // resolving the references in these files.
  // Note: exportsNonSourceFiles is only needed when compiling with summaries,
  // which is not the case when .d.ts files are treated as input files.

  if (!isDeclarationFile || hasDecorators) {
    staticSymbolResolver.getSymbolsOf(fileName).forEach(function (symbol) {
      var resolvedSymbol = staticSymbolResolver.resolveSymbol(symbol);
      var symbolMeta = resolvedSymbol.metadata;

      if (!symbolMeta || symbolMeta.__symbolic === 'error') {
        return;
      }

      var isNgSymbol = false;

      if (symbolMeta.__symbolic === 'class') {
        if (metadataResolver.isDirective(symbol)) {
          isNgSymbol = true; // This directive either has a selector or doesn't. Selector-less directives get tracked
          // in abstractDirectives, not directives. The compiler doesn't deal with selector-less
          // directives at all, really, other than to persist their metadata. This is done so that
          // apps will have an easier time migrating to Ivy, which requires the selector-less
          // annotations to be applied.

          if (!metadataResolver.isAbstractDirective(symbol)) {
            // The directive is an ordinary directive.
            directives.push(symbol);
          } else {
            // The directive has no selector and is an "abstract" directive, so track it
            // accordingly.
            abstractDirectives.push(symbol);
          }
        } else if (metadataResolver.isPipe(symbol)) {
          isNgSymbol = true;
          pipes.push(symbol);
        } else if (metadataResolver.isNgModule(symbol)) {
          var ngModule = metadataResolver.getNgModuleMetadata(symbol, false);

          if (ngModule) {
            isNgSymbol = true;
            ngModules.push(ngModule);
          }
        } else if (metadataResolver.isInjectable(symbol)) {
          isNgSymbol = true;
          var injectable = metadataResolver.getInjectableMetadata(symbol, null, false);

          if (injectable) {
            injectables.push(injectable);
          }
        }
      }

      if (!isNgSymbol) {
        exportsNonSourceFiles = exportsNonSourceFiles || isValueExportingNonSourceFile(host, symbolMeta);
      }
    });
  }

  return {
    fileName: fileName,
    directives: directives,
    abstractDirectives: abstractDirectives,
    pipes: pipes,
    ngModules: ngModules,
    injectables: injectables,
    exportsNonSourceFiles: exportsNonSourceFiles
  };
}

function analyzeFileForInjectables(host, staticSymbolResolver, metadataResolver, fileName) {
  var injectables = [];
  var shallowModules = [];

  if (staticSymbolResolver.hasDecorators(fileName)) {
    staticSymbolResolver.getSymbolsOf(fileName).forEach(function (symbol) {
      var resolvedSymbol = staticSymbolResolver.resolveSymbol(symbol);
      var symbolMeta = resolvedSymbol.metadata;

      if (!symbolMeta || symbolMeta.__symbolic === 'error') {
        return;
      }

      if (symbolMeta.__symbolic === 'class') {
        if (metadataResolver.isInjectable(symbol)) {
          var injectable = metadataResolver.getInjectableMetadata(symbol, null, false);

          if (injectable) {
            injectables.push(injectable);
          }
        } else if (metadataResolver.isNgModule(symbol)) {
          var module = metadataResolver.getShallowModuleMetadata(symbol);

          if (module) {
            shallowModules.push(module);
          }
        }
      }
    });
  }

  return {
    fileName: fileName,
    injectables: injectables,
    shallowModules: shallowModules
  };
}

function isValueExportingNonSourceFile(host, metadata) {
  var exportsNonSourceFiles = false;

  var Visitor = /*#__PURE__*/function () {
    function Visitor() {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Visitor);
    }

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Visitor, [{
      key: "visitArray",
      value: function visitArray(arr, context) {
        var _this277 = this;

        arr.forEach(function (v) {
          return visitValue(v, _this277, context);
        });
      }
    }, {
      key: "visitStringMap",
      value: function visitStringMap(map, context) {
        var _this278 = this;

        Object.keys(map).forEach(function (key) {
          return visitValue(map[key], _this278, context);
        });
      }
    }, {
      key: "visitPrimitive",
      value: function visitPrimitive(value, context) {}
    }, {
      key: "visitOther",
      value: function visitOther(value, context) {
        if (value instanceof StaticSymbol && !host.isSourceFile(value.filePath)) {
          exportsNonSourceFiles = true;
        }
      }
    }]);

    return Visitor;
  }();

  visitValue(metadata, new Visitor(), null);
  return exportsNonSourceFiles;
}

function mergeAnalyzedFiles(analyzedFiles) {
  var allNgModules = [];
  var ngModuleByPipeOrDirective = new Map();
  var allPipesAndDirectives = new Set();
  analyzedFiles.forEach(function (af) {
    af.ngModules.forEach(function (ngModule) {
      allNgModules.push(ngModule);
      ngModule.declaredDirectives.forEach(function (d) {
        return ngModuleByPipeOrDirective.set(d.reference, ngModule);
      });
      ngModule.declaredPipes.forEach(function (p) {
        return ngModuleByPipeOrDirective.set(p.reference, ngModule);
      });
    });
    af.directives.forEach(function (d) {
      return allPipesAndDirectives.add(d);
    });
    af.pipes.forEach(function (p) {
      return allPipesAndDirectives.add(p);
    });
  });
  var symbolsMissingModule = [];
  allPipesAndDirectives.forEach(function (ref) {
    if (!ngModuleByPipeOrDirective.has(ref)) {
      symbolsMissingModule.push(ref);
    }
  });
  return {
    ngModules: allNgModules,
    ngModuleByPipeOrDirective: ngModuleByPipeOrDirective,
    symbolsMissingModule: symbolsMissingModule,
    files: analyzedFiles
  };
}

function mergeAndValidateNgFiles(files) {
  return validateAnalyzedModules(mergeAnalyzedFiles(files));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var FORMATTED_MESSAGE = 'ngFormattedMessage';

function indentStr(level) {
  if (level <= 0) return '';
  if (level < 6) return ['', ' ', '  ', '   ', '    ', '     '][level];
  var half = indentStr(Math.floor(level / 2));
  return half + half + (level % 2 === 1 ? ' ' : '');
}

function formatChain(chain) {
  var indent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  if (!chain) return '';
  var position = chain.position ? "".concat(chain.position.fileName, "(").concat(chain.position.line + 1, ",").concat(chain.position.column + 1, ")") : '';
  var prefix = position && indent === 0 ? "".concat(position, ": ") : '';
  var postfix = position && indent !== 0 ? " at ".concat(position) : '';
  var message = "".concat(prefix).concat(chain.message).concat(postfix);

  if (chain.next) {
    var _iterator33 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(chain.next),
        _step33;

    try {
      for (_iterator33.s(); !(_step33 = _iterator33.n()).done;) {
        var kid = _step33.value;
        message += '\n' + formatChain(kid, indent + 2);
      }
    } catch (err) {
      _iterator33.e(err);
    } finally {
      _iterator33.f();
    }
  }

  return "".concat(indentStr(indent)).concat(message);
}

function formattedError(chain) {
  var message = formatChain(chain) + '.';
  var error = syntaxError(message);
  error[FORMATTED_MESSAGE] = true;
  error.chain = chain;
  error.position = chain.position;
  return error;
}

function isFormattedError(error) {
  return !!error[FORMATTED_MESSAGE];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ANGULAR_CORE = '@angular/core';
var ANGULAR_ROUTER = '@angular/router';
var HIDDEN_KEY = /^\$.*\$$/;
var IGNORE = {
  __symbolic: 'ignore'
};
var USE_VALUE$1 = 'useValue';
var PROVIDE = 'provide';
var REFERENCE_SET = new Set([USE_VALUE$1, 'useFactory', 'data', 'id', 'loadChildren']);
var TYPEGUARD_POSTFIX = 'TypeGuard';
var USE_IF = 'UseIf';

function shouldIgnore(value) {
  return value && value.__symbolic == 'ignore';
}
/**
 * A static reflector implements enough of the Reflector API that is necessary to compile
 * templates statically.
 */


var StaticReflector = /*#__PURE__*/function () {
  function StaticReflector(summaryResolver, symbolResolver) {
    var _this279 = this;

    var knownMetadataClasses = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
    var knownMetadataFunctions = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
    var errorRecorder = arguments.length > 4 ? arguments[4] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StaticReflector);

    this.summaryResolver = summaryResolver;
    this.symbolResolver = symbolResolver;
    this.errorRecorder = errorRecorder;
    this.annotationCache = new Map();
    this.shallowAnnotationCache = new Map();
    this.propertyCache = new Map();
    this.parameterCache = new Map();
    this.methodCache = new Map();
    this.staticCache = new Map();
    this.conversionMap = new Map();
    this.resolvedExternalReferences = new Map();
    this.annotationForParentClassWithSummaryKind = new Map();
    this.initializeConversionMap();
    knownMetadataClasses.forEach(function (kc) {
      return _this279._registerDecoratorOrConstructor(_this279.getStaticSymbol(kc.filePath, kc.name), kc.ctor);
    });
    knownMetadataFunctions.forEach(function (kf) {
      return _this279._registerFunction(_this279.getStaticSymbol(kf.filePath, kf.name), kf.fn);
    });
    this.annotationForParentClassWithSummaryKind.set(CompileSummaryKind.Directive, [createDirective, createComponent]);
    this.annotationForParentClassWithSummaryKind.set(CompileSummaryKind.Pipe, [createPipe]);
    this.annotationForParentClassWithSummaryKind.set(CompileSummaryKind.NgModule, [createNgModule]);
    this.annotationForParentClassWithSummaryKind.set(CompileSummaryKind.Injectable, [createInjectable, createPipe, createDirective, createComponent, createNgModule]);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StaticReflector, [{
    key: "componentModuleUrl",
    value: function componentModuleUrl(typeOrFunc) {
      var staticSymbol = this.findSymbolDeclaration(typeOrFunc);
      return this.symbolResolver.getResourcePath(staticSymbol);
    }
    /**
     * Invalidate the specified `symbols` on program change.
     * @param symbols
     */

  }, {
    key: "invalidateSymbols",
    value: function invalidateSymbols(symbols) {
      var _iterator34 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(symbols),
          _step34;

      try {
        for (_iterator34.s(); !(_step34 = _iterator34.n()).done;) {
          var symbol = _step34.value;
          this.annotationCache.delete(symbol);
          this.shallowAnnotationCache.delete(symbol);
          this.propertyCache.delete(symbol);
          this.parameterCache.delete(symbol);
          this.methodCache.delete(symbol);
          this.staticCache.delete(symbol);
          this.conversionMap.delete(symbol);
        }
      } catch (err) {
        _iterator34.e(err);
      } finally {
        _iterator34.f();
      }
    }
  }, {
    key: "resolveExternalReference",
    value: function resolveExternalReference(ref, containingFile) {
      var key = undefined;

      if (!containingFile) {
        key = "".concat(ref.moduleName, ":").concat(ref.name);

        var _declarationSymbol = this.resolvedExternalReferences.get(key);

        if (_declarationSymbol) return _declarationSymbol;
      }

      var refSymbol = this.symbolResolver.getSymbolByModule(ref.moduleName, ref.name, containingFile);
      var declarationSymbol = this.findSymbolDeclaration(refSymbol);

      if (!containingFile) {
        this.symbolResolver.recordModuleNameForFileName(refSymbol.filePath, ref.moduleName);
        this.symbolResolver.recordImportAs(declarationSymbol, refSymbol);
      }

      if (key) {
        this.resolvedExternalReferences.set(key, declarationSymbol);
      }

      return declarationSymbol;
    }
  }, {
    key: "findDeclaration",
    value: function findDeclaration(moduleUrl, name, containingFile) {
      return this.findSymbolDeclaration(this.symbolResolver.getSymbolByModule(moduleUrl, name, containingFile));
    }
  }, {
    key: "tryFindDeclaration",
    value: function tryFindDeclaration(moduleUrl, name, containingFile) {
      var _this280 = this;

      return this.symbolResolver.ignoreErrorsFor(function () {
        return _this280.findDeclaration(moduleUrl, name, containingFile);
      });
    }
  }, {
    key: "findSymbolDeclaration",
    value: function findSymbolDeclaration(symbol) {
      var resolvedSymbol = this.symbolResolver.resolveSymbol(symbol);

      if (resolvedSymbol) {
        var resolvedMetadata = resolvedSymbol.metadata;

        if (resolvedMetadata && resolvedMetadata.__symbolic === 'resolved') {
          resolvedMetadata = resolvedMetadata.symbol;
        }

        if (resolvedMetadata instanceof StaticSymbol) {
          return this.findSymbolDeclaration(resolvedSymbol.metadata);
        }
      }

      return symbol;
    }
  }, {
    key: "tryAnnotations",
    value: function tryAnnotations(type) {
      var originalRecorder = this.errorRecorder;

      this.errorRecorder = function (error, fileName) {};

      try {
        return this.annotations(type);
      } finally {
        this.errorRecorder = originalRecorder;
      }
    }
  }, {
    key: "annotations",
    value: function annotations(type) {
      var _this281 = this;

      return this._annotations(type, function (type, decorators) {
        return _this281.simplify(type, decorators);
      }, this.annotationCache);
    }
  }, {
    key: "shallowAnnotations",
    value: function shallowAnnotations(type) {
      var _this282 = this;

      return this._annotations(type, function (type, decorators) {
        return _this282.simplify(type, decorators, true);
      }, this.shallowAnnotationCache);
    }
  }, {
    key: "_annotations",
    value: function _annotations(type, simplify, annotationCache) {
      var annotations = annotationCache.get(type);

      if (!annotations) {
        annotations = [];
        var classMetadata = this.getTypeMetadata(type);
        var parentType = this.findParentType(type, classMetadata);

        if (parentType) {
          var _annotations2;

          var parentAnnotations = this.annotations(parentType);

          (_annotations2 = annotations).push.apply(_annotations2, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(parentAnnotations));
        }

        var ownAnnotations = [];

        if (classMetadata['decorators']) {
          ownAnnotations = simplify(type, classMetadata['decorators']);

          if (ownAnnotations) {
            var _annotations3;

            (_annotations3 = annotations).push.apply(_annotations3, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(ownAnnotations));
          }
        }

        if (parentType && !this.summaryResolver.isLibraryFile(type.filePath) && this.summaryResolver.isLibraryFile(parentType.filePath)) {
          var summary = this.summaryResolver.resolveSummary(parentType);

          if (summary && summary.type) {
            var requiredAnnotationTypes = this.annotationForParentClassWithSummaryKind.get(summary.type.summaryKind);
            var typeHasRequiredAnnotation = requiredAnnotationTypes.some(function (requiredType) {
              return ownAnnotations.some(function (ann) {
                return requiredType.isTypeOf(ann);
              });
            });

            if (!typeHasRequiredAnnotation) {
              this.reportError(formatMetadataError(metadataError("Class ".concat(type.name, " in ").concat(type.filePath, " extends from a ").concat(CompileSummaryKind[summary.type.summaryKind], " in another compilation unit without duplicating the decorator"),
              /* summary */
              undefined, "Please add a ".concat(requiredAnnotationTypes.map(function (type) {
                return type.ngMetadataName;
              }).join(' or '), " decorator to the class")), type), type);
            }
          }
        }

        annotationCache.set(type, annotations.filter(function (ann) {
          return !!ann;
        }));
      }

      return annotations;
    }
  }, {
    key: "propMetadata",
    value: function propMetadata(type) {
      var _this283 = this;

      var propMetadata = this.propertyCache.get(type);

      if (!propMetadata) {
        var classMetadata = this.getTypeMetadata(type);
        propMetadata = {};
        var parentType = this.findParentType(type, classMetadata);

        if (parentType) {
          var parentPropMetadata = this.propMetadata(parentType);
          Object.keys(parentPropMetadata).forEach(function (parentProp) {
            propMetadata[parentProp] = parentPropMetadata[parentProp];
          });
        }

        var members = classMetadata['members'] || {};
        Object.keys(members).forEach(function (propName) {
          var propData = members[propName];
          var prop = propData.find(function (a) {
            return a['__symbolic'] == 'property' || a['__symbolic'] == 'method';
          });
          var decorators = []; // hasOwnProperty() is used here to make sure we do not look up methods
          // on `Object.prototype`.

          if (propMetadata === null || propMetadata === void 0 ? void 0 : propMetadata.hasOwnProperty(propName)) {
            decorators.push.apply(decorators, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(propMetadata[propName]));
          }

          propMetadata[propName] = decorators;

          if (prop && prop['decorators']) {
            decorators.push.apply(decorators, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this283.simplify(type, prop['decorators'])));
          }
        });
        this.propertyCache.set(type, propMetadata);
      }

      return propMetadata;
    }
  }, {
    key: "parameters",
    value: function parameters(type) {
      var _this284 = this;

      if (!(type instanceof StaticSymbol)) {
        this.reportError(new Error("parameters received ".concat(JSON.stringify(type), " which is not a StaticSymbol")), type);
        return [];
      }

      try {
        var parameters = this.parameterCache.get(type);

        if (!parameters) {
          var classMetadata = this.getTypeMetadata(type);
          var parentType = this.findParentType(type, classMetadata);
          var members = classMetadata ? classMetadata['members'] : null;
          var ctorData = members ? members['__ctor__'] : null;

          if (ctorData) {
            var ctor = ctorData.find(function (a) {
              return a['__symbolic'] == 'constructor';
            });
            var rawParameterTypes = ctor['parameters'] || [];
            var parameterDecorators = this.simplify(type, ctor['parameterDecorators'] || []);
            parameters = [];
            rawParameterTypes.forEach(function (rawParamType, index) {
              var nestedResult = [];

              var paramType = _this284.trySimplify(type, rawParamType);

              if (paramType) nestedResult.push(paramType);
              var decorators = parameterDecorators ? parameterDecorators[index] : null;

              if (decorators) {
                nestedResult.push.apply(nestedResult, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(decorators));
              }

              parameters.push(nestedResult);
            });
          } else if (parentType) {
            parameters = this.parameters(parentType);
          }

          if (!parameters) {
            parameters = [];
          }

          this.parameterCache.set(type, parameters);
        }

        return parameters;
      } catch (e) {
        console.error("Failed on type ".concat(JSON.stringify(type), " with error ").concat(e));
        throw e;
      }
    }
  }, {
    key: "_methodNames",
    value: function _methodNames(type) {
      var methodNames = this.methodCache.get(type);

      if (!methodNames) {
        var classMetadata = this.getTypeMetadata(type);
        methodNames = {};
        var parentType = this.findParentType(type, classMetadata);

        if (parentType) {
          var parentMethodNames = this._methodNames(parentType);

          Object.keys(parentMethodNames).forEach(function (parentProp) {
            methodNames[parentProp] = parentMethodNames[parentProp];
          });
        }

        var members = classMetadata['members'] || {};
        Object.keys(members).forEach(function (propName) {
          var propData = members[propName];
          var isMethod = propData.some(function (a) {
            return a['__symbolic'] == 'method';
          });
          methodNames[propName] = methodNames[propName] || isMethod;
        });
        this.methodCache.set(type, methodNames);
      }

      return methodNames;
    }
  }, {
    key: "_staticMembers",
    value: function _staticMembers(type) {
      var staticMembers = this.staticCache.get(type);

      if (!staticMembers) {
        var classMetadata = this.getTypeMetadata(type);
        var staticMemberData = classMetadata['statics'] || {};
        staticMembers = Object.keys(staticMemberData);
        this.staticCache.set(type, staticMembers);
      }

      return staticMembers;
    }
  }, {
    key: "findParentType",
    value: function findParentType(type, classMetadata) {
      var parentType = this.trySimplify(type, classMetadata['extends']);

      if (parentType instanceof StaticSymbol) {
        return parentType;
      }
    }
  }, {
    key: "hasLifecycleHook",
    value: function hasLifecycleHook(type, lcProperty) {
      if (!(type instanceof StaticSymbol)) {
        this.reportError(new Error("hasLifecycleHook received ".concat(JSON.stringify(type), " which is not a StaticSymbol")), type);
      }

      try {
        return !!this._methodNames(type)[lcProperty];
      } catch (e) {
        console.error("Failed on type ".concat(JSON.stringify(type), " with error ").concat(e));
        throw e;
      }
    }
  }, {
    key: "guards",
    value: function guards(type) {
      if (!(type instanceof StaticSymbol)) {
        this.reportError(new Error("guards received ".concat(JSON.stringify(type), " which is not a StaticSymbol")), type);
        return {};
      }

      var staticMembers = this._staticMembers(type);

      var result = {};

      var _iterator35 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(staticMembers),
          _step35;

      try {
        for (_iterator35.s(); !(_step35 = _iterator35.n()).done;) {
          var name = _step35.value;

          if (name.endsWith(TYPEGUARD_POSTFIX)) {
            var property = name.substr(0, name.length - TYPEGUARD_POSTFIX.length);
            var value = void 0;

            if (property.endsWith(USE_IF)) {
              property = name.substr(0, property.length - USE_IF.length);
              value = USE_IF;
            } else {
              value = this.getStaticSymbol(type.filePath, type.name, [name]);
            }

            result[property] = value;
          }
        }
      } catch (err) {
        _iterator35.e(err);
      } finally {
        _iterator35.f();
      }

      return result;
    }
  }, {
    key: "_registerDecoratorOrConstructor",
    value: function _registerDecoratorOrConstructor(type, ctor) {
      this.conversionMap.set(type, function (context, args) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_3__["default"])(ctor, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(args));
      });
    }
  }, {
    key: "_registerFunction",
    value: function _registerFunction(type, fn) {
      this.conversionMap.set(type, function (context, args) {
        return fn.apply(undefined, args);
      });
    }
  }, {
    key: "initializeConversionMap",
    value: function initializeConversionMap() {
      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Injectable'), createInjectable);

      this.injectionToken = this.findDeclaration(ANGULAR_CORE, 'InjectionToken');
      this.opaqueToken = this.findDeclaration(ANGULAR_CORE, 'OpaqueToken');
      this.ROUTES = this.tryFindDeclaration(ANGULAR_ROUTER, 'ROUTES');
      this.ANALYZE_FOR_ENTRY_COMPONENTS = this.findDeclaration(ANGULAR_CORE, 'ANALYZE_FOR_ENTRY_COMPONENTS');

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Host'), createHost);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Self'), createSelf);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'SkipSelf'), createSkipSelf);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Inject'), createInject);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Optional'), createOptional);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Attribute'), createAttribute);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'ContentChild'), createContentChild);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'ContentChildren'), createContentChildren);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'ViewChild'), createViewChild);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'ViewChildren'), createViewChildren);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Input'), createInput);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Output'), createOutput);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Pipe'), createPipe);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'HostBinding'), createHostBinding);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'HostListener'), createHostListener);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Directive'), createDirective);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Component'), createComponent);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'NgModule'), createNgModule); // Note: Some metadata classes can be used directly with Provider.deps.


      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Host'), createHost);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Self'), createSelf);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'SkipSelf'), createSkipSelf);

      this._registerDecoratorOrConstructor(this.findDeclaration(ANGULAR_CORE, 'Optional'), createOptional);
    }
    /**
     * getStaticSymbol produces a Type whose metadata is known but whose implementation is not loaded.
     * All types passed to the StaticResolver should be pseudo-types returned by this method.
     *
     * @param declarationFile the absolute path of the file where the symbol is declared
     * @param name the name of the type.
     */

  }, {
    key: "getStaticSymbol",
    value: function getStaticSymbol(declarationFile, name, members) {
      return this.symbolResolver.getStaticSymbol(declarationFile, name, members);
    }
    /**
     * Simplify but discard any errors
     */

  }, {
    key: "trySimplify",
    value: function trySimplify(context, value) {
      var originalRecorder = this.errorRecorder;

      this.errorRecorder = function (error, fileName) {};

      var result = this.simplify(context, value);
      this.errorRecorder = originalRecorder;
      return result;
    }
    /** @internal */

  }, {
    key: "simplify",
    value: function simplify(context, value) {
      var lazy = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
      var self = this;
      var scope = BindingScope$1.empty;
      var calling = new Map();
      var rootContext = context;

      function simplifyInContext(context, value, depth, references) {
        function resolveReferenceValue(staticSymbol) {
          var resolvedSymbol = self.symbolResolver.resolveSymbol(staticSymbol);
          return resolvedSymbol ? resolvedSymbol.metadata : null;
        }

        function simplifyEagerly(value) {
          return simplifyInContext(context, value, depth, 0);
        }

        function simplifyLazily(value) {
          return simplifyInContext(context, value, depth, references + 1);
        }

        function simplifyNested(nestedContext, value) {
          if (nestedContext === context) {
            // If the context hasn't changed let the exception propagate unmodified.
            return simplifyInContext(nestedContext, value, depth + 1, references);
          }

          try {
            return simplifyInContext(nestedContext, value, depth + 1, references);
          } catch (e) {
            if (isMetadataError(e)) {
              // Propagate the message text up but add a message to the chain that explains how we got
              // here.
              // e.chain implies e.symbol
              var summaryMsg = e.chain ? 'references \'' + e.symbol.name + '\'' : errorSummary(e);
              var summary = "'".concat(nestedContext.name, "' ").concat(summaryMsg);
              var chain = {
                message: summary,
                position: e.position,
                next: e.chain
              }; // TODO(chuckj): retrieve the position information indirectly from the collectors node
              // map if the metadata is from a .ts file.

              self.error({
                message: e.message,
                advise: e.advise,
                context: e.context,
                chain: chain,
                symbol: nestedContext
              }, context);
            } else {
              // It is probably an internal error.
              throw e;
            }
          }
        }

        function simplifyCall(functionSymbol, targetFunction, args, targetExpression) {
          if (targetFunction && targetFunction['__symbolic'] == 'function') {
            if (calling.get(functionSymbol)) {
              self.error({
                message: 'Recursion is not supported',
                summary: "called '".concat(functionSymbol.name, "' recursively"),
                value: targetFunction
              }, functionSymbol);
            }

            try {
              var _value6 = targetFunction['value'];

              if (_value6 && (depth != 0 || _value6.__symbolic != 'error')) {
                var parameters = targetFunction['parameters'];
                var defaults = targetFunction.defaults;
                args = args.map(function (arg) {
                  return simplifyNested(context, arg);
                }).map(function (arg) {
                  return shouldIgnore(arg) ? undefined : arg;
                });

                if (defaults && defaults.length > args.length) {
                  var _args2;

                  (_args2 = args).push.apply(_args2, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(defaults.slice(args.length).map(function (value) {
                    return simplify(value);
                  })));
                }

                calling.set(functionSymbol, true);
                var functionScope = BindingScope$1.build();

                for (var i = 0; i < parameters.length; i++) {
                  functionScope.define(parameters[i], args[i]);
                }

                var oldScope = scope;

                var _result;

                try {
                  scope = functionScope.done();
                  _result = simplifyNested(functionSymbol, _value6);
                } finally {
                  scope = oldScope;
                }

                return _result;
              }
            } finally {
              calling.delete(functionSymbol);
            }
          }

          if (depth === 0) {
            // If depth is 0 we are evaluating the top level expression that is describing element
            // decorator. In this case, it is a decorator we don't understand, such as a custom
            // non-angular decorator, and we should just ignore it.
            return IGNORE;
          }

          var position = undefined;

          if (targetExpression && targetExpression.__symbolic == 'resolved') {
            var line = targetExpression.line;
            var character = targetExpression.character;
            var fileName = targetExpression.fileName;

            if (fileName != null && line != null && character != null) {
              position = {
                fileName: fileName,
                line: line,
                column: character
              };
            }
          }

          self.error({
            message: FUNCTION_CALL_NOT_SUPPORTED,
            context: functionSymbol,
            value: targetFunction,
            position: position
          }, context);
        }

        function simplify(expression) {
          if (isPrimitive(expression)) {
            return expression;
          }

          if (Array.isArray(expression)) {
            var _result2 = [];

            var _iterator36 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(expression),
                _step36;

            try {
              for (_iterator36.s(); !(_step36 = _iterator36.n()).done;) {
                var item = _step36.value;

                // Check for a spread expression
                if (item && item.__symbolic === 'spread') {
                  // We call with references as 0 because we require the actual value and cannot
                  // tolerate a reference here.
                  var spreadArray = simplifyEagerly(item.expression);

                  if (Array.isArray(spreadArray)) {
                    var _iterator37 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_6__["default"])(spreadArray),
                        _step37;

                    try {
                      for (_iterator37.s(); !(_step37 = _iterator37.n()).done;) {
                        var spreadItem = _step37.value;

                        _result2.push(spreadItem);
                      }
                    } catch (err) {
                      _iterator37.e(err);
                    } finally {
                      _iterator37.f();
                    }

                    continue;
                  }
                }

                var _value7 = simplify(item);

                if (shouldIgnore(_value7)) {
                  continue;
                }

                _result2.push(_value7);
              }
            } catch (err) {
              _iterator36.e(err);
            } finally {
              _iterator36.f();
            }

            return _result2;
          }

          if (expression instanceof StaticSymbol) {
            // Stop simplification at builtin symbols or if we are in a reference context and
            // the symbol doesn't have members.
            if (expression === self.injectionToken || self.conversionMap.has(expression) || references > 0 && !expression.members.length) {
              return expression;
            } else {
              var staticSymbol = expression;
              var declarationValue = resolveReferenceValue(staticSymbol);

              if (declarationValue != null) {
                return simplifyNested(staticSymbol, declarationValue);
              } else {
                return staticSymbol;
              }
            }
          }

          if (expression) {
            if (expression['__symbolic']) {
              var _staticSymbol;

              switch (expression['__symbolic']) {
                case 'binop':
                  var left = simplify(expression['left']);
                  if (shouldIgnore(left)) return left;
                  var right = simplify(expression['right']);
                  if (shouldIgnore(right)) return right;

                  switch (expression['operator']) {
                    case '&&':
                      return left && right;

                    case '||':
                      return left || right;

                    case '|':
                      return left | right;

                    case '^':
                      return left ^ right;

                    case '&':
                      return left & right;

                    case '==':
                      return left == right;

                    case '!=':
                      return left != right;

                    case '===':
                      return left === right;

                    case '!==':
                      return left !== right;

                    case '<':
                      return left < right;

                    case '>':
                      return left > right;

                    case '<=':
                      return left <= right;

                    case '>=':
                      return left >= right;

                    case '<<':
                      return left << right;

                    case '>>':
                      return left >> right;

                    case '+':
                      return left + right;

                    case '-':
                      return left - right;

                    case '*':
                      return left * right;

                    case '/':
                      return left / right;

                    case '%':
                      return left % right;
                  }

                  return null;

                case 'if':
                  var condition = simplify(expression['condition']);
                  return condition ? simplify(expression['thenExpression']) : simplify(expression['elseExpression']);

                case 'pre':
                  var operand = simplify(expression['operand']);
                  if (shouldIgnore(operand)) return operand;

                  switch (expression['operator']) {
                    case '+':
                      return operand;

                    case '-':
                      return -operand;

                    case '!':
                      return !operand;

                    case '~':
                      return ~operand;
                  }

                  return null;

                case 'index':
                  var indexTarget = simplifyEagerly(expression['expression']);
                  var index = simplifyEagerly(expression['index']);
                  if (indexTarget && isPrimitive(index)) return indexTarget[index];
                  return null;

                case 'select':
                  var member = expression['member'];
                  var selectContext = context;
                  var selectTarget = simplify(expression['expression']);

                  if (selectTarget instanceof StaticSymbol) {
                    var members = selectTarget.members.concat(member);
                    selectContext = self.getStaticSymbol(selectTarget.filePath, selectTarget.name, members);

                    var _declarationValue = resolveReferenceValue(selectContext);

                    if (_declarationValue != null) {
                      return simplifyNested(selectContext, _declarationValue);
                    } else {
                      return selectContext;
                    }
                  }

                  if (selectTarget && isPrimitive(member)) return simplifyNested(selectContext, selectTarget[member]);
                  return null;

                case 'reference':
                  // Note: This only has to deal with variable references, as symbol references have
                  // been converted into 'resolved'
                  // in the StaticSymbolResolver.
                  var name = expression['name'];
                  var localValue = scope.resolve(name);

                  if (localValue != BindingScope$1.missing) {
                    return localValue;
                  }

                  break;

                case 'resolved':
                  try {
                    return simplify(expression.symbol);
                  } catch (e) {
                    // If an error is reported evaluating the symbol record the position of the
                    // reference in the error so it can
                    // be reported in the error message generated from the exception.
                    if (isMetadataError(e) && expression.fileName != null && expression.line != null && expression.character != null) {
                      e.position = {
                        fileName: expression.fileName,
                        line: expression.line,
                        column: expression.character
                      };
                    }

                    throw e;
                  }

                case 'class':
                  return context;

                case 'function':
                  return context;

                case 'new':
                case 'call':
                  // Determine if the function is a built-in conversion
                  _staticSymbol = simplifyInContext(context, expression['expression'], depth + 1,
                  /* references */
                  0);

                  if (_staticSymbol instanceof StaticSymbol) {
                    if (_staticSymbol === self.injectionToken || _staticSymbol === self.opaqueToken) {
                      // if somebody calls new InjectionToken, don't create an InjectionToken,
                      // but rather return the symbol to which the InjectionToken is assigned to.
                      // OpaqueToken is supported too as it is required by the language service to
                      // support v4 and prior versions of Angular.
                      return context;
                    }

                    var argExpressions = expression['arguments'] || [];
                    var converter = self.conversionMap.get(_staticSymbol);

                    if (converter) {
                      var args = argExpressions.map(function (arg) {
                        return simplifyNested(context, arg);
                      }).map(function (arg) {
                        return shouldIgnore(arg) ? undefined : arg;
                      });
                      return converter(context, args);
                    } else {
                      // Determine if the function is one we can simplify.
                      var targetFunction = resolveReferenceValue(_staticSymbol);
                      return simplifyCall(_staticSymbol, targetFunction, argExpressions, expression['expression']);
                    }
                  }

                  return IGNORE;

                case 'error':
                  var message = expression.message;

                  if (expression['line'] != null) {
                    self.error({
                      message: message,
                      context: expression.context,
                      value: expression,
                      position: {
                        fileName: expression['fileName'],
                        line: expression['line'],
                        column: expression['character']
                      }
                    }, context);
                  } else {
                    self.error({
                      message: message,
                      context: expression.context
                    }, context);
                  }

                  return IGNORE;

                case 'ignore':
                  return expression;
              }

              return null;
            }

            return mapStringMap(expression, function (value, name) {
              if (REFERENCE_SET.has(name)) {
                if (name === USE_VALUE$1 && PROVIDE in expression) {
                  // If this is a provider expression, check for special tokens that need the value
                  // during analysis.
                  var provide = simplify(expression.provide);

                  if (provide === self.ROUTES || provide == self.ANALYZE_FOR_ENTRY_COMPONENTS) {
                    return simplify(value);
                  }
                }

                return simplifyLazily(value);
              }

              return simplify(value);
            });
          }

          return IGNORE;
        }

        return simplify(value);
      }

      var result;

      try {
        result = simplifyInContext(context, value, 0, lazy ? 1 : 0);
      } catch (e) {
        if (this.errorRecorder) {
          this.reportError(e, context);
        } else {
          throw formatMetadataError(e, context);
        }
      }

      if (shouldIgnore(result)) {
        return undefined;
      }

      return result;
    }
  }, {
    key: "getTypeMetadata",
    value: function getTypeMetadata(type) {
      var resolvedSymbol = this.symbolResolver.resolveSymbol(type);
      return resolvedSymbol && resolvedSymbol.metadata ? resolvedSymbol.metadata : {
        __symbolic: 'class'
      };
    }
  }, {
    key: "reportError",
    value: function reportError(error, context, path) {
      if (this.errorRecorder) {
        this.errorRecorder(formatMetadataError(error, context), context && context.filePath || path);
      } else {
        throw error;
      }
    }
  }, {
    key: "error",
    value: function error(_ref45, reportingContext) {
      var message = _ref45.message,
          summary = _ref45.summary,
          advise = _ref45.advise,
          position = _ref45.position,
          context = _ref45.context,
          value = _ref45.value,
          symbol = _ref45.symbol,
          chain = _ref45.chain;
      this.reportError(metadataError(message, summary, advise, position, symbol, context, chain), reportingContext);
    }
  }]);

  return StaticReflector;
}();

var METADATA_ERROR = 'ngMetadataError';

function metadataError(message, summary, advise, position, symbol, context, chain) {
  var error = syntaxError(message);
  error[METADATA_ERROR] = true;
  if (advise) error.advise = advise;
  if (position) error.position = position;
  if (summary) error.summary = summary;
  if (context) error.context = context;
  if (chain) error.chain = chain;
  if (symbol) error.symbol = symbol;
  return error;
}

function isMetadataError(error) {
  return !!error[METADATA_ERROR];
}

var REFERENCE_TO_NONEXPORTED_CLASS = 'Reference to non-exported class';
var VARIABLE_NOT_INITIALIZED = 'Variable not initialized';
var DESTRUCTURE_NOT_SUPPORTED = 'Destructuring not supported';
var COULD_NOT_RESOLVE_TYPE = 'Could not resolve type';
var FUNCTION_CALL_NOT_SUPPORTED = 'Function call not supported';
var REFERENCE_TO_LOCAL_SYMBOL = 'Reference to a local symbol';
var LAMBDA_NOT_SUPPORTED = 'Lambda not supported';

function expandedMessage(message, context) {
  switch (message) {
    case REFERENCE_TO_NONEXPORTED_CLASS:
      if (context && context.className) {
        return "References to a non-exported class are not supported in decorators but ".concat(context.className, " was referenced.");
      }

      break;

    case VARIABLE_NOT_INITIALIZED:
      return 'Only initialized variables and constants can be referenced in decorators because the value of this variable is needed by the template compiler';

    case DESTRUCTURE_NOT_SUPPORTED:
      return 'Referencing an exported destructured variable or constant is not supported in decorators and this value is needed by the template compiler';

    case COULD_NOT_RESOLVE_TYPE:
      if (context && context.typeName) {
        return "Could not resolve type ".concat(context.typeName);
      }

      break;

    case FUNCTION_CALL_NOT_SUPPORTED:
      if (context && context.name) {
        return "Function calls are not supported in decorators but '".concat(context.name, "' was called");
      }

      return 'Function calls are not supported in decorators';

    case REFERENCE_TO_LOCAL_SYMBOL:
      if (context && context.name) {
        return "Reference to a local (non-exported) symbols are not supported in decorators but '".concat(context.name, "' was referenced");
      }

      break;

    case LAMBDA_NOT_SUPPORTED:
      return "Function expressions are not supported in decorators";
  }

  return message;
}

function messageAdvise(message, context) {
  switch (message) {
    case REFERENCE_TO_NONEXPORTED_CLASS:
      if (context && context.className) {
        return "Consider exporting '".concat(context.className, "'");
      }

      break;

    case DESTRUCTURE_NOT_SUPPORTED:
      return 'Consider simplifying to avoid destructuring';

    case REFERENCE_TO_LOCAL_SYMBOL:
      if (context && context.name) {
        return "Consider exporting '".concat(context.name, "'");
      }

      break;

    case LAMBDA_NOT_SUPPORTED:
      return "Consider changing the function expression into an exported function";
  }

  return undefined;
}

function errorSummary(error) {
  if (error.summary) {
    return error.summary;
  }

  switch (error.message) {
    case REFERENCE_TO_NONEXPORTED_CLASS:
      if (error.context && error.context.className) {
        return "references non-exported class ".concat(error.context.className);
      }

      break;

    case VARIABLE_NOT_INITIALIZED:
      return 'is not initialized';

    case DESTRUCTURE_NOT_SUPPORTED:
      return 'is a destructured variable';

    case COULD_NOT_RESOLVE_TYPE:
      return 'could not be resolved';

    case FUNCTION_CALL_NOT_SUPPORTED:
      if (error.context && error.context.name) {
        return "calls '".concat(error.context.name, "'");
      }

      return "calls a function";

    case REFERENCE_TO_LOCAL_SYMBOL:
      if (error.context && error.context.name) {
        return "references local variable ".concat(error.context.name);
      }

      return "references a local variable";
  }

  return 'contains the error';
}

function mapStringMap(input, transform) {
  if (!input) return {};
  var result = {};
  Object.keys(input).forEach(function (key) {
    var value = transform(input[key], key);

    if (!shouldIgnore(value)) {
      if (HIDDEN_KEY.test(key)) {
        Object.defineProperty(result, key, {
          enumerable: false,
          configurable: true,
          value: value
        });
      } else {
        result[key] = value;
      }
    }
  });
  return result;
}

function isPrimitive(o) {
  return o === null || typeof o !== 'function' && typeof o !== 'object';
}

var BindingScope$1 = /*#__PURE__*/function () {
  function BindingScope$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, BindingScope$1);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(BindingScope$1, null, [{
    key: "build",
    value: function build() {
      var current = new Map();
      return {
        define: function define(name, value) {
          current.set(name, value);
          return this;
        },
        done: function done() {
          return current.size > 0 ? new PopulatedScope(current) : BindingScope$1.empty;
        }
      };
    }
  }]);

  return BindingScope$1;
}();

BindingScope$1.missing = {};
BindingScope$1.empty = {
  resolve: function resolve(name) {
    return BindingScope$1.missing;
  }
};

var PopulatedScope = /*#__PURE__*/function (_BindingScope$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(PopulatedScope, _BindingScope$);

  var _super108 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(PopulatedScope);

  function PopulatedScope(bindings) {
    var _this285;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, PopulatedScope);

    _this285 = _super108.call(this);
    _this285.bindings = bindings;
    return _this285;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(PopulatedScope, [{
    key: "resolve",
    value: function resolve(name) {
      return this.bindings.has(name) ? this.bindings.get(name) : BindingScope$1.missing;
    }
  }]);

  return PopulatedScope;
}(BindingScope$1);

function formatMetadataMessageChain(chain, advise) {
  var expanded = expandedMessage(chain.message, chain.context);
  var nesting = chain.symbol ? " in '".concat(chain.symbol.name, "'") : '';
  var message = "".concat(expanded).concat(nesting);
  var position = chain.position;
  var next = chain.next ? formatMetadataMessageChain(chain.next, advise) : advise ? {
    message: advise
  } : undefined;
  return {
    message: message,
    position: position,
    next: next ? [next] : undefined
  };
}

function formatMetadataError(e, context) {
  if (isMetadataError(e)) {
    // Produce a formatted version of the and leaving enough information in the original error
    // to recover the formatting information to eventually produce a diagnostic error message.
    var position = e.position;
    var chain = {
      message: "Error during template compile of '".concat(context.name, "'"),
      position: position,
      next: {
        message: e.message,
        next: e.chain,
        context: e.context,
        symbol: e.symbol
      }
    };
    var advise = e.advise || messageAdvise(e.message, e.context);
    return formattedError(formatMetadataMessageChain(chain, advise));
  }

  return e;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var AotSummaryResolver = /*#__PURE__*/function () {
  function AotSummaryResolver(host, staticSymbolCache) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, AotSummaryResolver);

    this.host = host;
    this.staticSymbolCache = staticSymbolCache; // Note: this will only contain StaticSymbols without members!

    this.summaryCache = new Map();
    this.loadedFilePaths = new Map(); // Note: this will only contain StaticSymbols without members!

    this.importAs = new Map();
    this.knownFileNameToModuleNames = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(AotSummaryResolver, [{
    key: "isLibraryFile",
    value: function isLibraryFile(filePath) {
      // Note: We need to strip the .ngfactory. file path,
      // so this method also works for generated files
      // (for which host.isSourceFile will always return false).
      return !this.host.isSourceFile(stripGeneratedFileSuffix(filePath));
    }
  }, {
    key: "toSummaryFileName",
    value: function toSummaryFileName(filePath, referringSrcFileName) {
      return this.host.toSummaryFileName(filePath, referringSrcFileName);
    }
  }, {
    key: "fromSummaryFileName",
    value: function fromSummaryFileName(fileName, referringLibFileName) {
      return this.host.fromSummaryFileName(fileName, referringLibFileName);
    }
  }, {
    key: "resolveSummary",
    value: function resolveSummary(staticSymbol) {
      var rootSymbol = staticSymbol.members.length ? this.staticSymbolCache.get(staticSymbol.filePath, staticSymbol.name) : staticSymbol;
      var summary = this.summaryCache.get(rootSymbol);

      if (!summary) {
        this._loadSummaryFile(staticSymbol.filePath);

        summary = this.summaryCache.get(staticSymbol);
      }

      return rootSymbol === staticSymbol && summary || null;
    }
  }, {
    key: "getSymbolsOf",
    value: function getSymbolsOf(filePath) {
      if (this._loadSummaryFile(filePath)) {
        return Array.from(this.summaryCache.keys()).filter(function (symbol) {
          return symbol.filePath === filePath;
        });
      }

      return null;
    }
  }, {
    key: "getImportAs",
    value: function getImportAs(staticSymbol) {
      staticSymbol.assertNoMembers();
      return this.importAs.get(staticSymbol);
    }
    /**
     * Converts a file path to a module name that can be used as an `import`.
     */

  }, {
    key: "getKnownModuleName",
    value: function getKnownModuleName(importedFilePath) {
      return this.knownFileNameToModuleNames.get(importedFilePath) || null;
    }
  }, {
    key: "addSummary",
    value: function addSummary(summary) {
      this.summaryCache.set(summary.symbol, summary);
    }
  }, {
    key: "_loadSummaryFile",
    value: function _loadSummaryFile(filePath) {
      var _this286 = this;

      var hasSummary = this.loadedFilePaths.get(filePath);

      if (hasSummary != null) {
        return hasSummary;
      }

      var json = null;

      if (this.isLibraryFile(filePath)) {
        var summaryFilePath = summaryFileName(filePath);

        try {
          json = this.host.loadSummary(summaryFilePath);
        } catch (e) {
          console.error("Error loading summary file ".concat(summaryFilePath));
          throw e;
        }
      }

      hasSummary = json != null;
      this.loadedFilePaths.set(filePath, hasSummary);

      if (json) {
        var _deserializeSummaries = deserializeSummaries(this.staticSymbolCache, this, filePath, json),
            moduleName = _deserializeSummaries.moduleName,
            summaries = _deserializeSummaries.summaries,
            importAs = _deserializeSummaries.importAs;

        summaries.forEach(function (summary) {
          return _this286.summaryCache.set(summary.symbol, summary);
        });

        if (moduleName) {
          this.knownFileNameToModuleNames.set(filePath, moduleName);
        }

        importAs.forEach(function (importAs) {
          _this286.importAs.set(importAs.symbol, importAs.importAs);
        });
      }

      return hasSummary;
    }
  }]);

  return AotSummaryResolver;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function createAotUrlResolver(host) {
  return {
    resolve: function resolve(basePath, url) {
      var filePath = host.resourceNameToFileName(url, basePath);

      if (!filePath) {
        throw syntaxError("Couldn't resolve resource ".concat(url, " from ").concat(basePath));
      }

      return filePath;
    }
  };
}
/**
 * Creates a new AotCompiler based on options and a host.
 */


function createAotCompiler(compilerHost, options, errorCollector) {
  var translations = options.translations || '';
  var urlResolver = createAotUrlResolver(compilerHost);
  var symbolCache = new StaticSymbolCache();
  var summaryResolver = new AotSummaryResolver(compilerHost, symbolCache);
  var symbolResolver = new StaticSymbolResolver(compilerHost, symbolCache, summaryResolver);
  var staticReflector = new StaticReflector(summaryResolver, symbolResolver, [], [], errorCollector);
  var htmlParser;

  if (!!options.enableIvy) {
    // Ivy handles i18n at the compiler level so we must use a regular parser
    htmlParser = new HtmlParser();
  } else {
    htmlParser = new I18NHtmlParser(new HtmlParser(), translations, options.i18nFormat, options.missingTranslation, console);
  }

  var config = new CompilerConfig({
    defaultEncapsulation: ViewEncapsulation.Emulated,
    useJit: false,
    missingTranslation: options.missingTranslation,
    preserveWhitespaces: options.preserveWhitespaces,
    strictInjectionParameters: options.strictInjectionParameters
  });
  var normalizer = new DirectiveNormalizer({
    get: function get(url) {
      return compilerHost.loadResource(url);
    }
  }, urlResolver, htmlParser, config);
  var expressionParser = new Parser$1(new Lexer());
  var elementSchemaRegistry = new DomElementSchemaRegistry();
  var tmplParser = new TemplateParser(config, staticReflector, expressionParser, elementSchemaRegistry, htmlParser, console, []);
  var resolver = new CompileMetadataResolver(config, htmlParser, new NgModuleResolver(staticReflector), new DirectiveResolver(staticReflector), new PipeResolver(staticReflector), summaryResolver, elementSchemaRegistry, normalizer, console, symbolCache, staticReflector, errorCollector); // TODO(vicb): do not pass options.i18nFormat here

  var viewCompiler = new ViewCompiler(staticReflector);
  var typeCheckCompiler = new TypeCheckCompiler(options, staticReflector);
  var compiler = new AotCompiler(config, options, compilerHost, staticReflector, resolver, tmplParser, new StyleCompiler(urlResolver), viewCompiler, typeCheckCompiler, new NgModuleCompiler(staticReflector), new InjectableCompiler(staticReflector, !!options.enableIvy), new TypeScriptEmitter(), summaryResolver, symbolResolver);
  return {
    compiler: compiler,
    reflector: staticReflector
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SummaryResolver = function SummaryResolver() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, SummaryResolver);
};

var JitSummaryResolver = /*#__PURE__*/function () {
  function JitSummaryResolver() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, JitSummaryResolver);

    this._summaries = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(JitSummaryResolver, [{
    key: "isLibraryFile",
    value: function isLibraryFile() {
      return false;
    }
  }, {
    key: "toSummaryFileName",
    value: function toSummaryFileName(fileName) {
      return fileName;
    }
  }, {
    key: "fromSummaryFileName",
    value: function fromSummaryFileName(fileName) {
      return fileName;
    }
  }, {
    key: "resolveSummary",
    value: function resolveSummary(reference) {
      return this._summaries.get(reference) || null;
    }
  }, {
    key: "getSymbolsOf",
    value: function getSymbolsOf() {
      return [];
    }
  }, {
    key: "getImportAs",
    value: function getImportAs(reference) {
      return reference;
    }
  }, {
    key: "getKnownModuleName",
    value: function getKnownModuleName(fileName) {
      return null;
    }
  }, {
    key: "addSummary",
    value: function addSummary(summary) {
      this._summaries.set(summary.symbol, summary);
    }
  }]);

  return JitSummaryResolver;
}();

function interpretStatements(statements, reflector) {
  var ctx = new _ExecutionContext(null, null, null, new Map());
  var visitor = new StatementInterpreter(reflector);
  visitor.visitAllStatements(statements, ctx);
  var result = {};
  ctx.exports.forEach(function (exportName) {
    result[exportName] = ctx.vars.get(exportName);
  });
  return result;
}

function _executeFunctionStatements(varNames, varValues, statements, ctx, visitor) {
  var childCtx = ctx.createChildWihtLocalVars();

  for (var i = 0; i < varNames.length; i++) {
    childCtx.vars.set(varNames[i], varValues[i]);
  }

  var result = visitor.visitAllStatements(statements, childCtx);
  return result ? result.value : null;
}

var _ExecutionContext = /*#__PURE__*/function () {
  function _ExecutionContext(parent, instance, className, vars) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, _ExecutionContext);

    this.parent = parent;
    this.instance = instance;
    this.className = className;
    this.vars = vars;
    this.exports = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(_ExecutionContext, [{
    key: "createChildWihtLocalVars",
    value: function createChildWihtLocalVars() {
      return new _ExecutionContext(this, this.instance, this.className, new Map());
    }
  }]);

  return _ExecutionContext;
}();

var ReturnValue = function ReturnValue(value) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, ReturnValue);

  this.value = value;
};

function createDynamicClass(_classStmt, _ctx, _visitor) {
  var propertyDescriptors = {};

  _classStmt.getters.forEach(function (getter) {
    // Note: use `function` instead of arrow function to capture `this`
    propertyDescriptors[getter.name] = {
      configurable: false,
      get: function get() {
        var instanceCtx = new _ExecutionContext(_ctx, this, _classStmt.name, _ctx.vars);
        return _executeFunctionStatements([], [], getter.body, instanceCtx, _visitor);
      }
    };
  });

  _classStmt.methods.forEach(function (method) {
    var paramNames = method.params.map(function (param) {
      return param.name;
    }); // Note: use `function` instead of arrow function to capture `this`

    propertyDescriptors[method.name] = {
      writable: false,
      configurable: false,
      value: function value() {
        var instanceCtx = new _ExecutionContext(_ctx, this, _classStmt.name, _ctx.vars);

        for (var _len5 = arguments.length, args = new Array(_len5), _key6 = 0; _key6 < _len5; _key6++) {
          args[_key6] = arguments[_key6];
        }

        return _executeFunctionStatements(paramNames, args, method.body, instanceCtx, _visitor);
      }
    };
  });

  var ctorParamNames = _classStmt.constructorMethod.params.map(function (param) {
    return param.name;
  }); // Note: use `function` instead of arrow function to capture `this`


  var ctor = function ctor() {
    var _this287 = this;

    var instanceCtx = new _ExecutionContext(_ctx, this, _classStmt.name, _ctx.vars);

    _classStmt.fields.forEach(function (field) {
      _this287[field.name] = undefined;
    });

    for (var _len6 = arguments.length, args = new Array(_len6), _key7 = 0; _key7 < _len6; _key7++) {
      args[_key7] = arguments[_key7];
    }

    _executeFunctionStatements(ctorParamNames, args, _classStmt.constructorMethod.body, instanceCtx, _visitor);
  };

  var superClass = _classStmt.parent ? _classStmt.parent.visitExpression(_visitor, _ctx) : Object;
  ctor.prototype = Object.create(superClass.prototype, propertyDescriptors);
  return ctor;
}

var StatementInterpreter = /*#__PURE__*/function () {
  function StatementInterpreter(reflector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, StatementInterpreter);

    this.reflector = reflector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(StatementInterpreter, [{
    key: "debugAst",
    value: function debugAst(ast) {
      return debugOutputAstAsTypeScript(ast);
    }
  }, {
    key: "visitDeclareVarStmt",
    value: function visitDeclareVarStmt(stmt, ctx) {
      var initialValue = stmt.value ? stmt.value.visitExpression(this, ctx) : undefined;
      ctx.vars.set(stmt.name, initialValue);

      if (stmt.hasModifier(StmtModifier.Exported)) {
        ctx.exports.push(stmt.name);
      }

      return null;
    }
  }, {
    key: "visitWriteVarExpr",
    value: function visitWriteVarExpr(expr, ctx) {
      var value = expr.value.visitExpression(this, ctx);
      var currCtx = ctx;

      while (currCtx != null) {
        if (currCtx.vars.has(expr.name)) {
          currCtx.vars.set(expr.name, value);
          return value;
        }

        currCtx = currCtx.parent;
      }

      throw new Error("Not declared variable ".concat(expr.name));
    }
  }, {
    key: "visitWrappedNodeExpr",
    value: function visitWrappedNodeExpr(ast, ctx) {
      throw new Error('Cannot interpret a WrappedNodeExpr.');
    }
  }, {
    key: "visitTypeofExpr",
    value: function visitTypeofExpr(ast, ctx) {
      throw new Error('Cannot interpret a TypeofExpr');
    }
  }, {
    key: "visitReadVarExpr",
    value: function visitReadVarExpr(ast, ctx) {
      var varName = ast.name;

      if (ast.builtin != null) {
        switch (ast.builtin) {
          case BuiltinVar.Super:
            return Object.getPrototypeOf(ctx.instance);

          case BuiltinVar.This:
            return ctx.instance;

          case BuiltinVar.CatchError:
            varName = CATCH_ERROR_VAR$2;
            break;

          case BuiltinVar.CatchStack:
            varName = CATCH_STACK_VAR$2;
            break;

          default:
            throw new Error("Unknown builtin variable ".concat(ast.builtin));
        }
      }

      var currCtx = ctx;

      while (currCtx != null) {
        if (currCtx.vars.has(varName)) {
          return currCtx.vars.get(varName);
        }

        currCtx = currCtx.parent;
      }

      throw new Error("Not declared variable ".concat(varName));
    }
  }, {
    key: "visitWriteKeyExpr",
    value: function visitWriteKeyExpr(expr, ctx) {
      var receiver = expr.receiver.visitExpression(this, ctx);
      var index = expr.index.visitExpression(this, ctx);
      var value = expr.value.visitExpression(this, ctx);
      receiver[index] = value;
      return value;
    }
  }, {
    key: "visitWritePropExpr",
    value: function visitWritePropExpr(expr, ctx) {
      var receiver = expr.receiver.visitExpression(this, ctx);
      var value = expr.value.visitExpression(this, ctx);
      receiver[expr.name] = value;
      return value;
    }
  }, {
    key: "visitInvokeMethodExpr",
    value: function visitInvokeMethodExpr(expr, ctx) {
      var receiver = expr.receiver.visitExpression(this, ctx);
      var args = this.visitAllExpressions(expr.args, ctx);
      var result;

      if (expr.builtin != null) {
        switch (expr.builtin) {
          case BuiltinMethod.ConcatArray:
            result = receiver.concat.apply(receiver, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(args));
            break;

          case BuiltinMethod.SubscribeObservable:
            result = receiver.subscribe({
              next: args[0]
            });
            break;

          case BuiltinMethod.Bind:
            result = receiver.bind.apply(receiver, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(args));
            break;

          default:
            throw new Error("Unknown builtin method ".concat(expr.builtin));
        }
      } else {
        result = receiver[expr.name].apply(receiver, args);
      }

      return result;
    }
  }, {
    key: "visitInvokeFunctionExpr",
    value: function visitInvokeFunctionExpr(stmt, ctx) {
      var args = this.visitAllExpressions(stmt.args, ctx);
      var fnExpr = stmt.fn;

      if (fnExpr instanceof ReadVarExpr && fnExpr.builtin === BuiltinVar.Super) {
        ctx.instance.constructor.prototype.constructor.apply(ctx.instance, args);
        return null;
      } else {
        var _fn = stmt.fn.visitExpression(this, ctx);

        return _fn.apply(null, args);
      }
    }
  }, {
    key: "visitReturnStmt",
    value: function visitReturnStmt(stmt, ctx) {
      return new ReturnValue(stmt.value.visitExpression(this, ctx));
    }
  }, {
    key: "visitDeclareClassStmt",
    value: function visitDeclareClassStmt(stmt, ctx) {
      var clazz = createDynamicClass(stmt, ctx, this);
      ctx.vars.set(stmt.name, clazz);

      if (stmt.hasModifier(StmtModifier.Exported)) {
        ctx.exports.push(stmt.name);
      }

      return null;
    }
  }, {
    key: "visitExpressionStmt",
    value: function visitExpressionStmt(stmt, ctx) {
      return stmt.expr.visitExpression(this, ctx);
    }
  }, {
    key: "visitIfStmt",
    value: function visitIfStmt(stmt, ctx) {
      var condition = stmt.condition.visitExpression(this, ctx);

      if (condition) {
        return this.visitAllStatements(stmt.trueCase, ctx);
      } else if (stmt.falseCase != null) {
        return this.visitAllStatements(stmt.falseCase, ctx);
      }

      return null;
    }
  }, {
    key: "visitTryCatchStmt",
    value: function visitTryCatchStmt(stmt, ctx) {
      try {
        return this.visitAllStatements(stmt.bodyStmts, ctx);
      } catch (e) {
        var childCtx = ctx.createChildWihtLocalVars();
        childCtx.vars.set(CATCH_ERROR_VAR$2, e);
        childCtx.vars.set(CATCH_STACK_VAR$2, e.stack);
        return this.visitAllStatements(stmt.catchStmts, childCtx);
      }
    }
  }, {
    key: "visitThrowStmt",
    value: function visitThrowStmt(stmt, ctx) {
      throw stmt.error.visitExpression(this, ctx);
    }
  }, {
    key: "visitInstantiateExpr",
    value: function visitInstantiateExpr(ast, ctx) {
      var args = this.visitAllExpressions(ast.args, ctx);
      var clazz = ast.classExpr.visitExpression(this, ctx);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_3__["default"])(clazz, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(args));
    }
  }, {
    key: "visitLiteralExpr",
    value: function visitLiteralExpr(ast, ctx) {
      return ast.value;
    }
  }, {
    key: "visitLocalizedString",
    value: function visitLocalizedString(ast, context) {
      return null;
    }
  }, {
    key: "visitExternalExpr",
    value: function visitExternalExpr(ast, ctx) {
      return this.reflector.resolveExternalReference(ast.value);
    }
  }, {
    key: "visitConditionalExpr",
    value: function visitConditionalExpr(ast, ctx) {
      if (ast.condition.visitExpression(this, ctx)) {
        return ast.trueCase.visitExpression(this, ctx);
      } else if (ast.falseCase != null) {
        return ast.falseCase.visitExpression(this, ctx);
      }

      return null;
    }
  }, {
    key: "visitNotExpr",
    value: function visitNotExpr(ast, ctx) {
      return !ast.condition.visitExpression(this, ctx);
    }
  }, {
    key: "visitAssertNotNullExpr",
    value: function visitAssertNotNullExpr(ast, ctx) {
      return ast.condition.visitExpression(this, ctx);
    }
  }, {
    key: "visitCastExpr",
    value: function visitCastExpr(ast, ctx) {
      return ast.value.visitExpression(this, ctx);
    }
  }, {
    key: "visitFunctionExpr",
    value: function visitFunctionExpr(ast, ctx) {
      var paramNames = ast.params.map(function (param) {
        return param.name;
      });
      return _declareFn(paramNames, ast.statements, ctx, this);
    }
  }, {
    key: "visitDeclareFunctionStmt",
    value: function visitDeclareFunctionStmt(stmt, ctx) {
      var paramNames = stmt.params.map(function (param) {
        return param.name;
      });
      ctx.vars.set(stmt.name, _declareFn(paramNames, stmt.statements, ctx, this));

      if (stmt.hasModifier(StmtModifier.Exported)) {
        ctx.exports.push(stmt.name);
      }

      return null;
    }
  }, {
    key: "visitUnaryOperatorExpr",
    value: function visitUnaryOperatorExpr(ast, ctx) {
      var _this288 = this;

      var rhs = function rhs() {
        return ast.expr.visitExpression(_this288, ctx);
      };

      switch (ast.operator) {
        case UnaryOperator.Plus:
          return +rhs();

        case UnaryOperator.Minus:
          return -rhs();

        default:
          throw new Error("Unknown operator ".concat(ast.operator));
      }
    }
  }, {
    key: "visitBinaryOperatorExpr",
    value: function visitBinaryOperatorExpr(ast, ctx) {
      var _this289 = this;

      var lhs = function lhs() {
        return ast.lhs.visitExpression(_this289, ctx);
      };

      var rhs = function rhs() {
        return ast.rhs.visitExpression(_this289, ctx);
      };

      switch (ast.operator) {
        case BinaryOperator.Equals:
          return lhs() == rhs();

        case BinaryOperator.Identical:
          return lhs() === rhs();

        case BinaryOperator.NotEquals:
          return lhs() != rhs();

        case BinaryOperator.NotIdentical:
          return lhs() !== rhs();

        case BinaryOperator.And:
          return lhs() && rhs();

        case BinaryOperator.Or:
          return lhs() || rhs();

        case BinaryOperator.Plus:
          return lhs() + rhs();

        case BinaryOperator.Minus:
          return lhs() - rhs();

        case BinaryOperator.Divide:
          return lhs() / rhs();

        case BinaryOperator.Multiply:
          return lhs() * rhs();

        case BinaryOperator.Modulo:
          return lhs() % rhs();

        case BinaryOperator.Lower:
          return lhs() < rhs();

        case BinaryOperator.LowerEquals:
          return lhs() <= rhs();

        case BinaryOperator.Bigger:
          return lhs() > rhs();

        case BinaryOperator.BiggerEquals:
          return lhs() >= rhs();

        default:
          throw new Error("Unknown operator ".concat(ast.operator));
      }
    }
  }, {
    key: "visitReadPropExpr",
    value: function visitReadPropExpr(ast, ctx) {
      var result;
      var receiver = ast.receiver.visitExpression(this, ctx);
      result = receiver[ast.name];
      return result;
    }
  }, {
    key: "visitReadKeyExpr",
    value: function visitReadKeyExpr(ast, ctx) {
      var receiver = ast.receiver.visitExpression(this, ctx);
      var prop = ast.index.visitExpression(this, ctx);
      return receiver[prop];
    }
  }, {
    key: "visitLiteralArrayExpr",
    value: function visitLiteralArrayExpr(ast, ctx) {
      return this.visitAllExpressions(ast.entries, ctx);
    }
  }, {
    key: "visitLiteralMapExpr",
    value: function visitLiteralMapExpr(ast, ctx) {
      var _this290 = this;

      var result = {};
      ast.entries.forEach(function (entry) {
        return result[entry.key] = entry.value.visitExpression(_this290, ctx);
      });
      return result;
    }
  }, {
    key: "visitCommaExpr",
    value: function visitCommaExpr(ast, context) {
      var values = this.visitAllExpressions(ast.parts, context);
      return values[values.length - 1];
    }
  }, {
    key: "visitAllExpressions",
    value: function visitAllExpressions(expressions, ctx) {
      var _this291 = this;

      return expressions.map(function (expr) {
        return expr.visitExpression(_this291, ctx);
      });
    }
  }, {
    key: "visitAllStatements",
    value: function visitAllStatements(statements, ctx) {
      for (var i = 0; i < statements.length; i++) {
        var stmt = statements[i];
        var val = stmt.visitStatement(this, ctx);

        if (val instanceof ReturnValue) {
          return val;
        }
      }

      return null;
    }
  }]);

  return StatementInterpreter;
}();

function _declareFn(varNames, statements, ctx, visitor) {
  return function () {
    for (var _len7 = arguments.length, args = new Array(_len7), _key8 = 0; _key8 < _len7; _key8++) {
      args[_key8] = arguments[_key8];
    }

    return _executeFunctionStatements(varNames, args, statements, ctx, visitor);
  };
}

var CATCH_ERROR_VAR$2 = 'error';
var CATCH_STACK_VAR$2 = 'stack';
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An internal module of the Angular compiler that begins with component types,
 * extracts templates, and eventually produces a compiled version of the component
 * ready for linking into an application.
 *
 * @security  When compiling templates at runtime, you must ensure that the entire template comes
 * from a trusted source. Attacker-controlled data introduced by a template could expose your
 * application to XSS risks.  For more detail, see the [Security Guide](http://g.co/ng/security).
 */

var JitCompiler = /*#__PURE__*/function () {
  function JitCompiler(_metadataResolver, _templateParser, _styleCompiler, _viewCompiler, _ngModuleCompiler, _summaryResolver, _reflector, _jitEvaluator, _compilerConfig, _console, getExtraNgModuleProviders) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, JitCompiler);

    this._metadataResolver = _metadataResolver;
    this._templateParser = _templateParser;
    this._styleCompiler = _styleCompiler;
    this._viewCompiler = _viewCompiler;
    this._ngModuleCompiler = _ngModuleCompiler;
    this._summaryResolver = _summaryResolver;
    this._reflector = _reflector;
    this._jitEvaluator = _jitEvaluator;
    this._compilerConfig = _compilerConfig;
    this._console = _console;
    this.getExtraNgModuleProviders = getExtraNgModuleProviders;
    this._compiledTemplateCache = new Map();
    this._compiledHostTemplateCache = new Map();
    this._compiledDirectiveWrapperCache = new Map();
    this._compiledNgModuleCache = new Map();
    this._sharedStylesheetCount = 0;
    this._addedAotSummaries = new Set();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(JitCompiler, [{
    key: "compileModuleSync",
    value: function compileModuleSync(moduleType) {
      return SyncAsync.assertSync(this._compileModuleAndComponents(moduleType, true));
    }
  }, {
    key: "compileModuleAsync",
    value: function compileModuleAsync(moduleType) {
      return Promise.resolve(this._compileModuleAndComponents(moduleType, false));
    }
  }, {
    key: "compileModuleAndAllComponentsSync",
    value: function compileModuleAndAllComponentsSync(moduleType) {
      return SyncAsync.assertSync(this._compileModuleAndAllComponents(moduleType, true));
    }
  }, {
    key: "compileModuleAndAllComponentsAsync",
    value: function compileModuleAndAllComponentsAsync(moduleType) {
      return Promise.resolve(this._compileModuleAndAllComponents(moduleType, false));
    }
  }, {
    key: "getComponentFactory",
    value: function getComponentFactory(component) {
      var summary = this._metadataResolver.getDirectiveSummary(component);

      return summary.componentFactory;
    }
  }, {
    key: "loadAotSummaries",
    value: function loadAotSummaries(summaries) {
      this.clearCache();

      this._addAotSummaries(summaries);
    }
  }, {
    key: "_addAotSummaries",
    value: function _addAotSummaries(fn) {
      if (this._addedAotSummaries.has(fn)) {
        return;
      }

      this._addedAotSummaries.add(fn);

      var summaries = fn();

      for (var i = 0; i < summaries.length; i++) {
        var entry = summaries[i];

        if (typeof entry === 'function') {
          this._addAotSummaries(entry);
        } else {
          var summary = entry;

          this._summaryResolver.addSummary({
            symbol: summary.type.reference,
            metadata: null,
            type: summary
          });
        }
      }
    }
  }, {
    key: "hasAotSummary",
    value: function hasAotSummary(ref) {
      return !!this._summaryResolver.resolveSummary(ref);
    }
  }, {
    key: "_filterJitIdentifiers",
    value: function _filterJitIdentifiers(ids) {
      var _this292 = this;

      return ids.map(function (mod) {
        return mod.reference;
      }).filter(function (ref) {
        return !_this292.hasAotSummary(ref);
      });
    }
  }, {
    key: "_compileModuleAndComponents",
    value: function _compileModuleAndComponents(moduleType, isSync) {
      var _this293 = this;

      return SyncAsync.then(this._loadModules(moduleType, isSync), function () {
        _this293._compileComponents(moduleType, null);

        return _this293._compileModule(moduleType);
      });
    }
  }, {
    key: "_compileModuleAndAllComponents",
    value: function _compileModuleAndAllComponents(moduleType, isSync) {
      var _this294 = this;

      return SyncAsync.then(this._loadModules(moduleType, isSync), function () {
        var componentFactories = [];

        _this294._compileComponents(moduleType, componentFactories);

        return {
          ngModuleFactory: _this294._compileModule(moduleType),
          componentFactories: componentFactories
        };
      });
    }
  }, {
    key: "_loadModules",
    value: function _loadModules(mainModule, isSync) {
      var _this295 = this;

      var loading = [];

      var mainNgModule = this._metadataResolver.getNgModuleMetadata(mainModule); // Note: for runtime compilation, we want to transitively compile all modules,
      // so we also need to load the declared directives / pipes for all nested modules.


      this._filterJitIdentifiers(mainNgModule.transitiveModule.modules).forEach(function (nestedNgModule) {
        // getNgModuleMetadata only returns null if the value passed in is not an NgModule
        var moduleMeta = _this295._metadataResolver.getNgModuleMetadata(nestedNgModule);

        _this295._filterJitIdentifiers(moduleMeta.declaredDirectives).forEach(function (ref) {
          var promise = _this295._metadataResolver.loadDirectiveMetadata(moduleMeta.type.reference, ref, isSync);

          if (promise) {
            loading.push(promise);
          }
        });

        _this295._filterJitIdentifiers(moduleMeta.declaredPipes).forEach(function (ref) {
          return _this295._metadataResolver.getOrLoadPipeMetadata(ref);
        });
      });

      return SyncAsync.all(loading);
    }
  }, {
    key: "_compileModule",
    value: function _compileModule(moduleType) {
      var ngModuleFactory = this._compiledNgModuleCache.get(moduleType);

      if (!ngModuleFactory) {
        var moduleMeta = this._metadataResolver.getNgModuleMetadata(moduleType); // Always provide a bound Compiler


        var extraProviders = this.getExtraNgModuleProviders(moduleMeta.type.reference);
        var outputCtx = createOutputContext();

        var compileResult = this._ngModuleCompiler.compile(outputCtx, moduleMeta, extraProviders);

        ngModuleFactory = this._interpretOrJit(ngModuleJitUrl(moduleMeta), outputCtx.statements)[compileResult.ngModuleFactoryVar];

        this._compiledNgModuleCache.set(moduleMeta.type.reference, ngModuleFactory);
      }

      return ngModuleFactory;
    }
    /**
     * @internal
     */

  }, {
    key: "_compileComponents",
    value: function _compileComponents(mainModule, allComponentFactories) {
      var _this296 = this;

      var ngModule = this._metadataResolver.getNgModuleMetadata(mainModule);

      var moduleByJitDirective = new Map();
      var templates = new Set();

      var transJitModules = this._filterJitIdentifiers(ngModule.transitiveModule.modules);

      transJitModules.forEach(function (localMod) {
        var localModuleMeta = _this296._metadataResolver.getNgModuleMetadata(localMod);

        _this296._filterJitIdentifiers(localModuleMeta.declaredDirectives).forEach(function (dirRef) {
          moduleByJitDirective.set(dirRef, localModuleMeta);

          var dirMeta = _this296._metadataResolver.getDirectiveMetadata(dirRef);

          if (dirMeta.isComponent) {
            templates.add(_this296._createCompiledTemplate(dirMeta, localModuleMeta));

            if (allComponentFactories) {
              var template = _this296._createCompiledHostTemplate(dirMeta.type.reference, localModuleMeta);

              templates.add(template);
              allComponentFactories.push(dirMeta.componentFactory);
            }
          }
        });
      });
      transJitModules.forEach(function (localMod) {
        var localModuleMeta = _this296._metadataResolver.getNgModuleMetadata(localMod);

        _this296._filterJitIdentifiers(localModuleMeta.declaredDirectives).forEach(function (dirRef) {
          var dirMeta = _this296._metadataResolver.getDirectiveMetadata(dirRef);

          if (dirMeta.isComponent) {
            dirMeta.entryComponents.forEach(function (entryComponentType) {
              var moduleMeta = moduleByJitDirective.get(entryComponentType.componentType);
              templates.add(_this296._createCompiledHostTemplate(entryComponentType.componentType, moduleMeta));
            });
          }
        });

        localModuleMeta.entryComponents.forEach(function (entryComponentType) {
          if (!_this296.hasAotSummary(entryComponentType.componentType)) {
            var moduleMeta = moduleByJitDirective.get(entryComponentType.componentType);
            templates.add(_this296._createCompiledHostTemplate(entryComponentType.componentType, moduleMeta));
          }
        });
      });
      templates.forEach(function (template) {
        return _this296._compileTemplate(template);
      });
    }
  }, {
    key: "clearCacheFor",
    value: function clearCacheFor(type) {
      this._compiledNgModuleCache.delete(type);

      this._metadataResolver.clearCacheFor(type);

      this._compiledHostTemplateCache.delete(type);

      var compiledTemplate = this._compiledTemplateCache.get(type);

      if (compiledTemplate) {
        this._compiledTemplateCache.delete(type);
      }
    }
  }, {
    key: "clearCache",
    value: function clearCache() {
      // Note: don't clear the _addedAotSummaries, as they don't change!
      this._metadataResolver.clearCache();

      this._compiledTemplateCache.clear();

      this._compiledHostTemplateCache.clear();

      this._compiledNgModuleCache.clear();
    }
  }, {
    key: "_createCompiledHostTemplate",
    value: function _createCompiledHostTemplate(compType, ngModule) {
      if (!ngModule) {
        throw new Error("Component ".concat(stringify(compType), " is not part of any NgModule or the module has not been imported into your module."));
      }

      var compiledTemplate = this._compiledHostTemplateCache.get(compType);

      if (!compiledTemplate) {
        var compMeta = this._metadataResolver.getDirectiveMetadata(compType);

        assertComponent(compMeta);

        var hostMeta = this._metadataResolver.getHostComponentMetadata(compMeta, compMeta.componentFactory.viewDefFactory);

        compiledTemplate = new CompiledTemplate(true, compMeta.type, hostMeta, ngModule, [compMeta.type]);

        this._compiledHostTemplateCache.set(compType, compiledTemplate);
      }

      return compiledTemplate;
    }
  }, {
    key: "_createCompiledTemplate",
    value: function _createCompiledTemplate(compMeta, ngModule) {
      var compiledTemplate = this._compiledTemplateCache.get(compMeta.type.reference);

      if (!compiledTemplate) {
        assertComponent(compMeta);
        compiledTemplate = new CompiledTemplate(false, compMeta.type, compMeta, ngModule, ngModule.transitiveModule.directives);

        this._compiledTemplateCache.set(compMeta.type.reference, compiledTemplate);
      }

      return compiledTemplate;
    }
  }, {
    key: "_compileTemplate",
    value: function _compileTemplate(template) {
      var _this297 = this;

      if (template.isCompiled) {
        return;
      }

      var compMeta = template.compMeta;
      var externalStylesheetsByModuleUrl = new Map();
      var outputContext = createOutputContext();

      var componentStylesheet = this._styleCompiler.compileComponent(outputContext, compMeta);

      compMeta.template.externalStylesheets.forEach(function (stylesheetMeta) {
        var compiledStylesheet = _this297._styleCompiler.compileStyles(createOutputContext(), compMeta, stylesheetMeta);

        externalStylesheetsByModuleUrl.set(stylesheetMeta.moduleUrl, compiledStylesheet);
      });

      this._resolveStylesCompileResult(componentStylesheet, externalStylesheetsByModuleUrl);

      var pipes = template.ngModule.transitiveModule.pipes.map(function (pipe) {
        return _this297._metadataResolver.getPipeSummary(pipe.reference);
      });

      var _this$_parseTemplate3 = this._parseTemplate(compMeta, template.ngModule, template.directives),
          parsedTemplate = _this$_parseTemplate3.template,
          usedPipes = _this$_parseTemplate3.pipes;

      var compileResult = this._viewCompiler.compileComponent(outputContext, compMeta, parsedTemplate, variable(componentStylesheet.stylesVar), usedPipes);

      var evalResult = this._interpretOrJit(templateJitUrl(template.ngModule.type, template.compMeta), outputContext.statements);

      var viewClass = evalResult[compileResult.viewClassVar];
      var rendererType = evalResult[compileResult.rendererTypeVar];
      template.compiled(viewClass, rendererType);
    }
  }, {
    key: "_parseTemplate",
    value: function _parseTemplate(compMeta, ngModule, directiveIdentifiers) {
      var _this298 = this;

      // Note: ! is ok here as components always have a template.
      var preserveWhitespaces = compMeta.template.preserveWhitespaces;
      var directives = directiveIdentifiers.map(function (dir) {
        return _this298._metadataResolver.getDirectiveSummary(dir.reference);
      });
      var pipes = ngModule.transitiveModule.pipes.map(function (pipe) {
        return _this298._metadataResolver.getPipeSummary(pipe.reference);
      });
      return this._templateParser.parse(compMeta, compMeta.template.htmlAst, directives, pipes, ngModule.schemas, templateSourceUrl(ngModule.type, compMeta, compMeta.template), preserveWhitespaces);
    }
  }, {
    key: "_resolveStylesCompileResult",
    value: function _resolveStylesCompileResult(result, externalStylesheetsByModuleUrl) {
      var _this299 = this;

      result.dependencies.forEach(function (dep, i) {
        var nestedCompileResult = externalStylesheetsByModuleUrl.get(dep.moduleUrl);

        var nestedStylesArr = _this299._resolveAndEvalStylesCompileResult(nestedCompileResult, externalStylesheetsByModuleUrl);

        dep.setValue(nestedStylesArr);
      });
    }
  }, {
    key: "_resolveAndEvalStylesCompileResult",
    value: function _resolveAndEvalStylesCompileResult(result, externalStylesheetsByModuleUrl) {
      this._resolveStylesCompileResult(result, externalStylesheetsByModuleUrl);

      return this._interpretOrJit(sharedStylesheetJitUrl(result.meta, this._sharedStylesheetCount++), result.outputCtx.statements)[result.stylesVar];
    }
  }, {
    key: "_interpretOrJit",
    value: function _interpretOrJit(sourceUrl, statements) {
      if (!this._compilerConfig.useJit) {
        return interpretStatements(statements, this._reflector);
      } else {
        return this._jitEvaluator.evaluateStatements(sourceUrl, statements, this._reflector, this._compilerConfig.jitDevMode);
      }
    }
  }]);

  return JitCompiler;
}();

var CompiledTemplate = /*#__PURE__*/function () {
  function CompiledTemplate(isHost, compType, compMeta, ngModule, directives) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompiledTemplate);

    this.isHost = isHost;
    this.compType = compType;
    this.compMeta = compMeta;
    this.ngModule = ngModule;
    this.directives = directives;
    this._viewClass = null;
    this.isCompiled = false;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(CompiledTemplate, [{
    key: "compiled",
    value: function compiled(viewClass, rendererType) {
      this._viewClass = viewClass;
      this.compMeta.componentViewType.setDelegate(viewClass);

      for (var prop in rendererType) {
        this.compMeta.rendererType[prop] = rendererType[prop];
      }

      this.isCompiled = true;
    }
  }]);

  return CompiledTemplate;
}();

function assertComponent(meta) {
  if (!meta.isComponent) {
    throw new Error("Could not compile '".concat(identifierName(meta.type), "' because it is not a component."));
  }
}

function createOutputContext() {
  var importExpr$1 = function importExpr$1(symbol) {
    return importExpr({
      name: identifierName(symbol),
      moduleName: null,
      runtime: symbol
    });
  };

  return {
    statements: [],
    genFilePath: '',
    importExpr: importExpr$1,
    constantPool: new ConstantPool()
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Provides access to reflection data about symbols that the compiler needs.
 */


var CompileReflector = function CompileReflector() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, CompileReflector);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Create a {@link UrlResolver} with no package prefix.
 */


function createUrlResolverWithoutPackagePrefix() {
  return new UrlResolver();
}

function createOfflineCompileUrlResolver() {
  return new UrlResolver('.');
}

var UrlResolver = /*#__PURE__*/function () {
  function UrlResolverImpl() {
    var _packagePrefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, UrlResolverImpl);

    this._packagePrefix = _packagePrefix;
  }
  /**
   * Resolves the `url` given the `baseUrl`:
   * - when the `url` is null, the `baseUrl` is returned,
   * - if `url` is relative ('path/to/here', './path/to/here'), the resolved url is a combination of
   * `baseUrl` and `url`,
   * - if `url` is absolute (it has a scheme: 'http://', 'https://' or start with '/'), the `url` is
   * returned as is (ignoring the `baseUrl`)
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(UrlResolverImpl, [{
    key: "resolve",
    value: function resolve(baseUrl, url) {
      var resolvedUrl = url;

      if (baseUrl != null && baseUrl.length > 0) {
        resolvedUrl = _resolveUrl(baseUrl, resolvedUrl);
      }

      var resolvedParts = _split(resolvedUrl);

      var prefix = this._packagePrefix;

      if (prefix != null && resolvedParts != null && resolvedParts[_ComponentIndex.Scheme] == 'package') {
        var path = resolvedParts[_ComponentIndex.Path];
        prefix = prefix.replace(/\/+$/, '');
        path = path.replace(/^\/+/, '');
        return "".concat(prefix, "/").concat(path);
      }

      return resolvedUrl;
    }
  }]);

  return UrlResolverImpl;
}();
/**
 * Extract the scheme of a URL.
 */


function getUrlScheme(url) {
  var match = _split(url);

  return match && match[_ComponentIndex.Scheme] || '';
} // The code below is adapted from Traceur:
// https://github.com/google/traceur-compiler/blob/9511c1dafa972bf0de1202a8a863bad02f0f95a8/src/runtime/url.js

/**
 * Builds a URI string from already-encoded parts.
 *
 * No encoding is performed.  Any component may be omitted as either null or
 * undefined.
 *
 * @param opt_scheme The scheme such as 'http'.
 * @param opt_userInfo The user name before the '@'.
 * @param opt_domain The domain such as 'www.google.com', already
 *     URI-encoded.
 * @param opt_port The port number.
 * @param opt_path The path, already URI-encoded.  If it is not
 *     empty, it must begin with a slash.
 * @param opt_queryData The URI-encoded query data.
 * @param opt_fragment The URI-encoded fragment identifier.
 * @return The fully combined URI.
 */


function _buildFromEncodedParts(opt_scheme, opt_userInfo, opt_domain, opt_port, opt_path, opt_queryData, opt_fragment) {
  var out = [];

  if (opt_scheme != null) {
    out.push(opt_scheme + ':');
  }

  if (opt_domain != null) {
    out.push('//');

    if (opt_userInfo != null) {
      out.push(opt_userInfo + '@');
    }

    out.push(opt_domain);

    if (opt_port != null) {
      out.push(':' + opt_port);
    }
  }

  if (opt_path != null) {
    out.push(opt_path);
  }

  if (opt_queryData != null) {
    out.push('?' + opt_queryData);
  }

  if (opt_fragment != null) {
    out.push('#' + opt_fragment);
  }

  return out.join('');
}
/**
 * A regular expression for breaking a URI into its component parts.
 *
 * {@link http://www.gbiv.com/protocols/uri/rfc/rfc3986.html#RFC2234} says
 * As the "first-match-wins" algorithm is identical to the "greedy"
 * disambiguation method used by POSIX regular expressions, it is natural and
 * commonplace to use a regular expression for parsing the potential five
 * components of a URI reference.
 *
 * The following line is the regular expression for breaking-down a
 * well-formed URI reference into its components.
 *
 * <pre>
 * ^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?
 *  12            3  4          5       6  7        8 9
 * </pre>
 *
 * The numbers in the second line above are only to assist readability; they
 * indicate the reference points for each subexpression (i.e., each paired
 * parenthesis). We refer to the value matched for subexpression <n> as $<n>.
 * For example, matching the above expression to
 * <pre>
 *     http://www.ics.uci.edu/pub/ietf/uri/#Related
 * </pre>
 * results in the following subexpression matches:
 * <pre>
 *    $1 = http:
 *    $2 = http
 *    $3 = //www.ics.uci.edu
 *    $4 = www.ics.uci.edu
 *    $5 = /pub/ietf/uri/
 *    $6 = <undefined>
 *    $7 = <undefined>
 *    $8 = #Related
 *    $9 = Related
 * </pre>
 * where <undefined> indicates that the component is not present, as is the
 * case for the query component in the above example. Therefore, we can
 * determine the value of the five components as
 * <pre>
 *    scheme    = $2
 *    authority = $4
 *    path      = $5
 *    query     = $7
 *    fragment  = $9
 * </pre>
 *
 * The regular expression has been modified slightly to expose the
 * userInfo, domain, and port separately from the authority.
 * The modified version yields
 * <pre>
 *    $1 = http              scheme
 *    $2 = <undefined>       userInfo -\
 *    $3 = www.ics.uci.edu   domain     | authority
 *    $4 = <undefined>       port     -/
 *    $5 = /pub/ietf/uri/    path
 *    $6 = <undefined>       query without ?
 *    $7 = Related           fragment without #
 * </pre>
 * @internal
 */


var _splitRe = new RegExp('^' + '(?:' + '([^:/?#.]+)' + // scheme - ignore special characters
// used by other URL parts such as :,
// ?, /, #, and .
':)?' + '(?://' + '(?:([^/?#]*)@)?' + // userInfo
"([\\w\\d\\-\\u0100-\\uffff.%]*)" + // domain - restrict to letters,
// digits, dashes, dots, percent
// escapes, and unicode characters.
'(?::([0-9]+))?' + // port
')?' + '([^?#]+)?' + // path
'(?:\\?([^#]*))?' + // query
'(?:#(.*))?' + // fragment
'$');
/**
 * The index of each URI component in the return value of goog.uri.utils.split.
 * @enum {number}
 */


var _ComponentIndex;

(function (_ComponentIndex) {
  _ComponentIndex[_ComponentIndex["Scheme"] = 1] = "Scheme";
  _ComponentIndex[_ComponentIndex["UserInfo"] = 2] = "UserInfo";
  _ComponentIndex[_ComponentIndex["Domain"] = 3] = "Domain";
  _ComponentIndex[_ComponentIndex["Port"] = 4] = "Port";
  _ComponentIndex[_ComponentIndex["Path"] = 5] = "Path";
  _ComponentIndex[_ComponentIndex["QueryData"] = 6] = "QueryData";
  _ComponentIndex[_ComponentIndex["Fragment"] = 7] = "Fragment";
})(_ComponentIndex || (_ComponentIndex = {}));
/**
 * Splits a URI into its component parts.
 *
 * Each component can be accessed via the component indices; for example:
 * <pre>
 * goog.uri.utils.split(someStr)[goog.uri.utils.CompontentIndex.QUERY_DATA];
 * </pre>
 *
 * @param uri The URI string to examine.
 * @return Each component still URI-encoded.
 *     Each component that is present will contain the encoded value, whereas
 *     components that are not present will be undefined or empty, depending
 *     on the browser's regular expression implementation.  Never null, since
 *     arbitrary strings may still look like path names.
 */


function _split(uri) {
  return uri.match(_splitRe);
}
/**
 * Removes dot segments in given path component, as described in
 * RFC 3986, section 5.2.4.
 *
 * @param path A non-empty path component.
 * @return Path component with removed dot segments.
 */


function _removeDotSegments(path) {
  if (path == '/') return '/';
  var leadingSlash = path[0] == '/' ? '/' : '';
  var trailingSlash = path[path.length - 1] === '/' ? '/' : '';
  var segments = path.split('/');
  var out = [];
  var up = 0;

  for (var pos = 0; pos < segments.length; pos++) {
    var segment = segments[pos];

    switch (segment) {
      case '':
      case '.':
        break;

      case '..':
        if (out.length > 0) {
          out.pop();
        } else {
          up++;
        }

        break;

      default:
        out.push(segment);
    }
  }

  if (leadingSlash == '') {
    while (up-- > 0) {
      out.unshift('..');
    }

    if (out.length === 0) out.push('.');
  }

  return leadingSlash + out.join('/') + trailingSlash;
}
/**
 * Takes an array of the parts from split and canonicalizes the path part
 * and then joins all the parts.
 */


function _joinAndCanonicalizePath(parts) {
  var path = parts[_ComponentIndex.Path];
  path = path == null ? '' : _removeDotSegments(path);
  parts[_ComponentIndex.Path] = path;
  return _buildFromEncodedParts(parts[_ComponentIndex.Scheme], parts[_ComponentIndex.UserInfo], parts[_ComponentIndex.Domain], parts[_ComponentIndex.Port], path, parts[_ComponentIndex.QueryData], parts[_ComponentIndex.Fragment]);
}
/**
 * Resolves a URL.
 * @param base The URL acting as the base URL.
 * @param to The URL to resolve.
 */


function _resolveUrl(base, url) {
  var parts = _split(encodeURI(url));

  var baseParts = _split(base);

  if (parts[_ComponentIndex.Scheme] != null) {
    return _joinAndCanonicalizePath(parts);
  } else {
    parts[_ComponentIndex.Scheme] = baseParts[_ComponentIndex.Scheme];
  }

  for (var i = _ComponentIndex.Scheme; i <= _ComponentIndex.Port; i++) {
    if (parts[i] == null) {
      parts[i] = baseParts[i];
    }
  }

  if (parts[_ComponentIndex.Path][0] == '/') {
    return _joinAndCanonicalizePath(parts);
  }

  var path = baseParts[_ComponentIndex.Path];
  if (path == null) path = '/';
  var index = path.lastIndexOf('/');
  path = path.substring(0, index + 1) + parts[_ComponentIndex.Path];
  parts[_ComponentIndex.Path] = path;
  return _joinAndCanonicalizePath(parts);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var Extractor = /*#__PURE__*/function () {
  function Extractor(host, staticSymbolResolver, messageBundle, metadataResolver) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Extractor);

    this.host = host;
    this.staticSymbolResolver = staticSymbolResolver;
    this.messageBundle = messageBundle;
    this.metadataResolver = metadataResolver;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Extractor, [{
    key: "extract",
    value: function extract(rootFiles) {
      var _this300 = this;

      var _analyzeAndValidateNg = analyzeAndValidateNgModules(rootFiles, this.host, this.staticSymbolResolver, this.metadataResolver),
          files = _analyzeAndValidateNg.files,
          ngModules = _analyzeAndValidateNg.ngModules;

      return Promise.all(ngModules.map(function (ngModule) {
        return _this300.metadataResolver.loadNgModuleDirectiveAndPipeMetadata(ngModule.type.reference, false);
      })).then(function () {
        var errors = [];
        files.forEach(function (file) {
          var compMetas = [];
          file.directives.forEach(function (directiveType) {
            var dirMeta = _this300.metadataResolver.getDirectiveMetadata(directiveType);

            if (dirMeta && dirMeta.isComponent) {
              compMetas.push(dirMeta);
            }
          });
          compMetas.forEach(function (compMeta) {
            var html = compMeta.template.template; // Template URL points to either an HTML or TS file depending on
            // whether the file is used with `templateUrl:` or `template:`,
            // respectively.

            var templateUrl = compMeta.template.templateUrl;
            var interpolationConfig = InterpolationConfig.fromArray(compMeta.template.interpolation);
            errors.push.apply(errors, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_11__["default"])(_this300.messageBundle.updateFromTemplate(html, templateUrl, interpolationConfig)));
          });
        });

        if (errors.length) {
          throw new Error(errors.map(function (e) {
            return e.toString();
          }).join('\n'));
        }

        return _this300.messageBundle;
      });
    }
  }], [{
    key: "create",
    value: function create(host, locale) {
      var htmlParser = new HtmlParser();
      var urlResolver = createAotUrlResolver(host);
      var symbolCache = new StaticSymbolCache();
      var summaryResolver = new AotSummaryResolver(host, symbolCache);
      var staticSymbolResolver = new StaticSymbolResolver(host, symbolCache, summaryResolver);
      var staticReflector = new StaticReflector(summaryResolver, staticSymbolResolver);
      var config = new CompilerConfig({
        defaultEncapsulation: ViewEncapsulation.Emulated,
        useJit: false
      });
      var normalizer = new DirectiveNormalizer({
        get: function get(url) {
          return host.loadResource(url);
        }
      }, urlResolver, htmlParser, config);
      var elementSchemaRegistry = new DomElementSchemaRegistry();
      var resolver = new CompileMetadataResolver(config, htmlParser, new NgModuleResolver(staticReflector), new DirectiveResolver(staticReflector), new PipeResolver(staticReflector), summaryResolver, elementSchemaRegistry, normalizer, console, symbolCache, staticReflector); // TODO(vicb): implicit tags & attributes

      var messageBundle = new MessageBundle(htmlParser, [], {}, locale);
      var extractor = new Extractor(host, staticSymbolResolver, messageBundle, resolver);
      return {
        extractor: extractor,
        staticReflector: staticReflector
      };
    }
  }]);

  return Extractor;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Processes `Target`s with a given set of directives and performs a binding operation, which
 * returns an object similar to TypeScript's `ts.TypeChecker` that contains knowledge about the
 * target.
 */


var R3TargetBinder = /*#__PURE__*/function () {
  function R3TargetBinder(directiveMatcher) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, R3TargetBinder);

    this.directiveMatcher = directiveMatcher;
  }
  /**
   * Perform a binding operation on the given `Target` and return a `BoundTarget` which contains
   * metadata about the types referenced in the template.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(R3TargetBinder, [{
    key: "bind",
    value: function bind(target) {
      if (!target.template) {
        // TODO(alxhub): handle targets which contain things like HostBindings, etc.
        throw new Error('Binding without a template not yet supported');
      } // First, parse the template into a `Scope` structure. This operation captures the syntactic
      // scopes in the template and makes them available for later use.


      var scope = Scope.apply(target.template); // Next, perform directive matching on the template using the `DirectiveBinder`. This returns:
      //   - directives: Map of nodes (elements & ng-templates) to the directives on them.
      //   - bindings: Map of inputs, outputs, and attributes to the directive/element that claims
      //     them. TODO(alxhub): handle multiple directives claiming an input/output/etc.
      //   - references: Map of #references to their targets.

      var _DirectiveBinder$appl = DirectiveBinder.apply(target.template, this.directiveMatcher),
          directives = _DirectiveBinder$appl.directives,
          bindings = _DirectiveBinder$appl.bindings,
          references = _DirectiveBinder$appl.references; // Finally, run the TemplateBinder to bind references, variables, and other entities within the
      // template. This extracts all the metadata that doesn't depend on directive matching.


      var _TemplateBinder$apply = TemplateBinder.apply(target.template, scope),
          expressions = _TemplateBinder$apply.expressions,
          symbols = _TemplateBinder$apply.symbols,
          nestingLevel = _TemplateBinder$apply.nestingLevel,
          usedPipes = _TemplateBinder$apply.usedPipes;

      return new R3BoundTarget(target, directives, bindings, references, expressions, symbols, nestingLevel, usedPipes);
    }
  }]);

  return R3TargetBinder;
}();
/**
 * Represents a binding scope within a template.
 *
 * Any variables, references, or other named entities declared within the template will
 * be captured and available by name in `namedEntities`. Additionally, child templates will
 * be analyzed and have their child `Scope`s available in `childScopes`.
 */


var Scope = /*#__PURE__*/function () {
  function Scope(parentScope) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, Scope);

    this.parentScope = parentScope;
    /**
     * Named members of the `Scope`, such as `Reference`s or `Variable`s.
     */

    this.namedEntities = new Map();
    /**
     * Child `Scope`s for immediately nested `Template`s.
     */

    this.childScopes = new Map();
  }
  /**
   * Process a template (either as a `Template` sub-template with variables, or a plain array of
   * template `Node`s) and construct its `Scope`.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(Scope, [{
    key: "ingest",

    /**
     * Internal method to process the template and populate the `Scope`.
     */
    value: function ingest(template) {
      var _this301 = this;

      if (template instanceof Template) {
        // Variables on an <ng-template> are defined in the inner scope.
        template.variables.forEach(function (node) {
          return _this301.visitVariable(node);
        }); // Process the nodes of the template.

        template.children.forEach(function (node) {
          return node.visit(_this301);
        });
      } else {
        // No overarching `Template` instance, so process the nodes directly.
        template.forEach(function (node) {
          return node.visit(_this301);
        });
      }
    }
  }, {
    key: "visitElement",
    value: function visitElement(element) {
      var _this302 = this;

      // `Element`s in the template may have `Reference`s which are captured in the scope.
      element.references.forEach(function (node) {
        return _this302.visitReference(node);
      }); // Recurse into the `Element`'s children.

      element.children.forEach(function (node) {
        return node.visit(_this302);
      });
    }
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {
      var _this303 = this;

      // References on a <ng-template> are defined in the outer scope, so capture them before
      // processing the template's child scope.
      template.references.forEach(function (node) {
        return _this303.visitReference(node);
      }); // Next, create an inner scope and process the template within it.

      var scope = new Scope(this);
      scope.ingest(template);
      this.childScopes.set(template, scope);
    }
  }, {
    key: "visitVariable",
    value: function visitVariable(variable) {
      // Declare the variable if it's not already.
      this.maybeDeclare(variable);
    }
  }, {
    key: "visitReference",
    value: function visitReference(reference) {
      // Declare the variable if it's not already.
      this.maybeDeclare(reference);
    } // Unused visitors.

  }, {
    key: "visitContent",
    value: function visitContent(content) {}
  }, {
    key: "visitBoundAttribute",
    value: function visitBoundAttribute(attr) {}
  }, {
    key: "visitBoundEvent",
    value: function visitBoundEvent(event) {}
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {}
  }, {
    key: "visitText",
    value: function visitText(text) {}
  }, {
    key: "visitTextAttribute",
    value: function visitTextAttribute(attr) {}
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {}
  }, {
    key: "maybeDeclare",
    value: function maybeDeclare(thing) {
      // Declare something with a name, as long as that name isn't taken.
      if (!this.namedEntities.has(thing.name)) {
        this.namedEntities.set(thing.name, thing);
      }
    }
    /**
     * Look up a variable within this `Scope`.
     *
     * This can recurse into a parent `Scope` if it's available.
     */

  }, {
    key: "lookup",
    value: function lookup(name) {
      if (this.namedEntities.has(name)) {
        // Found in the local scope.
        return this.namedEntities.get(name);
      } else if (this.parentScope !== undefined) {
        // Not in the local scope, but there's a parent scope so check there.
        return this.parentScope.lookup(name);
      } else {
        // At the top level and it wasn't found.
        return null;
      }
    }
    /**
     * Get the child scope for a `Template`.
     *
     * This should always be defined.
     */

  }, {
    key: "getChildScope",
    value: function getChildScope(template) {
      var res = this.childScopes.get(template);

      if (res === undefined) {
        throw new Error("Assertion error: child scope for ".concat(template, " not found"));
      }

      return res;
    }
  }], [{
    key: "apply",
    value: function apply(template) {
      var scope = new Scope();
      scope.ingest(template);
      return scope;
    }
  }]);

  return Scope;
}();
/**
 * Processes a template and matches directives on nodes (elements and templates).
 *
 * Usually used via the static `apply()` method.
 */


var DirectiveBinder = /*#__PURE__*/function () {
  function DirectiveBinder(matcher, directives, bindings, references) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, DirectiveBinder);

    this.matcher = matcher;
    this.directives = directives;
    this.bindings = bindings;
    this.references = references;
  }
  /**
   * Process a template (list of `Node`s) and perform directive matching against each node.
   *
   * @param template the list of template `Node`s to match (recursively).
   * @param selectorMatcher a `SelectorMatcher` containing the directives that are in scope for
   * this template.
   * @returns three maps which contain information about directives in the template: the
   * `directives` map which lists directives matched on each node, the `bindings` map which
   * indicates which directives claimed which bindings (inputs, outputs, etc), and the `references`
   * map which resolves #references (`Reference`s) within the template to the named directive or
   * template node.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(DirectiveBinder, [{
    key: "ingest",
    value: function ingest(template) {
      var _this304 = this;

      template.forEach(function (node) {
        return node.visit(_this304);
      });
    }
  }, {
    key: "visitElement",
    value: function visitElement(element) {
      this.visitElementOrTemplate(element.name, element);
    }
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {
      this.visitElementOrTemplate('ng-template', template);
    }
  }, {
    key: "visitElementOrTemplate",
    value: function visitElementOrTemplate(elementName, node) {
      var _this305 = this;

      // First, determine the HTML shape of the node for the purpose of directive matching.
      // Do this by building up a `CssSelector` for the node.
      var cssSelector = createCssSelector(elementName, getAttrsForDirectiveMatching(node)); // Next, use the `SelectorMatcher` to get the list of directives on the node.

      var directives = [];
      this.matcher.match(cssSelector, function (_, directive) {
        return directives.push(directive);
      });

      if (directives.length > 0) {
        this.directives.set(node, directives);
      } // Resolve any references that are created on this node.


      node.references.forEach(function (ref) {
        var dirTarget = null; // If the reference expression is empty, then it matches the "primary" directive on the node
        // (if there is one). Otherwise it matches the host node itself (either an element or
        // <ng-template> node).

        if (ref.value.trim() === '') {
          // This could be a reference to a component if there is one.
          dirTarget = directives.find(function (dir) {
            return dir.isComponent;
          }) || null;
        } else {
          // This should be a reference to a directive exported via exportAs.
          dirTarget = directives.find(function (dir) {
            return dir.exportAs !== null && dir.exportAs.some(function (value) {
              return value === ref.value;
            });
          }) || null; // Check if a matching directive was found.

          if (dirTarget === null) {
            // No matching directive was found - this reference points to an unknown target. Leave it
            // unmapped.
            return;
          }
        }

        if (dirTarget !== null) {
          // This reference points to a directive.
          _this305.references.set(ref, {
            directive: dirTarget,
            node: node
          });
        } else {
          // This reference points to the node itself.
          _this305.references.set(ref, node);
        }
      });

      var setAttributeBinding = function setAttributeBinding(attribute, ioType) {
        var dir = directives.find(function (dir) {
          return dir[ioType].hasBindingPropertyName(attribute.name);
        });
        var binding = dir !== undefined ? dir : node;

        _this305.bindings.set(attribute, binding);
      }; // Node inputs (bound attributes) and text attributes can be bound to an
      // input on a directive.


      node.inputs.forEach(function (input) {
        return setAttributeBinding(input, 'inputs');
      });
      node.attributes.forEach(function (attr) {
        return setAttributeBinding(attr, 'inputs');
      });

      if (node instanceof Template) {
        node.templateAttrs.forEach(function (attr) {
          return setAttributeBinding(attr, 'inputs');
        });
      } // Node outputs (bound events) can be bound to an output on a directive.


      node.outputs.forEach(function (output) {
        return setAttributeBinding(output, 'outputs');
      }); // Recurse into the node's children.

      node.children.forEach(function (child) {
        return child.visit(_this305);
      });
    } // Unused visitors.

  }, {
    key: "visitContent",
    value: function visitContent(content) {}
  }, {
    key: "visitVariable",
    value: function visitVariable(variable) {}
  }, {
    key: "visitReference",
    value: function visitReference(reference) {}
  }, {
    key: "visitTextAttribute",
    value: function visitTextAttribute(attribute) {}
  }, {
    key: "visitBoundAttribute",
    value: function visitBoundAttribute(attribute) {}
  }, {
    key: "visitBoundEvent",
    value: function visitBoundEvent(attribute) {}
  }, {
    key: "visitBoundAttributeOrEvent",
    value: function visitBoundAttributeOrEvent(node) {}
  }, {
    key: "visitText",
    value: function visitText(text) {}
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {}
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {}
  }], [{
    key: "apply",
    value: function apply(template, selectorMatcher) {
      var directives = new Map();
      var bindings = new Map();
      var references = new Map();
      var matcher = new DirectiveBinder(selectorMatcher, directives, bindings, references);
      matcher.ingest(template);
      return {
        directives: directives,
        bindings: bindings,
        references: references
      };
    }
  }]);

  return DirectiveBinder;
}();
/**
 * Processes a template and extract metadata about expressions and symbols within.
 *
 * This is a companion to the `DirectiveBinder` that doesn't require knowledge of directives matched
 * within the template in order to operate.
 *
 * Expressions are visited by the superclass `RecursiveAstVisitor`, with custom logic provided
 * by overridden methods from that visitor.
 */


var TemplateBinder = /*#__PURE__*/function (_RecursiveAstVisitor$3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_9__["default"])(TemplateBinder, _RecursiveAstVisitor$3);

  var _super109 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_10__["default"])(TemplateBinder);

  function TemplateBinder(bindings, symbols, usedPipes, nestingLevel, scope, template, level) {
    var _this306;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, TemplateBinder);

    _this306 = _super109.call(this);
    _this306.bindings = bindings;
    _this306.symbols = symbols;
    _this306.usedPipes = usedPipes;
    _this306.nestingLevel = nestingLevel;
    _this306.scope = scope;
    _this306.template = template;
    _this306.level = level;
    _this306.pipesUsed = []; // Save a bit of processing time by constructing this closure in advance.

    _this306.visitNode = function (node) {
      return node.visit(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_5__["default"])(_this306));
    };

    return _this306;
  } // This method is defined to reconcile the type of TemplateBinder since both
  // RecursiveAstVisitor and Visitor define the visit() method in their
  // interfaces.


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(TemplateBinder, [{
    key: "visit",
    value: function visit(node, context) {
      if (node instanceof AST) {
        node.visit(this, context);
      } else {
        node.visit(this);
      }
    }
    /**
     * Process a template and extract metadata about expressions and symbols within.
     *
     * @param template the nodes of the template to process
     * @param scope the `Scope` of the template being processed.
     * @returns three maps which contain metadata about the template: `expressions` which interprets
     * special `AST` nodes in expressions as pointing to references or variables declared within the
     * template, `symbols` which maps those variables and references to the nested `Template` which
     * declares them, if any, and `nestingLevel` which associates each `Template` with a integer
     * nesting level (how many levels deep within the template structure the `Template` is), starting
     * at 1.
     */

  }, {
    key: "ingest",
    value: function ingest(template) {
      if (template instanceof Template) {
        // For <ng-template>s, process only variables and child nodes. Inputs, outputs, templateAttrs,
        // and references were all processed in the scope of the containing template.
        template.variables.forEach(this.visitNode);
        template.children.forEach(this.visitNode); // Set the nesting level.

        this.nestingLevel.set(template, this.level);
      } else {
        // Visit each node from the top-level template.
        template.forEach(this.visitNode);
      }
    }
  }, {
    key: "visitElement",
    value: function visitElement(element) {
      // Visit the inputs, outputs, and children of the element.
      element.inputs.forEach(this.visitNode);
      element.outputs.forEach(this.visitNode);
      element.children.forEach(this.visitNode);
    }
  }, {
    key: "visitTemplate",
    value: function visitTemplate(template) {
      // First, visit inputs, outputs and template attributes of the template node.
      template.inputs.forEach(this.visitNode);
      template.outputs.forEach(this.visitNode);
      template.templateAttrs.forEach(this.visitNode); // References are also evaluated in the outer context.

      template.references.forEach(this.visitNode); // Next, recurse into the template using its scope, and bumping the nesting level up by one.

      var childScope = this.scope.getChildScope(template);
      var binder = new TemplateBinder(this.bindings, this.symbols, this.usedPipes, this.nestingLevel, childScope, template, this.level + 1);
      binder.ingest(template);
    }
  }, {
    key: "visitVariable",
    value: function visitVariable(variable) {
      // Register the `Variable` as a symbol in the current `Template`.
      if (this.template !== null) {
        this.symbols.set(variable, this.template);
      }
    }
  }, {
    key: "visitReference",
    value: function visitReference(reference) {
      // Register the `Reference` as a symbol in the current `Template`.
      if (this.template !== null) {
        this.symbols.set(reference, this.template);
      }
    } // Unused template visitors

  }, {
    key: "visitText",
    value: function visitText(text) {}
  }, {
    key: "visitContent",
    value: function visitContent(content) {}
  }, {
    key: "visitTextAttribute",
    value: function visitTextAttribute(attribute) {}
  }, {
    key: "visitIcu",
    value: function visitIcu(icu) {
      var _this307 = this;

      Object.keys(icu.vars).forEach(function (key) {
        return icu.vars[key].visit(_this307);
      });
      Object.keys(icu.placeholders).forEach(function (key) {
        return icu.placeholders[key].visit(_this307);
      });
    } // The remaining visitors are concerned with processing AST expressions within template bindings

  }, {
    key: "visitBoundAttribute",
    value: function visitBoundAttribute(attribute) {
      attribute.value.visit(this);
    }
  }, {
    key: "visitBoundEvent",
    value: function visitBoundEvent(event) {
      event.handler.visit(this);
    }
  }, {
    key: "visitBoundText",
    value: function visitBoundText(text) {
      text.value.visit(this);
    }
  }, {
    key: "visitPipe",
    value: function visitPipe(ast, context) {
      this.usedPipes.add(ast.name);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateBinder.prototype), "visitPipe", this).call(this, ast, context);
    } // These five types of AST expressions can refer to expression roots, which could be variables
    // or references in the current scope.

  }, {
    key: "visitPropertyRead",
    value: function visitPropertyRead(ast, context) {
      this.maybeMap(context, ast, ast.name);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateBinder.prototype), "visitPropertyRead", this).call(this, ast, context);
    }
  }, {
    key: "visitSafePropertyRead",
    value: function visitSafePropertyRead(ast, context) {
      this.maybeMap(context, ast, ast.name);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateBinder.prototype), "visitSafePropertyRead", this).call(this, ast, context);
    }
  }, {
    key: "visitPropertyWrite",
    value: function visitPropertyWrite(ast, context) {
      this.maybeMap(context, ast, ast.name);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateBinder.prototype), "visitPropertyWrite", this).call(this, ast, context);
    }
  }, {
    key: "visitMethodCall",
    value: function visitMethodCall(ast, context) {
      this.maybeMap(context, ast, ast.name);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateBinder.prototype), "visitMethodCall", this).call(this, ast, context);
    }
  }, {
    key: "visitSafeMethodCall",
    value: function visitSafeMethodCall(ast, context) {
      this.maybeMap(context, ast, ast.name);
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_7__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateBinder.prototype), "visitSafeMethodCall", this).call(this, ast, context);
    }
  }, {
    key: "maybeMap",
    value: function maybeMap(scope, ast, name) {
      // If the receiver of the expression isn't the `ImplicitReceiver`, this isn't the root of an
      // `AST` expression that maps to a `Variable` or `Reference`.
      if (!(ast.receiver instanceof ImplicitReceiver)) {
        return;
      } // Check whether the name exists in the current scope. If so, map it. Otherwise, the name is
      // probably a property on the top-level component context.


      var target = this.scope.lookup(name);

      if (target !== null) {
        this.bindings.set(ast, target);
      }
    }
  }], [{
    key: "apply",
    value: function apply(template, scope) {
      var expressions = new Map();
      var symbols = new Map();
      var nestingLevel = new Map();
      var usedPipes = new Set(); // The top-level template has nesting level 0.

      var binder = new TemplateBinder(expressions, symbols, usedPipes, nestingLevel, scope, template instanceof Template ? template : null, 0);
      binder.ingest(template);
      return {
        expressions: expressions,
        symbols: symbols,
        nestingLevel: nestingLevel,
        usedPipes: usedPipes
      };
    }
  }]);

  return TemplateBinder;
}(RecursiveAstVisitor$1);
/**
 * Metadata container for a `Target` that allows queries for specific bits of metadata.
 *
 * See `BoundTarget` for documentation on the individual methods.
 */


var R3BoundTarget = /*#__PURE__*/function () {
  function R3BoundTarget(target, directives, bindings, references, exprTargets, symbols, nestingLevel, usedPipes) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_12__["default"])(this, R3BoundTarget);

    this.target = target;
    this.directives = directives;
    this.bindings = bindings;
    this.references = references;
    this.exprTargets = exprTargets;
    this.symbols = symbols;
    this.nestingLevel = nestingLevel;
    this.usedPipes = usedPipes;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_13__["default"])(R3BoundTarget, [{
    key: "getDirectivesOfNode",
    value: function getDirectivesOfNode(node) {
      return this.directives.get(node) || null;
    }
  }, {
    key: "getReferenceTarget",
    value: function getReferenceTarget(ref) {
      return this.references.get(ref) || null;
    }
  }, {
    key: "getConsumerOfBinding",
    value: function getConsumerOfBinding(binding) {
      return this.bindings.get(binding) || null;
    }
  }, {
    key: "getExpressionTarget",
    value: function getExpressionTarget(expr) {
      return this.exprTargets.get(expr) || null;
    }
  }, {
    key: "getTemplateOfSymbol",
    value: function getTemplateOfSymbol(symbol) {
      return this.symbols.get(symbol) || null;
    }
  }, {
    key: "getNestingLevel",
    value: function getNestingLevel(template) {
      return this.nestingLevel.get(template) || 0;
    }
  }, {
    key: "getUsedDirectives",
    value: function getUsedDirectives() {
      var set = new Set();
      this.directives.forEach(function (dirs) {
        return dirs.forEach(function (dir) {
          return set.add(dir);
        });
      });
      return Array.from(set.values());
    }
  }, {
    key: "getUsedPipes",
    value: function getUsedPipes() {
      return Array.from(this.usedPipes);
    }
  }]);

  return R3BoundTarget;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.
// This function call has a global side effects and publishes the compiler into global namespace for
// the late binding of the Compiler to the @angular/core for jit compilation.


publishFacade(_global);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */



/***/ }),

/***/ "1uah":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/zip.js ***!
  \***************************************************************/
/*! exports provided: zip, ZipOperator, ZipSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "zip", function() { return zip; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ZipOperator", function() { return ZipOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ZipSubscriber", function() { return ZipSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _fromArray__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./fromArray */ "yCtX");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _internal_symbol_iterator__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../internal/symbol/iterator */ "Lhse");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");









function zip() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  var resultSelector = observables[observables.length - 1];

  if (typeof resultSelector === 'function') {
    observables.pop();
  }

  return Object(_fromArray__WEBPACK_IMPORTED_MODULE_4__["fromArray"])(observables, undefined).lift(new ZipOperator(resultSelector));
}
var ZipOperator = /*#__PURE__*/function () {
  function ZipOperator(resultSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ZipOperator);

    this.resultSelector = resultSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ZipOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ZipSubscriber(subscriber, this.resultSelector));
    }
  }]);

  return ZipOperator;
}();
var ZipSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ZipSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ZipSubscriber);

  function ZipSubscriber(destination, resultSelector) {
    var _this;

    var values = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Object.create(null);

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ZipSubscriber);

    _this = _super.call(this, destination);
    _this.resultSelector = resultSelector;
    _this.iterators = [];
    _this.active = 0;
    _this.resultSelector = typeof resultSelector === 'function' ? resultSelector : undefined;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ZipSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var iterators = this.iterators;

      if (Object(_util_isArray__WEBPACK_IMPORTED_MODULE_5__["isArray"])(value)) {
        iterators.push(new StaticArrayIterator(value));
      } else if (typeof value[_internal_symbol_iterator__WEBPACK_IMPORTED_MODULE_7__["iterator"]] === 'function') {
        iterators.push(new StaticIterator(value[_internal_symbol_iterator__WEBPACK_IMPORTED_MODULE_7__["iterator"]]()));
      } else {
        iterators.push(new ZipBufferIterator(this.destination, this, value));
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var iterators = this.iterators;
      var len = iterators.length;
      this.unsubscribe();

      if (len === 0) {
        this.destination.complete();
        return;
      }

      this.active = len;

      for (var i = 0; i < len; i++) {
        var iterator = iterators[i];

        if (iterator.stillUnsubscribed) {
          var destination = this.destination;
          destination.add(iterator.subscribe());
        } else {
          this.active--;
        }
      }
    }
  }, {
    key: "notifyInactive",
    value: function notifyInactive() {
      this.active--;

      if (this.active === 0) {
        this.destination.complete();
      }
    }
  }, {
    key: "checkIterators",
    value: function checkIterators() {
      var iterators = this.iterators;
      var len = iterators.length;
      var destination = this.destination;

      for (var i = 0; i < len; i++) {
        var iterator = iterators[i];

        if (typeof iterator.hasValue === 'function' && !iterator.hasValue()) {
          return;
        }
      }

      var shouldComplete = false;
      var args = [];

      for (var _i = 0; _i < len; _i++) {
        var _iterator = iterators[_i];

        var result = _iterator.next();

        if (_iterator.hasCompleted()) {
          shouldComplete = true;
        }

        if (result.done) {
          destination.complete();
          return;
        }

        args.push(result.value);
      }

      if (this.resultSelector) {
        this._tryresultSelector(args);
      } else {
        destination.next(args);
      }

      if (shouldComplete) {
        destination.complete();
      }
    }
  }, {
    key: "_tryresultSelector",
    value: function _tryresultSelector(args) {
      var result;

      try {
        result = this.resultSelector.apply(this, args);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.destination.next(result);
    }
  }]);

  return ZipSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

var StaticIterator = /*#__PURE__*/function () {
  function StaticIterator(iterator) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, StaticIterator);

    this.iterator = iterator;
    this.nextResult = iterator.next();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(StaticIterator, [{
    key: "hasValue",
    value: function hasValue() {
      return true;
    }
  }, {
    key: "next",
    value: function next() {
      var result = this.nextResult;
      this.nextResult = this.iterator.next();
      return result;
    }
  }, {
    key: "hasCompleted",
    value: function hasCompleted() {
      var nextResult = this.nextResult;
      return Boolean(nextResult && nextResult.done);
    }
  }]);

  return StaticIterator;
}();

var StaticArrayIterator = /*#__PURE__*/function () {
  function StaticArrayIterator(array) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, StaticArrayIterator);

    this.array = array;
    this.index = 0;
    this.length = 0;
    this.length = array.length;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(StaticArrayIterator, [{
    key: _internal_symbol_iterator__WEBPACK_IMPORTED_MODULE_7__["iterator"],
    value: function value() {
      return this;
    }
  }, {
    key: "next",
    value: function next(value) {
      var i = this.index++;
      var array = this.array;
      return i < this.length ? {
        value: array[i],
        done: false
      } : {
        value: null,
        done: true
      };
    }
  }, {
    key: "hasValue",
    value: function hasValue() {
      return this.array.length > this.index;
    }
  }, {
    key: "hasCompleted",
    value: function hasCompleted() {
      return this.array.length === this.index;
    }
  }]);

  return StaticArrayIterator;
}();

var ZipBufferIterator = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ZipBufferIterator, _SimpleOuterSubscribe);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ZipBufferIterator);

  function ZipBufferIterator(destination, parent, observable) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ZipBufferIterator);

    _this2 = _super2.call(this, destination);
    _this2.parent = parent;
    _this2.observable = observable;
    _this2.stillUnsubscribed = true;
    _this2.buffer = [];
    _this2.isComplete = false;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ZipBufferIterator, [{
    key: _internal_symbol_iterator__WEBPACK_IMPORTED_MODULE_7__["iterator"],
    value: function value() {
      return this;
    }
  }, {
    key: "next",
    value: function next() {
      var buffer = this.buffer;

      if (buffer.length === 0 && this.isComplete) {
        return {
          value: null,
          done: true
        };
      } else {
        return {
          value: buffer.shift(),
          done: false
        };
      }
    }
  }, {
    key: "hasValue",
    value: function hasValue() {
      return this.buffer.length > 0;
    }
  }, {
    key: "hasCompleted",
    value: function hasCompleted() {
      return this.buffer.length === 0 && this.isComplete;
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      if (this.buffer.length > 0) {
        this.isComplete = true;
        this.parent.notifyInactive();
      } else {
        this.destination.complete();
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      this.buffer.push(innerValue);
      this.parent.checkIterators();
    }
  }, {
    key: "subscribe",
    value: function subscribe() {
      return Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["innerSubscribe"])(this.observable, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["SimpleInnerSubscriber"](this));
    }
  }]);

  return ZipBufferIterator;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "1xZ4":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ca.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Catalan [ca]
//! author : Juan G. Hurtado : https://github.com/juanghurtado
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ca = moment.defineLocale('ca', {
    months: {
      standalone: 'gener_febrer_març_abril_maig_juny_juliol_agost_setembre_octubre_novembre_desembre'.split('_'),
      format: "de gener_de febrer_de març_d'abril_de maig_de juny_de juliol_d'agost_de setembre_d'octubre_de novembre_de desembre".split('_'),
      isFormat: /D[oD]?(\s)+MMMM/
    },
    monthsShort: 'gen._febr._març_abr._maig_juny_jul._ag._set._oct._nov._des.'.split('_'),
    monthsParseExact: true,
    weekdays: 'diumenge_dilluns_dimarts_dimecres_dijous_divendres_dissabte'.split('_'),
    weekdaysShort: 'dg._dl._dt._dc._dj._dv._ds.'.split('_'),
    weekdaysMin: 'dg_dl_dt_dc_dj_dv_ds'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM [de] YYYY',
      ll: 'D MMM YYYY',
      LLL: 'D MMMM [de] YYYY [a les] H:mm',
      lll: 'D MMM YYYY, H:mm',
      LLLL: 'dddd D MMMM [de] YYYY [a les] H:mm',
      llll: 'ddd D MMM YYYY, H:mm'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[avui a ' + (this.hours() !== 1 ? 'les' : 'la') + '] LT';
      },
      nextDay: function nextDay() {
        return '[demà a ' + (this.hours() !== 1 ? 'les' : 'la') + '] LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [a ' + (this.hours() !== 1 ? 'les' : 'la') + '] LT';
      },
      lastDay: function lastDay() {
        return '[ahir a ' + (this.hours() !== 1 ? 'les' : 'la') + '] LT';
      },
      lastWeek: function lastWeek() {
        return '[el] dddd [passat a ' + (this.hours() !== 1 ? 'les' : 'la') + '] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: "d'aquí %s",
      past: 'fa %s',
      s: 'uns segons',
      ss: '%d segons',
      m: 'un minut',
      mm: '%d minuts',
      h: 'una hora',
      hh: '%d hores',
      d: 'un dia',
      dd: '%d dies',
      M: 'un mes',
      MM: '%d mesos',
      y: 'un any',
      yy: '%d anys'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(r|n|t|è|a)/,
    ordinal: function ordinal(number, period) {
      var output = number === 1 ? 'r' : number === 2 ? 'n' : number === 3 ? 'r' : number === 4 ? 't' : 'è';

      if (period === 'w' || period === 'W') {
        output = 'a';
      }

      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return ca;
});

/***/ }),

/***/ "25BE":
/*!********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/iterableToArray.js ***!
  \********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _iterableToArray; });
function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
}

/***/ }),

/***/ "2QA8":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/symbol/rxSubscriber.js ***!
  \********************************************************************/
/*! exports provided: rxSubscriber, $$rxSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "rxSubscriber", function() { return rxSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "$$rxSubscriber", function() { return $$rxSubscriber; });
var rxSubscriber = function () {
  return typeof Symbol === 'function' ? Symbol('rxSubscriber') : '@@rxSubscriber_' + Math.random();
}();
var $$rxSubscriber = rxSubscriber;

/***/ }),

/***/ "2QGa":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/partition.js ***!
  \*********************************************************************/
/*! exports provided: partition */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "partition", function() { return partition; });
/* harmony import */ var _util_not__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/not */ "F97/");
/* harmony import */ var _util_subscribeTo__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/subscribeTo */ "SeVD");
/* harmony import */ var _operators_filter__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../operators/filter */ "pLZG");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../Observable */ "HDdC");




function partition(source, predicate, thisArg) {
  return [Object(_operators_filter__WEBPACK_IMPORTED_MODULE_2__["filter"])(predicate, thisArg)(new _Observable__WEBPACK_IMPORTED_MODULE_3__["Observable"](Object(_util_subscribeTo__WEBPACK_IMPORTED_MODULE_1__["subscribeTo"])(source))), Object(_operators_filter__WEBPACK_IMPORTED_MODULE_2__["filter"])(Object(_util_not__WEBPACK_IMPORTED_MODULE_0__["not"])(predicate, thisArg))(new _Observable__WEBPACK_IMPORTED_MODULE_3__["Observable"](Object(_util_subscribeTo__WEBPACK_IMPORTED_MODULE_1__["subscribeTo"])(source)))];
}

/***/ }),

/***/ "2Vo4":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/BehaviorSubject.js ***!
  \****************************************************************/
/*! exports provided: BehaviorSubject */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BehaviorSubject", function() { return BehaviorSubject; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./Subject */ "XNiG");
/* harmony import */ var _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./util/ObjectUnsubscribedError */ "9ppp");








var BehaviorSubject = /*#__PURE__*/function (_Subject) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(BehaviorSubject, _Subject);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(BehaviorSubject);

  function BehaviorSubject(_value) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, BehaviorSubject);

    _this = _super.call(this);
    _this._value = _value;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(BehaviorSubject, [{
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      var subscription = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(BehaviorSubject.prototype), "_subscribe", this).call(this, subscriber);

      if (subscription && !subscription.closed) {
        subscriber.next(this._value);
      }

      return subscription;
    }
  }, {
    key: "getValue",
    value: function getValue() {
      if (this.hasError) {
        throw this.thrownError;
      } else if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_7__["ObjectUnsubscribedError"]();
      } else {
        return this._value;
      }
    }
  }, {
    key: "next",
    value: function next(value) {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(BehaviorSubject.prototype), "next", this).call(this, this._value = value);
    }
  }, {
    key: "value",
    get: function get() {
      return this.getValue();
    }
  }]);

  return BehaviorSubject;
}(_Subject__WEBPACK_IMPORTED_MODULE_6__["Subject"]);

/***/ }),

/***/ "2WcH":
/*!*****************************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/isNativeReflectConstruct.js ***!
  \*****************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isNativeReflectConstruct; });
function _isNativeReflectConstruct() {
  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
  if (Reflect.construct.sham) return false;
  if (typeof Proxy === "function") return true;

  try {
    Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
    return true;
  } catch (e) {
    return false;
  }
}

/***/ }),

/***/ "2fFW":
/*!*******************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/config.js ***!
  \*******************************************************/
/*! exports provided: config */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "config", function() { return config; });
var _enable_super_gross_mode_that_will_cause_bad_things = false;
var config = {
  Promise: undefined,

  set useDeprecatedSynchronousErrorHandling(value) {
    if (value) {
      var error = new Error();
      console.warn('DEPRECATED! RxJS was set to use deprecated synchronous error handling behavior by code at: \n' + error.stack);
    } else if (_enable_super_gross_mode_that_will_cause_bad_things) {
      console.log('RxJS: Back to a better error behavior. Thank you. <3');
    }

    _enable_super_gross_mode_that_will_cause_bad_things = value;
  },

  get useDeprecatedSynchronousErrorHandling() {
    return _enable_super_gross_mode_that_will_cause_bad_things;
  }

};

/***/ }),

/***/ "2fjn":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/fr-ca.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : French (Canada) [fr-ca]
//! author : Jonathan Abourbih : https://github.com/jonbca
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var frCa = moment.defineLocale('fr-ca', {
    months: 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
    monthsShort: 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
    monthsParseExact: true,
    weekdays: 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
    weekdaysShort: 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
    weekdaysMin: 'di_lu_ma_me_je_ve_sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Aujourd’hui à] LT',
      nextDay: '[Demain à] LT',
      nextWeek: 'dddd [à] LT',
      lastDay: '[Hier à] LT',
      lastWeek: 'dddd [dernier à] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dans %s',
      past: 'il y a %s',
      s: 'quelques secondes',
      ss: '%d secondes',
      m: 'une minute',
      mm: '%d minutes',
      h: 'une heure',
      hh: '%d heures',
      d: 'un jour',
      dd: '%d jours',
      M: 'un mois',
      MM: '%d mois',
      y: 'un an',
      yy: '%d ans'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(er|e)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        // Words with masculine grammatical gender: mois, trimestre, jour
        default:
        case 'M':
        case 'Q':
        case 'D':
        case 'DDD':
        case 'd':
          return number + (number === 1 ? 'er' : 'e');
        // Words with feminine grammatical gender: semaine

        case 'w':
        case 'W':
          return number + (number === 1 ? 're' : 'e');
      }
    }
  });
  return frCa;
});

/***/ }),

/***/ "2ykv":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/nl-be.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Dutch (Belgium) [nl-be]
//! author : Joris Röling : https://github.com/jorisroling
//! author : Jacob Middag : https://github.com/middagj
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortWithDots = 'jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.'.split('_'),
      monthsShortWithoutDots = 'jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec'.split('_'),
      monthsParse = [/^jan/i, /^feb/i, /^maart|mrt.?$/i, /^apr/i, /^mei$/i, /^jun[i.]?$/i, /^jul[i.]?$/i, /^aug/i, /^sep/i, /^okt/i, /^nov/i, /^dec/i],
      monthsRegex = /^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i;
  var nlBe = moment.defineLocale('nl-be', {
    months: 'januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortWithDots;
      } else if (/-MMM-/.test(format)) {
        return monthsShortWithoutDots[m.month()];
      } else {
        return monthsShortWithDots[m.month()];
      }
    },
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: /^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,
    monthsShortStrictRegex: /^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag'.split('_'),
    weekdaysShort: 'zo._ma._di._wo._do._vr._za.'.split('_'),
    weekdaysMin: 'zo_ma_di_wo_do_vr_za'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[vandaag om] LT',
      nextDay: '[morgen om] LT',
      nextWeek: 'dddd [om] LT',
      lastDay: '[gisteren om] LT',
      lastWeek: '[afgelopen] dddd [om] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'over %s',
      past: '%s geleden',
      s: 'een paar seconden',
      ss: '%d seconden',
      m: 'één minuut',
      mm: '%d minuten',
      h: 'één uur',
      hh: '%d uur',
      d: 'één dag',
      dd: '%d dagen',
      M: 'één maand',
      MM: '%d maanden',
      y: 'één jaar',
      yy: '%d jaar'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(ste|de)/,
    ordinal: function ordinal(number) {
      return number + (number === 1 || number === 8 || number >= 20 ? 'ste' : 'de');
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return nlBe;
});

/***/ }),

/***/ "32Ea":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/skipWhile.js ***!
  \********************************************************************/
/*! exports provided: skipWhile */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "skipWhile", function() { return skipWhile; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function skipWhile(predicate) {
  return function (source) {
    return source.lift(new SkipWhileOperator(predicate));
  };
}

var SkipWhileOperator = /*#__PURE__*/function () {
  function SkipWhileOperator(predicate) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SkipWhileOperator);

    this.predicate = predicate;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipWhileOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SkipWhileSubscriber(subscriber, this.predicate));
    }
  }]);

  return SkipWhileOperator;
}();

var SkipWhileSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SkipWhileSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SkipWhileSubscriber);

  function SkipWhileSubscriber(destination, predicate) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SkipWhileSubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.skipping = true;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipWhileSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var destination = this.destination;

      if (this.skipping) {
        this.tryCallPredicate(value);
      }

      if (!this.skipping) {
        destination.next(value);
      }
    }
  }, {
    key: "tryCallPredicate",
    value: function tryCallPredicate(value) {
      try {
        var result = this.predicate(value, this.index++);
        this.skipping = Boolean(result);
      } catch (err) {
        this.destination.error(err);
      }
    }
  }]);

  return SkipWhileSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "3E0/":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/delay.js ***!
  \****************************************************************/
/*! exports provided: delay */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "delay", function() { return delay; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _util_isDate__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isDate */ "mlxB");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Notification__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Notification */ "WMd4");








function delay(delay) {
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_4__["async"];
  var absoluteDelay = Object(_util_isDate__WEBPACK_IMPORTED_MODULE_5__["isDate"])(delay);
  var delayFor = absoluteDelay ? +delay - scheduler.now() : Math.abs(delay);
  return function (source) {
    return source.lift(new DelayOperator(delayFor, scheduler));
  };
}

var DelayOperator = /*#__PURE__*/function () {
  function DelayOperator(delay, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DelayOperator);

    this.delay = delay;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DelayOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DelaySubscriber(subscriber, this.delay, this.scheduler));
    }
  }]);

  return DelayOperator;
}();

var DelaySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(DelaySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(DelaySubscriber);

  function DelaySubscriber(destination, delay, scheduler) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DelaySubscriber);

    _this = _super.call(this, destination);
    _this.delay = delay;
    _this.scheduler = scheduler;
    _this.queue = [];
    _this.active = false;
    _this.errored = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DelaySubscriber, [{
    key: "_schedule",
    value: function _schedule(scheduler) {
      this.active = true;
      var destination = this.destination;
      destination.add(scheduler.schedule(DelaySubscriber.dispatch, this.delay, {
        source: this,
        destination: this.destination,
        scheduler: scheduler
      }));
    }
  }, {
    key: "scheduleNotification",
    value: function scheduleNotification(notification) {
      if (this.errored === true) {
        return;
      }

      var scheduler = this.scheduler;
      var message = new DelayMessage(scheduler.now() + this.delay, notification);
      this.queue.push(message);

      if (this.active === false) {
        this._schedule(scheduler);
      }
    }
  }, {
    key: "_next",
    value: function _next(value) {
      this.scheduleNotification(_Notification__WEBPACK_IMPORTED_MODULE_7__["Notification"].createNext(value));
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.errored = true;
      this.queue = [];
      this.destination.error(err);
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.scheduleNotification(_Notification__WEBPACK_IMPORTED_MODULE_7__["Notification"].createComplete());
      this.unsubscribe();
    }
  }], [{
    key: "dispatch",
    value: function dispatch(state) {
      var source = state.source;
      var queue = source.queue;
      var scheduler = state.scheduler;
      var destination = state.destination;

      while (queue.length > 0 && queue[0].time - scheduler.now() <= 0) {
        queue.shift().notification.observe(destination);
      }

      if (queue.length > 0) {
        var _delay = Math.max(0, queue[0].time - scheduler.now());

        this.schedule(state, _delay);
      } else {
        this.unsubscribe();
        source.active = false;
      }
    }
  }]);

  return DelaySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

var DelayMessage = function DelayMessage(time, notification) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DelayMessage);

  this.time = time;
  this.notification = notification;
};

/***/ }),

/***/ "3E1r":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/hi.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Hindi [hi]
//! author : Mayank Singhal : https://github.com/mayanksinghal
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '१',
    2: '२',
    3: '३',
    4: '४',
    5: '५',
    6: '६',
    7: '७',
    8: '८',
    9: '९',
    0: '०'
  },
      numberMap = {
    '१': '1',
    '२': '2',
    '३': '3',
    '४': '4',
    '५': '5',
    '६': '6',
    '७': '7',
    '८': '8',
    '९': '9',
    '०': '0'
  };
  var hi = moment.defineLocale('hi', {
    months: 'जनवरी_फ़रवरी_मार्च_अप्रैल_मई_जून_जुलाई_अगस्त_सितम्बर_अक्टूबर_नवम्बर_दिसम्बर'.split('_'),
    monthsShort: 'जन._फ़र._मार्च_अप्रै._मई_जून_जुल._अग._सित._अक्टू._नव._दिस.'.split('_'),
    monthsParseExact: true,
    weekdays: 'रविवार_सोमवार_मंगलवार_बुधवार_गुरूवार_शुक्रवार_शनिवार'.split('_'),
    weekdaysShort: 'रवि_सोम_मंगल_बुध_गुरू_शुक्र_शनि'.split('_'),
    weekdaysMin: 'र_सो_मं_बु_गु_शु_श'.split('_'),
    longDateFormat: {
      LT: 'A h:mm बजे',
      LTS: 'A h:mm:ss बजे',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm बजे',
      LLLL: 'dddd, D MMMM YYYY, A h:mm बजे'
    },
    calendar: {
      sameDay: '[आज] LT',
      nextDay: '[कल] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[कल] LT',
      lastWeek: '[पिछले] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s में',
      past: '%s पहले',
      s: 'कुछ ही क्षण',
      ss: '%d सेकंड',
      m: 'एक मिनट',
      mm: '%d मिनट',
      h: 'एक घंटा',
      hh: '%d घंटे',
      d: 'एक दिन',
      dd: '%d दिन',
      M: 'एक महीने',
      MM: '%d महीने',
      y: 'एक वर्ष',
      yy: '%d वर्ष'
    },
    preparse: function preparse(string) {
      return string.replace(/[१२३४५६७८९०]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    // Hindi notation for meridiems are quite fuzzy in practice. While there exists
    // a rigid notion of a 'Pahar' it is not used as rigidly in modern Hindi.
    meridiemParse: /रात|सुबह|दोपहर|शाम/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'रात') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'सुबह') {
        return hour;
      } else if (meridiem === 'दोपहर') {
        return hour >= 10 ? hour : hour + 12;
      } else if (meridiem === 'शाम') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'रात';
      } else if (hour < 10) {
        return 'सुबह';
      } else if (hour < 17) {
        return 'दोपहर';
      } else if (hour < 20) {
        return 'शाम';
      } else {
        return 'रात';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return hi;
});

/***/ }),

/***/ "3N8a":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/AsyncAction.js ***!
  \**********************************************************************/
/*! exports provided: AsyncAction */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AsyncAction", function() { return AsyncAction; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Action__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Action */ "7ve7");





var AsyncAction = /*#__PURE__*/function (_Action) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(AsyncAction, _Action);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(AsyncAction);

  function AsyncAction(scheduler, work) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AsyncAction);

    _this = _super.call(this, scheduler, work);
    _this.scheduler = scheduler;
    _this.work = work;
    _this.pending = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AsyncAction, [{
    key: "schedule",
    value: function schedule(state) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      if (this.closed) {
        return this;
      }

      this.state = state;
      var id = this.id;
      var scheduler = this.scheduler;

      if (id != null) {
        this.id = this.recycleAsyncId(scheduler, id, delay);
      }

      this.pending = true;
      this.delay = delay;
      this.id = this.id || this.requestAsyncId(scheduler, this.id, delay);
      return this;
    }
  }, {
    key: "requestAsyncId",
    value: function requestAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
      return setInterval(scheduler.flush.bind(scheduler, this), delay);
    }
  }, {
    key: "recycleAsyncId",
    value: function recycleAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

      if (delay !== null && this.delay === delay && this.pending === false) {
        return id;
      }

      clearInterval(id);
      return undefined;
    }
  }, {
    key: "execute",
    value: function execute(state, delay) {
      if (this.closed) {
        return new Error('executing a cancelled action');
      }

      this.pending = false;

      var error = this._execute(state, delay);

      if (error) {
        return error;
      } else if (this.pending === false && this.id != null) {
        this.id = this.recycleAsyncId(this.scheduler, this.id, null);
      }
    }
  }, {
    key: "_execute",
    value: function _execute(state, delay) {
      var errored = false;
      var errorValue = undefined;

      try {
        this.work(state);
      } catch (e) {
        errored = true;
        errorValue = !!e && e || new Error(e);
      }

      if (errored) {
        this.unsubscribe();
        return errorValue;
      }
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var id = this.id;
      var scheduler = this.scheduler;
      var actions = scheduler.actions;
      var index = actions.indexOf(this);
      this.work = null;
      this.state = null;
      this.pending = false;
      this.scheduler = null;

      if (index !== -1) {
        actions.splice(index, 1);
      }

      if (id != null) {
        this.id = this.recycleAsyncId(scheduler, id, null);
      }

      this.delay = null;
    }
  }]);

  return AsyncAction;
}(_Action__WEBPACK_IMPORTED_MODULE_4__["Action"]);

/***/ }),

/***/ "3Pt+":
/*!********************************************************************!*\
  !*** ./node_modules/@angular/forms/__ivy_ngcc__/fesm2015/forms.js ***!
  \********************************************************************/
/*! exports provided: AbstractControl, AbstractControlDirective, AbstractFormGroupDirective, COMPOSITION_BUFFER_MODE, CheckboxControlValueAccessor, CheckboxRequiredValidator, ControlContainer, DefaultValueAccessor, EmailValidator, FormArray, FormArrayName, FormBuilder, FormControl, FormControlDirective, FormControlName, FormGroup, FormGroupDirective, FormGroupName, FormsModule, MaxLengthValidator, MinLengthValidator, NG_ASYNC_VALIDATORS, NG_VALIDATORS, NG_VALUE_ACCESSOR, NgControl, NgControlStatus, NgControlStatusGroup, NgForm, NgModel, NgModelGroup, NgSelectOption, NumberValueAccessor, PatternValidator, RadioControlValueAccessor, RangeValueAccessor, ReactiveFormsModule, RequiredValidator, SelectControlValueAccessor, SelectMultipleControlValueAccessor, VERSION, Validators, ɵInternalFormsSharedModule, ɵNgNoValidate, ɵNgSelectMultipleOption, ɵangular_packages_forms_forms_a, ɵangular_packages_forms_forms_b, ɵangular_packages_forms_forms_ba, ɵangular_packages_forms_forms_bb, ɵangular_packages_forms_forms_bc, ɵangular_packages_forms_forms_bd, ɵangular_packages_forms_forms_be, ɵangular_packages_forms_forms_c, ɵangular_packages_forms_forms_d, ɵangular_packages_forms_forms_e, ɵangular_packages_forms_forms_f, ɵangular_packages_forms_forms_g, ɵangular_packages_forms_forms_h, ɵangular_packages_forms_forms_i, ɵangular_packages_forms_forms_j, ɵangular_packages_forms_forms_k, ɵangular_packages_forms_forms_l, ɵangular_packages_forms_forms_m, ɵangular_packages_forms_forms_n, ɵangular_packages_forms_forms_o, ɵangular_packages_forms_forms_p, ɵangular_packages_forms_forms_q, ɵangular_packages_forms_forms_r, ɵangular_packages_forms_forms_s, ɵangular_packages_forms_forms_t, ɵangular_packages_forms_forms_u, ɵangular_packages_forms_forms_v, ɵangular_packages_forms_forms_w, ɵangular_packages_forms_forms_x, ɵangular_packages_forms_forms_y, ɵangular_packages_forms_forms_z */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AbstractControl", function() { return AbstractControl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AbstractControlDirective", function() { return AbstractControlDirective; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AbstractFormGroupDirective", function() { return AbstractFormGroupDirective; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "COMPOSITION_BUFFER_MODE", function() { return COMPOSITION_BUFFER_MODE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CheckboxControlValueAccessor", function() { return CheckboxControlValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CheckboxRequiredValidator", function() { return CheckboxRequiredValidator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ControlContainer", function() { return ControlContainer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DefaultValueAccessor", function() { return DefaultValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EmailValidator", function() { return EmailValidator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormArray", function() { return FormArray; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormArrayName", function() { return FormArrayName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormBuilder", function() { return FormBuilder; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormControl", function() { return FormControl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormControlDirective", function() { return FormControlDirective; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormControlName", function() { return FormControlName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormGroup", function() { return FormGroup; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormGroupDirective", function() { return FormGroupDirective; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormGroupName", function() { return FormGroupName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormsModule", function() { return FormsModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MaxLengthValidator", function() { return MaxLengthValidator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MinLengthValidator", function() { return MinLengthValidator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NG_ASYNC_VALIDATORS", function() { return NG_ASYNC_VALIDATORS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NG_VALIDATORS", function() { return NG_VALIDATORS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NG_VALUE_ACCESSOR", function() { return NG_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgControl", function() { return NgControl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgControlStatus", function() { return NgControlStatus; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgControlStatusGroup", function() { return NgControlStatusGroup; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgForm", function() { return NgForm; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModel", function() { return NgModel; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModelGroup", function() { return NgModelGroup; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgSelectOption", function() { return NgSelectOption; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NumberValueAccessor", function() { return NumberValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PatternValidator", function() { return PatternValidator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RadioControlValueAccessor", function() { return RadioControlValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RangeValueAccessor", function() { return RangeValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReactiveFormsModule", function() { return ReactiveFormsModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RequiredValidator", function() { return RequiredValidator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SelectControlValueAccessor", function() { return SelectControlValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SelectMultipleControlValueAccessor", function() { return SelectMultipleControlValueAccessor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Validators", function() { return Validators; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵInternalFormsSharedModule", function() { return ɵInternalFormsSharedModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNgNoValidate", function() { return ɵNgNoValidate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNgSelectMultipleOption", function() { return ɵNgSelectMultipleOption; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_a", function() { return SHARED_FORM_DIRECTIVES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_b", function() { return TEMPLATE_DRIVEN_DIRECTIVES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_ba", function() { return CHECKBOX_REQUIRED_VALIDATOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_bb", function() { return EMAIL_VALIDATOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_bc", function() { return MIN_LENGTH_VALIDATOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_bd", function() { return MAX_LENGTH_VALIDATOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_be", function() { return PATTERN_VALIDATOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_c", function() { return REACTIVE_DRIVEN_DIRECTIVES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_d", function() { return ɵInternalFormsSharedModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_e", function() { return CHECKBOX_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_f", function() { return DEFAULT_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_g", function() { return AbstractControlStatus; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_h", function() { return ngControlStatusHost; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_i", function() { return formDirectiveProvider; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_j", function() { return formControlBinding; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_k", function() { return modelGroupProvider; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_l", function() { return NUMBER_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_m", function() { return RADIO_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_n", function() { return RadioControlRegistry; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_o", function() { return RANGE_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_p", function() { return NG_MODEL_WITH_FORM_CONTROL_WARNING; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_q", function() { return formControlBinding$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_r", function() { return controlNameBinding; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_s", function() { return formDirectiveProvider$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_t", function() { return formGroupNameProvider; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_u", function() { return formArrayNameProvider; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_v", function() { return SELECT_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_w", function() { return SELECT_MULTIPLE_VALUE_ACCESSOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_x", function() { return ɵNgSelectMultipleOption; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_y", function() { return ɵNgNoValidate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_forms_forms_z", function() { return REQUIRED_VALIDATOR; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createForOfIteratorHelper */ "uFwe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @angular/core */ "fXoL");
/* harmony import */ var _angular_common__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @angular/common */ "ofXK");
/* harmony import */ var rxjs__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! rxjs */ "qCKp");
/* harmony import */ var rxjs_operators__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! rxjs/operators */ "kU1M");








/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */




/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Used to provide a `ControlValueAccessor` for form controls.
 *
 * See `DefaultValueAccessor` for how to implement one.
 *
 * @publicApi
 */


var NG_VALUE_ACCESSOR = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('NgValueAccessor');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var CHECKBOX_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return CheckboxControlValueAccessor;
  }),
  multi: true
};
/**
 * @description
 * A `ControlValueAccessor` for writing a value and listening to changes on a checkbox input
 * element.
 *
 * @usageNotes
 *
 * ### Using a checkbox with a reactive form.
 *
 * The following example shows how to use a checkbox with a reactive form.
 *
 * ```ts
 * const rememberLoginControl = new FormControl();
 * ```
 *
 * ```
 * <input type="checkbox" [formControl]="rememberLoginControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var CheckboxControlValueAccessor = /*#__PURE__*/function () {
  function CheckboxControlValueAccessor(_renderer, _elementRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, CheckboxControlValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    /**
     * The registered callback function called when a change event occurs on the input element.
     * @nodoc
     */

    this.onChange = function (_) {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};
  }
  /**
   * Sets the "checked" property on the input element.
   * @nodoc
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(CheckboxControlValueAccessor, [{
    key: "writeValue",
    value: function writeValue(value) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'checked', value);
    }
    /**
     * Registers a function called when the control value changes.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      this.onChange = fn;
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
  }]);

  return CheckboxControlValueAccessor;
}();

CheckboxControlValueAccessor.ɵfac = function CheckboxControlValueAccessor_Factory(t) {
  return new (t || CheckboxControlValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]));
};

CheckboxControlValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: CheckboxControlValueAccessor,
  selectors: [["input", "type", "checkbox", "formControlName", ""], ["input", "type", "checkbox", "formControl", ""], ["input", "type", "checkbox", "ngModel", ""]],
  hostBindings: function CheckboxControlValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("change", function CheckboxControlValueAccessor_change_HostBindingHandler($event) {
        return ctx.onChange($event.target.checked);
      })("blur", function CheckboxControlValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      });
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([CHECKBOX_VALUE_ACCESSOR])]
});

CheckboxControlValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](CheckboxControlValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]',
      host: {
        '(change)': 'onChange($event.target.checked)',
        '(blur)': 'onTouched()'
      },
      providers: [CHECKBOX_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var DEFAULT_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return DefaultValueAccessor;
  }),
  multi: true
};
/**
 * We must check whether the agent is Android because composition events
 * behave differently between iOS and Android.
 */

function _isAndroid() {
  var userAgent = Object(_angular_common__WEBPACK_IMPORTED_MODULE_8__["ɵgetDOM"])() ? Object(_angular_common__WEBPACK_IMPORTED_MODULE_8__["ɵgetDOM"])().getUserAgent() : '';
  return /android (\d+)/.test(userAgent.toLowerCase());
}
/**
 * @description
 * Provide this token to control if form directives buffer IME input until
 * the "compositionend" event occurs.
 * @publicApi
 */


var COMPOSITION_BUFFER_MODE = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('CompositionEventMode');
/**
 * @description
 * The default `ControlValueAccessor` for writing a value and listening to changes on input
 * elements. The accessor is used by the `FormControlDirective`, `FormControlName`, and
 * `NgModel` directives.
 *
 * @usageNotes
 *
 * ### Using the default value accessor
 *
 * The following example shows how to use an input element that activates the default value accessor
 * (in this case, a text field).
 *
 * ```ts
 * const firstNameControl = new FormControl();
 * ```
 *
 * ```
 * <input type="text" [formControl]="firstNameControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var DefaultValueAccessor = /*#__PURE__*/function () {
  function DefaultValueAccessor(_renderer, _elementRef, _compositionMode) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, DefaultValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    this._compositionMode = _compositionMode;
    /**
     * The registered callback function called when an input event occurs on the input element.
     * @nodoc
     */

    this.onChange = function (_) {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};
    /** Whether the user is creating a composition string (IME events). */


    this._composing = false;

    if (this._compositionMode == null) {
      this._compositionMode = !_isAndroid();
    }
  }
  /**
   * Sets the "value" property on the input element.
   * @nodoc
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(DefaultValueAccessor, [{
    key: "writeValue",
    value: function writeValue(value) {
      var normalizedValue = value == null ? '' : value;

      this._renderer.setProperty(this._elementRef.nativeElement, 'value', normalizedValue);
    }
    /**
     * Registers a function called when the control value changes.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      this.onChange = fn;
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
    /** @internal */

  }, {
    key: "_handleInput",
    value: function _handleInput(value) {
      if (!this._compositionMode || this._compositionMode && !this._composing) {
        this.onChange(value);
      }
    }
    /** @internal */

  }, {
    key: "_compositionStart",
    value: function _compositionStart() {
      this._composing = true;
    }
    /** @internal */

  }, {
    key: "_compositionEnd",
    value: function _compositionEnd(value) {
      this._composing = false;
      this._compositionMode && this.onChange(value);
    }
  }]);

  return DefaultValueAccessor;
}();

DefaultValueAccessor.ɵfac = function DefaultValueAccessor_Factory(t) {
  return new (t || DefaultValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](COMPOSITION_BUFFER_MODE, 8));
};

DefaultValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: DefaultValueAccessor,
  selectors: [["input", "formControlName", "", 3, "type", "checkbox"], ["textarea", "formControlName", ""], ["input", "formControl", "", 3, "type", "checkbox"], ["textarea", "formControl", ""], ["input", "ngModel", "", 3, "type", "checkbox"], ["textarea", "ngModel", ""], ["", "ngDefaultControl", ""]],
  hostBindings: function DefaultValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("input", function DefaultValueAccessor_input_HostBindingHandler($event) {
        return ctx._handleInput($event.target.value);
      })("blur", function DefaultValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      })("compositionstart", function DefaultValueAccessor_compositionstart_HostBindingHandler() {
        return ctx._compositionStart();
      })("compositionend", function DefaultValueAccessor_compositionend_HostBindingHandler($event) {
        return ctx._compositionEnd($event.target.value);
      });
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([DEFAULT_VALUE_ACCESSOR])]
});

DefaultValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }, {
    type: Boolean,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [COMPOSITION_BUFFER_MODE]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](DefaultValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]',
      // TODO: vsavkin replace the above selector with the one below it once
      // https://github.com/angular/angular/issues/3011 is implemented
      // selector: '[ngModel],[formControl],[formControlName]',
      host: {
        '(input)': '$any(this)._handleInput($event.target.value)',
        '(blur)': 'onTouched()',
        '(compositionstart)': '$any(this)._compositionStart()',
        '(compositionend)': '$any(this)._compositionEnd($event.target.value)'
      },
      providers: [DEFAULT_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }, {
      type: Boolean,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [COMPOSITION_BUFFER_MODE]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 * Base class for control directives.
 *
 * This class is only used internally in the `ReactiveFormsModule` and the `FormsModule`.
 *
 * @publicApi
 */


var AbstractControlDirective = /*#__PURE__*/function () {
  function AbstractControlDirective() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, AbstractControlDirective);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(AbstractControlDirective, [{
    key: "reset",

    /**
     * @description
     * Resets the control with the provided value if the control is present.
     */
    value: function reset() {
      var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : undefined;
      if (this.control) this.control.reset(value);
    }
    /**
     * @description
     * Reports whether the control with the given path has the error specified.
     *
     * @param errorCode The code of the error to check
     * @param path A list of control names that designates how to move from the current control
     * to the control that should be queried for errors.
     *
     * @usageNotes
     * For example, for the following `FormGroup`:
     *
     * ```
     * form = new FormGroup({
     *   address: new FormGroup({ street: new FormControl() })
     * });
     * ```
     *
     * The path to the 'street' control from the root form would be 'address' -> 'street'.
     *
     * It can be provided to this method in one of two formats:
     *
     * 1. An array of string control names, e.g. `['address', 'street']`
     * 1. A period-delimited list of control names in one string, e.g. `'address.street'`
     *
     * If no path is given, this method checks for the error on the current control.
     *
     * @returns whether the given error is present in the control at the given path.
     *
     * If the control is not present, false is returned.
     */

  }, {
    key: "hasError",
    value: function hasError(errorCode, path) {
      return this.control ? this.control.hasError(errorCode, path) : false;
    }
    /**
     * @description
     * Reports error data for the control with the given path.
     *
     * @param errorCode The code of the error to check
     * @param path A list of control names that designates how to move from the current control
     * to the control that should be queried for errors.
     *
     * @usageNotes
     * For example, for the following `FormGroup`:
     *
     * ```
     * form = new FormGroup({
     *   address: new FormGroup({ street: new FormControl() })
     * });
     * ```
     *
     * The path to the 'street' control from the root form would be 'address' -> 'street'.
     *
     * It can be provided to this method in one of two formats:
     *
     * 1. An array of string control names, e.g. `['address', 'street']`
     * 1. A period-delimited list of control names in one string, e.g. `'address.street'`
     *
     * @returns error data for that particular error. If the control or error is not present,
     * null is returned.
     */

  }, {
    key: "getError",
    value: function getError(errorCode, path) {
      return this.control ? this.control.getError(errorCode, path) : null;
    }
  }, {
    key: "value",

    /**
     * @description
     * Reports the value of the control if it is present, otherwise null.
     */
    get: function get() {
      return this.control ? this.control.value : null;
    }
    /**
     * @description
     * Reports whether the control is valid. A control is considered valid if no
     * validation errors exist with the current value.
     * If the control is not present, null is returned.
     */

  }, {
    key: "valid",
    get: function get() {
      return this.control ? this.control.valid : null;
    }
    /**
     * @description
     * Reports whether the control is invalid, meaning that an error exists in the input value.
     * If the control is not present, null is returned.
     */

  }, {
    key: "invalid",
    get: function get() {
      return this.control ? this.control.invalid : null;
    }
    /**
     * @description
     * Reports whether a control is pending, meaning that that async validation is occurring and
     * errors are not yet available for the input value. If the control is not present, null is
     * returned.
     */

  }, {
    key: "pending",
    get: function get() {
      return this.control ? this.control.pending : null;
    }
    /**
     * @description
     * Reports whether the control is disabled, meaning that the control is disabled
     * in the UI and is exempt from validation checks and excluded from aggregate
     * values of ancestor controls. If the control is not present, null is returned.
     */

  }, {
    key: "disabled",
    get: function get() {
      return this.control ? this.control.disabled : null;
    }
    /**
     * @description
     * Reports whether the control is enabled, meaning that the control is included in ancestor
     * calculations of validity or value. If the control is not present, null is returned.
     */

  }, {
    key: "enabled",
    get: function get() {
      return this.control ? this.control.enabled : null;
    }
    /**
     * @description
     * Reports the control's validation errors. If the control is not present, null is returned.
     */

  }, {
    key: "errors",
    get: function get() {
      return this.control ? this.control.errors : null;
    }
    /**
     * @description
     * Reports whether the control is pristine, meaning that the user has not yet changed
     * the value in the UI. If the control is not present, null is returned.
     */

  }, {
    key: "pristine",
    get: function get() {
      return this.control ? this.control.pristine : null;
    }
    /**
     * @description
     * Reports whether the control is dirty, meaning that the user has changed
     * the value in the UI. If the control is not present, null is returned.
     */

  }, {
    key: "dirty",
    get: function get() {
      return this.control ? this.control.dirty : null;
    }
    /**
     * @description
     * Reports whether the control is touched, meaning that the user has triggered
     * a `blur` event on it. If the control is not present, null is returned.
     */

  }, {
    key: "touched",
    get: function get() {
      return this.control ? this.control.touched : null;
    }
    /**
     * @description
     * Reports the validation status of the control. Possible values include:
     * 'VALID', 'INVALID', 'DISABLED', and 'PENDING'.
     * If the control is not present, null is returned.
     */

  }, {
    key: "status",
    get: function get() {
      return this.control ? this.control.status : null;
    }
    /**
     * @description
     * Reports whether the control is untouched, meaning that the user has not yet triggered
     * a `blur` event on it. If the control is not present, null is returned.
     */

  }, {
    key: "untouched",
    get: function get() {
      return this.control ? this.control.untouched : null;
    }
    /**
     * @description
     * Returns a multicasting observable that emits a validation status whenever it is
     * calculated for the control. If the control is not present, null is returned.
     */

  }, {
    key: "statusChanges",
    get: function get() {
      return this.control ? this.control.statusChanges : null;
    }
    /**
     * @description
     * Returns a multicasting observable of value changes for the control that emits every time the
     * value of the control changes in the UI or programmatically.
     * If the control is not present, null is returned.
     */

  }, {
    key: "valueChanges",
    get: function get() {
      return this.control ? this.control.valueChanges : null;
    }
    /**
     * @description
     * Returns an array that represents the path from the top-level form to this control.
     * Each index is the string name of the control on that level.
     */

  }, {
    key: "path",
    get: function get() {
      return null;
    }
  }]);

  return AbstractControlDirective;
}();

AbstractControlDirective.ɵfac = function AbstractControlDirective_Factory(t) {
  return new (t || AbstractControlDirective)();
};

AbstractControlDirective.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: AbstractControlDirective
});
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 * A base class for directives that contain multiple registered instances of `NgControl`.
 * Only used by the forms module.
 *
 * @publicApi
 */

var ControlContainer = /*#__PURE__*/function (_AbstractControlDirec) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(ControlContainer, _AbstractControlDirec);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(ControlContainer);

  function ControlContainer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ControlContainer);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(ControlContainer, [{
    key: "formDirective",

    /**
     * @description
     * The top-level form directive for the control.
     */
    get: function get() {
      return null;
    }
    /**
     * @description
     * The path to this group.
     */

  }, {
    key: "path",
    get: function get() {
      return null;
    }
  }]);

  return ControlContainer;
}(AbstractControlDirective);

ControlContainer.ɵfac = function ControlContainer_Factory(t) {
  return ɵControlContainer_BaseFactory(t || ControlContainer);
};

ControlContainer.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: ControlContainer,
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});
var ɵControlContainer_BaseFactory = /*@__PURE__*/_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵgetInheritedFactory"](ControlContainer);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function unimplemented() {
  if (typeof ngDevMode === 'undefined' || ngDevMode) {
    throw new Error('unimplemented');
  }
}
/**
 * @description
 * A base class that all `FormControl`-based directives extend. It binds a `FormControl`
 * object to a DOM element.
 *
 * @publicApi
 */


var NgControl = /*#__PURE__*/function (_AbstractControlDirec2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgControl, _AbstractControlDirec2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgControl);

  function NgControl() {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgControl);

    _this = _super2.apply(this, arguments);
    /**
     * @description
     * The parent form for the control.
     *
     * @internal
     */

    _this._parent = null;
    /**
     * @description
     * The name for the control
     */

    _this.name = null;
    /**
     * @description
     * The value accessor for the control
     */

    _this.valueAccessor = null;
    /**
     * @description
     * The uncomposed array of synchronous validators for the control
     *
     * @internal
     */

    _this._rawValidators = [];
    /**
     * @description
     * The uncomposed array of async validators for the control
     *
     * @internal
     */

    _this._rawAsyncValidators = [];
    return _this;
  }
  /**
   * @description
   * The registered synchronous validator function for the control
   *
   * @throws An exception that this method is not implemented
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(NgControl, [{
    key: "validator",
    get: function get() {
      return unimplemented();
    }
    /**
     * @description
     * The registered async validator function for the control
     *
     * @throws An exception that this method is not implemented
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return unimplemented();
    }
  }]);

  return NgControl;
}(AbstractControlDirective);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var AbstractControlStatus = /*#__PURE__*/function () {
  function AbstractControlStatus(cd) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, AbstractControlStatus);

    this._cd = cd;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(AbstractControlStatus, [{
    key: "ngClassUntouched",
    get: function get() {
      return this._cd.control ? this._cd.control.untouched : false;
    }
  }, {
    key: "ngClassTouched",
    get: function get() {
      return this._cd.control ? this._cd.control.touched : false;
    }
  }, {
    key: "ngClassPristine",
    get: function get() {
      return this._cd.control ? this._cd.control.pristine : false;
    }
  }, {
    key: "ngClassDirty",
    get: function get() {
      return this._cd.control ? this._cd.control.dirty : false;
    }
  }, {
    key: "ngClassValid",
    get: function get() {
      return this._cd.control ? this._cd.control.valid : false;
    }
  }, {
    key: "ngClassInvalid",
    get: function get() {
      return this._cd.control ? this._cd.control.invalid : false;
    }
  }, {
    key: "ngClassPending",
    get: function get() {
      return this._cd.control ? this._cd.control.pending : false;
    }
  }]);

  return AbstractControlStatus;
}();

var ngControlStatusHost = {
  '[class.ng-untouched]': 'ngClassUntouched',
  '[class.ng-touched]': 'ngClassTouched',
  '[class.ng-pristine]': 'ngClassPristine',
  '[class.ng-dirty]': 'ngClassDirty',
  '[class.ng-valid]': 'ngClassValid',
  '[class.ng-invalid]': 'ngClassInvalid',
  '[class.ng-pending]': 'ngClassPending'
};
/**
 * @description
 * Directive automatically applied to Angular form controls that sets CSS classes
 * based on control status.
 *
 * @usageNotes
 *
 * ### CSS classes applied
 *
 * The following classes are applied as the properties become true:
 *
 * * ng-valid
 * * ng-invalid
 * * ng-pending
 * * ng-pristine
 * * ng-dirty
 * * ng-untouched
 * * ng-touched
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var NgControlStatus = /*#__PURE__*/function (_AbstractControlStatu) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgControlStatus, _AbstractControlStatu);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgControlStatus);

  function NgControlStatus(cd) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgControlStatus);

    return _super3.call(this, cd);
  }

  return NgControlStatus;
}(AbstractControlStatus);

NgControlStatus.ɵfac = function NgControlStatus_Factory(t) {
  return new (t || NgControlStatus)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NgControl, 2));
};

NgControlStatus.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NgControlStatus,
  selectors: [["", "formControlName", ""], ["", "ngModel", ""], ["", "formControl", ""]],
  hostVars: 14,
  hostBindings: function NgControlStatus_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵclassProp"]("ng-untouched", ctx.ngClassUntouched)("ng-touched", ctx.ngClassTouched)("ng-pristine", ctx.ngClassPristine)("ng-dirty", ctx.ngClassDirty)("ng-valid", ctx.ngClassValid)("ng-invalid", ctx.ngClassInvalid)("ng-pending", ctx.ngClassPending);
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});

NgControlStatus.ctorParameters = function () {
  return [{
    type: NgControl,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NgControlStatus, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formControlName],[ngModel],[formControl]',
      host: ngControlStatusHost
    }]
  }], function () {
    return [{
      type: NgControl,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }]
    }];
  }, null);
})();
/**
 * @description
 * Directive automatically applied to Angular form groups that sets CSS classes
 * based on control status (valid/invalid/dirty/etc).
 *
 * @see `NgControlStatus`
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */


var NgControlStatusGroup = /*#__PURE__*/function (_AbstractControlStatu2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgControlStatusGroup, _AbstractControlStatu2);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgControlStatusGroup);

  function NgControlStatusGroup(cd) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgControlStatusGroup);

    return _super4.call(this, cd);
  }

  return NgControlStatusGroup;
}(AbstractControlStatus);

NgControlStatusGroup.ɵfac = function NgControlStatusGroup_Factory(t) {
  return new (t || NgControlStatusGroup)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](ControlContainer, 2));
};

NgControlStatusGroup.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NgControlStatusGroup,
  selectors: [["", "formGroupName", ""], ["", "formArrayName", ""], ["", "ngModelGroup", ""], ["", "formGroup", ""], ["form", 3, "ngNoForm", ""], ["", "ngForm", ""]],
  hostVars: 14,
  hostBindings: function NgControlStatusGroup_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵclassProp"]("ng-untouched", ctx.ngClassUntouched)("ng-touched", ctx.ngClassTouched)("ng-pristine", ctx.ngClassPristine)("ng-dirty", ctx.ngClassDirty)("ng-valid", ctx.ngClassValid)("ng-invalid", ctx.ngClassInvalid)("ng-pending", ctx.ngClassPending);
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});

NgControlStatusGroup.ctorParameters = function () {
  return [{
    type: ControlContainer,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NgControlStatusGroup, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]',
      host: ngControlStatusHost
    }]
  }], function () {
    return [{
      type: ControlContainer,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function isEmptyInputValue(value) {
  // we don't check for string here so it also works with arrays
  return value == null || value.length === 0;
}

function hasValidLength(value) {
  // non-strict comparison is intentional, to check for both `null` and `undefined` values
  return value != null && typeof value.length === 'number';
}
/**
 * @description
 * An `InjectionToken` for registering additional synchronous validators used with
 * `AbstractControl`s.
 *
 * @see `NG_ASYNC_VALIDATORS`
 *
 * @usageNotes
 *
 * ### Providing a custom validator
 *
 * The following example registers a custom validator directive. Adding the validator to the
 * existing collection of validators requires the `multi: true` option.
 *
 * ```typescript
 * @Directive({
 *   selector: '[customValidator]',
 *   providers: [{provide: NG_VALIDATORS, useExisting: CustomValidatorDirective, multi: true}]
 * })
 * class CustomValidatorDirective implements Validator {
 *   validate(control: AbstractControl): ValidationErrors | null {
 *     return { 'custom': true };
 *   }
 * }
 * ```
 *
 * @publicApi
 */


var NG_VALIDATORS = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('NgValidators');
/**
 * @description
 * An `InjectionToken` for registering additional asynchronous validators used with
 * `AbstractControl`s.
 *
 * @see `NG_VALIDATORS`
 *
 * @publicApi
 */

var NG_ASYNC_VALIDATORS = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('NgAsyncValidators');
/**
 * A regular expression that matches valid e-mail addresses.
 *
 * At a high level, this regexp matches e-mail addresses of the format `local-part@tld`, where:
 * - `local-part` consists of one or more of the allowed characters (alphanumeric and some
 *   punctuation symbols).
 * - `local-part` cannot begin or end with a period (`.`).
 * - `local-part` cannot be longer than 64 characters.
 * - `tld` consists of one or more `labels` separated by periods (`.`). For example `localhost` or
 *   `foo.com`.
 * - A `label` consists of one or more of the allowed characters (alphanumeric, dashes (`-`) and
 *   periods (`.`)).
 * - A `label` cannot begin or end with a dash (`-`) or a period (`.`).
 * - A `label` cannot be longer than 63 characters.
 * - The whole address cannot be longer than 254 characters.
 *
 * ## Implementation background
 *
 * This regexp was ported over from AngularJS (see there for git history):
 * https://github.com/angular/angular.js/blob/c133ef836/src/ng/directive/input.js#L27
 * It is based on the
 * [WHATWG version](https://html.spec.whatwg.org/multipage/input.html#valid-e-mail-address) with
 * some enhancements to incorporate more RFC rules (such as rules related to domain names and the
 * lengths of different parts of the address). The main differences from the WHATWG version are:
 *   - Disallow `local-part` to begin or end with a period (`.`).
 *   - Disallow `local-part` length to exceed 64 characters.
 *   - Disallow total address length to exceed 254 characters.
 *
 * See [this commit](https://github.com/angular/angular.js/commit/f3f5cf72e) for more details.
 */

var EMAIL_REGEXP = /^(?=.{1,254}$)(?=.{1,64}@)[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-zA-Z0-9!#$%&'*+/=?^_`{|}~-]+)*@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/;
/**
 * @description
 * Provides a set of built-in validators that can be used by form controls.
 *
 * A validator is a function that processes a `FormControl` or collection of
 * controls and returns an error map or null. A null map means that validation has passed.
 *
 * @see [Form Validation](/guide/form-validation)
 *
 * @publicApi
 */

var Validators = /*#__PURE__*/function () {
  function Validators() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, Validators);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(Validators, null, [{
    key: "min",

    /**
     * @description
     * Validator that requires the control's value to be greater than or equal to the provided number.
     * The validator exists only as a function and not as a directive.
     *
     * @usageNotes
     *
     * ### Validate against a minimum of 3
     *
     * ```typescript
     * const control = new FormControl(2, Validators.min(3));
     *
     * console.log(control.errors); // {min: {min: 3, actual: 2}}
     * ```
     *
     * @returns A validator function that returns an error map with the
     * `min` property if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */
    value: function min(_min) {
      return function (control) {
        if (isEmptyInputValue(control.value) || isEmptyInputValue(_min)) {
          return null; // don't validate empty values to allow optional controls
        }

        var value = parseFloat(control.value); // Controls with NaN values after parsing should be treated as not having a
        // minimum, per the HTML forms spec: https://www.w3.org/TR/html5/forms.html#attr-input-min

        return !isNaN(value) && value < _min ? {
          'min': {
            'min': _min,
            'actual': control.value
          }
        } : null;
      };
    }
    /**
     * @description
     * Validator that requires the control's value to be less than or equal to the provided number.
     * The validator exists only as a function and not as a directive.
     *
     * @usageNotes
     *
     * ### Validate against a maximum of 15
     *
     * ```typescript
     * const control = new FormControl(16, Validators.max(15));
     *
     * console.log(control.errors); // {max: {max: 15, actual: 16}}
     * ```
     *
     * @returns A validator function that returns an error map with the
     * `max` property if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "max",
    value: function max(_max) {
      return function (control) {
        if (isEmptyInputValue(control.value) || isEmptyInputValue(_max)) {
          return null; // don't validate empty values to allow optional controls
        }

        var value = parseFloat(control.value); // Controls with NaN values after parsing should be treated as not having a
        // maximum, per the HTML forms spec: https://www.w3.org/TR/html5/forms.html#attr-input-max

        return !isNaN(value) && value > _max ? {
          'max': {
            'max': _max,
            'actual': control.value
          }
        } : null;
      };
    }
    /**
     * @description
     * Validator that requires the control have a non-empty value.
     *
     * @usageNotes
     *
     * ### Validate that the field is non-empty
     *
     * ```typescript
     * const control = new FormControl('', Validators.required);
     *
     * console.log(control.errors); // {required: true}
     * ```
     *
     * @returns An error map with the `required` property
     * if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "required",
    value: function required(control) {
      return isEmptyInputValue(control.value) ? {
        'required': true
      } : null;
    }
    /**
     * @description
     * Validator that requires the control's value be true. This validator is commonly
     * used for required checkboxes.
     *
     * @usageNotes
     *
     * ### Validate that the field value is true
     *
     * ```typescript
     * const control = new FormControl('', Validators.requiredTrue);
     *
     * console.log(control.errors); // {required: true}
     * ```
     *
     * @returns An error map that contains the `required` property
     * set to `true` if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "requiredTrue",
    value: function requiredTrue(control) {
      return control.value === true ? null : {
        'required': true
      };
    }
    /**
     * @description
     * Validator that requires the control's value pass an email validation test.
     *
     * Tests the value using a [regular
     * expression](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions)
     * pattern suitable for common usecases. The pattern is based on the definition of a valid email
     * address in the [WHATWG HTML
     * specification](https://html.spec.whatwg.org/multipage/input.html#valid-e-mail-address) with
     * some enhancements to incorporate more RFC rules (such as rules related to domain names and the
     * lengths of different parts of the address).
     *
     * The differences from the WHATWG version include:
     * - Disallow `local-part` (the part before the `@` symbol) to begin or end with a period (`.`).
     * - Disallow `local-part` to be longer than 64 characters.
     * - Disallow the whole address to be longer than 254 characters.
     *
     * If this pattern does not satisfy your business needs, you can use `Validators.pattern()` to
     * validate the value against a different pattern.
     *
     * @usageNotes
     *
     * ### Validate that the field matches a valid email pattern
     *
     * ```typescript
     * const control = new FormControl('bad@', Validators.email);
     *
     * console.log(control.errors); // {email: true}
     * ```
     *
     * @returns An error map with the `email` property
     * if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "email",
    value: function email(control) {
      if (isEmptyInputValue(control.value)) {
        return null; // don't validate empty values to allow optional controls
      }

      return EMAIL_REGEXP.test(control.value) ? null : {
        'email': true
      };
    }
    /**
     * @description
     * Validator that requires the length of the control's value to be greater than or equal
     * to the provided minimum length. This validator is also provided by default if you use the
     * the HTML5 `minlength` attribute. Note that the `minLength` validator is intended to be used
     * only for types that have a numeric `length` property, such as strings or arrays. The
     * `minLength` validator logic is also not invoked for values when their `length` property is 0
     * (for example in case of an empty string or an empty array), to support optional controls. You
     * can use the standard `required` validator if empty values should not be considered valid.
     *
     * @usageNotes
     *
     * ### Validate that the field has a minimum of 3 characters
     *
     * ```typescript
     * const control = new FormControl('ng', Validators.minLength(3));
     *
     * console.log(control.errors); // {minlength: {requiredLength: 3, actualLength: 2}}
     * ```
     *
     * ```html
     * <input minlength="5">
     * ```
     *
     * @returns A validator function that returns an error map with the
     * `minlength` if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "minLength",
    value: function minLength(_minLength) {
      return function (control) {
        if (isEmptyInputValue(control.value) || !hasValidLength(control.value)) {
          // don't validate empty values to allow optional controls
          // don't validate values without `length` property
          return null;
        }

        return control.value.length < _minLength ? {
          'minlength': {
            'requiredLength': _minLength,
            'actualLength': control.value.length
          }
        } : null;
      };
    }
    /**
     * @description
     * Validator that requires the length of the control's value to be less than or equal
     * to the provided maximum length. This validator is also provided by default if you use the
     * the HTML5 `maxlength` attribute. Note that the `maxLength` validator is intended to be used
     * only for types that have a numeric `length` property, such as strings or arrays.
     *
     * @usageNotes
     *
     * ### Validate that the field has maximum of 5 characters
     *
     * ```typescript
     * const control = new FormControl('Angular', Validators.maxLength(5));
     *
     * console.log(control.errors); // {maxlength: {requiredLength: 5, actualLength: 7}}
     * ```
     *
     * ```html
     * <input maxlength="5">
     * ```
     *
     * @returns A validator function that returns an error map with the
     * `maxlength` property if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "maxLength",
    value: function maxLength(_maxLength) {
      return function (control) {
        return hasValidLength(control.value) && control.value.length > _maxLength ? {
          'maxlength': {
            'requiredLength': _maxLength,
            'actualLength': control.value.length
          }
        } : null;
      };
    }
    /**
     * @description
     * Validator that requires the control's value to match a regex pattern. This validator is also
     * provided by default if you use the HTML5 `pattern` attribute.
     *
     * @usageNotes
     *
     * ### Validate that the field only contains letters or spaces
     *
     * ```typescript
     * const control = new FormControl('1', Validators.pattern('[a-zA-Z ]*'));
     *
     * console.log(control.errors); // {pattern: {requiredPattern: '^[a-zA-Z ]*$', actualValue: '1'}}
     * ```
     *
     * ```html
     * <input pattern="[a-zA-Z ]*">
     * ```
     *
     * @param pattern A regular expression to be used as is to test the values, or a string.
     * If a string is passed, the `^` character is prepended and the `$` character is
     * appended to the provided string (if not already present), and the resulting regular
     * expression is used to test the values.
     *
     * @returns A validator function that returns an error map with the
     * `pattern` property if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "pattern",
    value: function pattern(_pattern) {
      if (!_pattern) return Validators.nullValidator;
      var regex;
      var regexStr;

      if (typeof _pattern === 'string') {
        regexStr = '';
        if (_pattern.charAt(0) !== '^') regexStr += '^';
        regexStr += _pattern;
        if (_pattern.charAt(_pattern.length - 1) !== '$') regexStr += '$';
        regex = new RegExp(regexStr);
      } else {
        regexStr = _pattern.toString();
        regex = _pattern;
      }

      return function (control) {
        if (isEmptyInputValue(control.value)) {
          return null; // don't validate empty values to allow optional controls
        }

        var value = control.value;
        return regex.test(value) ? null : {
          'pattern': {
            'requiredPattern': regexStr,
            'actualValue': value
          }
        };
      };
    }
    /**
     * @description
     * Validator that performs no operation.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "nullValidator",
    value: function nullValidator(control) {
      return null;
    }
  }, {
    key: "compose",
    value: function compose(validators) {
      if (!validators) return null;
      var presentValidators = validators.filter(isPresent);
      if (presentValidators.length == 0) return null;
      return function (control) {
        return mergeErrors(executeValidators(control, presentValidators));
      };
    }
    /**
     * @description
     * Compose multiple async validators into a single function that returns the union
     * of the individual error objects for the provided control.
     *
     * @returns A validator function that returns an error map with the
     * merged error objects of the async validators if the validation check fails, otherwise `null`.
     *
     * @see `updateValueAndValidity()`
     *
     */

  }, {
    key: "composeAsync",
    value: function composeAsync(validators) {
      if (!validators) return null;
      var presentValidators = validators.filter(isPresent);
      if (presentValidators.length == 0) return null;
      return function (control) {
        var observables = executeValidators(control, presentValidators).map(toObservable);
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_9__["forkJoin"])(observables).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_10__["map"])(mergeErrors));
      };
    }
  }]);

  return Validators;
}();

function isPresent(o) {
  return o != null;
}

function toObservable(r) {
  var obs = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵisPromise"])(r) ? Object(rxjs__WEBPACK_IMPORTED_MODULE_9__["from"])(r) : r;

  if (!Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵisObservable"])(obs) && (typeof ngDevMode === 'undefined' || ngDevMode)) {
    throw new Error("Expected validator to return Promise or Observable.");
  }

  return obs;
}

function mergeErrors(arrayOfErrors) {
  var res = {}; // Not using Array.reduce here due to a Chrome 80 bug
  // https://bugs.chromium.org/p/chromium/issues/detail?id=1049982

  arrayOfErrors.forEach(function (errors) {
    res = errors != null ? Object.assign(Object.assign({}, res), errors) : res;
  });
  return Object.keys(res).length === 0 ? null : res;
}

function executeValidators(control, validators) {
  return validators.map(function (validator) {
    return validator(control);
  });
}

function isValidatorFn(validator) {
  return !validator.validate;
}
/**
 * Given the list of validators that may contain both functions as well as classes, return the list
 * of validator functions (convert validator classes into validator functions). This is needed to
 * have consistent structure in validators list before composing them.
 *
 * @param validators The set of validators that may contain validators both in plain function form
 *     as well as represented as a validator class.
 */


function normalizeValidators(validators) {
  return validators.map(function (validator) {
    return isValidatorFn(validator) ? validator : function (c) {
      return validator.validate(c);
    };
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NUMBER_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return NumberValueAccessor;
  }),
  multi: true
};
/**
 * @description
 * The `ControlValueAccessor` for writing a number value and listening to number input changes.
 * The value accessor is used by the `FormControlDirective`, `FormControlName`, and `NgModel`
 * directives.
 *
 * @usageNotes
 *
 * ### Using a number input with a reactive form.
 *
 * The following example shows how to use a number input with a reactive form.
 *
 * ```ts
 * const totalCountControl = new FormControl();
 * ```
 *
 * ```
 * <input type="number" [formControl]="totalCountControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var NumberValueAccessor = /*#__PURE__*/function () {
  function NumberValueAccessor(_renderer, _elementRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NumberValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    /**
     * The registered callback function called when a change or input event occurs on the input
     * element.
     * @nodoc
     */

    this.onChange = function (_) {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};
  }
  /**
   * Sets the "value" property on the input element.
   * @nodoc
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(NumberValueAccessor, [{
    key: "writeValue",
    value: function writeValue(value) {
      // The value needs to be normalized for IE9, otherwise it is set to 'null' when null
      var normalizedValue = value == null ? '' : value;

      this._renderer.setProperty(this._elementRef.nativeElement, 'value', normalizedValue);
    }
    /**
     * Registers a function called when the control value changes.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      this.onChange = function (value) {
        fn(value == '' ? null : parseFloat(value));
      };
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
  }]);

  return NumberValueAccessor;
}();

NumberValueAccessor.ɵfac = function NumberValueAccessor_Factory(t) {
  return new (t || NumberValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]));
};

NumberValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NumberValueAccessor,
  selectors: [["input", "type", "number", "formControlName", ""], ["input", "type", "number", "formControl", ""], ["input", "type", "number", "ngModel", ""]],
  hostBindings: function NumberValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("input", function NumberValueAccessor_input_HostBindingHandler($event) {
        return ctx.onChange($event.target.value);
      })("blur", function NumberValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      });
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([NUMBER_VALUE_ACCESSOR])]
});

NumberValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NumberValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]',
      host: {
        '(input)': 'onChange($event.target.value)',
        '(blur)': 'onTouched()'
      },
      providers: [NUMBER_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var RADIO_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return RadioControlValueAccessor;
  }),
  multi: true
};

function throwNameError() {
  throw new Error("\n      If you define both a name and a formControlName attribute on your radio button, their values\n      must match. Ex: <input type=\"radio\" formControlName=\"food\" name=\"food\">\n    ");
}
/**
 * @description
 * Class used by Angular to track radio buttons. For internal use only.
 */


var RadioControlRegistry = /*#__PURE__*/function () {
  function RadioControlRegistry() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, RadioControlRegistry);

    this._accessors = [];
  }
  /**
   * @description
   * Adds a control to the internal registry. For internal use only.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(RadioControlRegistry, [{
    key: "add",
    value: function add(control, accessor) {
      this._accessors.push([control, accessor]);
    }
    /**
     * @description
     * Removes a control from the internal registry. For internal use only.
     */

  }, {
    key: "remove",
    value: function remove(accessor) {
      for (var i = this._accessors.length - 1; i >= 0; --i) {
        if (this._accessors[i][1] === accessor) {
          this._accessors.splice(i, 1);

          return;
        }
      }
    }
    /**
     * @description
     * Selects a radio button. For internal use only.
     */

  }, {
    key: "select",
    value: function select(accessor) {
      var _this2 = this;

      this._accessors.forEach(function (c) {
        if (_this2._isSameGroup(c, accessor) && c[1] !== accessor) {
          c[1].fireUncheck(accessor.value);
        }
      });
    }
  }, {
    key: "_isSameGroup",
    value: function _isSameGroup(controlPair, accessor) {
      if (!controlPair[0].control) return false;
      return controlPair[0]._parent === accessor._control._parent && controlPair[1].name === accessor.name;
    }
  }]);

  return RadioControlRegistry;
}();

RadioControlRegistry.ɵfac = function RadioControlRegistry_Factory(t) {
  return new (t || RadioControlRegistry)();
};

RadioControlRegistry.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: RadioControlRegistry,
  factory: RadioControlRegistry.ɵfac
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](RadioControlRegistry, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [];
  }, null);
})();
/**
 * @description
 * The `ControlValueAccessor` for writing radio control values and listening to radio control
 * changes. The value accessor is used by the `FormControlDirective`, `FormControlName`, and
 * `NgModel` directives.
 *
 * @usageNotes
 *
 * ### Using radio buttons with reactive form directives
 *
 * The follow example shows how to use radio buttons in a reactive form. When using radio buttons in
 * a reactive form, radio buttons in the same group should have the same `formControlName`.
 * Providing a `name` attribute is optional.
 *
 * {@example forms/ts/reactiveRadioButtons/reactive_radio_button_example.ts region='Reactive'}
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */


var RadioControlValueAccessor = /*#__PURE__*/function () {
  function RadioControlValueAccessor(_renderer, _elementRef, _registry, _injector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, RadioControlValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    this._registry = _registry;
    this._injector = _injector;
    /**
     * The registered callback function called when a change event occurs on the input element.
     * @nodoc
     */

    this.onChange = function () {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(RadioControlValueAccessor, [{
    key: "ngOnInit",
    value: function ngOnInit() {
      this._control = this._injector.get(NgControl);

      this._checkName();

      this._registry.add(this._control, this);
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      this._registry.remove(this);
    }
    /**
     * Sets the "checked" property value on the radio input element.
     * @nodoc
     */

  }, {
    key: "writeValue",
    value: function writeValue(value) {
      this._state = value === this.value;

      this._renderer.setProperty(this._elementRef.nativeElement, 'checked', this._state);
    }
    /**
     * Registers a function called when the control value changes.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      var _this3 = this;

      this._fn = fn;

      this.onChange = function () {
        fn(_this3.value);

        _this3._registry.select(_this3);
      };
    }
    /**
     * Sets the "value" on the radio input element and unchecks it.
     *
     * @param value
     */

  }, {
    key: "fireUncheck",
    value: function fireUncheck(value) {
      this.writeValue(value);
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
  }, {
    key: "_checkName",
    value: function _checkName() {
      if (this.name && this.formControlName && this.name !== this.formControlName && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        throwNameError();
      }

      if (!this.name && this.formControlName) this.name = this.formControlName;
    }
  }]);

  return RadioControlValueAccessor;
}();

RadioControlValueAccessor.ɵfac = function RadioControlValueAccessor_Factory(t) {
  return new (t || RadioControlValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](RadioControlRegistry), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Injector"]));
};

RadioControlValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: RadioControlValueAccessor,
  selectors: [["input", "type", "radio", "formControlName", ""], ["input", "type", "radio", "formControl", ""], ["input", "type", "radio", "ngModel", ""]],
  hostBindings: function RadioControlValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("change", function RadioControlValueAccessor_change_HostBindingHandler() {
        return ctx.onChange();
      })("blur", function RadioControlValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      });
    }
  },
  inputs: {
    name: "name",
    formControlName: "formControlName",
    value: "value"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([RADIO_VALUE_ACCESSOR])]
});

RadioControlValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }, {
    type: RadioControlRegistry
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injector"]
  }];
};

RadioControlValueAccessor.propDecorators = {
  name: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }],
  formControlName: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }],
  value: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](RadioControlValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'input[type=radio][formControlName],input[type=radio][formControl],input[type=radio][ngModel]',
      host: {
        '(change)': 'onChange()',
        '(blur)': 'onTouched()'
      },
      providers: [RADIO_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }, {
      type: RadioControlRegistry
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injector"]
    }];
  }, {
    name: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }],
    formControlName: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }],
    value: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var RANGE_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return RangeValueAccessor;
  }),
  multi: true
};
/**
 * @description
 * The `ControlValueAccessor` for writing a range value and listening to range input changes.
 * The value accessor is used by the `FormControlDirective`, `FormControlName`, and  `NgModel`
 * directives.
 *
 * @usageNotes
 *
 * ### Using a range input with a reactive form
 *
 * The following example shows how to use a range input with a reactive form.
 *
 * ```ts
 * const ageControl = new FormControl();
 * ```
 *
 * ```
 * <input type="range" [formControl]="ageControl">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var RangeValueAccessor = /*#__PURE__*/function () {
  function RangeValueAccessor(_renderer, _elementRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, RangeValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    /**
     * The registered callback function called when a change or input event occurs on the input
     * element.
     * @nodoc
     */

    this.onChange = function (_) {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};
  }
  /**
   * Sets the "value" property on the input element.
   * @nodoc
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(RangeValueAccessor, [{
    key: "writeValue",
    value: function writeValue(value) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'value', parseFloat(value));
    }
    /**
     * Registers a function called when the control value changes.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      this.onChange = function (value) {
        fn(value == '' ? null : parseFloat(value));
      };
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the range input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
  }]);

  return RangeValueAccessor;
}();

RangeValueAccessor.ɵfac = function RangeValueAccessor_Factory(t) {
  return new (t || RangeValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]));
};

RangeValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: RangeValueAccessor,
  selectors: [["input", "type", "range", "formControlName", ""], ["input", "type", "range", "formControl", ""], ["input", "type", "range", "ngModel", ""]],
  hostBindings: function RangeValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("change", function RangeValueAccessor_change_HostBindingHandler($event) {
        return ctx.onChange($event.target.value);
      })("input", function RangeValueAccessor_input_HostBindingHandler($event) {
        return ctx.onChange($event.target.value);
      })("blur", function RangeValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      });
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([RANGE_VALUE_ACCESSOR])]
});

RangeValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](RangeValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'input[type=range][formControlName],input[type=range][formControl],input[type=range][ngModel]',
      host: {
        '(change)': 'onChange($event.target.value)',
        '(input)': 'onChange($event.target.value)',
        '(blur)': 'onTouched()'
      },
      providers: [RANGE_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var FormErrorExamples = {
  formControlName: "\n    <div [formGroup]=\"myGroup\">\n      <input formControlName=\"firstName\">\n    </div>\n\n    In your class:\n\n    this.myGroup = new FormGroup({\n       firstName: new FormControl()\n    });",
  formGroupName: "\n    <div [formGroup]=\"myGroup\">\n       <div formGroupName=\"person\">\n          <input formControlName=\"firstName\">\n       </div>\n    </div>\n\n    In your class:\n\n    this.myGroup = new FormGroup({\n       person: new FormGroup({ firstName: new FormControl() })\n    });",
  formArrayName: "\n    <div [formGroup]=\"myGroup\">\n      <div formArrayName=\"cities\">\n        <div *ngFor=\"let city of cityArray.controls; index as i\">\n          <input [formControlName]=\"i\">\n        </div>\n      </div>\n    </div>\n\n    In your class:\n\n    this.cityArray = new FormArray([new FormControl('SF')]);\n    this.myGroup = new FormGroup({\n      cities: this.cityArray\n    });",
  ngModelGroup: "\n    <form>\n       <div ngModelGroup=\"person\">\n          <input [(ngModel)]=\"person.name\" name=\"firstName\">\n       </div>\n    </form>",
  ngModelWithFormGroup: "\n    <div [formGroup]=\"myGroup\">\n       <input formControlName=\"firstName\">\n       <input [(ngModel)]=\"showMoreControls\" [ngModelOptions]=\"{standalone: true}\">\n    </div>\n  "
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var ReactiveErrors = /*#__PURE__*/function () {
  function ReactiveErrors() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ReactiveErrors);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(ReactiveErrors, null, [{
    key: "controlParentException",
    value: function controlParentException() {
      throw new Error("formControlName must be used with a parent formGroup directive.  You'll want to add a formGroup\n       directive and pass it an existing FormGroup instance (you can create one in your class).\n\n      Example:\n\n      ".concat(FormErrorExamples.formControlName));
    }
  }, {
    key: "ngModelGroupException",
    value: function ngModelGroupException() {
      throw new Error("formControlName cannot be used with an ngModelGroup parent. It is only compatible with parents\n       that also have a \"form\" prefix: formGroupName, formArrayName, or formGroup.\n\n       Option 1:  Update the parent to be formGroupName (reactive form strategy)\n\n        ".concat(FormErrorExamples.formGroupName, "\n\n        Option 2: Use ngModel instead of formControlName (template-driven strategy)\n\n        ").concat(FormErrorExamples.ngModelGroup));
    }
  }, {
    key: "missingFormException",
    value: function missingFormException() {
      throw new Error("formGroup expects a FormGroup instance. Please pass one in.\n\n       Example:\n\n       ".concat(FormErrorExamples.formControlName));
    }
  }, {
    key: "groupParentException",
    value: function groupParentException() {
      throw new Error("formGroupName must be used with a parent formGroup directive.  You'll want to add a formGroup\n      directive and pass it an existing FormGroup instance (you can create one in your class).\n\n      Example:\n\n      ".concat(FormErrorExamples.formGroupName));
    }
  }, {
    key: "arrayParentException",
    value: function arrayParentException() {
      throw new Error("formArrayName must be used with a parent formGroup directive.  You'll want to add a formGroup\n       directive and pass it an existing FormGroup instance (you can create one in your class).\n\n        Example:\n\n        ".concat(FormErrorExamples.formArrayName));
    }
  }, {
    key: "disabledAttrWarning",
    value: function disabledAttrWarning() {
      console.warn("\n      It looks like you're using the disabled attribute with a reactive form directive. If you set disabled to true\n      when you set up this control in your component class, the disabled attribute will actually be set in the DOM for\n      you. We recommend using this approach to avoid 'changed after checked' errors.\n\n      Example:\n      form = new FormGroup({\n        first: new FormControl({value: 'Nancy', disabled: true}, Validators.required),\n        last: new FormControl('Drew', Validators.required)\n      });\n    ");
    }
  }, {
    key: "ngModelWarning",
    value: function ngModelWarning(directiveName) {
      console.warn("\n    It looks like you're using ngModel on the same form field as ".concat(directiveName, ".\n    Support for using the ngModel input property and ngModelChange event with\n    reactive form directives has been deprecated in Angular v6 and will be removed\n    in a future version of Angular.\n\n    For more information on this, see our API docs here:\n    https://angular.io/api/forms/").concat(directiveName === 'formControl' ? 'FormControlDirective' : 'FormControlName', "#use-with-ngmodel\n    "));
    }
  }]);

  return ReactiveErrors;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SELECT_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return SelectControlValueAccessor;
  }),
  multi: true
};

function _buildValueString(id, value) {
  if (id == null) return "".concat(value);
  if (value && typeof value === 'object') value = 'Object';
  return "".concat(id, ": ").concat(value).slice(0, 50);
}

function _extractId(valueString) {
  return valueString.split(':')[0];
}
/**
 * @description
 * The `ControlValueAccessor` for writing select control values and listening to select control
 * changes. The value accessor is used by the `FormControlDirective`, `FormControlName`, and
 * `NgModel` directives.
 *
 * @usageNotes
 *
 * ### Using select controls in a reactive form
 *
 * The following examples show how to use a select control in a reactive form.
 *
 * {@example forms/ts/reactiveSelectControl/reactive_select_control_example.ts region='Component'}
 *
 * ### Using select controls in a template-driven form
 *
 * To use a select in a template-driven form, simply add an `ngModel` and a `name`
 * attribute to the main `<select>` tag.
 *
 * {@example forms/ts/selectControl/select_control_example.ts region='Component'}
 *
 * ### Customizing option selection
 *
 * Angular uses object identity to select option. It's possible for the identities of items
 * to change while the data does not. This can happen, for example, if the items are produced
 * from an RPC to the server, and that RPC is re-run. Even if the data hasn't changed, the
 * second response will produce objects with different identities.
 *
 * To customize the default option comparison algorithm, `<select>` supports `compareWith` input.
 * `compareWith` takes a **function** which has two arguments: `option1` and `option2`.
 * If `compareWith` is given, Angular selects option by the return value of the function.
 *
 * ```ts
 * const selectedCountriesControl = new FormControl();
 * ```
 *
 * ```
 * <select [compareWith]="compareFn"  [formControl]="selectedCountriesControl">
 *     <option *ngFor="let country of countries" [ngValue]="country">
 *         {{country.name}}
 *     </option>
 * </select>
 *
 * compareFn(c1: Country, c2: Country): boolean {
 *     return c1 && c2 ? c1.id === c2.id : c1 === c2;
 * }
 * ```
 *
 * **Note:** We listen to the 'change' event because 'input' events aren't fired
 * for selects in Firefox and IE:
 * https://bugzilla.mozilla.org/show_bug.cgi?id=1024350
 * https://developer.microsoft.com/en-us/microsoft-edge/platform/issues/4660045/
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */


var SelectControlValueAccessor = /*#__PURE__*/function () {
  function SelectControlValueAccessor(_renderer, _elementRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, SelectControlValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    /** @internal */

    this._optionMap = new Map();
    /** @internal */

    this._idCounter = 0;
    /**
     * The registered callback function called when a change event occurs on the input element.
     * @nodoc
     */

    this.onChange = function (_) {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};

    this._compareWith = Object.is;
  }
  /**
   * @description
   * Tracks the option comparison algorithm for tracking identities when
   * checking for changes.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(SelectControlValueAccessor, [{
    key: "writeValue",

    /**
     * Sets the "value" property on the input element. The "selectedIndex"
     * property is also set if an ID is provided on the option element.
     * @nodoc
     */
    value: function writeValue(value) {
      this.value = value;

      var id = this._getOptionId(value);

      if (id == null) {
        this._renderer.setProperty(this._elementRef.nativeElement, 'selectedIndex', -1);
      }

      var valueString = _buildValueString(id, value);

      this._renderer.setProperty(this._elementRef.nativeElement, 'value', valueString);
    }
    /**
     * Registers a function called when the control value changes.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      var _this4 = this;

      this.onChange = function (valueString) {
        _this4.value = _this4._getOptionValue(valueString);
        fn(_this4.value);
      };
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the select input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
    /** @internal */

  }, {
    key: "_registerOption",
    value: function _registerOption() {
      return (this._idCounter++).toString();
    }
    /** @internal */

  }, {
    key: "_getOptionId",
    value: function _getOptionId(value) {
      for (var _i = 0, _Array$from = Array.from(this._optionMap.keys()); _i < _Array$from.length; _i++) {
        var id = _Array$from[_i];
        if (this._compareWith(this._optionMap.get(id), value)) return id;
      }

      return null;
    }
    /** @internal */

  }, {
    key: "_getOptionValue",
    value: function _getOptionValue(valueString) {
      var id = _extractId(valueString);

      return this._optionMap.has(id) ? this._optionMap.get(id) : valueString;
    }
  }, {
    key: "compareWith",
    set: function set(fn) {
      if (typeof fn !== 'function' && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        throw new Error("compareWith must be a function, but received ".concat(JSON.stringify(fn)));
      }

      this._compareWith = fn;
    }
  }]);

  return SelectControlValueAccessor;
}();

SelectControlValueAccessor.ɵfac = function SelectControlValueAccessor_Factory(t) {
  return new (t || SelectControlValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]));
};

SelectControlValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: SelectControlValueAccessor,
  selectors: [["select", "formControlName", "", 3, "multiple", ""], ["select", "formControl", "", 3, "multiple", ""], ["select", "ngModel", "", 3, "multiple", ""]],
  hostBindings: function SelectControlValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("change", function SelectControlValueAccessor_change_HostBindingHandler($event) {
        return ctx.onChange($event.target.value);
      })("blur", function SelectControlValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      });
    }
  },
  inputs: {
    compareWith: "compareWith"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([SELECT_VALUE_ACCESSOR])]
});

SelectControlValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }];
};

SelectControlValueAccessor.propDecorators = {
  compareWith: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](SelectControlValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]',
      host: {
        '(change)': 'onChange($event.target.value)',
        '(blur)': 'onTouched()'
      },
      providers: [SELECT_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }];
  }, {
    compareWith: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @description
 * Marks `<option>` as dynamic, so Angular can be notified when options change.
 *
 * @see `SelectControlValueAccessor`
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */


var NgSelectOption = /*#__PURE__*/function () {
  function NgSelectOption(_element, _renderer, _select) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgSelectOption);

    this._element = _element;
    this._renderer = _renderer;
    this._select = _select;
    if (this._select) this.id = this._select._registerOption();
  }
  /**
   * @description
   * Tracks the value bound to the option element. Unlike the value binding,
   * ngValue supports binding to objects.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(NgSelectOption, [{
    key: "_setElementValue",

    /** @internal */
    value: function _setElementValue(value) {
      this._renderer.setProperty(this._element.nativeElement, 'value', value);
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this._select) {
        this._select._optionMap.delete(this.id);

        this._select.writeValue(this._select.value);
      }
    }
  }, {
    key: "ngValue",
    set: function set(value) {
      if (this._select == null) return;

      this._select._optionMap.set(this.id, value);

      this._setElementValue(_buildValueString(this.id, value));

      this._select.writeValue(this._select.value);
    }
    /**
     * @description
     * Tracks simple string values bound to the option element.
     * For objects, use the `ngValue` input binding.
     */

  }, {
    key: "value",
    set: function set(value) {
      this._setElementValue(value);

      if (this._select) this._select.writeValue(this._select.value);
    }
  }]);

  return NgSelectOption;
}();

NgSelectOption.ɵfac = function NgSelectOption_Factory(t) {
  return new (t || NgSelectOption)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](SelectControlValueAccessor, 9));
};

NgSelectOption.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NgSelectOption,
  selectors: [["option"]],
  inputs: {
    ngValue: "ngValue",
    value: "value"
  }
});

NgSelectOption.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: SelectControlValueAccessor,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }]
  }];
};

NgSelectOption.propDecorators = {
  ngValue: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngValue']
  }],
  value: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['value']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NgSelectOption, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'option'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: SelectControlValueAccessor,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }]
    }];
  }, {
    ngValue: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngValue']
    }],
    value: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['value']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SELECT_MULTIPLE_VALUE_ACCESSOR = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return SelectMultipleControlValueAccessor;
  }),
  multi: true
};

function _buildValueString$1(id, value) {
  if (id == null) return "".concat(value);
  if (typeof value === 'string') value = "'".concat(value, "'");
  if (value && typeof value === 'object') value = 'Object';
  return "".concat(id, ": ").concat(value).slice(0, 50);
}

function _extractId$1(valueString) {
  return valueString.split(':')[0];
}
/** Mock interface for HTMLCollection */


var HTMLCollection = function HTMLCollection() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HTMLCollection);
};
/**
 * @description
 * The `ControlValueAccessor` for writing multi-select control values and listening to multi-select
 * control changes. The value accessor is used by the `FormControlDirective`, `FormControlName`, and
 * `NgModel` directives.
 *
 * @see `SelectControlValueAccessor`
 *
 * @usageNotes
 *
 * ### Using a multi-select control
 *
 * The follow example shows you how to use a multi-select control with a reactive form.
 *
 * ```ts
 * const countryControl = new FormControl();
 * ```
 *
 * ```
 * <select multiple name="countries" [formControl]="countryControl">
 *   <option *ngFor="let country of countries" [ngValue]="country">
 *     {{ country.name }}
 *   </option>
 * </select>
 * ```
 *
 * ### Customizing option selection
 *
 * To customize the default option comparison algorithm, `<select>` supports `compareWith` input.
 * See the `SelectControlValueAccessor` for usage.
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */


var SelectMultipleControlValueAccessor = /*#__PURE__*/function () {
  function SelectMultipleControlValueAccessor(_renderer, _elementRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, SelectMultipleControlValueAccessor);

    this._renderer = _renderer;
    this._elementRef = _elementRef;
    /** @internal */

    this._optionMap = new Map();
    /** @internal */

    this._idCounter = 0;
    /**
     * The registered callback function called when a change event occurs on the input element.
     * @nodoc
     */

    this.onChange = function (_) {};
    /**
     * The registered callback function called when a blur event occurs on the input element.
     * @nodoc
     */


    this.onTouched = function () {};

    this._compareWith = Object.is;
  }
  /**
   * @description
   * Tracks the option comparison algorithm for tracking identities when
   * checking for changes.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(SelectMultipleControlValueAccessor, [{
    key: "writeValue",

    /**
     * Sets the "value" property on one or of more of the select's options.
     * @nodoc
     */
    value: function writeValue(value) {
      var _this5 = this;

      this.value = value;
      var optionSelectedStateSetter;

      if (Array.isArray(value)) {
        // convert values to ids
        var ids = value.map(function (v) {
          return _this5._getOptionId(v);
        });

        optionSelectedStateSetter = function optionSelectedStateSetter(opt, o) {
          opt._setSelected(ids.indexOf(o.toString()) > -1);
        };
      } else {
        optionSelectedStateSetter = function optionSelectedStateSetter(opt, o) {
          opt._setSelected(false);
        };
      }

      this._optionMap.forEach(optionSelectedStateSetter);
    }
    /**
     * Registers a function called when the control value changes
     * and writes an array of the selected options.
     * @nodoc
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      var _this6 = this;

      this.onChange = function (_) {
        var selected = [];

        if (_.selectedOptions !== undefined) {
          var options = _.selectedOptions;

          for (var i = 0; i < options.length; i++) {
            var opt = options.item(i);

            var val = _this6._getOptionValue(opt.value);

            selected.push(val);
          }
        } // Degrade on IE
        else {
            var _options = _.options;

            for (var _i2 = 0; _i2 < _options.length; _i2++) {
              var _opt = _options.item(_i2);

              if (_opt.selected) {
                var _val = _this6._getOptionValue(_opt.value);

                selected.push(_val);
              }
            }
          }

        _this6.value = selected;
        fn(selected);
      };
    }
    /**
     * Registers a function called when the control is touched.
     * @nodoc
     */

  }, {
    key: "registerOnTouched",
    value: function registerOnTouched(fn) {
      this.onTouched = fn;
    }
    /**
     * Sets the "disabled" property on the select input element.
     * @nodoc
     */

  }, {
    key: "setDisabledState",
    value: function setDisabledState(isDisabled) {
      this._renderer.setProperty(this._elementRef.nativeElement, 'disabled', isDisabled);
    }
    /** @internal */

  }, {
    key: "_registerOption",
    value: function _registerOption(value) {
      var id = (this._idCounter++).toString();

      this._optionMap.set(id, value);

      return id;
    }
    /** @internal */

  }, {
    key: "_getOptionId",
    value: function _getOptionId(value) {
      for (var _i3 = 0, _Array$from2 = Array.from(this._optionMap.keys()); _i3 < _Array$from2.length; _i3++) {
        var id = _Array$from2[_i3];
        if (this._compareWith(this._optionMap.get(id)._value, value)) return id;
      }

      return null;
    }
    /** @internal */

  }, {
    key: "_getOptionValue",
    value: function _getOptionValue(valueString) {
      var id = _extractId$1(valueString);

      return this._optionMap.has(id) ? this._optionMap.get(id)._value : valueString;
    }
  }, {
    key: "compareWith",
    set: function set(fn) {
      if (typeof fn !== 'function' && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        throw new Error("compareWith must be a function, but received ".concat(JSON.stringify(fn)));
      }

      this._compareWith = fn;
    }
  }]);

  return SelectMultipleControlValueAccessor;
}();

SelectMultipleControlValueAccessor.ɵfac = function SelectMultipleControlValueAccessor_Factory(t) {
  return new (t || SelectMultipleControlValueAccessor)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]));
};

SelectMultipleControlValueAccessor.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: SelectMultipleControlValueAccessor,
  selectors: [["select", "multiple", "", "formControlName", ""], ["select", "multiple", "", "formControl", ""], ["select", "multiple", "", "ngModel", ""]],
  hostBindings: function SelectMultipleControlValueAccessor_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("change", function SelectMultipleControlValueAccessor_change_HostBindingHandler($event) {
        return ctx.onChange($event.target);
      })("blur", function SelectMultipleControlValueAccessor_blur_HostBindingHandler() {
        return ctx.onTouched();
      });
    }
  },
  inputs: {
    compareWith: "compareWith"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([SELECT_MULTIPLE_VALUE_ACCESSOR])]
});

SelectMultipleControlValueAccessor.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }];
};

SelectMultipleControlValueAccessor.propDecorators = {
  compareWith: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](SelectMultipleControlValueAccessor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'select[multiple][formControlName],select[multiple][formControl],select[multiple][ngModel]',
      host: {
        '(change)': 'onChange($event.target)',
        '(blur)': 'onTouched()'
      },
      providers: [SELECT_MULTIPLE_VALUE_ACCESSOR]
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }];
  }, {
    compareWith: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @description
 * Marks `<option>` as dynamic, so Angular can be notified when options change.
 *
 * @see `SelectMultipleControlValueAccessor`
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */


var ɵNgSelectMultipleOption = /*#__PURE__*/function () {
  function ɵNgSelectMultipleOption(_element, _renderer, _select) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ɵNgSelectMultipleOption);

    this._element = _element;
    this._renderer = _renderer;
    this._select = _select;

    if (this._select) {
      this.id = this._select._registerOption(this);
    }
  }
  /**
   * @description
   * Tracks the value bound to the option element. Unlike the value binding,
   * ngValue supports binding to objects.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(ɵNgSelectMultipleOption, [{
    key: "_setElementValue",

    /** @internal */
    value: function _setElementValue(value) {
      this._renderer.setProperty(this._element.nativeElement, 'value', value);
    }
    /** @internal */

  }, {
    key: "_setSelected",
    value: function _setSelected(selected) {
      this._renderer.setProperty(this._element.nativeElement, 'selected', selected);
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this._select) {
        this._select._optionMap.delete(this.id);

        this._select.writeValue(this._select.value);
      }
    }
  }, {
    key: "ngValue",
    set: function set(value) {
      if (this._select == null) return;
      this._value = value;

      this._setElementValue(_buildValueString$1(this.id, value));

      this._select.writeValue(this._select.value);
    }
    /**
     * @description
     * Tracks simple string values bound to the option element.
     * For objects, use the `ngValue` input binding.
     */

  }, {
    key: "value",
    set: function set(value) {
      if (this._select) {
        this._value = value;

        this._setElementValue(_buildValueString$1(this.id, value));

        this._select.writeValue(this._select.value);
      } else {
        this._setElementValue(value);
      }
    }
  }]);

  return ɵNgSelectMultipleOption;
}();

ɵNgSelectMultipleOption.ɵfac = function ɵNgSelectMultipleOption_Factory(t) {
  return new (t || ɵNgSelectMultipleOption)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](SelectMultipleControlValueAccessor, 9));
};

ɵNgSelectMultipleOption.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: ɵNgSelectMultipleOption,
  selectors: [["option"]],
  inputs: {
    ngValue: "ngValue",
    value: "value"
  }
});

ɵNgSelectMultipleOption.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
  }, {
    type: SelectMultipleControlValueAccessor,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }]
  }];
};

ɵNgSelectMultipleOption.propDecorators = {
  ngValue: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngValue']
  }],
  value: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['value']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](ɵNgSelectMultipleOption, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'option'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ElementRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Renderer2"]
    }, {
      type: SelectMultipleControlValueAccessor,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }]
    }];
  }, {
    ngValue: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngValue']
    }],
    value: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['value']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function controlPath(name, parent) {
  return [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_2__["default"])(parent.path), [name]);
}

function setUpControl(control, dir) {
  if (typeof ngDevMode === 'undefined' || ngDevMode) {
    if (!control) _throwError(dir, 'Cannot find control with');
    if (!dir.valueAccessor) _throwError(dir, 'No value accessor for form control with');
  }

  control.validator = Validators.compose([control.validator, dir.validator]);
  control.asyncValidator = Validators.composeAsync([control.asyncValidator, dir.asyncValidator]);
  dir.valueAccessor.writeValue(control.value);
  setUpViewChangePipeline(control, dir);
  setUpModelChangePipeline(control, dir);
  setUpBlurPipeline(control, dir);

  if (dir.valueAccessor.setDisabledState) {
    control.registerOnDisabledChange(function (isDisabled) {
      dir.valueAccessor.setDisabledState(isDisabled);
    });
  } // re-run validation when validator binding changes, e.g. minlength=3 -> minlength=4


  dir._rawValidators.forEach(function (validator) {
    if (validator.registerOnValidatorChange) validator.registerOnValidatorChange(function () {
      return control.updateValueAndValidity();
    });
  });

  dir._rawAsyncValidators.forEach(function (validator) {
    if (validator.registerOnValidatorChange) validator.registerOnValidatorChange(function () {
      return control.updateValueAndValidity();
    });
  });
}

function cleanUpControl(control, dir) {
  var noop = function noop() {
    if (typeof ngDevMode === 'undefined' || ngDevMode) {
      _noControlError(dir);
    }
  };

  dir.valueAccessor.registerOnChange(noop);
  dir.valueAccessor.registerOnTouched(noop);

  dir._rawValidators.forEach(function (validator) {
    if (validator.registerOnValidatorChange) {
      validator.registerOnValidatorChange(null);
    }
  });

  dir._rawAsyncValidators.forEach(function (validator) {
    if (validator.registerOnValidatorChange) {
      validator.registerOnValidatorChange(null);
    }
  });

  if (control) control._clearChangeFns();
}

function setUpViewChangePipeline(control, dir) {
  dir.valueAccessor.registerOnChange(function (newValue) {
    control._pendingValue = newValue;
    control._pendingChange = true;
    control._pendingDirty = true;
    if (control.updateOn === 'change') updateControl(control, dir);
  });
}

function setUpBlurPipeline(control, dir) {
  dir.valueAccessor.registerOnTouched(function () {
    control._pendingTouched = true;
    if (control.updateOn === 'blur' && control._pendingChange) updateControl(control, dir);
    if (control.updateOn !== 'submit') control.markAsTouched();
  });
}

function updateControl(control, dir) {
  if (control._pendingDirty) control.markAsDirty();
  control.setValue(control._pendingValue, {
    emitModelToViewChange: false
  });
  dir.viewToModelUpdate(control._pendingValue);
  control._pendingChange = false;
}

function setUpModelChangePipeline(control, dir) {
  control.registerOnChange(function (newValue, emitModelEvent) {
    // control -> view
    dir.valueAccessor.writeValue(newValue); // control -> ngModel

    if (emitModelEvent) dir.viewToModelUpdate(newValue);
  });
}

function setUpFormContainer(control, dir) {
  if (control == null && (typeof ngDevMode === 'undefined' || ngDevMode)) _throwError(dir, 'Cannot find control with');
  control.validator = Validators.compose([control.validator, dir.validator]);
  control.asyncValidator = Validators.composeAsync([control.asyncValidator, dir.asyncValidator]);
}

function _noControlError(dir) {
  return _throwError(dir, 'There is no FormControl instance attached to form control element with');
}

function _throwError(dir, message) {
  var messageEnd;

  if (dir.path.length > 1) {
    messageEnd = "path: '".concat(dir.path.join(' -> '), "'");
  } else if (dir.path[0]) {
    messageEnd = "name: '".concat(dir.path, "'");
  } else {
    messageEnd = 'unspecified name attribute';
  }

  throw new Error("".concat(message, " ").concat(messageEnd));
}

function composeValidators(validators) {
  return validators != null ? Validators.compose(normalizeValidators(validators)) : null;
}

function composeAsyncValidators(validators) {
  return validators != null ? Validators.composeAsync(normalizeValidators(validators)) : null;
}

function isPropertyUpdated(changes, viewModel) {
  if (!changes.hasOwnProperty('model')) return false;
  var change = changes['model'];
  if (change.isFirstChange()) return true;
  return !Object.is(viewModel, change.currentValue);
}

var BUILTIN_ACCESSORS = [CheckboxControlValueAccessor, RangeValueAccessor, NumberValueAccessor, SelectControlValueAccessor, SelectMultipleControlValueAccessor, RadioControlValueAccessor];

function isBuiltInAccessor(valueAccessor) {
  return BUILTIN_ACCESSORS.some(function (a) {
    return valueAccessor.constructor === a;
  });
}

function syncPendingControls(form, directives) {
  form._syncPendingControls();

  directives.forEach(function (dir) {
    var control = dir.control;

    if (control.updateOn === 'submit' && control._pendingChange) {
      dir.viewToModelUpdate(control._pendingValue);
      control._pendingChange = false;
    }
  });
} // TODO: vsavkin remove it once https://github.com/angular/angular/issues/3011 is implemented


function selectValueAccessor(dir, valueAccessors) {
  if (!valueAccessors) return null;
  if (!Array.isArray(valueAccessors) && (typeof ngDevMode === 'undefined' || ngDevMode)) _throwError(dir, 'Value accessor was not provided as an array for form control with');
  var defaultAccessor = undefined;
  var builtinAccessor = undefined;
  var customAccessor = undefined;
  valueAccessors.forEach(function (v) {
    if (v.constructor === DefaultValueAccessor) {
      defaultAccessor = v;
    } else if (isBuiltInAccessor(v)) {
      if (builtinAccessor && (typeof ngDevMode === 'undefined' || ngDevMode)) _throwError(dir, 'More than one built-in value accessor matches form control with');
      builtinAccessor = v;
    } else {
      if (customAccessor && (typeof ngDevMode === 'undefined' || ngDevMode)) _throwError(dir, 'More than one custom value accessor matches form control with');
      customAccessor = v;
    }
  });
  if (customAccessor) return customAccessor;
  if (builtinAccessor) return builtinAccessor;
  if (defaultAccessor) return defaultAccessor;

  if (typeof ngDevMode === 'undefined' || ngDevMode) {
    _throwError(dir, 'No valid value accessor for form control with');
  }

  return null;
}

function removeDir(list, el) {
  var index = list.indexOf(el);
  if (index > -1) list.splice(index, 1);
} // TODO(kara): remove after deprecation period


function _ngModelWarning(name, type, instance, warningConfig) {
  if (!Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["isDevMode"])() || warningConfig === 'never') return;

  if ((warningConfig === null || warningConfig === 'once') && !type._ngModelWarningSentOnce || warningConfig === 'always' && !instance._ngModelWarningSent) {
    if (typeof ngDevMode === 'undefined' || ngDevMode) {
      ReactiveErrors.ngModelWarning(name);
    }

    type._ngModelWarningSentOnce = true;
    instance._ngModelWarningSent = true;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Reports that a FormControl is valid, meaning that no errors exist in the input value.
 *
 * @see `status`
 */


var VALID = 'VALID';
/**
 * Reports that a FormControl is invalid, meaning that an error exists in the input value.
 *
 * @see `status`
 */

var INVALID = 'INVALID';
/**
 * Reports that a FormControl is pending, meaning that that async validation is occurring and
 * errors are not yet available for the input value.
 *
 * @see `markAsPending`
 * @see `status`
 */

var PENDING = 'PENDING';
/**
 * Reports that a FormControl is disabled, meaning that the control is exempt from ancestor
 * calculations of validity or value.
 *
 * @see `markAsDisabled`
 * @see `status`
 */

var DISABLED = 'DISABLED';

function _find(control, path, delimiter) {
  if (path == null) return null;

  if (!Array.isArray(path)) {
    path = path.split(delimiter);
  }

  if (Array.isArray(path) && path.length === 0) return null; // Not using Array.reduce here due to a Chrome 80 bug
  // https://bugs.chromium.org/p/chromium/issues/detail?id=1049982

  var controlToFind = control;
  path.forEach(function (name) {
    if (controlToFind instanceof FormGroup) {
      controlToFind = controlToFind.controls.hasOwnProperty(name) ? controlToFind.controls[name] : null;
    } else if (controlToFind instanceof FormArray) {
      controlToFind = controlToFind.at(name) || null;
    } else {
      controlToFind = null;
    }
  });
  return controlToFind;
}
/**
 * Gets validators from either an options object or given validators.
 */


function pickValidators(validatorOrOpts) {
  return (isOptionsObj(validatorOrOpts) ? validatorOrOpts.validators : validatorOrOpts) || null;
}
/**
 * Creates validator function by combining provided validators.
 */


function coerceToValidator(validator) {
  return Array.isArray(validator) ? composeValidators(validator) : validator || null;
}
/**
 * Gets async validators from either an options object or given validators.
 */


function pickAsyncValidators(asyncValidator, validatorOrOpts) {
  return (isOptionsObj(validatorOrOpts) ? validatorOrOpts.asyncValidators : asyncValidator) || null;
}
/**
 * Creates async validator function by combining provided async validators.
 */


function coerceToAsyncValidator(asyncValidator) {
  return Array.isArray(asyncValidator) ? composeAsyncValidators(asyncValidator) : asyncValidator || null;
}

function isOptionsObj(validatorOrOpts) {
  return validatorOrOpts != null && !Array.isArray(validatorOrOpts) && typeof validatorOrOpts === 'object';
}
/**
 * This is the base class for `FormControl`, `FormGroup`, and `FormArray`.
 *
 * It provides some of the shared behavior that all controls and groups of controls have, like
 * running validators, calculating status, and resetting state. It also defines the properties
 * that are shared between all sub-classes, like `value`, `valid`, and `dirty`. It shouldn't be
 * instantiated directly.
 *
 * @see [Forms Guide](/guide/forms)
 * @see [Reactive Forms Guide](/guide/reactive-forms)
 * @see [Dynamic Forms Guide](/guide/dynamic-form)
 *
 * @publicApi
 */


var AbstractControl = /*#__PURE__*/function () {
  /**
   * Initialize the AbstractControl instance.
   *
   * @param validators The function or array of functions that is used to determine the validity of
   *     this control synchronously.
   * @param asyncValidators The function or array of functions that is used to determine validity of
   *     this control asynchronously.
   */
  function AbstractControl(validators, asyncValidators) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, AbstractControl);

    /**
     * Indicates that a control has its own pending asynchronous validation in progress.
     *
     * @internal
     */
    this._hasOwnPendingAsyncValidator = false;
    /** @internal */

    this._onCollectionChange = function () {};
    /**
     * A control is `pristine` if the user has not yet changed
     * the value in the UI.
     *
     * @returns True if the user has not yet changed the value in the UI; compare `dirty`.
     * Programmatic changes to a control's value do not mark it dirty.
     */


    this.pristine = true;
    /**
     * True if the control is marked as `touched`.
     *
     * A control is marked `touched` once the user has triggered
     * a `blur` event on it.
     */

    this.touched = false;
    /** @internal */

    this._onDisabledChange = [];
    this._rawValidators = validators;
    this._rawAsyncValidators = asyncValidators;
    this._composedValidatorFn = coerceToValidator(this._rawValidators);
    this._composedAsyncValidatorFn = coerceToAsyncValidator(this._rawAsyncValidators);
  }
  /**
   * The function that is used to determine the validity of this control synchronously.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(AbstractControl, [{
    key: "setValidators",

    /**
     * Sets the synchronous validators that are active on this control.  Calling
     * this overwrites any existing sync validators.
     *
     * When you add or remove a validator at run time, you must call
     * `updateValueAndValidity()` for the new validation to take effect.
     *
     */
    value: function setValidators(newValidator) {
      this._rawValidators = newValidator;
      this._composedValidatorFn = coerceToValidator(newValidator);
    }
    /**
     * Sets the async validators that are active on this control. Calling this
     * overwrites any existing async validators.
     *
     * When you add or remove a validator at run time, you must call
     * `updateValueAndValidity()` for the new validation to take effect.
     *
     */

  }, {
    key: "setAsyncValidators",
    value: function setAsyncValidators(newValidator) {
      this._rawAsyncValidators = newValidator;
      this._composedAsyncValidatorFn = coerceToAsyncValidator(newValidator);
    }
    /**
     * Empties out the sync validator list.
     *
     * When you add or remove a validator at run time, you must call
     * `updateValueAndValidity()` for the new validation to take effect.
     *
     */

  }, {
    key: "clearValidators",
    value: function clearValidators() {
      this.validator = null;
    }
    /**
     * Empties out the async validator list.
     *
     * When you add or remove a validator at run time, you must call
     * `updateValueAndValidity()` for the new validation to take effect.
     *
     */

  }, {
    key: "clearAsyncValidators",
    value: function clearAsyncValidators() {
      this.asyncValidator = null;
    }
    /**
     * Marks the control as `touched`. A control is touched by focus and
     * blur events that do not change the value.
     *
     * @see `markAsUntouched()`
     * @see `markAsDirty()`
     * @see `markAsPristine()`
     *
     * @param opts Configuration options that determine how the control propagates changes
     * and emits events after marking is applied.
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     */

  }, {
    key: "markAsTouched",
    value: function markAsTouched() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.touched = true;

      if (this._parent && !opts.onlySelf) {
        this._parent.markAsTouched(opts);
      }
    }
    /**
     * Marks the control and all its descendant controls as `touched`.
     * @see `markAsTouched()`
     */

  }, {
    key: "markAllAsTouched",
    value: function markAllAsTouched() {
      this.markAsTouched({
        onlySelf: true
      });

      this._forEachChild(function (control) {
        return control.markAllAsTouched();
      });
    }
    /**
     * Marks the control as `untouched`.
     *
     * If the control has any children, also marks all children as `untouched`
     * and recalculates the `touched` status of all parent controls.
     *
     * @see `markAsTouched()`
     * @see `markAsDirty()`
     * @see `markAsPristine()`
     *
     * @param opts Configuration options that determine how the control propagates changes
     * and emits events after the marking is applied.
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     */

  }, {
    key: "markAsUntouched",
    value: function markAsUntouched() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.touched = false;
      this._pendingTouched = false;

      this._forEachChild(function (control) {
        control.markAsUntouched({
          onlySelf: true
        });
      });

      if (this._parent && !opts.onlySelf) {
        this._parent._updateTouched(opts);
      }
    }
    /**
     * Marks the control as `dirty`. A control becomes dirty when
     * the control's value is changed through the UI; compare `markAsTouched`.
     *
     * @see `markAsTouched()`
     * @see `markAsUntouched()`
     * @see `markAsPristine()`
     *
     * @param opts Configuration options that determine how the control propagates changes
     * and emits events after marking is applied.
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     */

  }, {
    key: "markAsDirty",
    value: function markAsDirty() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.pristine = false;

      if (this._parent && !opts.onlySelf) {
        this._parent.markAsDirty(opts);
      }
    }
    /**
     * Marks the control as `pristine`.
     *
     * If the control has any children, marks all children as `pristine`,
     * and recalculates the `pristine` status of all parent
     * controls.
     *
     * @see `markAsTouched()`
     * @see `markAsUntouched()`
     * @see `markAsDirty()`
     *
     * @param opts Configuration options that determine how the control emits events after
     * marking is applied.
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     */

  }, {
    key: "markAsPristine",
    value: function markAsPristine() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.pristine = true;
      this._pendingDirty = false;

      this._forEachChild(function (control) {
        control.markAsPristine({
          onlySelf: true
        });
      });

      if (this._parent && !opts.onlySelf) {
        this._parent._updatePristine(opts);
      }
    }
    /**
     * Marks the control as `pending`.
     *
     * A control is pending while the control performs async validation.
     *
     * @see {@link AbstractControl.status}
     *
     * @param opts Configuration options that determine how the control propagates changes and
     * emits events after marking is applied.
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     * * `emitEvent`: When true or not supplied (the default), the `statusChanges`
     * observable emits an event with the latest status the control is marked pending.
     * When false, no events are emitted.
     *
     */

  }, {
    key: "markAsPending",
    value: function markAsPending() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.status = PENDING;

      if (opts.emitEvent !== false) {
        this.statusChanges.emit(this.status);
      }

      if (this._parent && !opts.onlySelf) {
        this._parent.markAsPending(opts);
      }
    }
    /**
     * Disables the control. This means the control is exempt from validation checks and
     * excluded from the aggregate value of any parent. Its status is `DISABLED`.
     *
     * If the control has children, all children are also disabled.
     *
     * @see {@link AbstractControl.status}
     *
     * @param opts Configuration options that determine how the control propagates
     * changes and emits events after the control is disabled.
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control is disabled.
     * When false, no events are emitted.
     */

  }, {
    key: "disable",
    value: function disable() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      // If parent has been marked artificially dirty we don't want to re-calculate the
      // parent's dirtiness based on the children.
      var skipPristineCheck = this._parentMarkedDirty(opts.onlySelf);

      this.status = DISABLED;
      this.errors = null;

      this._forEachChild(function (control) {
        control.disable(Object.assign(Object.assign({}, opts), {
          onlySelf: true
        }));
      });

      this._updateValue();

      if (opts.emitEvent !== false) {
        this.valueChanges.emit(this.value);
        this.statusChanges.emit(this.status);
      }

      this._updateAncestors(Object.assign(Object.assign({}, opts), {
        skipPristineCheck: skipPristineCheck
      }));

      this._onDisabledChange.forEach(function (changeFn) {
        return changeFn(true);
      });
    }
    /**
     * Enables the control. This means the control is included in validation checks and
     * the aggregate value of its parent. Its status recalculates based on its value and
     * its validators.
     *
     * By default, if the control has children, all children are enabled.
     *
     * @see {@link AbstractControl.status}
     *
     * @param opts Configure options that control how the control propagates changes and
     * emits events when marked as untouched
     * * `onlySelf`: When true, mark only this control. When false or not supplied,
     * marks all direct ancestors. Default is false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control is enabled.
     * When false, no events are emitted.
     */

  }, {
    key: "enable",
    value: function enable() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      // If parent has been marked artificially dirty we don't want to re-calculate the
      // parent's dirtiness based on the children.
      var skipPristineCheck = this._parentMarkedDirty(opts.onlySelf);

      this.status = VALID;

      this._forEachChild(function (control) {
        control.enable(Object.assign(Object.assign({}, opts), {
          onlySelf: true
        }));
      });

      this.updateValueAndValidity({
        onlySelf: true,
        emitEvent: opts.emitEvent
      });

      this._updateAncestors(Object.assign(Object.assign({}, opts), {
        skipPristineCheck: skipPristineCheck
      }));

      this._onDisabledChange.forEach(function (changeFn) {
        return changeFn(false);
      });
    }
  }, {
    key: "_updateAncestors",
    value: function _updateAncestors(opts) {
      if (this._parent && !opts.onlySelf) {
        this._parent.updateValueAndValidity(opts);

        if (!opts.skipPristineCheck) {
          this._parent._updatePristine();
        }

        this._parent._updateTouched();
      }
    }
    /**
     * @param parent Sets the parent of the control
     */

  }, {
    key: "setParent",
    value: function setParent(parent) {
      this._parent = parent;
    }
    /**
     * Recalculates the value and validation status of the control.
     *
     * By default, it also updates the value and validity of its ancestors.
     *
     * @param opts Configuration options determine how the control propagates changes and emits events
     * after updates and validity checks are applied.
     * * `onlySelf`: When true, only update this control. When false or not supplied,
     * update all direct ancestors. Default is false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control is updated.
     * When false, no events are emitted.
     */

  }, {
    key: "updateValueAndValidity",
    value: function updateValueAndValidity() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      this._setInitialStatus();

      this._updateValue();

      if (this.enabled) {
        this._cancelExistingSubscription();

        this.errors = this._runValidator();
        this.status = this._calculateStatus();

        if (this.status === VALID || this.status === PENDING) {
          this._runAsyncValidator(opts.emitEvent);
        }
      }

      if (opts.emitEvent !== false) {
        this.valueChanges.emit(this.value);
        this.statusChanges.emit(this.status);
      }

      if (this._parent && !opts.onlySelf) {
        this._parent.updateValueAndValidity(opts);
      }
    }
    /** @internal */

  }, {
    key: "_updateTreeValidity",
    value: function _updateTreeValidity() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
        emitEvent: true
      };

      this._forEachChild(function (ctrl) {
        return ctrl._updateTreeValidity(opts);
      });

      this.updateValueAndValidity({
        onlySelf: true,
        emitEvent: opts.emitEvent
      });
    }
  }, {
    key: "_setInitialStatus",
    value: function _setInitialStatus() {
      this.status = this._allControlsDisabled() ? DISABLED : VALID;
    }
  }, {
    key: "_runValidator",
    value: function _runValidator() {
      return this.validator ? this.validator(this) : null;
    }
  }, {
    key: "_runAsyncValidator",
    value: function _runAsyncValidator(emitEvent) {
      var _this7 = this;

      if (this.asyncValidator) {
        this.status = PENDING;
        this._hasOwnPendingAsyncValidator = true;
        var obs = toObservable(this.asyncValidator(this));
        this._asyncValidationSubscription = obs.subscribe(function (errors) {
          _this7._hasOwnPendingAsyncValidator = false; // This will trigger the recalculation of the validation status, which depends on
          // the state of the asynchronous validation (whether it is in progress or not). So, it is
          // necessary that we have updated the `_hasOwnPendingAsyncValidator` boolean flag first.

          _this7.setErrors(errors, {
            emitEvent: emitEvent
          });
        });
      }
    }
  }, {
    key: "_cancelExistingSubscription",
    value: function _cancelExistingSubscription() {
      if (this._asyncValidationSubscription) {
        this._asyncValidationSubscription.unsubscribe();

        this._hasOwnPendingAsyncValidator = false;
      }
    }
    /**
     * Sets errors on a form control when running validations manually, rather than automatically.
     *
     * Calling `setErrors` also updates the validity of the parent control.
     *
     * @usageNotes
     *
     * ### Manually set the errors for a control
     *
     * ```
     * const login = new FormControl('someLogin');
     * login.setErrors({
     *   notUnique: true
     * });
     *
     * expect(login.valid).toEqual(false);
     * expect(login.errors).toEqual({ notUnique: true });
     *
     * login.setValue('someOtherLogin');
     *
     * expect(login.valid).toEqual(true);
     * ```
     */

  }, {
    key: "setErrors",
    value: function setErrors(errors) {
      var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      this.errors = errors;

      this._updateControlsErrors(opts.emitEvent !== false);
    }
    /**
     * Retrieves a child control given the control's name or path.
     *
     * @param path A dot-delimited string or array of string/number values that define the path to the
     * control.
     *
     * @usageNotes
     * ### Retrieve a nested control
     *
     * For example, to get a `name` control nested within a `person` sub-group:
     *
     * * `this.form.get('person.name');`
     *
     * -OR-
     *
     * * `this.form.get(['person', 'name']);`
     */

  }, {
    key: "get",
    value: function get(path) {
      return _find(this, path, '.');
    }
    /**
     * @description
     * Reports error data for the control with the given path.
     *
     * @param errorCode The code of the error to check
     * @param path A list of control names that designates how to move from the current control
     * to the control that should be queried for errors.
     *
     * @usageNotes
     * For example, for the following `FormGroup`:
     *
     * ```
     * form = new FormGroup({
     *   address: new FormGroup({ street: new FormControl() })
     * });
     * ```
     *
     * The path to the 'street' control from the root form would be 'address' -> 'street'.
     *
     * It can be provided to this method in one of two formats:
     *
     * 1. An array of string control names, e.g. `['address', 'street']`
     * 1. A period-delimited list of control names in one string, e.g. `'address.street'`
     *
     * @returns error data for that particular error. If the control or error is not present,
     * null is returned.
     */

  }, {
    key: "getError",
    value: function getError(errorCode, path) {
      var control = path ? this.get(path) : this;
      return control && control.errors ? control.errors[errorCode] : null;
    }
    /**
     * @description
     * Reports whether the control with the given path has the error specified.
     *
     * @param errorCode The code of the error to check
     * @param path A list of control names that designates how to move from the current control
     * to the control that should be queried for errors.
     *
     * @usageNotes
     * For example, for the following `FormGroup`:
     *
     * ```
     * form = new FormGroup({
     *   address: new FormGroup({ street: new FormControl() })
     * });
     * ```
     *
     * The path to the 'street' control from the root form would be 'address' -> 'street'.
     *
     * It can be provided to this method in one of two formats:
     *
     * 1. An array of string control names, e.g. `['address', 'street']`
     * 1. A period-delimited list of control names in one string, e.g. `'address.street'`
     *
     * If no path is given, this method checks for the error on the current control.
     *
     * @returns whether the given error is present in the control at the given path.
     *
     * If the control is not present, false is returned.
     */

  }, {
    key: "hasError",
    value: function hasError(errorCode, path) {
      return !!this.getError(errorCode, path);
    }
    /**
     * Retrieves the top-level ancestor of this control.
     */

  }, {
    key: "_updateControlsErrors",

    /** @internal */
    value: function _updateControlsErrors(emitEvent) {
      this.status = this._calculateStatus();

      if (emitEvent) {
        this.statusChanges.emit(this.status);
      }

      if (this._parent) {
        this._parent._updateControlsErrors(emitEvent);
      }
    }
    /** @internal */

  }, {
    key: "_initObservables",
    value: function _initObservables() {
      this.valueChanges = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
      this.statusChanges = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
    }
  }, {
    key: "_calculateStatus",
    value: function _calculateStatus() {
      if (this._allControlsDisabled()) return DISABLED;
      if (this.errors) return INVALID;
      if (this._hasOwnPendingAsyncValidator || this._anyControlsHaveStatus(PENDING)) return PENDING;
      if (this._anyControlsHaveStatus(INVALID)) return INVALID;
      return VALID;
    }
    /** @internal */

  }, {
    key: "_anyControlsHaveStatus",
    value: function _anyControlsHaveStatus(status) {
      return this._anyControls(function (control) {
        return control.status === status;
      });
    }
    /** @internal */

  }, {
    key: "_anyControlsDirty",
    value: function _anyControlsDirty() {
      return this._anyControls(function (control) {
        return control.dirty;
      });
    }
    /** @internal */

  }, {
    key: "_anyControlsTouched",
    value: function _anyControlsTouched() {
      return this._anyControls(function (control) {
        return control.touched;
      });
    }
    /** @internal */

  }, {
    key: "_updatePristine",
    value: function _updatePristine() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.pristine = !this._anyControlsDirty();

      if (this._parent && !opts.onlySelf) {
        this._parent._updatePristine(opts);
      }
    }
    /** @internal */

  }, {
    key: "_updateTouched",
    value: function _updateTouched() {
      var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.touched = this._anyControlsTouched();

      if (this._parent && !opts.onlySelf) {
        this._parent._updateTouched(opts);
      }
    }
    /** @internal */

  }, {
    key: "_isBoxedValue",
    value: function _isBoxedValue(formState) {
      return typeof formState === 'object' && formState !== null && Object.keys(formState).length === 2 && 'value' in formState && 'disabled' in formState;
    }
    /** @internal */

  }, {
    key: "_registerOnCollectionChange",
    value: function _registerOnCollectionChange(fn) {
      this._onCollectionChange = fn;
    }
    /** @internal */

  }, {
    key: "_setUpdateStrategy",
    value: function _setUpdateStrategy(opts) {
      if (isOptionsObj(opts) && opts.updateOn != null) {
        this._updateOn = opts.updateOn;
      }
    }
    /**
     * Check to see if parent has been marked artificially dirty.
     *
     * @internal
     */

  }, {
    key: "_parentMarkedDirty",
    value: function _parentMarkedDirty(onlySelf) {
      var parentDirty = this._parent && this._parent.dirty;
      return !onlySelf && parentDirty && !this._parent._anyControlsDirty();
    }
  }, {
    key: "validator",
    get: function get() {
      return this._composedValidatorFn;
    },
    set: function set(validatorFn) {
      this._rawValidators = this._composedValidatorFn = validatorFn;
    }
    /**
     * The function that is used to determine the validity of this control asynchronously.
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return this._composedAsyncValidatorFn;
    },
    set: function set(asyncValidatorFn) {
      this._rawAsyncValidators = this._composedAsyncValidatorFn = asyncValidatorFn;
    }
    /**
     * The parent control.
     */

  }, {
    key: "parent",
    get: function get() {
      return this._parent;
    }
    /**
     * A control is `valid` when its `status` is `VALID`.
     *
     * @see {@link AbstractControl.status}
     *
     * @returns True if the control has passed all of its validation tests,
     * false otherwise.
     */

  }, {
    key: "valid",
    get: function get() {
      return this.status === VALID;
    }
    /**
     * A control is `invalid` when its `status` is `INVALID`.
     *
     * @see {@link AbstractControl.status}
     *
     * @returns True if this control has failed one or more of its validation checks,
     * false otherwise.
     */

  }, {
    key: "invalid",
    get: function get() {
      return this.status === INVALID;
    }
    /**
     * A control is `pending` when its `status` is `PENDING`.
     *
     * @see {@link AbstractControl.status}
     *
     * @returns True if this control is in the process of conducting a validation check,
     * false otherwise.
     */

  }, {
    key: "pending",
    get: function get() {
      return this.status == PENDING;
    }
    /**
     * A control is `disabled` when its `status` is `DISABLED`.
     *
     * Disabled controls are exempt from validation checks and
     * are not included in the aggregate value of their ancestor
     * controls.
     *
     * @see {@link AbstractControl.status}
     *
     * @returns True if the control is disabled, false otherwise.
     */

  }, {
    key: "disabled",
    get: function get() {
      return this.status === DISABLED;
    }
    /**
     * A control is `enabled` as long as its `status` is not `DISABLED`.
     *
     * @returns True if the control has any status other than 'DISABLED',
     * false if the status is 'DISABLED'.
     *
     * @see {@link AbstractControl.status}
     *
     */

  }, {
    key: "enabled",
    get: function get() {
      return this.status !== DISABLED;
    }
    /**
     * A control is `dirty` if the user has changed the value
     * in the UI.
     *
     * @returns True if the user has changed the value of this control in the UI; compare `pristine`.
     * Programmatic changes to a control's value do not mark it dirty.
     */

  }, {
    key: "dirty",
    get: function get() {
      return !this.pristine;
    }
    /**
     * True if the control has not been marked as touched
     *
     * A control is `untouched` if the user has not yet triggered
     * a `blur` event on it.
     */

  }, {
    key: "untouched",
    get: function get() {
      return !this.touched;
    }
    /**
     * Reports the update strategy of the `AbstractControl` (meaning
     * the event on which the control updates itself).
     * Possible values: `'change'` | `'blur'` | `'submit'`
     * Default value: `'change'`
     */

  }, {
    key: "updateOn",
    get: function get() {
      return this._updateOn ? this._updateOn : this.parent ? this.parent.updateOn : 'change';
    }
  }, {
    key: "root",
    get: function get() {
      var x = this;

      while (x._parent) {
        x = x._parent;
      }

      return x;
    }
  }]);

  return AbstractControl;
}();
/**
 * Tracks the value and validation status of an individual form control.
 *
 * This is one of the three fundamental building blocks of Angular forms, along with
 * `FormGroup` and `FormArray`. It extends the `AbstractControl` class that
 * implements most of the base functionality for accessing the value, validation status,
 * user interactions and events. See [usage examples below](#usage-notes).
 *
 * @see `AbstractControl`
 * @see [Reactive Forms Guide](guide/reactive-forms)
 * @see [Usage Notes](#usage-notes)
 *
 * @usageNotes
 *
 * ### Initializing Form Controls
 *
 * Instantiate a `FormControl`, with an initial value.
 *
 * ```ts
 * const control = new FormControl('some value');
 * console.log(control.value);     // 'some value'
 *```
 *
 * The following example initializes the control with a form state object. The `value`
 * and `disabled` keys are required in this case.
 *
 * ```ts
 * const control = new FormControl({ value: 'n/a', disabled: true });
 * console.log(control.value);     // 'n/a'
 * console.log(control.status);    // 'DISABLED'
 * ```
 *
 * The following example initializes the control with a sync validator.
 *
 * ```ts
 * const control = new FormControl('', Validators.required);
 * console.log(control.value);      // ''
 * console.log(control.status);     // 'INVALID'
 * ```
 *
 * The following example initializes the control using an options object.
 *
 * ```ts
 * const control = new FormControl('', {
 *    validators: Validators.required,
 *    asyncValidators: myAsyncValidator
 * });
 * ```
 *
 * ### Configure the control to update on a blur event
 *
 * Set the `updateOn` option to `'blur'` to update on the blur `event`.
 *
 * ```ts
 * const control = new FormControl('', { updateOn: 'blur' });
 * ```
 *
 * ### Configure the control to update on a submit event
 *
 * Set the `updateOn` option to `'submit'` to update on a submit `event`.
 *
 * ```ts
 * const control = new FormControl('', { updateOn: 'submit' });
 * ```
 *
 * ### Reset the control back to an initial value
 *
 * You reset to a specific form state by passing through a standalone
 * value or a form state object that contains both a value and a disabled state
 * (these are the only two properties that cannot be calculated).
 *
 * ```ts
 * const control = new FormControl('Nancy');
 *
 * console.log(control.value); // 'Nancy'
 *
 * control.reset('Drew');
 *
 * console.log(control.value); // 'Drew'
 * ```
 *
 * ### Reset the control back to an initial value and disabled
 *
 * ```
 * const control = new FormControl('Nancy');
 *
 * console.log(control.value); // 'Nancy'
 * console.log(control.status); // 'VALID'
 *
 * control.reset({ value: 'Drew', disabled: true });
 *
 * console.log(control.value); // 'Drew'
 * console.log(control.status); // 'DISABLED'
 * ```
 *
 * @publicApi
 */


var FormControl = /*#__PURE__*/function (_AbstractControl) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormControl, _AbstractControl);

  var _super5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormControl);

  /**
   * Creates a new `FormControl` instance.
   *
   * @param formState Initializes the control with an initial value,
   * or an object that defines the initial value and disabled state.
   *
   * @param validatorOrOpts A synchronous validator function, or an array of
   * such functions, or an `AbstractControlOptions` object that contains validation functions
   * and a validation trigger.
   *
   * @param asyncValidator A single async validator or array of async validator functions
   *
   */
  function FormControl() {
    var _this8;

    var formState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
    var validatorOrOpts = arguments.length > 1 ? arguments[1] : undefined;
    var asyncValidator = arguments.length > 2 ? arguments[2] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormControl);

    _this8 = _super5.call(this, pickValidators(validatorOrOpts), pickAsyncValidators(asyncValidator, validatorOrOpts));
    /** @internal */

    _this8._onChange = [];

    _this8._applyFormState(formState);

    _this8._setUpdateStrategy(validatorOrOpts);

    _this8.updateValueAndValidity({
      onlySelf: true,
      emitEvent: false
    });

    _this8._initObservables();

    return _this8;
  }
  /**
   * Sets a new value for the form control.
   *
   * @param value The new value for the control.
   * @param options Configuration options that determine how the control propagates changes
   * and emits events when the value changes.
   * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
   * updateValueAndValidity} method.
   *
   * * `onlySelf`: When true, each change only affects this control, and not its parent. Default is
   * false.
   * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
   * `valueChanges`
   * observables emit events with the latest status and value when the control value is updated.
   * When false, no events are emitted.
   * * `emitModelToViewChange`: When true or not supplied  (the default), each change triggers an
   * `onChange` event to
   * update the view.
   * * `emitViewToModelChange`: When true or not supplied (the default), each change triggers an
   * `ngModelChange`
   * event to update the model.
   *
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormControl, [{
    key: "setValue",
    value: function setValue(value) {
      var _this9 = this;

      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      this.value = this._pendingValue = value;

      if (this._onChange.length && options.emitModelToViewChange !== false) {
        this._onChange.forEach(function (changeFn) {
          return changeFn(_this9.value, options.emitViewToModelChange !== false);
        });
      }

      this.updateValueAndValidity(options);
    }
    /**
     * Patches the value of a control.
     *
     * This function is functionally the same as {@link FormControl#setValue setValue} at this level.
     * It exists for symmetry with {@link FormGroup#patchValue patchValue} on `FormGroups` and
     * `FormArrays`, where it does behave differently.
     *
     * @see `setValue` for options
     */

  }, {
    key: "patchValue",
    value: function patchValue(value) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      this.setValue(value, options);
    }
    /**
     * Resets the form control, marking it `pristine` and `untouched`, and setting
     * the value to null.
     *
     * @param formState Resets the control with an initial value,
     * or an object that defines the initial value and disabled state.
     *
     * @param options Configuration options that determine how the control propagates changes
     * and emits events after the value changes.
     *
     * * `onlySelf`: When true, each change only affects this control, and not its parent. Default is
     * false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control is reset.
     * When false, no events are emitted.
     *
     */

  }, {
    key: "reset",
    value: function reset() {
      var formState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      this._applyFormState(formState);

      this.markAsPristine(options);
      this.markAsUntouched(options);
      this.setValue(this.value, options);
      this._pendingChange = false;
    }
    /**
     * @internal
     */

  }, {
    key: "_updateValue",
    value: function _updateValue() {}
    /**
     * @internal
     */

  }, {
    key: "_anyControls",
    value: function _anyControls(condition) {
      return false;
    }
    /**
     * @internal
     */

  }, {
    key: "_allControlsDisabled",
    value: function _allControlsDisabled() {
      return this.disabled;
    }
    /**
     * Register a listener for change events.
     *
     * @param fn The method that is called when the value changes
     */

  }, {
    key: "registerOnChange",
    value: function registerOnChange(fn) {
      this._onChange.push(fn);
    }
    /**
     * @internal
     */

  }, {
    key: "_clearChangeFns",
    value: function _clearChangeFns() {
      this._onChange = [];
      this._onDisabledChange = [];

      this._onCollectionChange = function () {};
    }
    /**
     * Register a listener for disabled events.
     *
     * @param fn The method that is called when the disabled status changes.
     */

  }, {
    key: "registerOnDisabledChange",
    value: function registerOnDisabledChange(fn) {
      this._onDisabledChange.push(fn);
    }
    /**
     * @internal
     */

  }, {
    key: "_forEachChild",
    value: function _forEachChild(cb) {}
    /** @internal */

  }, {
    key: "_syncPendingControls",
    value: function _syncPendingControls() {
      if (this.updateOn === 'submit') {
        if (this._pendingDirty) this.markAsDirty();
        if (this._pendingTouched) this.markAsTouched();

        if (this._pendingChange) {
          this.setValue(this._pendingValue, {
            onlySelf: true,
            emitModelToViewChange: false
          });
          return true;
        }
      }

      return false;
    }
  }, {
    key: "_applyFormState",
    value: function _applyFormState(formState) {
      if (this._isBoxedValue(formState)) {
        this.value = this._pendingValue = formState.value;
        formState.disabled ? this.disable({
          onlySelf: true,
          emitEvent: false
        }) : this.enable({
          onlySelf: true,
          emitEvent: false
        });
      } else {
        this.value = this._pendingValue = formState;
      }
    }
  }]);

  return FormControl;
}(AbstractControl);
/**
 * Tracks the value and validity state of a group of `FormControl` instances.
 *
 * A `FormGroup` aggregates the values of each child `FormControl` into one object,
 * with each control name as the key.  It calculates its status by reducing the status values
 * of its children. For example, if one of the controls in a group is invalid, the entire
 * group becomes invalid.
 *
 * `FormGroup` is one of the three fundamental building blocks used to define forms in Angular,
 * along with `FormControl` and `FormArray`.
 *
 * When instantiating a `FormGroup`, pass in a collection of child controls as the first
 * argument. The key for each child registers the name for the control.
 *
 * @usageNotes
 *
 * ### Create a form group with 2 controls
 *
 * ```
 * const form = new FormGroup({
 *   first: new FormControl('Nancy', Validators.minLength(2)),
 *   last: new FormControl('Drew'),
 * });
 *
 * console.log(form.value);   // {first: 'Nancy', last; 'Drew'}
 * console.log(form.status);  // 'VALID'
 * ```
 *
 * ### Create a form group with a group-level validator
 *
 * You include group-level validators as the second arg, or group-level async
 * validators as the third arg. These come in handy when you want to perform validation
 * that considers the value of more than one child control.
 *
 * ```
 * const form = new FormGroup({
 *   password: new FormControl('', Validators.minLength(2)),
 *   passwordConfirm: new FormControl('', Validators.minLength(2)),
 * }, passwordMatchValidator);
 *
 *
 * function passwordMatchValidator(g: FormGroup) {
 *    return g.get('password').value === g.get('passwordConfirm').value
 *       ? null : {'mismatch': true};
 * }
 * ```
 *
 * Like `FormControl` instances, you choose to pass in
 * validators and async validators as part of an options object.
 *
 * ```
 * const form = new FormGroup({
 *   password: new FormControl('')
 *   passwordConfirm: new FormControl('')
 * }, { validators: passwordMatchValidator, asyncValidators: otherValidator });
 * ```
 *
 * ### Set the updateOn property for all controls in a form group
 *
 * The options object is used to set a default value for each child
 * control's `updateOn` property. If you set `updateOn` to `'blur'` at the
 * group level, all child controls default to 'blur', unless the child
 * has explicitly specified a different `updateOn` value.
 *
 * ```ts
 * const c = new FormGroup({
 *   one: new FormControl()
 * }, { updateOn: 'blur' });
 * ```
 *
 * @publicApi
 */


var FormGroup = /*#__PURE__*/function (_AbstractControl2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormGroup, _AbstractControl2);

  var _super6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormGroup);

  /**
   * Creates a new `FormGroup` instance.
   *
   * @param controls A collection of child controls. The key for each child is the name
   * under which it is registered.
   *
   * @param validatorOrOpts A synchronous validator function, or an array of
   * such functions, or an `AbstractControlOptions` object that contains validation functions
   * and a validation trigger.
   *
   * @param asyncValidator A single async validator or array of async validator functions
   *
   */
  function FormGroup(controls, validatorOrOpts, asyncValidator) {
    var _this10;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormGroup);

    _this10 = _super6.call(this, pickValidators(validatorOrOpts), pickAsyncValidators(asyncValidator, validatorOrOpts));
    _this10.controls = controls;

    _this10._initObservables();

    _this10._setUpdateStrategy(validatorOrOpts);

    _this10._setUpControls();

    _this10.updateValueAndValidity({
      onlySelf: true,
      emitEvent: false
    });

    return _this10;
  }
  /**
   * Registers a control with the group's list of controls.
   *
   * This method does not update the value or validity of the control.
   * Use {@link FormGroup#addControl addControl} instead.
   *
   * @param name The control name to register in the collection
   * @param control Provides the control for the given name
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormGroup, [{
    key: "registerControl",
    value: function registerControl(name, control) {
      if (this.controls[name]) return this.controls[name];
      this.controls[name] = control;
      control.setParent(this);

      control._registerOnCollectionChange(this._onCollectionChange);

      return control;
    }
    /**
     * Add a control to this group.
     *
     * This method also updates the value and validity of the control.
     *
     * @param name The control name to add to the collection
     * @param control Provides the control for the given name
     */

  }, {
    key: "addControl",
    value: function addControl(name, control) {
      this.registerControl(name, control);
      this.updateValueAndValidity();

      this._onCollectionChange();
    }
    /**
     * Remove a control from this group.
     *
     * @param name The control name to remove from the collection
     */

  }, {
    key: "removeControl",
    value: function removeControl(name) {
      if (this.controls[name]) this.controls[name]._registerOnCollectionChange(function () {});
      delete this.controls[name];
      this.updateValueAndValidity();

      this._onCollectionChange();
    }
    /**
     * Replace an existing control.
     *
     * @param name The control name to replace in the collection
     * @param control Provides the control for the given name
     */

  }, {
    key: "setControl",
    value: function setControl(name, control) {
      if (this.controls[name]) this.controls[name]._registerOnCollectionChange(function () {});
      delete this.controls[name];
      if (control) this.registerControl(name, control);
      this.updateValueAndValidity();

      this._onCollectionChange();
    }
    /**
     * Check whether there is an enabled control with the given name in the group.
     *
     * Reports false for disabled controls. If you'd like to check for existence in the group
     * only, use {@link AbstractControl#get get} instead.
     *
     * @param controlName The control name to check for existence in the collection
     *
     * @returns false for disabled controls, true otherwise.
     */

  }, {
    key: "contains",
    value: function contains(controlName) {
      return this.controls.hasOwnProperty(controlName) && this.controls[controlName].enabled;
    }
    /**
     * Sets the value of the `FormGroup`. It accepts an object that matches
     * the structure of the group, with control names as keys.
     *
     * @usageNotes
     * ### Set the complete value for the form group
     *
     * ```
     * const form = new FormGroup({
     *   first: new FormControl(),
     *   last: new FormControl()
     * });
     *
     * console.log(form.value);   // {first: null, last: null}
     *
     * form.setValue({first: 'Nancy', last: 'Drew'});
     * console.log(form.value);   // {first: 'Nancy', last: 'Drew'}
     * ```
     *
     * @throws When strict checks fail, such as setting the value of a control
     * that doesn't exist or if you exclude a value of a control that does exist.
     *
     * @param value The new value for the control that matches the structure of the group.
     * @param options Configuration options that determine how the control propagates changes
     * and emits events after the value changes.
     * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
     * updateValueAndValidity} method.
     *
     * * `onlySelf`: When true, each change only affects this control, and not its parent. Default is
     * false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control value is updated.
     * When false, no events are emitted.
     */

  }, {
    key: "setValue",
    value: function setValue(value) {
      var _this11 = this;

      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      this._checkAllValuesPresent(value);

      Object.keys(value).forEach(function (name) {
        _this11._throwIfControlMissing(name);

        _this11.controls[name].setValue(value[name], {
          onlySelf: true,
          emitEvent: options.emitEvent
        });
      });
      this.updateValueAndValidity(options);
    }
    /**
     * Patches the value of the `FormGroup`. It accepts an object with control
     * names as keys, and does its best to match the values to the correct controls
     * in the group.
     *
     * It accepts both super-sets and sub-sets of the group without throwing an error.
     *
     * @usageNotes
     * ### Patch the value for a form group
     *
     * ```
     * const form = new FormGroup({
     *    first: new FormControl(),
     *    last: new FormControl()
     * });
     * console.log(form.value);   // {first: null, last: null}
     *
     * form.patchValue({first: 'Nancy'});
     * console.log(form.value);   // {first: 'Nancy', last: null}
     * ```
     *
     * @param value The object that matches the structure of the group.
     * @param options Configuration options that determine how the control propagates changes and
     * emits events after the value is patched.
     * * `onlySelf`: When true, each change only affects this control and not its parent. Default is
     * true.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control value is updated.
     * When false, no events are emitted.
     * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
     * updateValueAndValidity} method.
     */

  }, {
    key: "patchValue",
    value: function patchValue(value) {
      var _this12 = this;

      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      Object.keys(value).forEach(function (name) {
        if (_this12.controls[name]) {
          _this12.controls[name].patchValue(value[name], {
            onlySelf: true,
            emitEvent: options.emitEvent
          });
        }
      });
      this.updateValueAndValidity(options);
    }
    /**
     * Resets the `FormGroup`, marks all descendants `pristine` and `untouched` and sets
     * the value of all descendants to null.
     *
     * You reset to a specific form state by passing in a map of states
     * that matches the structure of your form, with control names as keys. The state
     * is a standalone value or a form state object with both a value and a disabled
     * status.
     *
     * @param value Resets the control with an initial value,
     * or an object that defines the initial value and disabled state.
     *
     * @param options Configuration options that determine how the control propagates changes
     * and emits events when the group is reset.
     * * `onlySelf`: When true, each change only affects this control, and not its parent. Default is
     * false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control is reset.
     * When false, no events are emitted.
     * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
     * updateValueAndValidity} method.
     *
     * @usageNotes
     *
     * ### Reset the form group values
     *
     * ```ts
     * const form = new FormGroup({
     *   first: new FormControl('first name'),
     *   last: new FormControl('last name')
     * });
     *
     * console.log(form.value);  // {first: 'first name', last: 'last name'}
     *
     * form.reset({ first: 'name', last: 'last name' });
     *
     * console.log(form.value);  // {first: 'name', last: 'last name'}
     * ```
     *
     * ### Reset the form group values and disabled status
     *
     * ```
     * const form = new FormGroup({
     *   first: new FormControl('first name'),
     *   last: new FormControl('last name')
     * });
     *
     * form.reset({
     *   first: {value: 'name', disabled: true},
     *   last: 'last'
     * });
     *
     * console.log(this.form.value);  // {first: 'name', last: 'last name'}
     * console.log(this.form.get('first').status);  // 'DISABLED'
     * ```
     */

  }, {
    key: "reset",
    value: function reset() {
      var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      this._forEachChild(function (control, name) {
        control.reset(value[name], {
          onlySelf: true,
          emitEvent: options.emitEvent
        });
      });

      this._updatePristine(options);

      this._updateTouched(options);

      this.updateValueAndValidity(options);
    }
    /**
     * The aggregate value of the `FormGroup`, including any disabled controls.
     *
     * Retrieves all values regardless of disabled status.
     * The `value` property is the best way to get the value of the group, because
     * it excludes disabled controls in the `FormGroup`.
     */

  }, {
    key: "getRawValue",
    value: function getRawValue() {
      return this._reduceChildren({}, function (acc, control, name) {
        acc[name] = control instanceof FormControl ? control.value : control.getRawValue();
        return acc;
      });
    }
    /** @internal */

  }, {
    key: "_syncPendingControls",
    value: function _syncPendingControls() {
      var subtreeUpdated = this._reduceChildren(false, function (updated, child) {
        return child._syncPendingControls() ? true : updated;
      });

      if (subtreeUpdated) this.updateValueAndValidity({
        onlySelf: true
      });
      return subtreeUpdated;
    }
    /** @internal */

  }, {
    key: "_throwIfControlMissing",
    value: function _throwIfControlMissing(name) {
      if (!Object.keys(this.controls).length) {
        throw new Error("\n        There are no form controls registered with this group yet. If you're using ngModel,\n        you may want to check next tick (e.g. use setTimeout).\n      ");
      }

      if (!this.controls[name]) {
        throw new Error("Cannot find form control with name: ".concat(name, "."));
      }
    }
    /** @internal */

  }, {
    key: "_forEachChild",
    value: function _forEachChild(cb) {
      var _this13 = this;

      Object.keys(this.controls).forEach(function (k) {
        return cb(_this13.controls[k], k);
      });
    }
    /** @internal */

  }, {
    key: "_setUpControls",
    value: function _setUpControls() {
      var _this14 = this;

      this._forEachChild(function (control) {
        control.setParent(_this14);

        control._registerOnCollectionChange(_this14._onCollectionChange);
      });
    }
    /** @internal */

  }, {
    key: "_updateValue",
    value: function _updateValue() {
      this.value = this._reduceValue();
    }
    /** @internal */

  }, {
    key: "_anyControls",
    value: function _anyControls(condition) {
      for (var _i4 = 0, _Object$keys = Object.keys(this.controls); _i4 < _Object$keys.length; _i4++) {
        var controlName = _Object$keys[_i4];
        var control = this.controls[controlName];

        if (this.contains(controlName) && condition(control)) {
          return true;
        }
      }

      return false;
    }
    /** @internal */

  }, {
    key: "_reduceValue",
    value: function _reduceValue() {
      var _this15 = this;

      return this._reduceChildren({}, function (acc, control, name) {
        if (control.enabled || _this15.disabled) {
          acc[name] = control.value;
        }

        return acc;
      });
    }
    /** @internal */

  }, {
    key: "_reduceChildren",
    value: function _reduceChildren(initValue, fn) {
      var res = initValue;

      this._forEachChild(function (control, name) {
        res = fn(res, control, name);
      });

      return res;
    }
    /** @internal */

  }, {
    key: "_allControlsDisabled",
    value: function _allControlsDisabled() {
      for (var _i5 = 0, _Object$keys2 = Object.keys(this.controls); _i5 < _Object$keys2.length; _i5++) {
        var controlName = _Object$keys2[_i5];

        if (this.controls[controlName].enabled) {
          return false;
        }
      }

      return Object.keys(this.controls).length > 0 || this.disabled;
    }
    /** @internal */

  }, {
    key: "_checkAllValuesPresent",
    value: function _checkAllValuesPresent(value) {
      this._forEachChild(function (control, name) {
        if (value[name] === undefined) {
          throw new Error("Must supply a value for form control with name: '".concat(name, "'."));
        }
      });
    }
  }]);

  return FormGroup;
}(AbstractControl);
/**
 * Tracks the value and validity state of an array of `FormControl`,
 * `FormGroup` or `FormArray` instances.
 *
 * A `FormArray` aggregates the values of each child `FormControl` into an array.
 * It calculates its status by reducing the status values of its children. For example, if one of
 * the controls in a `FormArray` is invalid, the entire array becomes invalid.
 *
 * `FormArray` is one of the three fundamental building blocks used to define forms in Angular,
 * along with `FormControl` and `FormGroup`.
 *
 * @usageNotes
 *
 * ### Create an array of form controls
 *
 * ```
 * const arr = new FormArray([
 *   new FormControl('Nancy', Validators.minLength(2)),
 *   new FormControl('Drew'),
 * ]);
 *
 * console.log(arr.value);   // ['Nancy', 'Drew']
 * console.log(arr.status);  // 'VALID'
 * ```
 *
 * ### Create a form array with array-level validators
 *
 * You include array-level validators and async validators. These come in handy
 * when you want to perform validation that considers the value of more than one child
 * control.
 *
 * The two types of validators are passed in separately as the second and third arg
 * respectively, or together as part of an options object.
 *
 * ```
 * const arr = new FormArray([
 *   new FormControl('Nancy'),
 *   new FormControl('Drew')
 * ], {validators: myValidator, asyncValidators: myAsyncValidator});
 * ```
 *
 * ### Set the updateOn property for all controls in a form array
 *
 * The options object is used to set a default value for each child
 * control's `updateOn` property. If you set `updateOn` to `'blur'` at the
 * array level, all child controls default to 'blur', unless the child
 * has explicitly specified a different `updateOn` value.
 *
 * ```ts
 * const arr = new FormArray([
 *    new FormControl()
 * ], {updateOn: 'blur'});
 * ```
 *
 * ### Adding or removing controls from a form array
 *
 * To change the controls in the array, use the `push`, `insert`, `removeAt` or `clear` methods
 * in `FormArray` itself. These methods ensure the controls are properly tracked in the
 * form's hierarchy. Do not modify the array of `AbstractControl`s used to instantiate
 * the `FormArray` directly, as that result in strange and unexpected behavior such
 * as broken change detection.
 *
 * @publicApi
 */


var FormArray = /*#__PURE__*/function (_AbstractControl3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormArray, _AbstractControl3);

  var _super7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormArray);

  /**
   * Creates a new `FormArray` instance.
   *
   * @param controls An array of child controls. Each child control is given an index
   * where it is registered.
   *
   * @param validatorOrOpts A synchronous validator function, or an array of
   * such functions, or an `AbstractControlOptions` object that contains validation functions
   * and a validation trigger.
   *
   * @param asyncValidator A single async validator or array of async validator functions
   *
   */
  function FormArray(controls, validatorOrOpts, asyncValidator) {
    var _this16;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormArray);

    _this16 = _super7.call(this, pickValidators(validatorOrOpts), pickAsyncValidators(asyncValidator, validatorOrOpts));
    _this16.controls = controls;

    _this16._initObservables();

    _this16._setUpdateStrategy(validatorOrOpts);

    _this16._setUpControls();

    _this16.updateValueAndValidity({
      onlySelf: true,
      emitEvent: false
    });

    return _this16;
  }
  /**
   * Get the `AbstractControl` at the given `index` in the array.
   *
   * @param index Index in the array to retrieve the control
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormArray, [{
    key: "at",
    value: function at(index) {
      return this.controls[index];
    }
    /**
     * Insert a new `AbstractControl` at the end of the array.
     *
     * @param control Form control to be inserted
     */

  }, {
    key: "push",
    value: function push(control) {
      this.controls.push(control);

      this._registerControl(control);

      this.updateValueAndValidity();

      this._onCollectionChange();
    }
    /**
     * Insert a new `AbstractControl` at the given `index` in the array.
     *
     * @param index Index in the array to insert the control
     * @param control Form control to be inserted
     */

  }, {
    key: "insert",
    value: function insert(index, control) {
      this.controls.splice(index, 0, control);

      this._registerControl(control);

      this.updateValueAndValidity();
    }
    /**
     * Remove the control at the given `index` in the array.
     *
     * @param index Index in the array to remove the control
     */

  }, {
    key: "removeAt",
    value: function removeAt(index) {
      if (this.controls[index]) this.controls[index]._registerOnCollectionChange(function () {});
      this.controls.splice(index, 1);
      this.updateValueAndValidity();
    }
    /**
     * Replace an existing control.
     *
     * @param index Index in the array to replace the control
     * @param control The `AbstractControl` control to replace the existing control
     */

  }, {
    key: "setControl",
    value: function setControl(index, control) {
      if (this.controls[index]) this.controls[index]._registerOnCollectionChange(function () {});
      this.controls.splice(index, 1);

      if (control) {
        this.controls.splice(index, 0, control);

        this._registerControl(control);
      }

      this.updateValueAndValidity();

      this._onCollectionChange();
    }
    /**
     * Length of the control array.
     */

  }, {
    key: "setValue",

    /**
     * Sets the value of the `FormArray`. It accepts an array that matches
     * the structure of the control.
     *
     * This method performs strict checks, and throws an error if you try
     * to set the value of a control that doesn't exist or if you exclude the
     * value of a control.
     *
     * @usageNotes
     * ### Set the values for the controls in the form array
     *
     * ```
     * const arr = new FormArray([
     *   new FormControl(),
     *   new FormControl()
     * ]);
     * console.log(arr.value);   // [null, null]
     *
     * arr.setValue(['Nancy', 'Drew']);
     * console.log(arr.value);   // ['Nancy', 'Drew']
     * ```
     *
     * @param value Array of values for the controls
     * @param options Configure options that determine how the control propagates changes and
     * emits events after the value changes
     *
     * * `onlySelf`: When true, each change only affects this control, and not its parent. Default
     * is false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control value is updated.
     * When false, no events are emitted.
     * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
     * updateValueAndValidity} method.
     */
    value: function setValue(value) {
      var _this17 = this;

      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      this._checkAllValuesPresent(value);

      value.forEach(function (newValue, index) {
        _this17._throwIfControlMissing(index);

        _this17.at(index).setValue(newValue, {
          onlySelf: true,
          emitEvent: options.emitEvent
        });
      });
      this.updateValueAndValidity(options);
    }
    /**
     * Patches the value of the `FormArray`. It accepts an array that matches the
     * structure of the control, and does its best to match the values to the correct
     * controls in the group.
     *
     * It accepts both super-sets and sub-sets of the array without throwing an error.
     *
     * @usageNotes
     * ### Patch the values for controls in a form array
     *
     * ```
     * const arr = new FormArray([
     *    new FormControl(),
     *    new FormControl()
     * ]);
     * console.log(arr.value);   // [null, null]
     *
     * arr.patchValue(['Nancy']);
     * console.log(arr.value);   // ['Nancy', null]
     * ```
     *
     * @param value Array of latest values for the controls
     * @param options Configure options that determine how the control propagates changes and
     * emits events after the value changes
     *
     * * `onlySelf`: When true, each change only affects this control, and not its parent. Default
     * is false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control value is updated.
     * When false, no events are emitted.
     * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
     * updateValueAndValidity} method.
     */

  }, {
    key: "patchValue",
    value: function patchValue(value) {
      var _this18 = this;

      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      value.forEach(function (newValue, index) {
        if (_this18.at(index)) {
          _this18.at(index).patchValue(newValue, {
            onlySelf: true,
            emitEvent: options.emitEvent
          });
        }
      });
      this.updateValueAndValidity(options);
    }
    /**
     * Resets the `FormArray` and all descendants are marked `pristine` and `untouched`, and the
     * value of all descendants to null or null maps.
     *
     * You reset to a specific form state by passing in an array of states
     * that matches the structure of the control. The state is a standalone value
     * or a form state object with both a value and a disabled status.
     *
     * @usageNotes
     * ### Reset the values in a form array
     *
     * ```ts
     * const arr = new FormArray([
     *    new FormControl(),
     *    new FormControl()
     * ]);
     * arr.reset(['name', 'last name']);
     *
     * console.log(this.arr.value);  // ['name', 'last name']
     * ```
     *
     * ### Reset the values in a form array and the disabled status for the first control
     *
     * ```
     * this.arr.reset([
     *   {value: 'name', disabled: true},
     *   'last'
     * ]);
     *
     * console.log(this.arr.value);  // ['name', 'last name']
     * console.log(this.arr.get(0).status);  // 'DISABLED'
     * ```
     *
     * @param value Array of values for the controls
     * @param options Configure options that determine how the control propagates changes and
     * emits events after the value changes
     *
     * * `onlySelf`: When true, each change only affects this control, and not its parent. Default
     * is false.
     * * `emitEvent`: When true or not supplied (the default), both the `statusChanges` and
     * `valueChanges`
     * observables emit events with the latest status and value when the control is reset.
     * When false, no events are emitted.
     * The configuration options are passed to the {@link AbstractControl#updateValueAndValidity
     * updateValueAndValidity} method.
     */

  }, {
    key: "reset",
    value: function reset() {
      var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      this._forEachChild(function (control, index) {
        control.reset(value[index], {
          onlySelf: true,
          emitEvent: options.emitEvent
        });
      });

      this._updatePristine(options);

      this._updateTouched(options);

      this.updateValueAndValidity(options);
    }
    /**
     * The aggregate value of the array, including any disabled controls.
     *
     * Reports all values regardless of disabled status.
     * For enabled controls only, the `value` property is the best way to get the value of the array.
     */

  }, {
    key: "getRawValue",
    value: function getRawValue() {
      return this.controls.map(function (control) {
        return control instanceof FormControl ? control.value : control.getRawValue();
      });
    }
    /**
     * Remove all controls in the `FormArray`.
     *
     * @usageNotes
     * ### Remove all elements from a FormArray
     *
     * ```ts
     * const arr = new FormArray([
     *    new FormControl(),
     *    new FormControl()
     * ]);
     * console.log(arr.length);  // 2
     *
     * arr.clear();
     * console.log(arr.length);  // 0
     * ```
     *
     * It's a simpler and more efficient alternative to removing all elements one by one:
     *
     * ```ts
     * const arr = new FormArray([
     *    new FormControl(),
     *    new FormControl()
     * ]);
     *
     * while (arr.length) {
     *    arr.removeAt(0);
     * }
     * ```
     */

  }, {
    key: "clear",
    value: function clear() {
      if (this.controls.length < 1) return;

      this._forEachChild(function (control) {
        return control._registerOnCollectionChange(function () {});
      });

      this.controls.splice(0);
      this.updateValueAndValidity();
    }
    /** @internal */

  }, {
    key: "_syncPendingControls",
    value: function _syncPendingControls() {
      var subtreeUpdated = this.controls.reduce(function (updated, child) {
        return child._syncPendingControls() ? true : updated;
      }, false);
      if (subtreeUpdated) this.updateValueAndValidity({
        onlySelf: true
      });
      return subtreeUpdated;
    }
    /** @internal */

  }, {
    key: "_throwIfControlMissing",
    value: function _throwIfControlMissing(index) {
      if (!this.controls.length) {
        throw new Error("\n        There are no form controls registered with this array yet. If you're using ngModel,\n        you may want to check next tick (e.g. use setTimeout).\n      ");
      }

      if (!this.at(index)) {
        throw new Error("Cannot find form control at index ".concat(index));
      }
    }
    /** @internal */

  }, {
    key: "_forEachChild",
    value: function _forEachChild(cb) {
      this.controls.forEach(function (control, index) {
        cb(control, index);
      });
    }
    /** @internal */

  }, {
    key: "_updateValue",
    value: function _updateValue() {
      var _this19 = this;

      this.value = this.controls.filter(function (control) {
        return control.enabled || _this19.disabled;
      }).map(function (control) {
        return control.value;
      });
    }
    /** @internal */

  }, {
    key: "_anyControls",
    value: function _anyControls(condition) {
      return this.controls.some(function (control) {
        return control.enabled && condition(control);
      });
    }
    /** @internal */

  }, {
    key: "_setUpControls",
    value: function _setUpControls() {
      var _this20 = this;

      this._forEachChild(function (control) {
        return _this20._registerControl(control);
      });
    }
    /** @internal */

  }, {
    key: "_checkAllValuesPresent",
    value: function _checkAllValuesPresent(value) {
      this._forEachChild(function (control, i) {
        if (value[i] === undefined) {
          throw new Error("Must supply a value for form control at index: ".concat(i, "."));
        }
      });
    }
    /** @internal */

  }, {
    key: "_allControlsDisabled",
    value: function _allControlsDisabled() {
      var _iterator = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_1__["default"])(this.controls),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var control = _step.value;
          if (control.enabled) return false;
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }

      return this.controls.length > 0 || this.disabled;
    }
  }, {
    key: "_registerControl",
    value: function _registerControl(control) {
      control.setParent(this);

      control._registerOnCollectionChange(this._onCollectionChange);
    }
  }, {
    key: "length",
    get: function get() {
      return this.controls.length;
    }
  }]);

  return FormArray;
}(AbstractControl);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var formDirectiveProvider = {
  provide: ControlContainer,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return NgForm;
  })
};

var ɵ0 = function ɵ0() {
  return Promise.resolve(null);
};

var resolvedPromise = ɵ0();
/**
 * @description
 * Creates a top-level `FormGroup` instance and binds it to a form
 * to track aggregate form value and validation status.
 *
 * As soon as you import the `FormsModule`, this directive becomes active by default on
 * all `<form>` tags.  You don't need to add a special selector.
 *
 * You optionally export the directive into a local template variable using `ngForm` as the key
 * (ex: `#myForm="ngForm"`). This is optional, but useful.  Many properties from the underlying
 * `FormGroup` instance are duplicated on the directive itself, so a reference to it
 * gives you access to the aggregate value and validity status of the form, as well as
 * user interaction properties like `dirty` and `touched`.
 *
 * To register child controls with the form, use `NgModel` with a `name`
 * attribute. You may use `NgModelGroup` to create sub-groups within the form.
 *
 * If necessary, listen to the directive's `ngSubmit` event to be notified when the user has
 * triggered a form submission. The `ngSubmit` event emits the original form
 * submission event.
 *
 * In template driven forms, all `<form>` tags are automatically tagged as `NgForm`.
 * To import the `FormsModule` but skip its usage in some forms,
 * for example, to use native HTML5 validation, add the `ngNoForm` and the `<form>`
 * tags won't create an `NgForm` directive. In reactive forms, using `ngNoForm` is
 * unnecessary because the `<form>` tags are inert. In that case, you would
 * refrain from using the `formGroup` directive.
 *
 * @usageNotes
 *
 * ### Listening for form submission
 *
 * The following example shows how to capture the form values from the "ngSubmit" event.
 *
 * {@example forms/ts/simpleForm/simple_form_example.ts region='Component'}
 *
 * ### Setting the update options
 *
 * The following example shows you how to change the "updateOn" option from its default using
 * ngFormOptions.
 *
 * ```html
 * <form [ngFormOptions]="{updateOn: 'blur'}">
 *    <input name="one" ngModel>  <!-- this ngModel will update on blur -->
 * </form>
 * ```
 *
 * ### Native DOM validation UI
 *
 * In order to prevent the native DOM form validation UI from interfering with Angular's form
 * validation, Angular automatically adds the `novalidate` attribute on any `<form>` whenever
 * `FormModule` or `ReactiveFormModule` are imported into the application.
 * If you want to explicitly enable native DOM validation UI with Angular forms, you can add the
 * `ngNativeValidate` attribute to the `<form>` element:
 *
 * ```html
 * <form ngNativeValidate>
 *   ...
 * </form>
 * ```
 *
 * @ngModule FormsModule
 * @publicApi
 */

var NgForm = /*#__PURE__*/function (_ControlContainer) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgForm, _ControlContainer);

  var _super8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgForm);

  function NgForm(validators, asyncValidators) {
    var _this21;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgForm);

    _this21 = _super8.call(this);
    /**
     * @description
     * Returns whether the form submission has been triggered.
     */

    _this21.submitted = false;
    _this21._directives = [];
    /**
     * @description
     * Event emitter for the "ngSubmit" event
     */

    _this21.ngSubmit = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
    _this21.form = new FormGroup({}, composeValidators(validators), composeAsyncValidators(asyncValidators));
    return _this21;
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(NgForm, [{
    key: "ngAfterViewInit",
    value: function ngAfterViewInit() {
      this._setUpdateStrategy();
    }
    /**
     * @description
     * The directive instance.
     */

  }, {
    key: "addControl",

    /**
     * @description
     * Method that sets up the control directive in this group, re-calculates its value
     * and validity, and adds the instance to the internal list of directives.
     *
     * @param dir The `NgModel` directive instance.
     */
    value: function addControl(dir) {
      var _this22 = this;

      resolvedPromise.then(function () {
        var container = _this22._findContainer(dir.path);

        dir.control = container.registerControl(dir.name, dir.control);
        setUpControl(dir.control, dir);
        dir.control.updateValueAndValidity({
          emitEvent: false
        });

        _this22._directives.push(dir);
      });
    }
    /**
     * @description
     * Retrieves the `FormControl` instance from the provided `NgModel` directive.
     *
     * @param dir The `NgModel` directive instance.
     */

  }, {
    key: "getControl",
    value: function getControl(dir) {
      return this.form.get(dir.path);
    }
    /**
     * @description
     * Removes the `NgModel` instance from the internal list of directives
     *
     * @param dir The `NgModel` directive instance.
     */

  }, {
    key: "removeControl",
    value: function removeControl(dir) {
      var _this23 = this;

      resolvedPromise.then(function () {
        var container = _this23._findContainer(dir.path);

        if (container) {
          container.removeControl(dir.name);
        }

        removeDir(_this23._directives, dir);
      });
    }
    /**
     * @description
     * Adds a new `NgModelGroup` directive instance to the form.
     *
     * @param dir The `NgModelGroup` directive instance.
     */

  }, {
    key: "addFormGroup",
    value: function addFormGroup(dir) {
      var _this24 = this;

      resolvedPromise.then(function () {
        var container = _this24._findContainer(dir.path);

        var group = new FormGroup({});
        setUpFormContainer(group, dir);
        container.registerControl(dir.name, group);
        group.updateValueAndValidity({
          emitEvent: false
        });
      });
    }
    /**
     * @description
     * Removes the `NgModelGroup` directive instance from the form.
     *
     * @param dir The `NgModelGroup` directive instance.
     */

  }, {
    key: "removeFormGroup",
    value: function removeFormGroup(dir) {
      var _this25 = this;

      resolvedPromise.then(function () {
        var container = _this25._findContainer(dir.path);

        if (container) {
          container.removeControl(dir.name);
        }
      });
    }
    /**
     * @description
     * Retrieves the `FormGroup` for a provided `NgModelGroup` directive instance
     *
     * @param dir The `NgModelGroup` directive instance.
     */

  }, {
    key: "getFormGroup",
    value: function getFormGroup(dir) {
      return this.form.get(dir.path);
    }
    /**
     * Sets the new value for the provided `NgControl` directive.
     *
     * @param dir The `NgControl` directive instance.
     * @param value The new value for the directive's control.
     */

  }, {
    key: "updateModel",
    value: function updateModel(dir, value) {
      var _this26 = this;

      resolvedPromise.then(function () {
        var ctrl = _this26.form.get(dir.path);

        ctrl.setValue(value);
      });
    }
    /**
     * @description
     * Sets the value for this `FormGroup`.
     *
     * @param value The new value
     */

  }, {
    key: "setValue",
    value: function setValue(value) {
      this.control.setValue(value);
    }
    /**
     * @description
     * Method called when the "submit" event is triggered on the form.
     * Triggers the `ngSubmit` emitter to emit the "submit" event as its payload.
     *
     * @param $event The "submit" event object
     */

  }, {
    key: "onSubmit",
    value: function onSubmit($event) {
      this.submitted = true;
      syncPendingControls(this.form, this._directives);
      this.ngSubmit.emit($event);
      return false;
    }
    /**
     * @description
     * Method called when the "reset" event is triggered on the form.
     */

  }, {
    key: "onReset",
    value: function onReset() {
      this.resetForm();
    }
    /**
     * @description
     * Resets the form to an initial value and resets its submitted status.
     *
     * @param value The new value for the form.
     */

  }, {
    key: "resetForm",
    value: function resetForm() {
      var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : undefined;
      this.form.reset(value);
      this.submitted = false;
    }
  }, {
    key: "_setUpdateStrategy",
    value: function _setUpdateStrategy() {
      if (this.options && this.options.updateOn != null) {
        this.form._updateOn = this.options.updateOn;
      }
    }
    /** @internal */

  }, {
    key: "_findContainer",
    value: function _findContainer(path) {
      path.pop();
      return path.length ? this.form.get(path) : this.form;
    }
  }, {
    key: "formDirective",
    get: function get() {
      return this;
    }
    /**
     * @description
     * The internal `FormGroup` instance.
     */

  }, {
    key: "control",
    get: function get() {
      return this.form;
    }
    /**
     * @description
     * Returns an array representing the path to this group. Because this directive
     * always lives at the top level of a form, it is always an empty array.
     */

  }, {
    key: "path",
    get: function get() {
      return [];
    }
    /**
     * @description
     * Returns a map of the controls in this group.
     */

  }, {
    key: "controls",
    get: function get() {
      return this.form.controls;
    }
  }]);

  return NgForm;
}(ControlContainer);

NgForm.ɵfac = function NgForm_Factory(t) {
  return new (t || NgForm)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10));
};

NgForm.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NgForm,
  selectors: [["form", 3, "ngNoForm", "", 3, "formGroup", ""], ["ng-form"], ["", "ngForm", ""]],
  hostBindings: function NgForm_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("submit", function NgForm_submit_HostBindingHandler($event) {
        return ctx.onSubmit($event);
      })("reset", function NgForm_reset_HostBindingHandler() {
        return ctx.onReset();
      });
    }
  },
  inputs: {
    options: ["ngFormOptions", "options"]
  },
  outputs: {
    ngSubmit: "ngSubmit"
  },
  exportAs: ["ngForm"],
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([formDirectiveProvider]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});

NgForm.ctorParameters = function () {
  return [{
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }];
};

NgForm.propDecorators = {
  options: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngFormOptions']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NgForm, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]',
      providers: [formDirectiveProvider],
      host: {
        '(submit)': 'onSubmit($event)',
        '(reset)': 'onReset()'
      },
      outputs: ['ngSubmit'],
      exportAs: 'ngForm'
    }]
  }], function () {
    return [{
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }];
  }, {
    options: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngFormOptions']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 * A base class for code shared between the `NgModelGroup` and `FormGroupName` directives.
 *
 * @publicApi
 */


var AbstractFormGroupDirective = /*#__PURE__*/function (_ControlContainer2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(AbstractFormGroupDirective, _ControlContainer2);

  var _super9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(AbstractFormGroupDirective);

  function AbstractFormGroupDirective() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, AbstractFormGroupDirective);

    return _super9.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(AbstractFormGroupDirective, [{
    key: "ngOnInit",

    /** @nodoc */
    value: function ngOnInit() {
      this._checkParentType(); // Register the group with its parent group.


      this.formDirective.addFormGroup(this);
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this.formDirective) {
        // Remove the group from its parent group.
        this.formDirective.removeFormGroup(this);
      }
    }
    /**
     * @description
     * The `FormGroup` bound to this directive.
     */

  }, {
    key: "_checkParentType",

    /** @internal */
    value: function _checkParentType() {}
  }, {
    key: "control",
    get: function get() {
      return this.formDirective.getFormGroup(this);
    }
    /**
     * @description
     * The path to this group from the top-level directive.
     */

  }, {
    key: "path",
    get: function get() {
      return controlPath(this.name == null ? this.name : this.name.toString(), this._parent);
    }
    /**
     * @description
     * The top-level directive for this group if present, otherwise null.
     */

  }, {
    key: "formDirective",
    get: function get() {
      return this._parent ? this._parent.formDirective : null;
    }
    /**
     * @description
     * The synchronous validators registered with this group.
     */

  }, {
    key: "validator",
    get: function get() {
      return composeValidators(this._validators);
    }
    /**
     * @description
     * The async validators registered with this group.
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return composeAsyncValidators(this._asyncValidators);
    }
  }]);

  return AbstractFormGroupDirective;
}(ControlContainer);

AbstractFormGroupDirective.ɵfac = function AbstractFormGroupDirective_Factory(t) {
  return ɵAbstractFormGroupDirective_BaseFactory(t || AbstractFormGroupDirective);
};

AbstractFormGroupDirective.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: AbstractFormGroupDirective,
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});
var ɵAbstractFormGroupDirective_BaseFactory = /*@__PURE__*/_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵgetInheritedFactory"](AbstractFormGroupDirective);
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](AbstractFormGroupDirective, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var TemplateDrivenErrors = /*#__PURE__*/function () {
  function TemplateDrivenErrors() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, TemplateDrivenErrors);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(TemplateDrivenErrors, null, [{
    key: "modelParentException",
    value: function modelParentException() {
      throw new Error("\n      ngModel cannot be used to register form controls with a parent formGroup directive.  Try using\n      formGroup's partner directive \"formControlName\" instead.  Example:\n\n      ".concat(FormErrorExamples.formControlName, "\n\n      Or, if you'd like to avoid registering this form control, indicate that it's standalone in ngModelOptions:\n\n      Example:\n\n      ").concat(FormErrorExamples.ngModelWithFormGroup));
    }
  }, {
    key: "formGroupNameException",
    value: function formGroupNameException() {
      throw new Error("\n      ngModel cannot be used to register form controls with a parent formGroupName or formArrayName directive.\n\n      Option 1: Use formControlName instead of ngModel (reactive strategy):\n\n      ".concat(FormErrorExamples.formGroupName, "\n\n      Option 2:  Update ngModel's parent be ngModelGroup (template-driven strategy):\n\n      ").concat(FormErrorExamples.ngModelGroup));
    }
  }, {
    key: "missingNameException",
    value: function missingNameException() {
      throw new Error("If ngModel is used within a form tag, either the name attribute must be set or the form\n      control must be defined as 'standalone' in ngModelOptions.\n\n      Example 1: <input [(ngModel)]=\"person.firstName\" name=\"first\">\n      Example 2: <input [(ngModel)]=\"person.firstName\" [ngModelOptions]=\"{standalone: true}\">");
    }
  }, {
    key: "modelGroupParentException",
    value: function modelGroupParentException() {
      throw new Error("\n      ngModelGroup cannot be used with a parent formGroup directive.\n\n      Option 1: Use formGroupName instead of ngModelGroup (reactive strategy):\n\n      ".concat(FormErrorExamples.formGroupName, "\n\n      Option 2:  Use a regular form tag instead of the formGroup directive (template-driven strategy):\n\n      ").concat(FormErrorExamples.ngModelGroup));
    }
  }]);

  return TemplateDrivenErrors;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var modelGroupProvider = {
  provide: ControlContainer,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return NgModelGroup;
  })
};
/**
 * @description
 * Creates and binds a `FormGroup` instance to a DOM element.
 *
 * This directive can only be used as a child of `NgForm` (within `<form>` tags).
 *
 * Use this directive to validate a sub-group of your form separately from the
 * rest of your form, or if some values in your domain model make more sense
 * to consume together in a nested object.
 *
 * Provide a name for the sub-group and it will become the key
 * for the sub-group in the form's full value. If you need direct access, export the directive into
 * a local template variable using `ngModelGroup` (ex: `#myGroup="ngModelGroup"`).
 *
 * @usageNotes
 *
 * ### Consuming controls in a grouping
 *
 * The following example shows you how to combine controls together in a sub-group
 * of the form.
 *
 * {@example forms/ts/ngModelGroup/ng_model_group_example.ts region='Component'}
 *
 * @ngModule FormsModule
 * @publicApi
 */

var NgModelGroup = /*#__PURE__*/function (_AbstractFormGroupDir) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgModelGroup, _AbstractFormGroupDir);

  var _super10 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgModelGroup);

  function NgModelGroup(parent, validators, asyncValidators) {
    var _this27;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgModelGroup);

    _this27 = _super10.call(this);
    _this27._parent = parent;
    _this27._validators = validators;
    _this27._asyncValidators = asyncValidators;
    return _this27;
  }
  /** @internal */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(NgModelGroup, [{
    key: "_checkParentType",
    value: function _checkParentType() {
      if (!(this._parent instanceof NgModelGroup) && !(this._parent instanceof NgForm) && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        TemplateDrivenErrors.modelGroupParentException();
      }
    }
  }]);

  return NgModelGroup;
}(AbstractFormGroupDirective);

NgModelGroup.ɵfac = function NgModelGroup_Factory(t) {
  return new (t || NgModelGroup)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](ControlContainer, 5), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10));
};

NgModelGroup.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NgModelGroup,
  selectors: [["", "ngModelGroup", ""]],
  inputs: {
    name: ["ngModelGroup", "name"]
  },
  exportAs: ["ngModelGroup"],
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([modelGroupProvider]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});

NgModelGroup.ctorParameters = function () {
  return [{
    type: ControlContainer,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }];
};

NgModelGroup.propDecorators = {
  name: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngModelGroup']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NgModelGroup, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[ngModelGroup]',
      providers: [modelGroupProvider],
      exportAs: 'ngModelGroup'
    }]
  }], function () {
    return [{
      type: ControlContainer,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }];
  }, {
    name: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngModelGroup']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var formControlBinding = {
  provide: NgControl,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return NgModel;
  })
};

var ɵ0$1 = function ɵ0$1() {
  return Promise.resolve(null);
};
/**
 * `ngModel` forces an additional change detection run when its inputs change:
 * E.g.:
 * ```
 * <div>{{myModel.valid}}</div>
 * <input [(ngModel)]="myValue" #myModel="ngModel">
 * ```
 * I.e. `ngModel` can export itself on the element and then be used in the template.
 * Normally, this would result in expressions before the `input` that use the exported directive
 * to have and old value as they have been
 * dirty checked before. As this is a very common case for `ngModel`, we added this second change
 * detection run.
 *
 * Notes:
 * - this is just one extra run no matter how many `ngModel` have been changed.
 * - this is a general problem when using `exportAs` for directives!
 */


var resolvedPromise$1 = ɵ0$1();
/**
 * @description
 * Creates a `FormControl` instance from a domain model and binds it
 * to a form control element.
 *
 * The `FormControl` instance tracks the value, user interaction, and
 * validation status of the control and keeps the view synced with the model. If used
 * within a parent form, the directive also registers itself with the form as a child
 * control.
 *
 * This directive is used by itself or as part of a larger form. Use the
 * `ngModel` selector to activate it.
 *
 * It accepts a domain model as an optional `Input`. If you have a one-way binding
 * to `ngModel` with `[]` syntax, changing the value of the domain model in the component
 * class sets the value in the view. If you have a two-way binding with `[()]` syntax
 * (also known as 'banana-box syntax'), the value in the UI always syncs back to
 * the domain model in your class.
 *
 * To inspect the properties of the associated `FormControl` (like validity state),
 * export the directive into a local template variable using `ngModel` as the key (ex:
 * `#myVar="ngModel"`). You then access the control using the directive's `control` property, but
 * most properties used (like `valid` and `dirty`) fall through to the control anyway for direct
 * access. See a full list of properties directly available in `AbstractControlDirective`.
 *
 * @see `RadioControlValueAccessor`
 * @see `SelectControlValueAccessor`
 *
 * @usageNotes
 *
 * ### Using ngModel on a standalone control
 *
 * The following examples show a simple standalone control using `ngModel`:
 *
 * {@example forms/ts/simpleNgModel/simple_ng_model_example.ts region='Component'}
 *
 * When using the `ngModel` within `<form>` tags, you'll also need to supply a `name` attribute
 * so that the control can be registered with the parent form under that name.
 *
 * In the context of a parent form, it's often unnecessary to include one-way or two-way binding,
 * as the parent form syncs the value for you. You access its properties by exporting it into a
 * local template variable using `ngForm` such as (`#f="ngForm"`). Use the variable where
 * needed on form submission.
 *
 * If you do need to populate initial values into your form, using a one-way binding for
 * `ngModel` tends to be sufficient as long as you use the exported form's value rather
 * than the domain model's value on submit.
 *
 * ### Using ngModel within a form
 *
 * The following example shows controls using `ngModel` within a form:
 *
 * {@example forms/ts/simpleForm/simple_form_example.ts region='Component'}
 *
 * ### Using a standalone ngModel within a group
 *
 * The following example shows you how to use a standalone ngModel control
 * within a form. This controls the display of the form, but doesn't contain form data.
 *
 * ```html
 * <form>
 *   <input name="login" ngModel placeholder="Login">
 *   <input type="checkbox" ngModel [ngModelOptions]="{standalone: true}"> Show more options?
 * </form>
 * <!-- form value: {login: ''} -->
 * ```
 *
 * ### Setting the ngModel name attribute through options
 *
 * The following example shows you an alternate way to set the name attribute. The name attribute is
 * used within a custom form component, and the name `@Input` property serves a different purpose.
 *
 * ```html
 * <form>
 *   <my-person-control name="Nancy" ngModel [ngModelOptions]="{name: 'user'}">
 *   </my-person-control>
 * </form>
 * <!-- form value: {user: ''} -->
 * ```
 *
 * @ngModule FormsModule
 * @publicApi
 */

var NgModel = /*#__PURE__*/function (_NgControl) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgModel, _NgControl);

  var _super11 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgModel);

  function NgModel(parent, validators, asyncValidators, valueAccessors) {
    var _this28;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgModel);

    _this28 = _super11.call(this);
    _this28.control = new FormControl();
    /** @internal */

    _this28._registered = false;
    /**
     * @description
     * Event emitter for producing the `ngModelChange` event after
     * the view model updates.
     */

    _this28.update = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
    _this28._parent = parent;
    _this28._rawValidators = validators || [];
    _this28._rawAsyncValidators = asyncValidators || [];
    _this28.valueAccessor = selectValueAccessor(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this28), valueAccessors);
    return _this28;
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(NgModel, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      this._checkForErrors();

      if (!this._registered) this._setUpControl();

      if ('isDisabled' in changes) {
        this._updateDisabled(changes);
      }

      if (isPropertyUpdated(changes, this.viewModel)) {
        this._updateValue(this.model);

        this.viewModel = this.model;
      }
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      this.formDirective && this.formDirective.removeControl(this);
    }
    /**
     * @description
     * Returns an array that represents the path from the top-level form to this control.
     * Each index is the string name of the control on that level.
     */

  }, {
    key: "viewToModelUpdate",

    /**
     * @description
     * Sets the new value for the view model and emits an `ngModelChange` event.
     *
     * @param newValue The new value emitted by `ngModelChange`.
     */
    value: function viewToModelUpdate(newValue) {
      this.viewModel = newValue;
      this.update.emit(newValue);
    }
  }, {
    key: "_setUpControl",
    value: function _setUpControl() {
      this._setUpdateStrategy();

      this._isStandalone() ? this._setUpStandalone() : this.formDirective.addControl(this);
      this._registered = true;
    }
  }, {
    key: "_setUpdateStrategy",
    value: function _setUpdateStrategy() {
      if (this.options && this.options.updateOn != null) {
        this.control._updateOn = this.options.updateOn;
      }
    }
  }, {
    key: "_isStandalone",
    value: function _isStandalone() {
      return !this._parent || !!(this.options && this.options.standalone);
    }
  }, {
    key: "_setUpStandalone",
    value: function _setUpStandalone() {
      setUpControl(this.control, this);
      this.control.updateValueAndValidity({
        emitEvent: false
      });
    }
  }, {
    key: "_checkForErrors",
    value: function _checkForErrors() {
      if (!this._isStandalone()) {
        this._checkParentType();
      }

      this._checkName();
    }
  }, {
    key: "_checkParentType",
    value: function _checkParentType() {
      if (typeof ngDevMode === 'undefined' || ngDevMode) {
        if (!(this._parent instanceof NgModelGroup) && this._parent instanceof AbstractFormGroupDirective) {
          TemplateDrivenErrors.formGroupNameException();
        } else if (!(this._parent instanceof NgModelGroup) && !(this._parent instanceof NgForm)) {
          TemplateDrivenErrors.modelParentException();
        }
      }
    }
  }, {
    key: "_checkName",
    value: function _checkName() {
      if (this.options && this.options.name) this.name = this.options.name;

      if (!this._isStandalone() && !this.name && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        TemplateDrivenErrors.missingNameException();
      }
    }
  }, {
    key: "_updateValue",
    value: function _updateValue(value) {
      var _this29 = this;

      resolvedPromise$1.then(function () {
        _this29.control.setValue(value, {
          emitViewToModelChange: false
        });
      });
    }
  }, {
    key: "_updateDisabled",
    value: function _updateDisabled(changes) {
      var _this30 = this;

      var disabledValue = changes['isDisabled'].currentValue;
      var isDisabled = disabledValue === '' || disabledValue && disabledValue !== 'false';
      resolvedPromise$1.then(function () {
        if (isDisabled && !_this30.control.disabled) {
          _this30.control.disable();
        } else if (!isDisabled && _this30.control.disabled) {
          _this30.control.enable();
        }
      });
    }
  }, {
    key: "path",
    get: function get() {
      return this._parent ? controlPath(this.name, this._parent) : [this.name];
    }
    /**
     * @description
     * The top-level directive for this control if present, otherwise null.
     */

  }, {
    key: "formDirective",
    get: function get() {
      return this._parent ? this._parent.formDirective : null;
    }
    /**
     * @description
     * Synchronous validator function composed of all the synchronous validators
     * registered with this directive.
     */

  }, {
    key: "validator",
    get: function get() {
      return composeValidators(this._rawValidators);
    }
    /**
     * @description
     * Async validator function composed of all the async validators registered with this
     * directive.
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return composeAsyncValidators(this._rawAsyncValidators);
    }
  }]);

  return NgModel;
}(NgControl);

NgModel.ɵfac = function NgModel_Factory(t) {
  return new (t || NgModel)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](ControlContainer, 9), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALUE_ACCESSOR, 10));
};

NgModel.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: NgModel,
  selectors: [["", "ngModel", "", 3, "formControlName", "", 3, "formControl", ""]],
  inputs: {
    name: "name",
    isDisabled: ["disabled", "isDisabled"],
    model: ["ngModel", "model"],
    options: ["ngModelOptions", "options"]
  },
  outputs: {
    update: "ngModelChange"
  },
  exportAs: ["ngModel"],
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([formControlBinding]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});

NgModel.ctorParameters = function () {
  return [{
    type: ControlContainer,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALUE_ACCESSOR]
    }]
  }];
};

NgModel.propDecorators = {
  name: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }],
  isDisabled: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['disabled']
  }],
  model: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngModel']
  }],
  options: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngModelOptions']
  }],
  update: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"],
    args: ['ngModelChange']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](NgModel, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[ngModel]:not([formControlName]):not([formControl])',
      providers: [formControlBinding],
      exportAs: 'ngModel'
    }]
  }], function () {
    return [{
      type: ControlContainer,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALUE_ACCESSOR]
      }]
    }];
  }, {
    update: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"],
      args: ['ngModelChange']
    }],
    name: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }],
    isDisabled: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['disabled']
    }],
    model: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngModel']
    }],
    options: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngModelOptions']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * Adds `novalidate` attribute to all forms by default.
 *
 * `novalidate` is used to disable browser's native form validation.
 *
 * If you want to use native validation with Angular forms, just add `ngNativeValidate` attribute:
 *
 * ```
 * <form ngNativeValidate></form>
 * ```
 *
 * @publicApi
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 */


var ɵNgNoValidate = function ɵNgNoValidate() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ɵNgNoValidate);
};

ɵNgNoValidate.ɵfac = function ɵNgNoValidate_Factory(t) {
  return new (t || ɵNgNoValidate)();
};

ɵNgNoValidate.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: ɵNgNoValidate,
  selectors: [["form", 3, "ngNoForm", "", 3, "ngNativeValidate", ""]],
  hostAttrs: ["novalidate", ""]
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](ɵNgNoValidate, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'form:not([ngNoForm]):not([ngNativeValidate])',
      host: {
        'novalidate': ''
      }
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Token to provide to turn off the ngModel warning on formControl and formControlName.
 */


var NG_MODEL_WITH_FORM_CONTROL_WARNING = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('NgModelWithFormControlWarning');
var formControlBinding$1 = {
  provide: NgControl,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return FormControlDirective;
  })
};
/**
 * @description
 * Synchronizes a standalone `FormControl` instance to a form control element.
 *
 * Note that support for using the `ngModel` input property and `ngModelChange` event with reactive
 * form directives was deprecated in Angular v6 and is scheduled for removal in
 * a future version of Angular.
 * For details, see [Deprecated features](guide/deprecations#ngmodel-with-reactive-forms).
 *
 * @see [Reactive Forms Guide](guide/reactive-forms)
 * @see `FormControl`
 * @see `AbstractControl`
 *
 * @usageNotes
 *
 * The following example shows how to register a standalone control and set its value.
 *
 * {@example forms/ts/simpleFormControl/simple_form_control_example.ts region='Component'}
 *
 * @ngModule ReactiveFormsModule
 * @publicApi
 */

var FormControlDirective = /*#__PURE__*/function (_NgControl2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormControlDirective, _NgControl2);

  var _super12 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormControlDirective);

  function FormControlDirective(validators, asyncValidators, valueAccessors, _ngModelWarningConfig) {
    var _this31;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormControlDirective);

    _this31 = _super12.call(this);
    _this31._ngModelWarningConfig = _ngModelWarningConfig;
    /** @deprecated as of v6 */

    _this31.update = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
    /**
     * @description
     * Instance property used to track whether an ngModel warning has been sent out for this
     * particular `FormControlDirective` instance. Used to support warning config of "always".
     *
     * @internal
     */

    _this31._ngModelWarningSent = false;
    _this31._rawValidators = validators || [];
    _this31._rawAsyncValidators = asyncValidators || [];
    _this31.valueAccessor = selectValueAccessor(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this31), valueAccessors);
    return _this31;
  }
  /**
   * @description
   * Triggers a warning in dev mode that this input should not be used with reactive forms.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormControlDirective, [{
    key: "ngOnChanges",

    /** @nodoc */
    value: function ngOnChanges(changes) {
      if (this._isControlChanged(changes)) {
        setUpControl(this.form, this);

        if (this.control.disabled && this.valueAccessor.setDisabledState) {
          this.valueAccessor.setDisabledState(true);
        }

        this.form.updateValueAndValidity({
          emitEvent: false
        });
      }

      if (isPropertyUpdated(changes, this.viewModel)) {
        _ngModelWarning('formControl', FormControlDirective, this, this._ngModelWarningConfig);

        this.form.setValue(this.model);
        this.viewModel = this.model;
      }
    }
    /**
     * @description
     * Returns an array that represents the path from the top-level form to this control.
     * Each index is the string name of the control on that level.
     */

  }, {
    key: "viewToModelUpdate",

    /**
     * @description
     * Sets the new value for the view model and emits an `ngModelChange` event.
     *
     * @param newValue The new value for the view model.
     */
    value: function viewToModelUpdate(newValue) {
      this.viewModel = newValue;
      this.update.emit(newValue);
    }
  }, {
    key: "_isControlChanged",
    value: function _isControlChanged(changes) {
      return changes.hasOwnProperty('form');
    }
  }, {
    key: "isDisabled",
    set: function set(isDisabled) {
      if (typeof ngDevMode === 'undefined' || ngDevMode) {
        ReactiveErrors.disabledAttrWarning();
      }
    }
  }, {
    key: "path",
    get: function get() {
      return [];
    }
    /**
     * @description
     * Synchronous validator function composed of all the synchronous validators
     * registered with this directive.
     */

  }, {
    key: "validator",
    get: function get() {
      return composeValidators(this._rawValidators);
    }
    /**
     * @description
     * Async validator function composed of all the async validators registered with this
     * directive.
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return composeAsyncValidators(this._rawAsyncValidators);
    }
    /**
     * @description
     * The `FormControl` bound to this directive.
     */

  }, {
    key: "control",
    get: function get() {
      return this.form;
    }
  }]);

  return FormControlDirective;
}(NgControl);

FormControlDirective.ɵfac = function FormControlDirective_Factory(t) {
  return new (t || FormControlDirective)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALUE_ACCESSOR, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_MODEL_WITH_FORM_CONTROL_WARNING, 8));
};

FormControlDirective.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: FormControlDirective,
  selectors: [["", "formControl", ""]],
  inputs: {
    isDisabled: ["disabled", "isDisabled"],
    form: ["formControl", "form"],
    model: ["ngModel", "model"]
  },
  outputs: {
    update: "ngModelChange"
  },
  exportAs: ["ngForm"],
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([formControlBinding$1]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});
/**
 * @description
 * Static property used to track whether any ngModel warnings have been sent across
 * all instances of FormControlDirective. Used to support warning config of "once".
 *
 * @internal
 */

FormControlDirective._ngModelWarningSentOnce = false;

FormControlDirective.ctorParameters = function () {
  return [{
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALUE_ACCESSOR]
    }]
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_MODEL_WITH_FORM_CONTROL_WARNING]
    }]
  }];
};

FormControlDirective.propDecorators = {
  form: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['formControl']
  }],
  isDisabled: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['disabled']
  }],
  model: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngModel']
  }],
  update: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"],
    args: ['ngModelChange']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormControlDirective, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formControl]',
      providers: [formControlBinding$1],
      exportAs: 'ngForm'
    }]
  }], function () {
    return [{
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALUE_ACCESSOR]
      }]
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_MODEL_WITH_FORM_CONTROL_WARNING]
      }]
    }];
  }, {
    update: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"],
      args: ['ngModelChange']
    }],
    isDisabled: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['disabled']
    }],
    form: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['formControl']
    }],
    model: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngModel']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var formDirectiveProvider$1 = {
  provide: ControlContainer,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return FormGroupDirective;
  })
};
/**
 * @description
 *
 * Binds an existing `FormGroup` to a DOM element.
 *
 * This directive accepts an existing `FormGroup` instance. It will then use this
 * `FormGroup` instance to match any child `FormControl`, `FormGroup`,
 * and `FormArray` instances to child `FormControlName`, `FormGroupName`,
 * and `FormArrayName` directives.
 *
 * @see [Reactive Forms Guide](guide/reactive-forms)
 * @see `AbstractControl`
 *
 * ### Register Form Group
 *
 * The following example registers a `FormGroup` with first name and last name controls,
 * and listens for the *ngSubmit* event when the button is clicked.
 *
 * {@example forms/ts/simpleFormGroup/simple_form_group_example.ts region='Component'}
 *
 * @ngModule ReactiveFormsModule
 * @publicApi
 */

var FormGroupDirective = /*#__PURE__*/function (_ControlContainer3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormGroupDirective, _ControlContainer3);

  var _super13 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormGroupDirective);

  function FormGroupDirective(_validators, _asyncValidators) {
    var _this32;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormGroupDirective);

    _this32 = _super13.call(this);
    _this32._validators = _validators;
    _this32._asyncValidators = _asyncValidators;
    /**
     * @description
     * Reports whether the form submission has been triggered.
     */

    _this32.submitted = false;
    /**
     * @description
     * Tracks the list of added `FormControlName` instances
     */

    _this32.directives = [];
    /**
     * @description
     * Tracks the `FormGroup` bound to this directive.
     */

    _this32.form = null;
    /**
     * @description
     * Emits an event when the form submission has been triggered.
     */

    _this32.ngSubmit = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
    return _this32;
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormGroupDirective, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      this._checkFormPresent();

      if (changes.hasOwnProperty('form')) {
        this._updateValidators();

        this._updateDomValue();

        this._updateRegistrations();
      }
    }
    /**
     * @description
     * Returns this directive's instance.
     */

  }, {
    key: "addControl",

    /**
     * @description
     * Method that sets up the control directive in this group, re-calculates its value
     * and validity, and adds the instance to the internal list of directives.
     *
     * @param dir The `FormControlName` directive instance.
     */
    value: function addControl(dir) {
      var ctrl = this.form.get(dir.path);
      setUpControl(ctrl, dir);
      ctrl.updateValueAndValidity({
        emitEvent: false
      });
      this.directives.push(dir);
      return ctrl;
    }
    /**
     * @description
     * Retrieves the `FormControl` instance from the provided `FormControlName` directive
     *
     * @param dir The `FormControlName` directive instance.
     */

  }, {
    key: "getControl",
    value: function getControl(dir) {
      return this.form.get(dir.path);
    }
    /**
     * @description
     * Removes the `FormControlName` instance from the internal list of directives
     *
     * @param dir The `FormControlName` directive instance.
     */

  }, {
    key: "removeControl",
    value: function removeControl(dir) {
      removeDir(this.directives, dir);
    }
    /**
     * Adds a new `FormGroupName` directive instance to the form.
     *
     * @param dir The `FormGroupName` directive instance.
     */

  }, {
    key: "addFormGroup",
    value: function addFormGroup(dir) {
      var ctrl = this.form.get(dir.path);
      setUpFormContainer(ctrl, dir);
      ctrl.updateValueAndValidity({
        emitEvent: false
      });
    }
    /**
     * No-op method to remove the form group.
     *
     * @param dir The `FormGroupName` directive instance.
     */

  }, {
    key: "removeFormGroup",
    value: function removeFormGroup(dir) {}
    /**
     * @description
     * Retrieves the `FormGroup` for a provided `FormGroupName` directive instance
     *
     * @param dir The `FormGroupName` directive instance.
     */

  }, {
    key: "getFormGroup",
    value: function getFormGroup(dir) {
      return this.form.get(dir.path);
    }
    /**
     * Adds a new `FormArrayName` directive instance to the form.
     *
     * @param dir The `FormArrayName` directive instance.
     */

  }, {
    key: "addFormArray",
    value: function addFormArray(dir) {
      var ctrl = this.form.get(dir.path);
      setUpFormContainer(ctrl, dir);
      ctrl.updateValueAndValidity({
        emitEvent: false
      });
    }
    /**
     * No-op method to remove the form array.
     *
     * @param dir The `FormArrayName` directive instance.
     */

  }, {
    key: "removeFormArray",
    value: function removeFormArray(dir) {}
    /**
     * @description
     * Retrieves the `FormArray` for a provided `FormArrayName` directive instance.
     *
     * @param dir The `FormArrayName` directive instance.
     */

  }, {
    key: "getFormArray",
    value: function getFormArray(dir) {
      return this.form.get(dir.path);
    }
    /**
     * Sets the new value for the provided `FormControlName` directive.
     *
     * @param dir The `FormControlName` directive instance.
     * @param value The new value for the directive's control.
     */

  }, {
    key: "updateModel",
    value: function updateModel(dir, value) {
      var ctrl = this.form.get(dir.path);
      ctrl.setValue(value);
    }
    /**
     * @description
     * Method called with the "submit" event is triggered on the form.
     * Triggers the `ngSubmit` emitter to emit the "submit" event as its payload.
     *
     * @param $event The "submit" event object
     */

  }, {
    key: "onSubmit",
    value: function onSubmit($event) {
      this.submitted = true;
      syncPendingControls(this.form, this.directives);
      this.ngSubmit.emit($event);
      return false;
    }
    /**
     * @description
     * Method called when the "reset" event is triggered on the form.
     */

  }, {
    key: "onReset",
    value: function onReset() {
      this.resetForm();
    }
    /**
     * @description
     * Resets the form to an initial value and resets its submitted status.
     *
     * @param value The new value for the form.
     */

  }, {
    key: "resetForm",
    value: function resetForm() {
      var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : undefined;
      this.form.reset(value);
      this.submitted = false;
    }
    /** @internal */

  }, {
    key: "_updateDomValue",
    value: function _updateDomValue() {
      var _this33 = this;

      this.directives.forEach(function (dir) {
        var newCtrl = _this33.form.get(dir.path);

        if (dir.control !== newCtrl) {
          cleanUpControl(dir.control, dir);
          if (newCtrl) setUpControl(newCtrl, dir);
          dir.control = newCtrl;
        }
      });

      this.form._updateTreeValidity({
        emitEvent: false
      });
    }
  }, {
    key: "_updateRegistrations",
    value: function _updateRegistrations() {
      var _this34 = this;

      this.form._registerOnCollectionChange(function () {
        return _this34._updateDomValue();
      });

      if (this._oldForm) this._oldForm._registerOnCollectionChange(function () {});
      this._oldForm = this.form;
    }
  }, {
    key: "_updateValidators",
    value: function _updateValidators() {
      var sync = composeValidators(this._validators);
      this.form.validator = Validators.compose([this.form.validator, sync]);
      var async = composeAsyncValidators(this._asyncValidators);
      this.form.asyncValidator = Validators.composeAsync([this.form.asyncValidator, async]);
    }
  }, {
    key: "_checkFormPresent",
    value: function _checkFormPresent() {
      if (!this.form && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        ReactiveErrors.missingFormException();
      }
    }
  }, {
    key: "formDirective",
    get: function get() {
      return this;
    }
    /**
     * @description
     * Returns the `FormGroup` bound to this directive.
     */

  }, {
    key: "control",
    get: function get() {
      return this.form;
    }
    /**
     * @description
     * Returns an array representing the path to this group. Because this directive
     * always lives at the top level of a form, it always an empty array.
     */

  }, {
    key: "path",
    get: function get() {
      return [];
    }
  }]);

  return FormGroupDirective;
}(ControlContainer);

FormGroupDirective.ɵfac = function FormGroupDirective_Factory(t) {
  return new (t || FormGroupDirective)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10));
};

FormGroupDirective.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: FormGroupDirective,
  selectors: [["", "formGroup", ""]],
  hostBindings: function FormGroupDirective_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵlistener"]("submit", function FormGroupDirective_submit_HostBindingHandler($event) {
        return ctx.onSubmit($event);
      })("reset", function FormGroupDirective_reset_HostBindingHandler() {
        return ctx.onReset();
      });
    }
  },
  inputs: {
    form: ["formGroup", "form"]
  },
  outputs: {
    ngSubmit: "ngSubmit"
  },
  exportAs: ["ngForm"],
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([formDirectiveProvider$1]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});

FormGroupDirective.ctorParameters = function () {
  return [{
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }];
};

FormGroupDirective.propDecorators = {
  form: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['formGroup']
  }],
  ngSubmit: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormGroupDirective, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formGroup]',
      providers: [formDirectiveProvider$1],
      host: {
        '(submit)': 'onSubmit($event)',
        '(reset)': 'onReset()'
      },
      exportAs: 'ngForm'
    }]
  }], function () {
    return [{
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }];
  }, {
    form: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['formGroup']
    }],
    ngSubmit: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"]
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var formGroupNameProvider = {
  provide: ControlContainer,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return FormGroupName;
  })
};
/**
 * @description
 *
 * Syncs a nested `FormGroup` to a DOM element.
 *
 * This directive can only be used with a parent `FormGroupDirective`.
 *
 * It accepts the string name of the nested `FormGroup` to link, and
 * looks for a `FormGroup` registered with that name in the parent
 * `FormGroup` instance you passed into `FormGroupDirective`.
 *
 * Use nested form groups to validate a sub-group of a
 * form separately from the rest or to group the values of certain
 * controls into their own nested object.
 *
 * @see [Reactive Forms Guide](guide/reactive-forms)
 *
 * @usageNotes
 *
 * ### Access the group by name
 *
 * The following example uses the {@link AbstractControl#get get} method to access the
 * associated `FormGroup`
 *
 * ```ts
 *   this.form.get('name');
 * ```
 *
 * ### Access individual controls in the group
 *
 * The following example uses the {@link AbstractControl#get get} method to access
 * individual controls within the group using dot syntax.
 *
 * ```ts
 *   this.form.get('name.first');
 * ```
 *
 * ### Register a nested `FormGroup`.
 *
 * The following example registers a nested *name* `FormGroup` within an existing `FormGroup`,
 * and provides methods to retrieve the nested `FormGroup` and individual controls.
 *
 * {@example forms/ts/nestedFormGroup/nested_form_group_example.ts region='Component'}
 *
 * @ngModule ReactiveFormsModule
 * @publicApi
 */

var FormGroupName = /*#__PURE__*/function (_AbstractFormGroupDir2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormGroupName, _AbstractFormGroupDir2);

  var _super14 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormGroupName);

  function FormGroupName(parent, validators, asyncValidators) {
    var _this35;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormGroupName);

    _this35 = _super14.call(this);
    _this35._parent = parent;
    _this35._validators = validators;
    _this35._asyncValidators = asyncValidators;
    return _this35;
  }
  /** @internal */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormGroupName, [{
    key: "_checkParentType",
    value: function _checkParentType() {
      if (_hasInvalidParent(this._parent) && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        ReactiveErrors.groupParentException();
      }
    }
  }]);

  return FormGroupName;
}(AbstractFormGroupDirective);

FormGroupName.ɵfac = function FormGroupName_Factory(t) {
  return new (t || FormGroupName)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](ControlContainer, 13), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10));
};

FormGroupName.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: FormGroupName,
  selectors: [["", "formGroupName", ""]],
  inputs: {
    name: ["formGroupName", "name"]
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([formGroupNameProvider]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});

FormGroupName.ctorParameters = function () {
  return [{
    type: ControlContainer,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }];
};

FormGroupName.propDecorators = {
  name: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['formGroupName']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormGroupName, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formGroupName]',
      providers: [formGroupNameProvider]
    }]
  }], function () {
    return [{
      type: ControlContainer,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }];
  }, {
    name: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['formGroupName']
    }]
  });
})();

var formArrayNameProvider = {
  provide: ControlContainer,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return FormArrayName;
  })
};
/**
 * @description
 *
 * Syncs a nested `FormArray` to a DOM element.
 *
 * This directive is designed to be used with a parent `FormGroupDirective` (selector:
 * `[formGroup]`).
 *
 * It accepts the string name of the nested `FormArray` you want to link, and
 * will look for a `FormArray` registered with that name in the parent
 * `FormGroup` instance you passed into `FormGroupDirective`.
 *
 * @see [Reactive Forms Guide](guide/reactive-forms)
 * @see `AbstractControl`
 *
 * @usageNotes
 *
 * ### Example
 *
 * {@example forms/ts/nestedFormArray/nested_form_array_example.ts region='Component'}
 *
 * @ngModule ReactiveFormsModule
 * @publicApi
 */

var FormArrayName = /*#__PURE__*/function (_ControlContainer4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormArrayName, _ControlContainer4);

  var _super15 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormArrayName);

  function FormArrayName(parent, validators, asyncValidators) {
    var _this36;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormArrayName);

    _this36 = _super15.call(this);
    _this36._parent = parent;
    _this36._validators = validators;
    _this36._asyncValidators = asyncValidators;
    return _this36;
  }
  /**
   * A lifecycle method called when the directive's inputs are initialized. For internal use only.
   * @throws If the directive does not have a valid parent.
   * @nodoc
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormArrayName, [{
    key: "ngOnInit",
    value: function ngOnInit() {
      this._checkParentType();

      this.formDirective.addFormArray(this);
    }
    /**
     * A lifecycle method called before the directive's instance is destroyed. For internal use only.
     * @nodoc
     */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this.formDirective) {
        this.formDirective.removeFormArray(this);
      }
    }
    /**
     * @description
     * The `FormArray` bound to this directive.
     */

  }, {
    key: "_checkParentType",
    value: function _checkParentType() {
      if (_hasInvalidParent(this._parent) && (typeof ngDevMode === 'undefined' || ngDevMode)) {
        ReactiveErrors.arrayParentException();
      }
    }
  }, {
    key: "control",
    get: function get() {
      return this.formDirective.getFormArray(this);
    }
    /**
     * @description
     * The top-level directive for this group if present, otherwise null.
     */

  }, {
    key: "formDirective",
    get: function get() {
      return this._parent ? this._parent.formDirective : null;
    }
    /**
     * @description
     * Returns an array that represents the path from the top-level form to this control.
     * Each index is the string name of the control on that level.
     */

  }, {
    key: "path",
    get: function get() {
      return controlPath(this.name == null ? this.name : this.name.toString(), this._parent);
    }
    /**
     * @description
     * Synchronous validator function composed of all the synchronous validators registered with this
     * directive.
     */

  }, {
    key: "validator",
    get: function get() {
      return composeValidators(this._validators);
    }
    /**
     * @description
     * Async validator function composed of all the async validators registered with this directive.
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return composeAsyncValidators(this._asyncValidators);
    }
  }]);

  return FormArrayName;
}(ControlContainer);

FormArrayName.ɵfac = function FormArrayName_Factory(t) {
  return new (t || FormArrayName)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](ControlContainer, 13), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10));
};

FormArrayName.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: FormArrayName,
  selectors: [["", "formArrayName", ""]],
  inputs: {
    name: ["formArrayName", "name"]
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([formArrayNameProvider]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});

FormArrayName.ctorParameters = function () {
  return [{
    type: ControlContainer,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }];
};

FormArrayName.propDecorators = {
  name: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['formArrayName']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormArrayName, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formArrayName]',
      providers: [formArrayNameProvider]
    }]
  }], function () {
    return [{
      type: ControlContainer,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }];
  }, {
    name: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['formArrayName']
    }]
  });
})();

function _hasInvalidParent(parent) {
  return !(parent instanceof FormGroupName) && !(parent instanceof FormGroupDirective) && !(parent instanceof FormArrayName);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var controlNameBinding = {
  provide: NgControl,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return FormControlName;
  })
};
/**
 * @description
 * Syncs a `FormControl` in an existing `FormGroup` to a form control
 * element by name.
 *
 * @see [Reactive Forms Guide](guide/reactive-forms)
 * @see `FormControl`
 * @see `AbstractControl`
 *
 * @usageNotes
 *
 * ### Register `FormControl` within a group
 *
 * The following example shows how to register multiple form controls within a form group
 * and set their value.
 *
 * {@example forms/ts/simpleFormGroup/simple_form_group_example.ts region='Component'}
 *
 * To see `formControlName` examples with different form control types, see:
 *
 * * Radio buttons: `RadioControlValueAccessor`
 * * Selects: `SelectControlValueAccessor`
 *
 * ### Use with ngModel is deprecated
 *
 * Support for using the `ngModel` input property and `ngModelChange` event with reactive
 * form directives has been deprecated in Angular v6 and is scheduled for removal in
 * a future version of Angular.
 *
 * For details, see [Deprecated features](guide/deprecations#ngmodel-with-reactive-forms).
 *
 * @ngModule ReactiveFormsModule
 * @publicApi
 */

var FormControlName = /*#__PURE__*/function (_NgControl3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(FormControlName, _NgControl3);

  var _super16 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(FormControlName);

  function FormControlName(parent, validators, asyncValidators, valueAccessors, _ngModelWarningConfig) {
    var _this37;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormControlName);

    _this37 = _super16.call(this);
    _this37._ngModelWarningConfig = _ngModelWarningConfig;
    _this37._added = false;
    /** @deprecated as of v6 */

    _this37.update = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["EventEmitter"]();
    /**
     * @description
     * Instance property used to track whether an ngModel warning has been sent out for this
     * particular FormControlName instance. Used to support warning config of "always".
     *
     * @internal
     */

    _this37._ngModelWarningSent = false;
    _this37._parent = parent;
    _this37._rawValidators = validators || [];
    _this37._rawAsyncValidators = asyncValidators || [];
    _this37.valueAccessor = selectValueAccessor(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this37), valueAccessors);
    return _this37;
  }
  /**
   * @description
   * Triggers a warning in dev mode that this input should not be used with reactive forms.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormControlName, [{
    key: "ngOnChanges",

    /** @nodoc */
    value: function ngOnChanges(changes) {
      if (!this._added) this._setUpControl();

      if (isPropertyUpdated(changes, this.viewModel)) {
        _ngModelWarning('formControlName', FormControlName, this, this._ngModelWarningConfig);

        this.viewModel = this.model;
        this.formDirective.updateModel(this, this.model);
      }
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this.formDirective) {
        this.formDirective.removeControl(this);
      }
    }
    /**
     * @description
     * Sets the new value for the view model and emits an `ngModelChange` event.
     *
     * @param newValue The new value for the view model.
     */

  }, {
    key: "viewToModelUpdate",
    value: function viewToModelUpdate(newValue) {
      this.viewModel = newValue;
      this.update.emit(newValue);
    }
    /**
     * @description
     * Returns an array that represents the path from the top-level form to this control.
     * Each index is the string name of the control on that level.
     */

  }, {
    key: "_checkParentType",
    value: function _checkParentType() {
      if (typeof ngDevMode === 'undefined' || ngDevMode) {
        if (!(this._parent instanceof FormGroupName) && this._parent instanceof AbstractFormGroupDirective) {
          ReactiveErrors.ngModelGroupException();
        } else if (!(this._parent instanceof FormGroupName) && !(this._parent instanceof FormGroupDirective) && !(this._parent instanceof FormArrayName)) {
          ReactiveErrors.controlParentException();
        }
      }
    }
  }, {
    key: "_setUpControl",
    value: function _setUpControl() {
      this._checkParentType();

      this.control = this.formDirective.addControl(this);

      if (this.control.disabled && this.valueAccessor.setDisabledState) {
        this.valueAccessor.setDisabledState(true);
      }

      this._added = true;
    }
  }, {
    key: "isDisabled",
    set: function set(isDisabled) {
      if (typeof ngDevMode === 'undefined' || ngDevMode) {
        ReactiveErrors.disabledAttrWarning();
      }
    }
  }, {
    key: "path",
    get: function get() {
      return controlPath(this.name == null ? this.name : this.name.toString(), this._parent);
    }
    /**
     * @description
     * The top-level directive for this group if present, otherwise null.
     */

  }, {
    key: "formDirective",
    get: function get() {
      return this._parent ? this._parent.formDirective : null;
    }
    /**
     * @description
     * Synchronous validator function composed of all the synchronous validators
     * registered with this directive.
     */

  }, {
    key: "validator",
    get: function get() {
      return composeValidators(this._rawValidators);
    }
    /**
     * @description
     * Async validator function composed of all the async validators registered with this
     * directive.
     */

  }, {
    key: "asyncValidator",
    get: function get() {
      return composeAsyncValidators(this._rawAsyncValidators);
    }
  }]);

  return FormControlName;
}(NgControl);

FormControlName.ɵfac = function FormControlName_Factory(t) {
  return new (t || FormControlName)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](ControlContainer, 13), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_ASYNC_VALIDATORS, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_VALUE_ACCESSOR, 10), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdirectiveInject"](NG_MODEL_WITH_FORM_CONTROL_WARNING, 8));
};

FormControlName.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: FormControlName,
  selectors: [["", "formControlName", ""]],
  inputs: {
    isDisabled: ["disabled", "isDisabled"],
    name: ["formControlName", "name"],
    model: ["ngModel", "model"]
  },
  outputs: {
    update: "ngModelChange"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([controlNameBinding]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});
/**
 * @description
 * Static property used to track whether any ngModel warnings have been sent across
 * all instances of FormControlName. Used to support warning config of "once".
 *
 * @internal
 */

FormControlName._ngModelWarningSentOnce = false;

FormControlName.ctorParameters = function () {
  return [{
    type: ControlContainer,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_ASYNC_VALIDATORS]
    }]
  }, {
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_VALUE_ACCESSOR]
    }]
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [NG_MODEL_WITH_FORM_CONTROL_WARNING]
    }]
  }];
};

FormControlName.propDecorators = {
  name: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['formControlName']
  }],
  isDisabled: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['disabled']
  }],
  model: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
    args: ['ngModel']
  }],
  update: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"],
    args: ['ngModelChange']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormControlName, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[formControlName]',
      providers: [controlNameBinding]
    }]
  }], function () {
    return [{
      type: ControlContainer,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Host"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_ASYNC_VALIDATORS]
      }]
    }, {
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Self"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_VALUE_ACCESSOR]
      }]
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [NG_MODEL_WITH_FORM_CONTROL_WARNING]
      }]
    }];
  }, {
    update: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Output"],
      args: ['ngModelChange']
    }],
    isDisabled: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['disabled']
    }],
    name: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['formControlName']
    }],
    model: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"],
      args: ['ngModel']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 * Provider which adds `RequiredValidator` to the `NG_VALIDATORS` multi-provider list.
 */


var REQUIRED_VALIDATOR = {
  provide: NG_VALIDATORS,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return RequiredValidator;
  }),
  multi: true
};
/**
 * @description
 * Provider which adds `CheckboxRequiredValidator` to the `NG_VALIDATORS` multi-provider list.
 */

var CHECKBOX_REQUIRED_VALIDATOR = {
  provide: NG_VALIDATORS,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return CheckboxRequiredValidator;
  }),
  multi: true
};
/**
 * @description
 * A directive that adds the `required` validator to any controls marked with the
 * `required` attribute. The directive is provided with the `NG_VALIDATORS` multi-provider list.
 *
 * @see [Form Validation](guide/form-validation)
 *
 * @usageNotes
 *
 * ### Adding a required validator using template-driven forms
 *
 * ```
 * <input name="fullName" ngModel required>
 * ```
 *
 * @ngModule FormsModule
 * @ngModule ReactiveFormsModule
 * @publicApi
 */

var RequiredValidator = /*#__PURE__*/function () {
  function RequiredValidator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, RequiredValidator);

    this._required = false;
  }
  /**
   * @description
   * Tracks changes to the required attribute bound to this directive.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(RequiredValidator, [{
    key: "validate",

    /**
     * Method that validates whether the control is empty.
     * Returns the validation result if enabled, otherwise null.
     * @nodoc
     */
    value: function validate(control) {
      return this.required ? Validators.required(control) : null;
    }
    /**
     * Registers a callback function to call when the validator inputs change.
     * @nodoc
     */

  }, {
    key: "registerOnValidatorChange",
    value: function registerOnValidatorChange(fn) {
      this._onChange = fn;
    }
  }, {
    key: "required",
    get: function get() {
      return this._required;
    },
    set: function set(value) {
      this._required = value != null && value !== false && "".concat(value) !== 'false';
      if (this._onChange) this._onChange();
    }
  }]);

  return RequiredValidator;
}();

RequiredValidator.ɵfac = function RequiredValidator_Factory(t) {
  return new (t || RequiredValidator)();
};

RequiredValidator.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: RequiredValidator,
  selectors: [["", "required", "", "formControlName", "", 3, "type", "checkbox"], ["", "required", "", "formControl", "", 3, "type", "checkbox"], ["", "required", "", "ngModel", "", 3, "type", "checkbox"]],
  hostVars: 1,
  hostBindings: function RequiredValidator_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵattribute"]("required", ctx.required ? "" : null);
    }
  },
  inputs: {
    required: "required"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([REQUIRED_VALIDATOR])]
});
RequiredValidator.propDecorators = {
  required: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](RequiredValidator, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: ':not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]',
      providers: [REQUIRED_VALIDATOR],
      host: {
        '[attr.required]': 'required ? "" : null'
      }
    }]
  }], function () {
    return [];
  }, {
    required: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * A Directive that adds the `required` validator to checkbox controls marked with the
 * `required` attribute. The directive is provided with the `NG_VALIDATORS` multi-provider list.
 *
 * @see [Form Validation](guide/form-validation)
 *
 * @usageNotes
 *
 * ### Adding a required checkbox validator using template-driven forms
 *
 * The following example shows how to add a checkbox required validator to an input attached to an
 * ngModel binding.
 *
 * ```
 * <input type="checkbox" name="active" ngModel required>
 * ```
 *
 * @publicApi
 * @ngModule FormsModule
 * @ngModule ReactiveFormsModule
 */


var CheckboxRequiredValidator = /*#__PURE__*/function (_RequiredValidator) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(CheckboxRequiredValidator, _RequiredValidator);

  var _super17 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(CheckboxRequiredValidator);

  function CheckboxRequiredValidator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, CheckboxRequiredValidator);

    return _super17.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(CheckboxRequiredValidator, [{
    key: "validate",

    /**
     * Method that validates whether or not the checkbox has been checked.
     * Returns the validation result if enabled, otherwise null.
     * @nodoc
     */
    value: function validate(control) {
      return this.required ? Validators.requiredTrue(control) : null;
    }
  }]);

  return CheckboxRequiredValidator;
}(RequiredValidator);

CheckboxRequiredValidator.ɵfac = function CheckboxRequiredValidator_Factory(t) {
  return ɵCheckboxRequiredValidator_BaseFactory(t || CheckboxRequiredValidator);
};

CheckboxRequiredValidator.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: CheckboxRequiredValidator,
  selectors: [["input", "type", "checkbox", "required", "", "formControlName", ""], ["input", "type", "checkbox", "required", "", "formControl", ""], ["input", "type", "checkbox", "required", "", "ngModel", ""]],
  hostVars: 1,
  hostBindings: function CheckboxRequiredValidator_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵattribute"]("required", ctx.required ? "" : null);
    }
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([CHECKBOX_REQUIRED_VALIDATOR]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵInheritDefinitionFeature"]]
});
var ɵCheckboxRequiredValidator_BaseFactory = /*@__PURE__*/_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵgetInheritedFactory"](CheckboxRequiredValidator);
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](CheckboxRequiredValidator, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: 'input[type=checkbox][required][formControlName],input[type=checkbox][required][formControl],input[type=checkbox][required][ngModel]',
      providers: [CHECKBOX_REQUIRED_VALIDATOR],
      host: {
        '[attr.required]': 'required ? "" : null'
      }
    }]
  }], null, null);
})();
/**
 * @description
 * Provider which adds `EmailValidator` to the `NG_VALIDATORS` multi-provider list.
 */


var EMAIL_VALIDATOR = {
  provide: NG_VALIDATORS,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return EmailValidator;
  }),
  multi: true
};
/**
 * A directive that adds the `email` validator to controls marked with the
 * `email` attribute. The directive is provided with the `NG_VALIDATORS` multi-provider list.
 *
 * @see [Form Validation](guide/form-validation)
 *
 * @usageNotes
 *
 * ### Adding an email validator
 *
 * The following example shows how to add an email validator to an input attached to an ngModel
 * binding.
 *
 * ```
 * <input type="email" name="email" ngModel email>
 * <input type="email" name="email" ngModel email="true">
 * <input type="email" name="email" ngModel [email]="true">
 * ```
 *
 * @publicApi
 * @ngModule FormsModule
 * @ngModule ReactiveFormsModule
 */

var EmailValidator = /*#__PURE__*/function () {
  function EmailValidator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, EmailValidator);

    this._enabled = false;
  }
  /**
   * @description
   * Tracks changes to the email attribute bound to this directive.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(EmailValidator, [{
    key: "validate",

    /**
     * Method that validates whether an email address is valid.
     * Returns the validation result if enabled, otherwise null.
     * @nodoc
     */
    value: function validate(control) {
      return this._enabled ? Validators.email(control) : null;
    }
    /**
     * Registers a callback function to call when the validator inputs change.
     * @nodoc
     */

  }, {
    key: "registerOnValidatorChange",
    value: function registerOnValidatorChange(fn) {
      this._onChange = fn;
    }
  }, {
    key: "email",
    set: function set(value) {
      this._enabled = value === '' || value === true || value === 'true';
      if (this._onChange) this._onChange();
    }
  }]);

  return EmailValidator;
}();

EmailValidator.ɵfac = function EmailValidator_Factory(t) {
  return new (t || EmailValidator)();
};

EmailValidator.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: EmailValidator,
  selectors: [["", "email", "", "formControlName", ""], ["", "email", "", "formControl", ""], ["", "email", "", "ngModel", ""]],
  inputs: {
    email: "email"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([EMAIL_VALIDATOR])]
});
EmailValidator.propDecorators = {
  email: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](EmailValidator, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[email][formControlName],[email][formControl],[email][ngModel]',
      providers: [EMAIL_VALIDATOR]
    }]
  }], function () {
    return [];
  }, {
    email: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @description
 * Provider which adds `MinLengthValidator` to the `NG_VALIDATORS` multi-provider list.
 */


var MIN_LENGTH_VALIDATOR = {
  provide: NG_VALIDATORS,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return MinLengthValidator;
  }),
  multi: true
};
/**
 * A directive that adds minimum length validation to controls marked with the
 * `minlength` attribute. The directive is provided with the `NG_VALIDATORS` multi-provider list.
 *
 * @see [Form Validation](guide/form-validation)
 *
 * @usageNotes
 *
 * ### Adding a minimum length validator
 *
 * The following example shows how to add a minimum length validator to an input attached to an
 * ngModel binding.
 *
 * ```html
 * <input name="firstName" ngModel minlength="4">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var MinLengthValidator = /*#__PURE__*/function () {
  function MinLengthValidator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, MinLengthValidator);

    this._validator = Validators.nullValidator;
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(MinLengthValidator, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      if ('minlength' in changes) {
        this._createValidator();

        if (this._onChange) this._onChange();
      }
    }
    /**
     * Method that validates whether the value meets a minimum length requirement.
     * Returns the validation result if enabled, otherwise null.
     * @nodoc
     */

  }, {
    key: "validate",
    value: function validate(control) {
      return this.minlength == null ? null : this._validator(control);
    }
    /**
     * Registers a callback function to call when the validator inputs change.
     * @nodoc
     */

  }, {
    key: "registerOnValidatorChange",
    value: function registerOnValidatorChange(fn) {
      this._onChange = fn;
    }
  }, {
    key: "_createValidator",
    value: function _createValidator() {
      this._validator = Validators.minLength(typeof this.minlength === 'number' ? this.minlength : parseInt(this.minlength, 10));
    }
  }]);

  return MinLengthValidator;
}();

MinLengthValidator.ɵfac = function MinLengthValidator_Factory(t) {
  return new (t || MinLengthValidator)();
};

MinLengthValidator.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: MinLengthValidator,
  selectors: [["", "minlength", "", "formControlName", ""], ["", "minlength", "", "formControl", ""], ["", "minlength", "", "ngModel", ""]],
  hostVars: 1,
  hostBindings: function MinLengthValidator_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵattribute"]("minlength", ctx.minlength ? ctx.minlength : null);
    }
  },
  inputs: {
    minlength: "minlength"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([MIN_LENGTH_VALIDATOR]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});
MinLengthValidator.propDecorators = {
  minlength: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](MinLengthValidator, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[minlength][formControlName],[minlength][formControl],[minlength][ngModel]',
      providers: [MIN_LENGTH_VALIDATOR],
      host: {
        '[attr.minlength]': 'minlength ? minlength : null'
      }
    }]
  }], function () {
    return [];
  }, {
    minlength: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @description
 * Provider which adds `MaxLengthValidator` to the `NG_VALIDATORS` multi-provider list.
 */


var MAX_LENGTH_VALIDATOR = {
  provide: NG_VALIDATORS,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return MaxLengthValidator;
  }),
  multi: true
};
/**
 * A directive that adds max length validation to controls marked with the
 * `maxlength` attribute. The directive is provided with the `NG_VALIDATORS` multi-provider list.
 *
 * @see [Form Validation](guide/form-validation)
 *
 * @usageNotes
 *
 * ### Adding a maximum length validator
 *
 * The following example shows how to add a maximum length validator to an input attached to an
 * ngModel binding.
 *
 * ```html
 * <input name="firstName" ngModel maxlength="25">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var MaxLengthValidator = /*#__PURE__*/function () {
  function MaxLengthValidator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, MaxLengthValidator);

    this._validator = Validators.nullValidator;
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(MaxLengthValidator, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      if ('maxlength' in changes) {
        this._createValidator();

        if (this._onChange) this._onChange();
      }
    }
    /**
     * Method that validates whether the value exceeds the maximum length requirement.
     * @nodoc
     */

  }, {
    key: "validate",
    value: function validate(control) {
      return this.maxlength != null ? this._validator(control) : null;
    }
    /**
     * Registers a callback function to call when the validator inputs change.
     * @nodoc
     */

  }, {
    key: "registerOnValidatorChange",
    value: function registerOnValidatorChange(fn) {
      this._onChange = fn;
    }
  }, {
    key: "_createValidator",
    value: function _createValidator() {
      this._validator = Validators.maxLength(typeof this.maxlength === 'number' ? this.maxlength : parseInt(this.maxlength, 10));
    }
  }]);

  return MaxLengthValidator;
}();

MaxLengthValidator.ɵfac = function MaxLengthValidator_Factory(t) {
  return new (t || MaxLengthValidator)();
};

MaxLengthValidator.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: MaxLengthValidator,
  selectors: [["", "maxlength", "", "formControlName", ""], ["", "maxlength", "", "formControl", ""], ["", "maxlength", "", "ngModel", ""]],
  hostVars: 1,
  hostBindings: function MaxLengthValidator_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵattribute"]("maxlength", ctx.maxlength ? ctx.maxlength : null);
    }
  },
  inputs: {
    maxlength: "maxlength"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([MAX_LENGTH_VALIDATOR]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});
MaxLengthValidator.propDecorators = {
  maxlength: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](MaxLengthValidator, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]',
      providers: [MAX_LENGTH_VALIDATOR],
      host: {
        '[attr.maxlength]': 'maxlength ? maxlength : null'
      }
    }]
  }], function () {
    return [];
  }, {
    maxlength: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @description
 * Provider which adds `PatternValidator` to the `NG_VALIDATORS` multi-provider list.
 */


var PATTERN_VALIDATOR = {
  provide: NG_VALIDATORS,
  useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
    return PatternValidator;
  }),
  multi: true
};
/**
 * @description
 * A directive that adds regex pattern validation to controls marked with the
 * `pattern` attribute. The regex must match the entire control value.
 * The directive is provided with the `NG_VALIDATORS` multi-provider list.
 *
 * @see [Form Validation](guide/form-validation)
 *
 * @usageNotes
 *
 * ### Adding a pattern validator
 *
 * The following example shows how to add a pattern validator to an input attached to an
 * ngModel binding.
 *
 * ```html
 * <input name="firstName" ngModel pattern="[a-zA-Z ]*">
 * ```
 *
 * @ngModule ReactiveFormsModule
 * @ngModule FormsModule
 * @publicApi
 */

var PatternValidator = /*#__PURE__*/function () {
  function PatternValidator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, PatternValidator);

    this._validator = Validators.nullValidator;
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(PatternValidator, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      if ('pattern' in changes) {
        this._createValidator();

        if (this._onChange) this._onChange();
      }
    }
    /**
     * Method that validates whether the value matches the the pattern requirement.
     * @nodoc
     */

  }, {
    key: "validate",
    value: function validate(control) {
      return this._validator(control);
    }
    /**
     * Registers a callback function to call when the validator inputs change.
     * @nodoc
     */

  }, {
    key: "registerOnValidatorChange",
    value: function registerOnValidatorChange(fn) {
      this._onChange = fn;
    }
  }, {
    key: "_createValidator",
    value: function _createValidator() {
      this._validator = Validators.pattern(this.pattern);
    }
  }]);

  return PatternValidator;
}();

PatternValidator.ɵfac = function PatternValidator_Factory(t) {
  return new (t || PatternValidator)();
};

PatternValidator.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineDirective"]({
  type: PatternValidator,
  selectors: [["", "pattern", "", "formControlName", ""], ["", "pattern", "", "formControl", ""], ["", "pattern", "", "ngModel", ""]],
  hostVars: 1,
  hostBindings: function PatternValidator_HostBindings(rf, ctx) {
    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵattribute"]("pattern", ctx.pattern ? ctx.pattern : null);
    }
  },
  inputs: {
    pattern: "pattern"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵProvidersFeature"]([PATTERN_VALIDATOR]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵNgOnChangesFeature"]]
});
PatternValidator.propDecorators = {
  pattern: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](PatternValidator, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Directive"],
    args: [{
      selector: '[pattern][formControlName],[pattern][formControl],[pattern][ngModel]',
      providers: [PATTERN_VALIDATOR],
      host: {
        '[attr.pattern]': 'pattern ? pattern : null'
      }
    }]
  }], function () {
    return [];
  }, {
    pattern: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Input"]
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SHARED_FORM_DIRECTIVES = [ɵNgNoValidate, NgSelectOption, ɵNgSelectMultipleOption, DefaultValueAccessor, NumberValueAccessor, RangeValueAccessor, CheckboxControlValueAccessor, SelectControlValueAccessor, SelectMultipleControlValueAccessor, RadioControlValueAccessor, NgControlStatus, NgControlStatusGroup, RequiredValidator, MinLengthValidator, MaxLengthValidator, PatternValidator, CheckboxRequiredValidator, EmailValidator];
var TEMPLATE_DRIVEN_DIRECTIVES = [NgModel, NgModelGroup, NgForm];
var REACTIVE_DRIVEN_DIRECTIVES = [FormControlDirective, FormGroupDirective, FormControlName, FormGroupName, FormArrayName];
/**
 * Internal module used for sharing directives between FormsModule and ReactiveFormsModule
 */

var ɵInternalFormsSharedModule = function ɵInternalFormsSharedModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ɵInternalFormsSharedModule);
};

ɵInternalFormsSharedModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineNgModule"]({
  type: ɵInternalFormsSharedModule
});
ɵInternalFormsSharedModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjector"]({
  factory: function ɵInternalFormsSharedModule_Factory(t) {
    return new (t || ɵInternalFormsSharedModule)();
  }
});

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵsetNgModuleScope"](ɵInternalFormsSharedModule, {
    declarations: [ɵNgNoValidate, NgSelectOption, ɵNgSelectMultipleOption, DefaultValueAccessor, NumberValueAccessor, RangeValueAccessor, CheckboxControlValueAccessor, SelectControlValueAccessor, SelectMultipleControlValueAccessor, RadioControlValueAccessor, NgControlStatus, NgControlStatusGroup, RequiredValidator, MinLengthValidator, MaxLengthValidator, PatternValidator, CheckboxRequiredValidator, EmailValidator],
    exports: [ɵNgNoValidate, NgSelectOption, ɵNgSelectMultipleOption, DefaultValueAccessor, NumberValueAccessor, RangeValueAccessor, CheckboxControlValueAccessor, SelectControlValueAccessor, SelectMultipleControlValueAccessor, RadioControlValueAccessor, NgControlStatus, NgControlStatusGroup, RequiredValidator, MinLengthValidator, MaxLengthValidator, PatternValidator, CheckboxRequiredValidator, EmailValidator]
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](ɵInternalFormsSharedModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgModule"],
    args: [{
      declarations: SHARED_FORM_DIRECTIVES,
      exports: SHARED_FORM_DIRECTIVES
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function isAbstractControlOptions(options) {
  return options.asyncValidators !== undefined || options.validators !== undefined || options.updateOn !== undefined;
}
/**
 * @description
 * Creates an `AbstractControl` from a user-specified configuration.
 *
 * The `FormBuilder` provides syntactic sugar that shortens creating instances of a `FormControl`,
 * `FormGroup`, or `FormArray`. It reduces the amount of boilerplate needed to build complex
 * forms.
 *
 * @see [Reactive Forms Guide](/guide/reactive-forms)
 *
 * @publicApi
 */


var FormBuilder = /*#__PURE__*/function () {
  function FormBuilder() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormBuilder);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(FormBuilder, [{
    key: "group",

    /**
     * @description
     * Construct a new `FormGroup` instance.
     *
     * @param controlsConfig A collection of child controls. The key for each child is the name
     * under which it is registered.
     *
     * @param options Configuration options object for the `FormGroup`. The object can
     * have two shapes:
     *
     * 1) `AbstractControlOptions` object (preferred), which consists of:
     * * `validators`: A synchronous validator function, or an array of validator functions
     * * `asyncValidators`: A single async validator or array of async validator functions
     * * `updateOn`: The event upon which the control should be updated (options: 'change' | 'blur' |
     * submit')
     *
     * 2) Legacy configuration object, which consists of:
     * * `validator`: A synchronous validator function, or an array of validator functions
     * * `asyncValidator`: A single async validator or array of async validator functions
     *
     */
    value: function group(controlsConfig) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      var controls = this._reduceControls(controlsConfig);

      var validators = null;
      var asyncValidators = null;
      var updateOn = undefined;

      if (options != null) {
        if (isAbstractControlOptions(options)) {
          // `options` are `AbstractControlOptions`
          validators = options.validators != null ? options.validators : null;
          asyncValidators = options.asyncValidators != null ? options.asyncValidators : null;
          updateOn = options.updateOn != null ? options.updateOn : undefined;
        } else {
          // `options` are legacy form group options
          validators = options['validator'] != null ? options['validator'] : null;
          asyncValidators = options['asyncValidator'] != null ? options['asyncValidator'] : null;
        }
      }

      return new FormGroup(controls, {
        asyncValidators: asyncValidators,
        updateOn: updateOn,
        validators: validators
      });
    }
    /**
     * @description
     * Construct a new `FormControl` with the given state, validators and options.
     *
     * @param formState Initializes the control with an initial state value, or
     * with an object that contains both a value and a disabled status.
     *
     * @param validatorOrOpts A synchronous validator function, or an array of
     * such functions, or an `AbstractControlOptions` object that contains
     * validation functions and a validation trigger.
     *
     * @param asyncValidator A single async validator or array of async validator
     * functions.
     *
     * @usageNotes
     *
     * ### Initialize a control as disabled
     *
     * The following example returns a control with an initial value in a disabled state.
     *
     * <code-example path="forms/ts/formBuilder/form_builder_example.ts" region="disabled-control">
     * </code-example>
     */

  }, {
    key: "control",
    value: function control(formState, validatorOrOpts, asyncValidator) {
      return new FormControl(formState, validatorOrOpts, asyncValidator);
    }
    /**
     * Constructs a new `FormArray` from the given array of configurations,
     * validators and options.
     *
     * @param controlsConfig An array of child controls or control configs. Each
     * child control is given an index when it is registered.
     *
     * @param validatorOrOpts A synchronous validator function, or an array of
     * such functions, or an `AbstractControlOptions` object that contains
     * validation functions and a validation trigger.
     *
     * @param asyncValidator A single async validator or array of async validator
     * functions.
     */

  }, {
    key: "array",
    value: function array(controlsConfig, validatorOrOpts, asyncValidator) {
      var _this38 = this;

      var controls = controlsConfig.map(function (c) {
        return _this38._createControl(c);
      });
      return new FormArray(controls, validatorOrOpts, asyncValidator);
    }
    /** @internal */

  }, {
    key: "_reduceControls",
    value: function _reduceControls(controlsConfig) {
      var _this39 = this;

      var controls = {};
      Object.keys(controlsConfig).forEach(function (controlName) {
        controls[controlName] = _this39._createControl(controlsConfig[controlName]);
      });
      return controls;
    }
    /** @internal */

  }, {
    key: "_createControl",
    value: function _createControl(controlConfig) {
      if (controlConfig instanceof FormControl || controlConfig instanceof FormGroup || controlConfig instanceof FormArray) {
        return controlConfig;
      } else if (Array.isArray(controlConfig)) {
        var value = controlConfig[0];
        var validator = controlConfig.length > 1 ? controlConfig[1] : null;
        var asyncValidator = controlConfig.length > 2 ? controlConfig[2] : null;
        return this.control(value, validator, asyncValidator);
      } else {
        return this.control(controlConfig);
      }
    }
  }]);

  return FormBuilder;
}();

FormBuilder.ɵfac = function FormBuilder_Factory(t) {
  return new (t || FormBuilder)();
};

FormBuilder.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: FormBuilder,
  factory: FormBuilder.ɵfac
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormBuilder, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var VERSION = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["Version"]('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Exports the required providers and directives for template-driven forms,
 * making them available for import by NgModules that import this module.
 *
 * @see [Forms Overview](/guide/forms-overview)
 * @see [Template-driven Forms Guide](/guide/forms)
 *
 * @publicApi
 */

var FormsModule = function FormsModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, FormsModule);
};

FormsModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineNgModule"]({
  type: FormsModule
});
FormsModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjector"]({
  factory: function FormsModule_Factory(t) {
    return new (t || FormsModule)();
  },
  providers: [RadioControlRegistry],
  imports: [ɵInternalFormsSharedModule]
});

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵsetNgModuleScope"](FormsModule, {
    declarations: [NgModel, NgModelGroup, NgForm],
    exports: [ɵInternalFormsSharedModule, NgModel, NgModelGroup, NgForm]
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](FormsModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgModule"],
    args: [{
      declarations: TEMPLATE_DRIVEN_DIRECTIVES,
      providers: [RadioControlRegistry],
      exports: [ɵInternalFormsSharedModule, TEMPLATE_DRIVEN_DIRECTIVES]
    }]
  }], null, null);
})();
/**
 * Exports the required infrastructure and directives for reactive forms,
 * making them available for import by NgModules that import this module.
 *
 * @see [Forms Overview](guide/forms-overview)
 * @see [Reactive Forms Guide](guide/reactive-forms)
 *
 * @publicApi
 */


var ReactiveFormsModule = /*#__PURE__*/function () {
  function ReactiveFormsModule() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ReactiveFormsModule);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(ReactiveFormsModule, null, [{
    key: "withConfig",

    /**
     * @description
     * Provides options for configuring the reactive forms module.
     *
     * @param opts An object of configuration options
     * * `warnOnNgModelWithFormControl` Configures when to emit a warning when an `ngModel`
     * binding is used with reactive form directives.
     */
    value: function withConfig(opts) {
      return {
        ngModule: ReactiveFormsModule,
        providers: [{
          provide: NG_MODEL_WITH_FORM_CONTROL_WARNING,
          useValue: opts.warnOnNgModelWithFormControl
        }]
      };
    }
  }]);

  return ReactiveFormsModule;
}();

ReactiveFormsModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineNgModule"]({
  type: ReactiveFormsModule
});
ReactiveFormsModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjector"]({
  factory: function ReactiveFormsModule_Factory(t) {
    return new (t || ReactiveFormsModule)();
  },
  providers: [FormBuilder, RadioControlRegistry],
  imports: [ɵInternalFormsSharedModule]
});

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵsetNgModuleScope"](ReactiveFormsModule, {
    declarations: [FormControlDirective, FormGroupDirective, FormControlName, FormGroupName, FormArrayName],
    exports: [ɵInternalFormsSharedModule, FormControlDirective, FormGroupDirective, FormControlName, FormGroupName, FormArrayName]
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](ReactiveFormsModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgModule"],
    args: [{
      declarations: [REACTIVE_DRIVEN_DIRECTIVES],
      providers: [FormBuilder, RadioControlRegistry],
      exports: [ɵInternalFormsSharedModule, REACTIVE_DRIVEN_DIRECTIVES]
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */




/***/ }),

/***/ "3UWI":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/auditTime.js ***!
  \********************************************************************/
/*! exports provided: auditTime */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "auditTime", function() { return auditTime; });
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _audit__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./audit */ "tnsW");
/* harmony import */ var _observable_timer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../observable/timer */ "PqYM");



function auditTime(duration) {
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_0__["async"];
  return Object(_audit__WEBPACK_IMPORTED_MODULE_1__["audit"])(function () {
    return Object(_observable_timer__WEBPACK_IMPORTED_MODULE_2__["timer"])(duration, scheduler);
  });
}

/***/ }),

/***/ "4A3s":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/ignoreElements.js ***!
  \*************************************************************************/
/*! exports provided: ignoreElements */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ignoreElements", function() { return ignoreElements; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function ignoreElements() {
  return function ignoreElementsOperatorFunction(source) {
    return source.lift(new IgnoreElementsOperator());
  };
}

var IgnoreElementsOperator = /*#__PURE__*/function () {
  function IgnoreElementsOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, IgnoreElementsOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(IgnoreElementsOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new IgnoreElementsSubscriber(subscriber));
    }
  }]);

  return IgnoreElementsOperator;
}();

var IgnoreElementsSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(IgnoreElementsSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(IgnoreElementsSubscriber);

  function IgnoreElementsSubscriber() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, IgnoreElementsSubscriber);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(IgnoreElementsSubscriber, [{
    key: "_next",
    value: function _next(unused) {}
  }]);

  return IgnoreElementsSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "4I5i":
/*!*****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/ArgumentOutOfRangeError.js ***!
  \*****************************************************************************/
/*! exports provided: ArgumentOutOfRangeError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ArgumentOutOfRangeError", function() { return ArgumentOutOfRangeError; });
var ArgumentOutOfRangeErrorImpl = function () {
  function ArgumentOutOfRangeErrorImpl() {
    Error.call(this);
    this.message = 'argument out of range';
    this.name = 'ArgumentOutOfRangeError';
    return this;
  }

  ArgumentOutOfRangeErrorImpl.prototype = Object.create(Error.prototype);
  return ArgumentOutOfRangeErrorImpl;
}();

var ArgumentOutOfRangeError = ArgumentOutOfRangeErrorImpl;

/***/ }),

/***/ "4MV3":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/gu.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Gujarati [gu]
//! author : Kaushik Thanki : https://github.com/Kaushik1987
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '૧',
    2: '૨',
    3: '૩',
    4: '૪',
    5: '૫',
    6: '૬',
    7: '૭',
    8: '૮',
    9: '૯',
    0: '૦'
  },
      numberMap = {
    '૧': '1',
    '૨': '2',
    '૩': '3',
    '૪': '4',
    '૫': '5',
    '૬': '6',
    '૭': '7',
    '૮': '8',
    '૯': '9',
    '૦': '0'
  };
  var gu = moment.defineLocale('gu', {
    months: 'જાન્યુઆરી_ફેબ્રુઆરી_માર્ચ_એપ્રિલ_મે_જૂન_જુલાઈ_ઑગસ્ટ_સપ્ટેમ્બર_ઑક્ટ્બર_નવેમ્બર_ડિસેમ્બર'.split('_'),
    monthsShort: 'જાન્યુ._ફેબ્રુ._માર્ચ_એપ્રિ._મે_જૂન_જુલા._ઑગ._સપ્ટે._ઑક્ટ્._નવે._ડિસે.'.split('_'),
    monthsParseExact: true,
    weekdays: 'રવિવાર_સોમવાર_મંગળવાર_બુધ્વાર_ગુરુવાર_શુક્રવાર_શનિવાર'.split('_'),
    weekdaysShort: 'રવિ_સોમ_મંગળ_બુધ્_ગુરુ_શુક્ર_શનિ'.split('_'),
    weekdaysMin: 'ર_સો_મં_બુ_ગુ_શુ_શ'.split('_'),
    longDateFormat: {
      LT: 'A h:mm વાગ્યે',
      LTS: 'A h:mm:ss વાગ્યે',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm વાગ્યે',
      LLLL: 'dddd, D MMMM YYYY, A h:mm વાગ્યે'
    },
    calendar: {
      sameDay: '[આજ] LT',
      nextDay: '[કાલે] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[ગઇકાલે] LT',
      lastWeek: '[પાછલા] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s મા',
      past: '%s પહેલા',
      s: 'અમુક પળો',
      ss: '%d સેકંડ',
      m: 'એક મિનિટ',
      mm: '%d મિનિટ',
      h: 'એક કલાક',
      hh: '%d કલાક',
      d: 'એક દિવસ',
      dd: '%d દિવસ',
      M: 'એક મહિનો',
      MM: '%d મહિનો',
      y: 'એક વર્ષ',
      yy: '%d વર્ષ'
    },
    preparse: function preparse(string) {
      return string.replace(/[૧૨૩૪૫૬૭૮૯૦]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    // Gujarati notation for meridiems are quite fuzzy in practice. While there exists
    // a rigid notion of a 'Pahar' it is not used as rigidly in modern Gujarati.
    meridiemParse: /રાત|બપોર|સવાર|સાંજ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'રાત') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'સવાર') {
        return hour;
      } else if (meridiem === 'બપોર') {
        return hour >= 10 ? hour : hour + 12;
      } else if (meridiem === 'સાંજ') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'રાત';
      } else if (hour < 10) {
        return 'સવાર';
      } else if (hour < 17) {
        return 'બપોર';
      } else if (hour < 20) {
        return 'સાંજ';
      } else {
        return 'રાત';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return gu;
});

/***/ }),

/***/ "4O5X":
/*!****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/bindNodeCallback.js ***!
  \****************************************************************************/
/*! exports provided: bindNodeCallback */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "bindNodeCallback", function() { return bindNodeCallback; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _AsyncSubject__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../AsyncSubject */ "NHP+");
/* harmony import */ var _operators_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../operators/map */ "lJxs");
/* harmony import */ var _util_canReportError__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/canReportError */ "8Qeq");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/isArray */ "DH7j");







function bindNodeCallback(callbackFunc, resultSelector, scheduler) {
  if (resultSelector) {
    if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_5__["isScheduler"])(resultSelector)) {
      scheduler = resultSelector;
    } else {
      return function () {
        return bindNodeCallback(callbackFunc, scheduler).apply(void 0, arguments).pipe(Object(_operators_map__WEBPACK_IMPORTED_MODULE_3__["map"])(function (args) {
          return Object(_util_isArray__WEBPACK_IMPORTED_MODULE_6__["isArray"])(args) ? resultSelector.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args)) : resultSelector(args);
        }));
      };
    }
  }

  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var params = {
      subject: undefined,
      args: args,
      callbackFunc: callbackFunc,
      scheduler: scheduler,
      context: this
    };
    return new _Observable__WEBPACK_IMPORTED_MODULE_1__["Observable"](function (subscriber) {
      var context = params.context;
      var subject = params.subject;

      if (!scheduler) {
        if (!subject) {
          subject = params.subject = new _AsyncSubject__WEBPACK_IMPORTED_MODULE_2__["AsyncSubject"]();

          var handler = function handler() {
            for (var _len2 = arguments.length, innerArgs = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
              innerArgs[_key2] = arguments[_key2];
            }

            var err = innerArgs.shift();

            if (err) {
              subject.error(err);
              return;
            }

            subject.next(innerArgs.length <= 1 ? innerArgs[0] : innerArgs);
            subject.complete();
          };

          try {
            callbackFunc.apply(context, [].concat(args, [handler]));
          } catch (err) {
            if (Object(_util_canReportError__WEBPACK_IMPORTED_MODULE_4__["canReportError"])(subject)) {
              subject.error(err);
            } else {
              console.warn(err);
            }
          }
        }

        return subject.subscribe(subscriber);
      } else {
        return scheduler.schedule(dispatch, 0, {
          params: params,
          subscriber: subscriber,
          context: context
        });
      }
    });
  };
}

function dispatch(state) {
  var _this = this;

  var params = state.params,
      subscriber = state.subscriber,
      context = state.context;
  var callbackFunc = params.callbackFunc,
      args = params.args,
      scheduler = params.scheduler;
  var subject = params.subject;

  if (!subject) {
    subject = params.subject = new _AsyncSubject__WEBPACK_IMPORTED_MODULE_2__["AsyncSubject"]();

    var handler = function handler() {
      for (var _len3 = arguments.length, innerArgs = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
        innerArgs[_key3] = arguments[_key3];
      }

      var err = innerArgs.shift();

      if (err) {
        _this.add(scheduler.schedule(dispatchError, 0, {
          err: err,
          subject: subject
        }));
      } else {
        var value = innerArgs.length <= 1 ? innerArgs[0] : innerArgs;

        _this.add(scheduler.schedule(dispatchNext, 0, {
          value: value,
          subject: subject
        }));
      }
    };

    try {
      callbackFunc.apply(context, [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args), [handler]));
    } catch (err) {
      this.add(scheduler.schedule(dispatchError, 0, {
        err: err,
        subject: subject
      }));
    }
  }

  this.add(subject.subscribe(subscriber));
}

function dispatchNext(arg) {
  var value = arg.value,
      subject = arg.subject;
  subject.next(value);
  subject.complete();
}

function dispatchError(arg) {
  var err = arg.err,
      subject = arg.subject;
  subject.error(err);
}

/***/ }),

/***/ "4dOw":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-ie.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (Ireland) [en-ie]
//! author : Chris Cartlidge : https://github.com/chriscartlidge
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enIe = moment.defineLocale('en-ie', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return enIe;
});

/***/ }),

/***/ "4f8F":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/race.js ***!
  \***************************************************************/
/*! exports provided: race */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "race", function() { return race; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _observable_race__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../observable/race */ "Nv8m");



function race() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  return function raceOperatorFunction(source) {
    if (observables.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_1__["isArray"])(observables[0])) {
      observables = observables[0];
    }

    return source.lift.call(_observable_race__WEBPACK_IMPORTED_MODULE_2__["race"].apply(void 0, [source].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(observables))));
  };
}

/***/ }),

/***/ "4hIw":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/timeInterval.js ***!
  \***********************************************************************/
/*! exports provided: timeInterval, TimeInterval */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "timeInterval", function() { return timeInterval; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TimeInterval", function() { return TimeInterval; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _scan__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./scan */ "Kqap");
/* harmony import */ var _observable_defer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../observable/defer */ "NXyV");
/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./map */ "lJxs");





function timeInterval() {
  var scheduler = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _scheduler_async__WEBPACK_IMPORTED_MODULE_1__["async"];
  return function (source) {
    return Object(_observable_defer__WEBPACK_IMPORTED_MODULE_3__["defer"])(function () {
      return source.pipe(Object(_scan__WEBPACK_IMPORTED_MODULE_2__["scan"])(function (_ref, value) {
        var current = _ref.current;
        return {
          value: value,
          current: scheduler.now(),
          last: current
        };
      }, {
        current: scheduler.now(),
        value: undefined,
        last: undefined
      }), Object(_map__WEBPACK_IMPORTED_MODULE_4__["map"])(function (_ref2) {
        var current = _ref2.current,
            last = _ref2.last,
            value = _ref2.value;
        return new TimeInterval(value, current - last);
      }));
    });
  };
}
var TimeInterval = function TimeInterval(value, interval) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, TimeInterval);

  this.value = value;
  this.interval = interval;
};

/***/ }),

/***/ "4yVj":
/*!**************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduled/schedulePromise.js ***!
  \**************************************************************************/
/*! exports provided: schedulePromise */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "schedulePromise", function() { return schedulePromise; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Subscription */ "quSY");


function schedulePromise(input, scheduler) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var sub = new _Subscription__WEBPACK_IMPORTED_MODULE_1__["Subscription"]();
    sub.add(scheduler.schedule(function () {
      return input.then(function (value) {
        sub.add(scheduler.schedule(function () {
          subscriber.next(value);
          sub.add(scheduler.schedule(function () {
            return subscriber.complete();
          }));
        }));
      }, function (err) {
        sub.add(scheduler.schedule(function () {
          return subscriber.error(err);
        }));
      });
    }));
    return sub;
  });
}

/***/ }),

/***/ "5+tZ":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/mergeMap.js ***!
  \*******************************************************************/
/*! exports provided: mergeMap, MergeMapOperator, MergeMapSubscriber, flatMap */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mergeMap", function() { return mergeMap; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MergeMapOperator", function() { return MergeMapOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MergeMapSubscriber", function() { return MergeMapSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "flatMap", function() { return flatMap; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./map */ "lJxs");
/* harmony import */ var _observable_from__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../observable/from */ "Cfvw");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");







function mergeMap(project, resultSelector) {
  var concurrent = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Number.POSITIVE_INFINITY;

  if (typeof resultSelector === 'function') {
    return function (source) {
      return source.pipe(mergeMap(function (a, i) {
        return Object(_observable_from__WEBPACK_IMPORTED_MODULE_5__["from"])(project(a, i)).pipe(Object(_map__WEBPACK_IMPORTED_MODULE_4__["map"])(function (b, ii) {
          return resultSelector(a, b, i, ii);
        }));
      }, concurrent));
    };
  } else if (typeof resultSelector === 'number') {
    concurrent = resultSelector;
  }

  return function (source) {
    return source.lift(new MergeMapOperator(project, concurrent));
  };
}
var MergeMapOperator = /*#__PURE__*/function () {
  function MergeMapOperator(project) {
    var concurrent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Number.POSITIVE_INFINITY;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MergeMapOperator);

    this.project = project;
    this.concurrent = concurrent;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MergeMapOperator, [{
    key: "call",
    value: function call(observer, source) {
      return source.subscribe(new MergeMapSubscriber(observer, this.project, this.concurrent));
    }
  }]);

  return MergeMapOperator;
}();
var MergeMapSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(MergeMapSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(MergeMapSubscriber);

  function MergeMapSubscriber(destination, project) {
    var _this;

    var concurrent = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Number.POSITIVE_INFINITY;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MergeMapSubscriber);

    _this = _super.call(this, destination);
    _this.project = project;
    _this.concurrent = concurrent;
    _this.hasCompleted = false;
    _this.buffer = [];
    _this.active = 0;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MergeMapSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (this.active < this.concurrent) {
        this._tryNext(value);
      } else {
        this.buffer.push(value);
      }
    }
  }, {
    key: "_tryNext",
    value: function _tryNext(value) {
      var result;
      var index = this.index++;

      try {
        result = this.project(value, index);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.active++;

      this._innerSub(result);
    }
  }, {
    key: "_innerSub",
    value: function _innerSub(ish) {
      var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleInnerSubscriber"](this);
      var destination = this.destination;
      destination.add(innerSubscriber);
      var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["innerSubscribe"])(ish, innerSubscriber);

      if (innerSubscription !== innerSubscriber) {
        destination.add(innerSubscription);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.hasCompleted = true;

      if (this.active === 0 && this.buffer.length === 0) {
        this.destination.complete();
      }

      this.unsubscribe();
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      this.destination.next(innerValue);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      var buffer = this.buffer;
      this.active--;

      if (buffer.length > 0) {
        this._next(buffer.shift());
      } else if (this.active === 0 && this.hasCompleted) {
        this.destination.complete();
      }
    }
  }]);

  return MergeMapSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleOuterSubscriber"]);
var flatMap = mergeMap;

/***/ }),

/***/ "51Bx":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/mergeScan.js ***!
  \********************************************************************/
/*! exports provided: mergeScan, MergeScanOperator, MergeScanSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mergeScan", function() { return mergeScan; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MergeScanOperator", function() { return MergeScanOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MergeScanSubscriber", function() { return MergeScanSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





function mergeScan(accumulator, seed) {
  var concurrent = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Number.POSITIVE_INFINITY;
  return function (source) {
    return source.lift(new MergeScanOperator(accumulator, seed, concurrent));
  };
}
var MergeScanOperator = /*#__PURE__*/function () {
  function MergeScanOperator(accumulator, seed, concurrent) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MergeScanOperator);

    this.accumulator = accumulator;
    this.seed = seed;
    this.concurrent = concurrent;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MergeScanOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new MergeScanSubscriber(subscriber, this.accumulator, this.seed, this.concurrent));
    }
  }]);

  return MergeScanOperator;
}();
var MergeScanSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(MergeScanSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(MergeScanSubscriber);

  function MergeScanSubscriber(destination, accumulator, acc, concurrent) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MergeScanSubscriber);

    _this = _super.call(this, destination);
    _this.accumulator = accumulator;
    _this.acc = acc;
    _this.concurrent = concurrent;
    _this.hasValue = false;
    _this.hasCompleted = false;
    _this.buffer = [];
    _this.active = 0;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MergeScanSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (this.active < this.concurrent) {
        var index = this.index++;
        var destination = this.destination;
        var ish;

        try {
          var accumulator = this.accumulator;
          ish = accumulator(this.acc, value, index);
        } catch (e) {
          return destination.error(e);
        }

        this.active++;

        this._innerSub(ish);
      } else {
        this.buffer.push(value);
      }
    }
  }, {
    key: "_innerSub",
    value: function _innerSub(ish) {
      var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](this);
      var destination = this.destination;
      destination.add(innerSubscriber);
      var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(ish, innerSubscriber);

      if (innerSubscription !== innerSubscriber) {
        destination.add(innerSubscription);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.hasCompleted = true;

      if (this.active === 0 && this.buffer.length === 0) {
        if (this.hasValue === false) {
          this.destination.next(this.acc);
        }

        this.destination.complete();
      }

      this.unsubscribe();
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      var destination = this.destination;
      this.acc = innerValue;
      this.hasValue = true;
      destination.next(innerValue);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      var buffer = this.buffer;
      this.active--;

      if (buffer.length > 0) {
        this._next(buffer.shift());
      } else if (this.active === 0 && this.hasCompleted) {
        if (this.hasValue === false) {
          this.destination.next(this.acc);
        }

        this.destination.complete();
      }
    }
  }]);

  return MergeScanSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "51Dv":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/InnerSubscriber.js ***!
  \****************************************************************/
/*! exports provided: InnerSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InnerSubscriber", function() { return InnerSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Subscriber */ "7o/Q");





var InnerSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(InnerSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(InnerSubscriber);

  function InnerSubscriber(parent, outerValue, outerIndex) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, InnerSubscriber);

    _this = _super.call(this);
    _this.parent = parent;
    _this.outerValue = outerValue;
    _this.outerIndex = outerIndex;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(InnerSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.parent.notifyNext(this.outerValue, value, this.outerIndex, this.index++, this);
    }
  }, {
    key: "_error",
    value: function _error(error) {
      this.parent.notifyError(error, this);
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.parent.notifyComplete(this);
      this.unsubscribe();
    }
  }]);

  return InnerSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "5B2Y":
/*!*****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduled/scheduleObservable.js ***!
  \*****************************************************************************/
/*! exports provided: scheduleObservable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "scheduleObservable", function() { return scheduleObservable; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _symbol_observable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../symbol/observable */ "kJWO");



function scheduleObservable(input, scheduler) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var sub = new _Subscription__WEBPACK_IMPORTED_MODULE_1__["Subscription"]();
    sub.add(scheduler.schedule(function () {
      var observable = input[_symbol_observable__WEBPACK_IMPORTED_MODULE_2__["observable"]]();
      sub.add(observable.subscribe({
        next: function next(value) {
          sub.add(scheduler.schedule(function () {
            return subscriber.next(value);
          }));
        },
        error: function error(err) {
          sub.add(scheduler.schedule(function () {
            return subscriber.error(err);
          }));
        },
        complete: function complete() {
          sub.add(scheduler.schedule(function () {
            return subscriber.complete();
          }));
        }
      }));
    }));
    return sub;
  });
}

/***/ }),

/***/ "5yfJ":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/never.js ***!
  \*****************************************************************/
/*! exports provided: NEVER, never */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NEVER", function() { return NEVER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "never", function() { return never; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_noop__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/noop */ "KqfI");


var NEVER = new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](_util_noop__WEBPACK_IMPORTED_MODULE_1__["noop"]);
function never() {
  return NEVER;
}

/***/ }),

/***/ "6+QB":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ms.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Malay [ms]
//! author : Weldan Jamili : https://github.com/weldan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ms = moment.defineLocale('ms', {
    months: 'Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember'.split('_'),
    monthsShort: 'Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis'.split('_'),
    weekdays: 'Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu'.split('_'),
    weekdaysShort: 'Ahd_Isn_Sel_Rab_Kha_Jum_Sab'.split('_'),
    weekdaysMin: 'Ah_Is_Sl_Rb_Km_Jm_Sb'.split('_'),
    longDateFormat: {
      LT: 'HH.mm',
      LTS: 'HH.mm.ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY [pukul] HH.mm',
      LLLL: 'dddd, D MMMM YYYY [pukul] HH.mm'
    },
    meridiemParse: /pagi|tengahari|petang|malam/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'pagi') {
        return hour;
      } else if (meridiem === 'tengahari') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === 'petang' || meridiem === 'malam') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 11) {
        return 'pagi';
      } else if (hours < 15) {
        return 'tengahari';
      } else if (hours < 19) {
        return 'petang';
      } else {
        return 'malam';
      }
    },
    calendar: {
      sameDay: '[Hari ini pukul] LT',
      nextDay: '[Esok pukul] LT',
      nextWeek: 'dddd [pukul] LT',
      lastDay: '[Kelmarin pukul] LT',
      lastWeek: 'dddd [lepas pukul] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dalam %s',
      past: '%s yang lepas',
      s: 'beberapa saat',
      ss: '%d saat',
      m: 'seminit',
      mm: '%d minit',
      h: 'sejam',
      hh: '%d jam',
      d: 'sehari',
      dd: '%d hari',
      M: 'sebulan',
      MM: '%d bulan',
      y: 'setahun',
      yy: '%d tahun'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return ms;
});

/***/ }),

/***/ "6B0Y":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/km.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Cambodian [km]
//! author : Kruy Vanna : https://github.com/kruyvanna
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '១',
    2: '២',
    3: '៣',
    4: '៤',
    5: '៥',
    6: '៦',
    7: '៧',
    8: '៨',
    9: '៩',
    0: '០'
  },
      numberMap = {
    '១': '1',
    '២': '2',
    '៣': '3',
    '៤': '4',
    '៥': '5',
    '៦': '6',
    '៧': '7',
    '៨': '8',
    '៩': '9',
    '០': '0'
  };
  var km = moment.defineLocale('km', {
    months: 'មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ'.split('_'),
    monthsShort: 'មករា_កុម្ភៈ_មីនា_មេសា_ឧសភា_មិថុនា_កក្កដា_សីហា_កញ្ញា_តុលា_វិច្ឆិកា_ធ្នូ'.split('_'),
    weekdays: 'អាទិត្យ_ច័ន្ទ_អង្គារ_ពុធ_ព្រហស្បតិ៍_សុក្រ_សៅរ៍'.split('_'),
    weekdaysShort: 'អា_ច_អ_ព_ព្រ_សុ_ស'.split('_'),
    weekdaysMin: 'អា_ច_អ_ព_ព្រ_សុ_ស'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    meridiemParse: /ព្រឹក|ល្ងាច/,
    isPM: function isPM(input) {
      return input === 'ល្ងាច';
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ព្រឹក';
      } else {
        return 'ល្ងាច';
      }
    },
    calendar: {
      sameDay: '[ថ្ងៃនេះ ម៉ោង] LT',
      nextDay: '[ស្អែក ម៉ោង] LT',
      nextWeek: 'dddd [ម៉ោង] LT',
      lastDay: '[ម្សិលមិញ ម៉ោង] LT',
      lastWeek: 'dddd [សប្តាហ៍មុន] [ម៉ោង] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%sទៀត',
      past: '%sមុន',
      s: 'ប៉ុន្មានវិនាទី',
      ss: '%d វិនាទី',
      m: 'មួយនាទី',
      mm: '%d នាទី',
      h: 'មួយម៉ោង',
      hh: '%d ម៉ោង',
      d: 'មួយថ្ងៃ',
      dd: '%d ថ្ងៃ',
      M: 'មួយខែ',
      MM: '%d ខែ',
      y: 'មួយឆ្នាំ',
      yy: '%d ឆ្នាំ'
    },
    dayOfMonthOrdinalParse: /ទី\d{1,2}/,
    ordinal: 'ទី%d',
    preparse: function preparse(string) {
      return string.replace(/[១២៣៤៥៦៧៨៩០]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return km;
});

/***/ }),

/***/ "6eBy":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/debounce.js ***!
  \*******************************************************************/
/*! exports provided: debounce */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "debounce", function() { return debounce; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");







function debounce(durationSelector) {
  return function (source) {
    return source.lift(new DebounceOperator(durationSelector));
  };
}

var DebounceOperator = /*#__PURE__*/function () {
  function DebounceOperator(durationSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, DebounceOperator);

    this.durationSelector = durationSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(DebounceOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DebounceSubscriber(subscriber, this.durationSelector));
    }
  }]);

  return DebounceOperator;
}();

var DebounceSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(DebounceSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(DebounceSubscriber);

  function DebounceSubscriber(destination, durationSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, DebounceSubscriber);

    _this = _super.call(this, destination);
    _this.durationSelector = durationSelector;
    _this.hasValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(DebounceSubscriber, [{
    key: "_next",
    value: function _next(value) {
      try {
        var result = this.durationSelector.call(this, value);

        if (result) {
          this._tryNext(value, result);
        }
      } catch (err) {
        this.destination.error(err);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.emitValue();
      this.destination.complete();
    }
  }, {
    key: "_tryNext",
    value: function _tryNext(value, duration) {
      var subscription = this.durationSubscription;
      this.value = value;
      this.hasValue = true;

      if (subscription) {
        subscription.unsubscribe();
        this.remove(subscription);
      }

      subscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["innerSubscribe"])(duration, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleInnerSubscriber"](this));

      if (subscription && !subscription.closed) {
        this.add(this.durationSubscription = subscription);
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      this.emitValue();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.emitValue();
    }
  }, {
    key: "emitValue",
    value: function emitValue() {
      if (this.hasValue) {
        var value = this.value;
        var subscription = this.durationSubscription;

        if (subscription) {
          this.durationSubscription = undefined;
          subscription.unsubscribe();
          this.remove(subscription);
        }

        this.value = undefined;
        this.hasValue = false;

        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(DebounceSubscriber.prototype), "_next", this).call(this, value);
      }
    }
  }]);

  return DebounceSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "7+OI":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isObservable.js ***!
  \******************************************************************/
/*! exports provided: isObservable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isObservable", function() { return isObservable; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");

function isObservable(obj) {
  return !!obj && (obj instanceof _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"] || typeof obj.lift === 'function' && typeof obj.subscribe === 'function');
}

/***/ }),

/***/ "7BjC":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/et.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Estonian [et]
//! author : Henry Kehlmann : https://github.com/madhenry
//! improvements : Illimar Tambek : https://github.com/ragulka
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      s: ['mõne sekundi', 'mõni sekund', 'paar sekundit'],
      ss: [number + 'sekundi', number + 'sekundit'],
      m: ['ühe minuti', 'üks minut'],
      mm: [number + ' minuti', number + ' minutit'],
      h: ['ühe tunni', 'tund aega', 'üks tund'],
      hh: [number + ' tunni', number + ' tundi'],
      d: ['ühe päeva', 'üks päev'],
      M: ['kuu aja', 'kuu aega', 'üks kuu'],
      MM: [number + ' kuu', number + ' kuud'],
      y: ['ühe aasta', 'aasta', 'üks aasta'],
      yy: [number + ' aasta', number + ' aastat']
    };

    if (withoutSuffix) {
      return format[key][2] ? format[key][2] : format[key][1];
    }

    return isFuture ? format[key][0] : format[key][1];
  }

  var et = moment.defineLocale('et', {
    months: 'jaanuar_veebruar_märts_aprill_mai_juuni_juuli_august_september_oktoober_november_detsember'.split('_'),
    monthsShort: 'jaan_veebr_märts_apr_mai_juuni_juuli_aug_sept_okt_nov_dets'.split('_'),
    weekdays: 'pühapäev_esmaspäev_teisipäev_kolmapäev_neljapäev_reede_laupäev'.split('_'),
    weekdaysShort: 'P_E_T_K_N_R_L'.split('_'),
    weekdaysMin: 'P_E_T_K_N_R_L'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm',
      LLLL: 'dddd, D. MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[Täna,] LT',
      nextDay: '[Homme,] LT',
      nextWeek: '[Järgmine] dddd LT',
      lastDay: '[Eile,] LT',
      lastWeek: '[Eelmine] dddd LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s pärast',
      past: '%s tagasi',
      s: processRelativeTime,
      ss: processRelativeTime,
      m: processRelativeTime,
      mm: processRelativeTime,
      h: processRelativeTime,
      hh: processRelativeTime,
      d: processRelativeTime,
      dd: '%d päeva',
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return et;
});

/***/ }),

/***/ "7C5Q":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-in.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (India) [en-in]
//! author : Jatin Agrawal : https://github.com/jatinag22
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enIn = moment.defineLocale('en-in', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY h:mm A',
      LLLL: 'dddd, D MMMM YYYY h:mm A'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 1st is the first week of the year.

    }
  });
  return enIn;
});

/***/ }),

/***/ "7HRe":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduled/scheduled.js ***!
  \********************************************************************/
/*! exports provided: scheduled */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "scheduled", function() { return scheduled; });
/* harmony import */ var _scheduleObservable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./scheduleObservable */ "5B2Y");
/* harmony import */ var _schedulePromise__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./schedulePromise */ "4yVj");
/* harmony import */ var _scheduleArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./scheduleArray */ "jZKg");
/* harmony import */ var _scheduleIterable__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./scheduleIterable */ "MBAA");
/* harmony import */ var _util_isInteropObservable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/isInteropObservable */ "QIAL");
/* harmony import */ var _util_isPromise__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isPromise */ "c2HN");
/* harmony import */ var _util_isArrayLike__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/isArrayLike */ "I55L");
/* harmony import */ var _util_isIterable__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/isIterable */ "CMyj");








function scheduled(input, scheduler) {
  if (input != null) {
    if (Object(_util_isInteropObservable__WEBPACK_IMPORTED_MODULE_4__["isInteropObservable"])(input)) {
      return Object(_scheduleObservable__WEBPACK_IMPORTED_MODULE_0__["scheduleObservable"])(input, scheduler);
    } else if (Object(_util_isPromise__WEBPACK_IMPORTED_MODULE_5__["isPromise"])(input)) {
      return Object(_schedulePromise__WEBPACK_IMPORTED_MODULE_1__["schedulePromise"])(input, scheduler);
    } else if (Object(_util_isArrayLike__WEBPACK_IMPORTED_MODULE_6__["isArrayLike"])(input)) {
      return Object(_scheduleArray__WEBPACK_IMPORTED_MODULE_2__["scheduleArray"])(input, scheduler);
    } else if (Object(_util_isIterable__WEBPACK_IMPORTED_MODULE_7__["isIterable"])(input) || typeof input === 'string') {
      return Object(_scheduleIterable__WEBPACK_IMPORTED_MODULE_3__["scheduleIterable"])(input, scheduler);
    }
  }

  throw new TypeError((input !== null && typeof input || input) + ' is not observable');
}

/***/ }),

/***/ "7Hc7":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/asap.js ***!
  \***************************************************************/
/*! exports provided: asapScheduler, asap */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "asapScheduler", function() { return asapScheduler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "asap", function() { return asap; });
/* harmony import */ var _AsapAction__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./AsapAction */ "Pz8W");
/* harmony import */ var _AsapScheduler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./AsapScheduler */ "RUbi");


var asapScheduler = new _AsapScheduler__WEBPACK_IMPORTED_MODULE_1__["AsapScheduler"](_AsapAction__WEBPACK_IMPORTED_MODULE_0__["AsapAction"]);
var asap = asapScheduler;

/***/ }),

/***/ "7aV9":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/si.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Sinhalese [si]
//! author : Sampath Sitinamaluwa : https://github.com/sampathsris
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  /*jshint -W100*/

  var si = moment.defineLocale('si', {
    months: 'ජනවාරි_පෙබරවාරි_මාර්තු_අප්‍රේල්_මැයි_ජූනි_ජූලි_අගෝස්තු_සැප්තැම්බර්_ඔක්තෝබර්_නොවැම්බර්_දෙසැම්බර්'.split('_'),
    monthsShort: 'ජන_පෙබ_මාර්_අප්_මැයි_ජූනි_ජූලි_අගෝ_සැප්_ඔක්_නොවැ_දෙසැ'.split('_'),
    weekdays: 'ඉරිදා_සඳුදා_අඟහරුවාදා_බදාදා_බ්‍රහස්පතින්දා_සිකුරාදා_සෙනසුරාදා'.split('_'),
    weekdaysShort: 'ඉරි_සඳු_අඟ_බදා_බ්‍රහ_සිකු_සෙන'.split('_'),
    weekdaysMin: 'ඉ_ස_අ_බ_බ්‍ර_සි_සෙ'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'a h:mm',
      LTS: 'a h:mm:ss',
      L: 'YYYY/MM/DD',
      LL: 'YYYY MMMM D',
      LLL: 'YYYY MMMM D, a h:mm',
      LLLL: 'YYYY MMMM D [වැනි] dddd, a h:mm:ss'
    },
    calendar: {
      sameDay: '[අද] LT[ට]',
      nextDay: '[හෙට] LT[ට]',
      nextWeek: 'dddd LT[ට]',
      lastDay: '[ඊයේ] LT[ට]',
      lastWeek: '[පසුගිය] dddd LT[ට]',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%sකින්',
      past: '%sකට පෙර',
      s: 'තත්පර කිහිපය',
      ss: 'තත්පර %d',
      m: 'මිනිත්තුව',
      mm: 'මිනිත්තු %d',
      h: 'පැය',
      hh: 'පැය %d',
      d: 'දිනය',
      dd: 'දින %d',
      M: 'මාසය',
      MM: 'මාස %d',
      y: 'වසර',
      yy: 'වසර %d'
    },
    dayOfMonthOrdinalParse: /\d{1,2} වැනි/,
    ordinal: function ordinal(number) {
      return number + ' වැනි';
    },
    meridiemParse: /පෙර වරු|පස් වරු|පෙ.ව|ප.ව./,
    isPM: function isPM(input) {
      return input === 'ප.ව.' || input === 'පස් වරු';
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours > 11) {
        return isLower ? 'ප.ව.' : 'පස් වරු';
      } else {
        return isLower ? 'පෙ.ව.' : 'පෙර වරු';
      }
    }
  });
  return si;
});

/***/ }),

/***/ "7o/Q":
/*!***********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Subscriber.js ***!
  \***********************************************************/
/*! exports provided: Subscriber, SafeSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Subscriber", function() { return Subscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SafeSubscriber", function() { return SafeSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _util_isFunction__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./util/isFunction */ "n6bG");
/* harmony import */ var _Observer__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./Observer */ "gRHU");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./Subscription */ "quSY");
/* harmony import */ var _internal_symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../internal/symbol/rxSubscriber */ "2QA8");
/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./config */ "2fFW");
/* harmony import */ var _util_hostReportError__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./util/hostReportError */ "NJ4a");













var Subscriber = /*#__PURE__*/function (_Subscription) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(Subscriber, _Subscription);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(Subscriber);

  function Subscriber(destinationOrNext, error, complete) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Subscriber);

    _this = _super.call(this);
    _this.syncErrorValue = null;
    _this.syncErrorThrown = false;
    _this.syncErrorThrowable = false;
    _this.isStopped = false;

    switch (arguments.length) {
      case 0:
        _this.destination = _Observer__WEBPACK_IMPORTED_MODULE_8__["empty"];
        break;

      case 1:
        if (!destinationOrNext) {
          _this.destination = _Observer__WEBPACK_IMPORTED_MODULE_8__["empty"];
          break;
        }

        if (typeof destinationOrNext === 'object') {
          if (destinationOrNext instanceof Subscriber) {
            _this.syncErrorThrowable = destinationOrNext.syncErrorThrowable;
            _this.destination = destinationOrNext;
            destinationOrNext.add(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this));
          } else {
            _this.syncErrorThrowable = true;
            _this.destination = new SafeSubscriber(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), destinationOrNext);
          }

          break;
        }

      default:
        _this.syncErrorThrowable = true;
        _this.destination = new SafeSubscriber(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this), destinationOrNext, error, complete);
        break;
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Subscriber, [{
    key: _internal_symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_10__["rxSubscriber"],
    value: function value() {
      return this;
    }
  }, {
    key: "next",
    value: function next(value) {
      if (!this.isStopped) {
        this._next(value);
      }
    }
  }, {
    key: "error",
    value: function error(err) {
      if (!this.isStopped) {
        this.isStopped = true;

        this._error(err);
      }
    }
  }, {
    key: "complete",
    value: function complete() {
      if (!this.isStopped) {
        this.isStopped = true;

        this._complete();
      }
    }
  }, {
    key: "unsubscribe",
    value: function unsubscribe() {
      if (this.closed) {
        return;
      }

      this.isStopped = true;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_3__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(Subscriber.prototype), "unsubscribe", this).call(this);
    }
  }, {
    key: "_next",
    value: function _next(value) {
      this.destination.next(value);
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.destination.error(err);
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.destination.complete();
      this.unsubscribe();
    }
  }, {
    key: "_unsubscribeAndRecycle",
    value: function _unsubscribeAndRecycle() {
      var _parentOrParents = this._parentOrParents;
      this._parentOrParents = null;
      this.unsubscribe();
      this.closed = false;
      this.isStopped = false;
      this._parentOrParents = _parentOrParents;
      return this;
    }
  }], [{
    key: "create",
    value: function create(next, error, complete) {
      var subscriber = new Subscriber(next, error, complete);
      subscriber.syncErrorThrowable = false;
      return subscriber;
    }
  }]);

  return Subscriber;
}(_Subscription__WEBPACK_IMPORTED_MODULE_9__["Subscription"]);
var SafeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(SafeSubscriber, _Subscriber);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(SafeSubscriber);

  function SafeSubscriber(_parentSubscriber, observerOrNext, error, complete) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SafeSubscriber);

    _this2 = _super2.call(this);
    _this2._parentSubscriber = _parentSubscriber;
    var next;

    var context = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this2);

    if (Object(_util_isFunction__WEBPACK_IMPORTED_MODULE_7__["isFunction"])(observerOrNext)) {
      next = observerOrNext;
    } else if (observerOrNext) {
      next = observerOrNext.next;
      error = observerOrNext.error;
      complete = observerOrNext.complete;

      if (observerOrNext !== _Observer__WEBPACK_IMPORTED_MODULE_8__["empty"]) {
        context = Object.create(observerOrNext);

        if (Object(_util_isFunction__WEBPACK_IMPORTED_MODULE_7__["isFunction"])(context.unsubscribe)) {
          _this2.add(context.unsubscribe.bind(context));
        }

        context.unsubscribe = _this2.unsubscribe.bind(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this2));
      }
    }

    _this2._context = context;
    _this2._next = next;
    _this2._error = error;
    _this2._complete = complete;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SafeSubscriber, [{
    key: "next",
    value: function next(value) {
      if (!this.isStopped && this._next) {
        var _parentSubscriber = this._parentSubscriber;

        if (!_config__WEBPACK_IMPORTED_MODULE_11__["config"].useDeprecatedSynchronousErrorHandling || !_parentSubscriber.syncErrorThrowable) {
          this.__tryOrUnsub(this._next, value);
        } else if (this.__tryOrSetError(_parentSubscriber, this._next, value)) {
          this.unsubscribe();
        }
      }
    }
  }, {
    key: "error",
    value: function error(err) {
      if (!this.isStopped) {
        var _parentSubscriber = this._parentSubscriber;
        var useDeprecatedSynchronousErrorHandling = _config__WEBPACK_IMPORTED_MODULE_11__["config"].useDeprecatedSynchronousErrorHandling;

        if (this._error) {
          if (!useDeprecatedSynchronousErrorHandling || !_parentSubscriber.syncErrorThrowable) {
            this.__tryOrUnsub(this._error, err);

            this.unsubscribe();
          } else {
            this.__tryOrSetError(_parentSubscriber, this._error, err);

            this.unsubscribe();
          }
        } else if (!_parentSubscriber.syncErrorThrowable) {
          this.unsubscribe();

          if (useDeprecatedSynchronousErrorHandling) {
            throw err;
          }

          Object(_util_hostReportError__WEBPACK_IMPORTED_MODULE_12__["hostReportError"])(err);
        } else {
          if (useDeprecatedSynchronousErrorHandling) {
            _parentSubscriber.syncErrorValue = err;
            _parentSubscriber.syncErrorThrown = true;
          } else {
            Object(_util_hostReportError__WEBPACK_IMPORTED_MODULE_12__["hostReportError"])(err);
          }

          this.unsubscribe();
        }
      }
    }
  }, {
    key: "complete",
    value: function complete() {
      var _this3 = this;

      if (!this.isStopped) {
        var _parentSubscriber = this._parentSubscriber;

        if (this._complete) {
          var wrappedComplete = function wrappedComplete() {
            return _this3._complete.call(_this3._context);
          };

          if (!_config__WEBPACK_IMPORTED_MODULE_11__["config"].useDeprecatedSynchronousErrorHandling || !_parentSubscriber.syncErrorThrowable) {
            this.__tryOrUnsub(wrappedComplete);

            this.unsubscribe();
          } else {
            this.__tryOrSetError(_parentSubscriber, wrappedComplete);

            this.unsubscribe();
          }
        } else {
          this.unsubscribe();
        }
      }
    }
  }, {
    key: "__tryOrUnsub",
    value: function __tryOrUnsub(fn, value) {
      try {
        fn.call(this._context, value);
      } catch (err) {
        this.unsubscribe();

        if (_config__WEBPACK_IMPORTED_MODULE_11__["config"].useDeprecatedSynchronousErrorHandling) {
          throw err;
        } else {
          Object(_util_hostReportError__WEBPACK_IMPORTED_MODULE_12__["hostReportError"])(err);
        }
      }
    }
  }, {
    key: "__tryOrSetError",
    value: function __tryOrSetError(parent, fn, value) {
      if (!_config__WEBPACK_IMPORTED_MODULE_11__["config"].useDeprecatedSynchronousErrorHandling) {
        throw new Error('bad call');
      }

      try {
        fn.call(this._context, value);
      } catch (err) {
        if (_config__WEBPACK_IMPORTED_MODULE_11__["config"].useDeprecatedSynchronousErrorHandling) {
          parent.syncErrorValue = err;
          parent.syncErrorThrown = true;
          return true;
        } else {
          Object(_util_hostReportError__WEBPACK_IMPORTED_MODULE_12__["hostReportError"])(err);
          return true;
        }
      }

      return false;
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var _parentSubscriber = this._parentSubscriber;
      this._context = null;
      this._parentSubscriber = null;

      _parentSubscriber.unsubscribe();
    }
  }]);

  return SafeSubscriber;
}(Subscriber);

/***/ }),

/***/ "7ve7":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/Action.js ***!
  \*****************************************************************/
/*! exports provided: Action */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Action", function() { return Action; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscription */ "quSY");





var Action = /*#__PURE__*/function (_Subscription) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(Action, _Subscription);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(Action);

  function Action(scheduler, work) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Action);

    return _super.call(this);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Action, [{
    key: "schedule",
    value: function schedule(state) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      return this;
    }
  }]);

  return Action;
}(_Subscription__WEBPACK_IMPORTED_MODULE_4__["Subscription"]);

/***/ }),

/***/ "7wxJ":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/combineAll.js ***!
  \*********************************************************************/
/*! exports provided: combineAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "combineAll", function() { return combineAll; });
/* harmony import */ var _observable_combineLatest__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/combineLatest */ "itXk");

function combineAll(project) {
  return function (source) {
    return source.lift(new _observable_combineLatest__WEBPACK_IMPORTED_MODULE_0__["CombineLatestOperator"](project));
  };
}

/***/ }),

/***/ "8/+R":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/pa-in.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Punjabi (India) [pa-in]
//! author : Harpreet Singh : https://github.com/harpreetkhalsagtbit
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '੧',
    2: '੨',
    3: '੩',
    4: '੪',
    5: '੫',
    6: '੬',
    7: '੭',
    8: '੮',
    9: '੯',
    0: '੦'
  },
      numberMap = {
    '੧': '1',
    '੨': '2',
    '੩': '3',
    '੪': '4',
    '੫': '5',
    '੬': '6',
    '੭': '7',
    '੮': '8',
    '੯': '9',
    '੦': '0'
  };
  var paIn = moment.defineLocale('pa-in', {
    // There are months name as per Nanakshahi Calendar but they are not used as rigidly in modern Punjabi.
    months: 'ਜਨਵਰੀ_ਫ਼ਰਵਰੀ_ਮਾਰਚ_ਅਪ੍ਰੈਲ_ਮਈ_ਜੂਨ_ਜੁਲਾਈ_ਅਗਸਤ_ਸਤੰਬਰ_ਅਕਤੂਬਰ_ਨਵੰਬਰ_ਦਸੰਬਰ'.split('_'),
    monthsShort: 'ਜਨਵਰੀ_ਫ਼ਰਵਰੀ_ਮਾਰਚ_ਅਪ੍ਰੈਲ_ਮਈ_ਜੂਨ_ਜੁਲਾਈ_ਅਗਸਤ_ਸਤੰਬਰ_ਅਕਤੂਬਰ_ਨਵੰਬਰ_ਦਸੰਬਰ'.split('_'),
    weekdays: 'ਐਤਵਾਰ_ਸੋਮਵਾਰ_ਮੰਗਲਵਾਰ_ਬੁਧਵਾਰ_ਵੀਰਵਾਰ_ਸ਼ੁੱਕਰਵਾਰ_ਸ਼ਨੀਚਰਵਾਰ'.split('_'),
    weekdaysShort: 'ਐਤ_ਸੋਮ_ਮੰਗਲ_ਬੁਧ_ਵੀਰ_ਸ਼ੁਕਰ_ਸ਼ਨੀ'.split('_'),
    weekdaysMin: 'ਐਤ_ਸੋਮ_ਮੰਗਲ_ਬੁਧ_ਵੀਰ_ਸ਼ੁਕਰ_ਸ਼ਨੀ'.split('_'),
    longDateFormat: {
      LT: 'A h:mm ਵਜੇ',
      LTS: 'A h:mm:ss ਵਜੇ',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm ਵਜੇ',
      LLLL: 'dddd, D MMMM YYYY, A h:mm ਵਜੇ'
    },
    calendar: {
      sameDay: '[ਅਜ] LT',
      nextDay: '[ਕਲ] LT',
      nextWeek: '[ਅਗਲਾ] dddd, LT',
      lastDay: '[ਕਲ] LT',
      lastWeek: '[ਪਿਛਲੇ] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s ਵਿੱਚ',
      past: '%s ਪਿਛਲੇ',
      s: 'ਕੁਝ ਸਕਿੰਟ',
      ss: '%d ਸਕਿੰਟ',
      m: 'ਇਕ ਮਿੰਟ',
      mm: '%d ਮਿੰਟ',
      h: 'ਇੱਕ ਘੰਟਾ',
      hh: '%d ਘੰਟੇ',
      d: 'ਇੱਕ ਦਿਨ',
      dd: '%d ਦਿਨ',
      M: 'ਇੱਕ ਮਹੀਨਾ',
      MM: '%d ਮਹੀਨੇ',
      y: 'ਇੱਕ ਸਾਲ',
      yy: '%d ਸਾਲ'
    },
    preparse: function preparse(string) {
      return string.replace(/[੧੨੩੪੫੬੭੮੯੦]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    // Punjabi notation for meridiems are quite fuzzy in practice. While there exists
    // a rigid notion of a 'Pahar' it is not used as rigidly in modern Punjabi.
    meridiemParse: /ਰਾਤ|ਸਵੇਰ|ਦੁਪਹਿਰ|ਸ਼ਾਮ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'ਰਾਤ') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'ਸਵੇਰ') {
        return hour;
      } else if (meridiem === 'ਦੁਪਹਿਰ') {
        return hour >= 10 ? hour : hour + 12;
      } else if (meridiem === 'ਸ਼ਾਮ') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'ਰਾਤ';
      } else if (hour < 10) {
        return 'ਸਵੇਰ';
      } else if (hour < 17) {
        return 'ਦੁਪਹਿਰ';
      } else if (hour < 20) {
        return 'ਸ਼ਾਮ';
      } else {
        return 'ਰਾਤ';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return paIn;
});

/***/ }),

/***/ "8Qeq":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/canReportError.js ***!
  \********************************************************************/
/*! exports provided: canReportError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "canReportError", function() { return canReportError; });
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");

function canReportError(observer) {
  while (observer) {
    var _observer = observer,
        closed = _observer.closed,
        destination = _observer.destination,
        isStopped = _observer.isStopped;

    if (closed || isStopped) {
      return false;
    } else if (destination && destination instanceof _Subscriber__WEBPACK_IMPORTED_MODULE_0__["Subscriber"]) {
      observer = destination;
    } else {
      observer = null;
    }
  }

  return true;
}

/***/ }),

/***/ "8mBD":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/pt.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Portuguese [pt]
//! author : Jefferson : https://github.com/jalex79
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var pt = moment.defineLocale('pt', {
    months: 'janeiro_fevereiro_março_abril_maio_junho_julho_agosto_setembro_outubro_novembro_dezembro'.split('_'),
    monthsShort: 'jan_fev_mar_abr_mai_jun_jul_ago_set_out_nov_dez'.split('_'),
    weekdays: 'Domingo_Segunda-feira_Terça-feira_Quarta-feira_Quinta-feira_Sexta-feira_Sábado'.split('_'),
    weekdaysShort: 'Dom_Seg_Ter_Qua_Qui_Sex_Sáb'.split('_'),
    weekdaysMin: 'Do_2ª_3ª_4ª_5ª_6ª_Sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY HH:mm',
      LLLL: 'dddd, D [de] MMMM [de] YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Hoje às] LT',
      nextDay: '[Amanhã às] LT',
      nextWeek: 'dddd [às] LT',
      lastDay: '[Ontem às] LT',
      lastWeek: function lastWeek() {
        return this.day() === 0 || this.day() === 6 ? '[Último] dddd [às] LT' // Saturday + Sunday
        : '[Última] dddd [às] LT'; // Monday - Friday
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'em %s',
      past: 'há %s',
      s: 'segundos',
      ss: '%d segundos',
      m: 'um minuto',
      mm: '%d minutos',
      h: 'uma hora',
      hh: '%d horas',
      d: 'um dia',
      dd: '%d dias',
      w: 'uma semana',
      ww: '%d semanas',
      M: 'um mês',
      MM: '%d meses',
      y: 'um ano',
      yy: '%d anos'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return pt;
});

/***/ }),

/***/ "9M8c":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/bufferCount.js ***!
  \**********************************************************************/
/*! exports provided: bufferCount */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "bufferCount", function() { return bufferCount; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");







function bufferCount(bufferSize) {
  var startBufferEvery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  return function bufferCountOperatorFunction(source) {
    return source.lift(new BufferCountOperator(bufferSize, startBufferEvery));
  };
}

var BufferCountOperator = /*#__PURE__*/function () {
  function BufferCountOperator(bufferSize, startBufferEvery) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, BufferCountOperator);

    this.bufferSize = bufferSize;
    this.startBufferEvery = startBufferEvery;

    if (!startBufferEvery || bufferSize === startBufferEvery) {
      this.subscriberClass = BufferCountSubscriber;
    } else {
      this.subscriberClass = BufferSkipCountSubscriber;
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(BufferCountOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new this.subscriberClass(subscriber, this.bufferSize, this.startBufferEvery));
    }
  }]);

  return BufferCountOperator;
}();

var BufferCountSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferCountSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(BufferCountSubscriber);

  function BufferCountSubscriber(destination, bufferSize) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, BufferCountSubscriber);

    _this = _super.call(this, destination);
    _this.bufferSize = bufferSize;
    _this.buffer = [];
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(BufferCountSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var buffer = this.buffer;
      buffer.push(value);

      if (buffer.length == this.bufferSize) {
        this.destination.next(buffer);
        this.buffer = [];
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var buffer = this.buffer;

      if (buffer.length > 0) {
        this.destination.next(buffer);
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(BufferCountSubscriber.prototype), "_complete", this).call(this);
    }
  }]);

  return BufferCountSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

var BufferSkipCountSubscriber = /*#__PURE__*/function (_Subscriber2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferSkipCountSubscriber, _Subscriber2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(BufferSkipCountSubscriber);

  function BufferSkipCountSubscriber(destination, bufferSize, startBufferEvery) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, BufferSkipCountSubscriber);

    _this2 = _super2.call(this, destination);
    _this2.bufferSize = bufferSize;
    _this2.startBufferEvery = startBufferEvery;
    _this2.buffers = [];
    _this2.count = 0;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(BufferSkipCountSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var bufferSize = this.bufferSize,
          startBufferEvery = this.startBufferEvery,
          buffers = this.buffers,
          count = this.count;
      this.count++;

      if (count % startBufferEvery === 0) {
        buffers.push([]);
      }

      for (var i = buffers.length; i--;) {
        var buffer = buffers[i];
        buffer.push(value);

        if (buffer.length === bufferSize) {
          buffers.splice(i, 1);
          this.destination.next(buffer);
        }
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var buffers = this.buffers,
          destination = this.destination;

      while (buffers.length > 0) {
        var buffer = buffers.shift();

        if (buffer.length > 0) {
          destination.next(buffer);
        }
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(BufferSkipCountSubscriber.prototype), "_complete", this).call(this);
    }
  }]);

  return BufferSkipCountSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

/***/ }),

/***/ "9ihq":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/elementAt.js ***!
  \********************************************************************/
/*! exports provided: elementAt */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "elementAt", function() { return elementAt; });
/* harmony import */ var _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/ArgumentOutOfRangeError */ "4I5i");
/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./filter */ "pLZG");
/* harmony import */ var _throwIfEmpty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./throwIfEmpty */ "XDbj");
/* harmony import */ var _defaultIfEmpty__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./defaultIfEmpty */ "xbPD");
/* harmony import */ var _take__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./take */ "IzEk");





function elementAt(index, defaultValue) {
  if (index < 0) {
    throw new _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_0__["ArgumentOutOfRangeError"]();
  }

  var hasDefaultValue = arguments.length >= 2;
  return function (source) {
    return source.pipe(Object(_filter__WEBPACK_IMPORTED_MODULE_1__["filter"])(function (v, i) {
      return i === index;
    }), Object(_take__WEBPACK_IMPORTED_MODULE_4__["take"])(1), hasDefaultValue ? Object(_defaultIfEmpty__WEBPACK_IMPORTED_MODULE_3__["defaultIfEmpty"])(defaultValue) : Object(_throwIfEmpty__WEBPACK_IMPORTED_MODULE_2__["throwIfEmpty"])(function () {
      return new _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_0__["ArgumentOutOfRangeError"]();
    }));
  };
}

/***/ }),

/***/ "9ppp":
/*!*****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/ObjectUnsubscribedError.js ***!
  \*****************************************************************************/
/*! exports provided: ObjectUnsubscribedError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ObjectUnsubscribedError", function() { return ObjectUnsubscribedError; });
var ObjectUnsubscribedErrorImpl = function () {
  function ObjectUnsubscribedErrorImpl() {
    Error.call(this);
    this.message = 'object unsubscribed';
    this.name = 'ObjectUnsubscribedError';
    return this;
  }

  ObjectUnsubscribedErrorImpl.prototype = Object.create(Error.prototype);
  return ObjectUnsubscribedErrorImpl;
}();

var ObjectUnsubscribedError = ObjectUnsubscribedErrorImpl;

/***/ }),

/***/ "9rRi":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/gd.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Scottish Gaelic [gd]
//! author : Jon Ashdown : https://github.com/jonashdown
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = ['Am Faoilleach', 'An Gearran', 'Am Màrt', 'An Giblean', 'An Cèitean', 'An t-Ògmhios', 'An t-Iuchar', 'An Lùnastal', 'An t-Sultain', 'An Dàmhair', 'An t-Samhain', 'An Dùbhlachd'],
      monthsShort = ['Faoi', 'Gear', 'Màrt', 'Gibl', 'Cèit', 'Ògmh', 'Iuch', 'Lùn', 'Sult', 'Dàmh', 'Samh', 'Dùbh'],
      weekdays = ['Didòmhnaich', 'Diluain', 'Dimàirt', 'Diciadain', 'Diardaoin', 'Dihaoine', 'Disathairne'],
      weekdaysShort = ['Did', 'Dil', 'Dim', 'Dic', 'Dia', 'Dih', 'Dis'],
      weekdaysMin = ['Dò', 'Lu', 'Mà', 'Ci', 'Ar', 'Ha', 'Sa'];
  var gd = moment.defineLocale('gd', {
    months: months,
    monthsShort: monthsShort,
    monthsParseExact: true,
    weekdays: weekdays,
    weekdaysShort: weekdaysShort,
    weekdaysMin: weekdaysMin,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[An-diugh aig] LT',
      nextDay: '[A-màireach aig] LT',
      nextWeek: 'dddd [aig] LT',
      lastDay: '[An-dè aig] LT',
      lastWeek: 'dddd [seo chaidh] [aig] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'ann an %s',
      past: 'bho chionn %s',
      s: 'beagan diogan',
      ss: '%d diogan',
      m: 'mionaid',
      mm: '%d mionaidean',
      h: 'uair',
      hh: '%d uairean',
      d: 'latha',
      dd: '%d latha',
      M: 'mìos',
      MM: '%d mìosan',
      y: 'bliadhna',
      yy: '%d bliadhna'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(d|na|mh)/,
    ordinal: function ordinal(number) {
      var output = number === 1 ? 'd' : number % 10 === 2 ? 'na' : 'mh';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return gd;
});

/***/ }),

/***/ "A+xa":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/cv.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Chuvash [cv]
//! author : Anatoly Mironov : https://github.com/mirontoli
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var cv = moment.defineLocale('cv', {
    months: 'кӑрлач_нарӑс_пуш_ака_май_ҫӗртме_утӑ_ҫурла_авӑн_юпа_чӳк_раштав'.split('_'),
    monthsShort: 'кӑр_нар_пуш_ака_май_ҫӗр_утӑ_ҫур_авн_юпа_чӳк_раш'.split('_'),
    weekdays: 'вырсарникун_тунтикун_ытларикун_юнкун_кӗҫнерникун_эрнекун_шӑматкун'.split('_'),
    weekdaysShort: 'выр_тун_ытл_юн_кӗҫ_эрн_шӑм'.split('_'),
    weekdaysMin: 'вр_тн_ыт_юн_кҫ_эр_шм'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD-MM-YYYY',
      LL: 'YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ]',
      LLL: 'YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm',
      LLLL: 'dddd, YYYY [ҫулхи] MMMM [уйӑхӗн] D[-мӗшӗ], HH:mm'
    },
    calendar: {
      sameDay: '[Паян] LT [сехетре]',
      nextDay: '[Ыран] LT [сехетре]',
      lastDay: '[Ӗнер] LT [сехетре]',
      nextWeek: '[Ҫитес] dddd LT [сехетре]',
      lastWeek: '[Иртнӗ] dddd LT [сехетре]',
      sameElse: 'L'
    },
    relativeTime: {
      future: function future(output) {
        var affix = /сехет$/i.exec(output) ? 'рен' : /ҫул$/i.exec(output) ? 'тан' : 'ран';
        return output + affix;
      },
      past: '%s каялла',
      s: 'пӗр-ик ҫеккунт',
      ss: '%d ҫеккунт',
      m: 'пӗр минут',
      mm: '%d минут',
      h: 'пӗр сехет',
      hh: '%d сехет',
      d: 'пӗр кун',
      dd: '%d кун',
      M: 'пӗр уйӑх',
      MM: '%d уйӑх',
      y: 'пӗр ҫул',
      yy: '%d ҫул'
    },
    dayOfMonthOrdinalParse: /\d{1,2}-мӗш/,
    ordinal: '%d-мӗш',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return cv;
});

/***/ }),

/***/ "A3iJ":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/partition.js ***!
  \********************************************************************/
/*! exports provided: partition */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "partition", function() { return partition; });
/* harmony import */ var _util_not__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/not */ "F97/");
/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./filter */ "pLZG");


function partition(predicate, thisArg) {
  return function (source) {
    return [Object(_filter__WEBPACK_IMPORTED_MODULE_1__["filter"])(predicate, thisArg)(source), Object(_filter__WEBPACK_IMPORTED_MODULE_1__["filter"])(Object(_util_not__WEBPACK_IMPORTED_MODULE_0__["not"])(predicate, thisArg))(source)];
  };
}

/***/ }),

/***/ "AQ68":
/*!***********************************************!*\
  !*** ./node_modules/moment/locale/uz-latn.js ***!
  \***********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Uzbek Latin [uz-latn]
//! author : Rasulbek Mirzayev : github.com/Rasulbeeek
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var uzLatn = moment.defineLocale('uz-latn', {
    months: 'Yanvar_Fevral_Mart_Aprel_May_Iyun_Iyul_Avgust_Sentabr_Oktabr_Noyabr_Dekabr'.split('_'),
    monthsShort: 'Yan_Fev_Mar_Apr_May_Iyun_Iyul_Avg_Sen_Okt_Noy_Dek'.split('_'),
    weekdays: 'Yakshanba_Dushanba_Seshanba_Chorshanba_Payshanba_Juma_Shanba'.split('_'),
    weekdaysShort: 'Yak_Dush_Sesh_Chor_Pay_Jum_Shan'.split('_'),
    weekdaysMin: 'Ya_Du_Se_Cho_Pa_Ju_Sha'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'D MMMM YYYY, dddd HH:mm'
    },
    calendar: {
      sameDay: '[Bugun soat] LT [da]',
      nextDay: '[Ertaga] LT [da]',
      nextWeek: 'dddd [kuni soat] LT [da]',
      lastDay: '[Kecha soat] LT [da]',
      lastWeek: "[O'tgan] dddd [kuni soat] LT [da]",
      sameElse: 'L'
    },
    relativeTime: {
      future: 'Yaqin %s ichida',
      past: 'Bir necha %s oldin',
      s: 'soniya',
      ss: '%d soniya',
      m: 'bir daqiqa',
      mm: '%d daqiqa',
      h: 'bir soat',
      hh: '%d soat',
      d: 'bir kun',
      dd: '%d kun',
      M: 'bir oy',
      MM: '%d oy',
      y: 'bir yil',
      yy: '%d yil'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return uzLatn;
});

/***/ }),

/***/ "AvvY":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ml.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Malayalam [ml]
//! author : Floyd Pink : https://github.com/floydpink
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ml = moment.defineLocale('ml', {
    months: 'ജനുവരി_ഫെബ്രുവരി_മാർച്ച്_ഏപ്രിൽ_മേയ്_ജൂൺ_ജൂലൈ_ഓഗസ്റ്റ്_സെപ്റ്റംബർ_ഒക്ടോബർ_നവംബർ_ഡിസംബർ'.split('_'),
    monthsShort: 'ജനു._ഫെബ്രു._മാർ._ഏപ്രി._മേയ്_ജൂൺ_ജൂലൈ._ഓഗ._സെപ്റ്റ._ഒക്ടോ._നവം._ഡിസം.'.split('_'),
    monthsParseExact: true,
    weekdays: 'ഞായറാഴ്ച_തിങ്കളാഴ്ച_ചൊവ്വാഴ്ച_ബുധനാഴ്ച_വ്യാഴാഴ്ച_വെള്ളിയാഴ്ച_ശനിയാഴ്ച'.split('_'),
    weekdaysShort: 'ഞായർ_തിങ്കൾ_ചൊവ്വ_ബുധൻ_വ്യാഴം_വെള്ളി_ശനി'.split('_'),
    weekdaysMin: 'ഞാ_തി_ചൊ_ബു_വ്യാ_വെ_ശ'.split('_'),
    longDateFormat: {
      LT: 'A h:mm -നു',
      LTS: 'A h:mm:ss -നു',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm -നു',
      LLLL: 'dddd, D MMMM YYYY, A h:mm -നു'
    },
    calendar: {
      sameDay: '[ഇന്ന്] LT',
      nextDay: '[നാളെ] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[ഇന്നലെ] LT',
      lastWeek: '[കഴിഞ്ഞ] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s കഴിഞ്ഞ്',
      past: '%s മുൻപ്',
      s: 'അൽപ നിമിഷങ്ങൾ',
      ss: '%d സെക്കൻഡ്',
      m: 'ഒരു മിനിറ്റ്',
      mm: '%d മിനിറ്റ്',
      h: 'ഒരു മണിക്കൂർ',
      hh: '%d മണിക്കൂർ',
      d: 'ഒരു ദിവസം',
      dd: '%d ദിവസം',
      M: 'ഒരു മാസം',
      MM: '%d മാസം',
      y: 'ഒരു വർഷം',
      yy: '%d വർഷം'
    },
    meridiemParse: /രാത്രി|രാവിലെ|ഉച്ച കഴിഞ്ഞ്|വൈകുന്നേരം|രാത്രി/i,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'രാത്രി' && hour >= 4 || meridiem === 'ഉച്ച കഴിഞ്ഞ്' || meridiem === 'വൈകുന്നേരം') {
        return hour + 12;
      } else {
        return hour;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'രാത്രി';
      } else if (hour < 12) {
        return 'രാവിലെ';
      } else if (hour < 17) {
        return 'ഉച്ച കഴിഞ്ഞ്';
      } else if (hour < 20) {
        return 'വൈകുന്നേരം';
      } else {
        return 'രാത്രി';
      }
    }
  });
  return ml;
});

/***/ }),

/***/ "B55N":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ja.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Japanese [ja]
//! author : LI Long : https://github.com/baryon
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ja = moment.defineLocale('ja', {
    eras: [{
      since: '2019-05-01',
      offset: 1,
      name: '令和',
      narrow: '㋿',
      abbr: 'R'
    }, {
      since: '1989-01-08',
      until: '2019-04-30',
      offset: 1,
      name: '平成',
      narrow: '㍻',
      abbr: 'H'
    }, {
      since: '1926-12-25',
      until: '1989-01-07',
      offset: 1,
      name: '昭和',
      narrow: '㍼',
      abbr: 'S'
    }, {
      since: '1912-07-30',
      until: '1926-12-24',
      offset: 1,
      name: '大正',
      narrow: '㍽',
      abbr: 'T'
    }, {
      since: '1873-01-01',
      until: '1912-07-29',
      offset: 6,
      name: '明治',
      narrow: '㍾',
      abbr: 'M'
    }, {
      since: '0001-01-01',
      until: '1873-12-31',
      offset: 1,
      name: '西暦',
      narrow: 'AD',
      abbr: 'AD'
    }, {
      since: '0000-12-31',
      until: -Infinity,
      offset: 1,
      name: '紀元前',
      narrow: 'BC',
      abbr: 'BC'
    }],
    eraYearOrdinalRegex: /(元|\d+)年/,
    eraYearOrdinalParse: function eraYearOrdinalParse(input, match) {
      return match[1] === '元' ? 1 : parseInt(match[1] || input, 10);
    },
    months: '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
    monthsShort: '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
    weekdays: '日曜日_月曜日_火曜日_水曜日_木曜日_金曜日_土曜日'.split('_'),
    weekdaysShort: '日_月_火_水_木_金_土'.split('_'),
    weekdaysMin: '日_月_火_水_木_金_土'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY/MM/DD',
      LL: 'YYYY年M月D日',
      LLL: 'YYYY年M月D日 HH:mm',
      LLLL: 'YYYY年M月D日 dddd HH:mm',
      l: 'YYYY/MM/DD',
      ll: 'YYYY年M月D日',
      lll: 'YYYY年M月D日 HH:mm',
      llll: 'YYYY年M月D日(ddd) HH:mm'
    },
    meridiemParse: /午前|午後/i,
    isPM: function isPM(input) {
      return input === '午後';
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return '午前';
      } else {
        return '午後';
      }
    },
    calendar: {
      sameDay: '[今日] LT',
      nextDay: '[明日] LT',
      nextWeek: function nextWeek(now) {
        if (now.week() !== this.week()) {
          return '[来週]dddd LT';
        } else {
          return 'dddd LT';
        }
      },
      lastDay: '[昨日] LT',
      lastWeek: function lastWeek(now) {
        if (this.week() !== now.week()) {
          return '[先週]dddd LT';
        } else {
          return 'dddd LT';
        }
      },
      sameElse: 'L'
    },
    dayOfMonthOrdinalParse: /\d{1,2}日/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'y':
          return number === 1 ? '元年' : number + '年';

        case 'd':
        case 'D':
        case 'DDD':
          return number + '日';

        default:
          return number;
      }
    },
    relativeTime: {
      future: '%s後',
      past: '%s前',
      s: '数秒',
      ss: '%d秒',
      m: '1分',
      mm: '%d分',
      h: '1時間',
      hh: '%d時間',
      d: '1日',
      dd: '%d日',
      M: '1ヶ月',
      MM: '%dヶ月',
      y: '1年',
      yy: '%d年'
    }
  });
  return ja;
});

/***/ }),

/***/ "BFxc":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/takeLast.js ***!
  \*******************************************************************/
/*! exports provided: takeLast */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "takeLast", function() { return takeLast; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/ArgumentOutOfRangeError */ "4I5i");
/* harmony import */ var _observable_empty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../observable/empty */ "EY2u");







function takeLast(count) {
  return function takeLastOperatorFunction(source) {
    if (count === 0) {
      return Object(_observable_empty__WEBPACK_IMPORTED_MODULE_6__["empty"])();
    } else {
      return source.lift(new TakeLastOperator(count));
    }
  };
}

var TakeLastOperator = /*#__PURE__*/function () {
  function TakeLastOperator(total) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeLastOperator);

    this.total = total;

    if (this.total < 0) {
      throw new _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_5__["ArgumentOutOfRangeError"]();
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeLastOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new TakeLastSubscriber(subscriber, this.total));
    }
  }]);

  return TakeLastOperator;
}();

var TakeLastSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(TakeLastSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(TakeLastSubscriber);

  function TakeLastSubscriber(destination, total) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeLastSubscriber);

    _this = _super.call(this, destination);
    _this.total = total;
    _this.ring = new Array();
    _this.count = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeLastSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var ring = this.ring;
      var total = this.total;
      var count = this.count++;

      if (ring.length < total) {
        ring.push(value);
      } else {
        var index = count % total;
        ring[index] = value;
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var destination = this.destination;
      var count = this.count;

      if (count > 0) {
        var total = this.count >= this.total ? this.total : this.count;
        var ring = this.ring;

        for (var i = 0; i < total; i++) {
          var idx = count++ % total;
          destination.next(ring[idx]);
        }
      }

      destination.complete();
    }
  }]);

  return TakeLastSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "BVg3":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/is.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Icelandic [is]
//! author : Hinrik Örn Sigurðsson : https://github.com/hinrik
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function plural(n) {
    if (n % 100 === 11) {
      return true;
    } else if (n % 10 === 1) {
      return false;
    }

    return true;
  }

  function translate(number, withoutSuffix, key, isFuture) {
    var result = number + ' ';

    switch (key) {
      case 's':
        return withoutSuffix || isFuture ? 'nokkrar sekúndur' : 'nokkrum sekúndum';

      case 'ss':
        if (plural(number)) {
          return result + (withoutSuffix || isFuture ? 'sekúndur' : 'sekúndum');
        }

        return result + 'sekúnda';

      case 'm':
        return withoutSuffix ? 'mínúta' : 'mínútu';

      case 'mm':
        if (plural(number)) {
          return result + (withoutSuffix || isFuture ? 'mínútur' : 'mínútum');
        } else if (withoutSuffix) {
          return result + 'mínúta';
        }

        return result + 'mínútu';

      case 'hh':
        if (plural(number)) {
          return result + (withoutSuffix || isFuture ? 'klukkustundir' : 'klukkustundum');
        }

        return result + 'klukkustund';

      case 'd':
        if (withoutSuffix) {
          return 'dagur';
        }

        return isFuture ? 'dag' : 'degi';

      case 'dd':
        if (plural(number)) {
          if (withoutSuffix) {
            return result + 'dagar';
          }

          return result + (isFuture ? 'daga' : 'dögum');
        } else if (withoutSuffix) {
          return result + 'dagur';
        }

        return result + (isFuture ? 'dag' : 'degi');

      case 'M':
        if (withoutSuffix) {
          return 'mánuður';
        }

        return isFuture ? 'mánuð' : 'mánuði';

      case 'MM':
        if (plural(number)) {
          if (withoutSuffix) {
            return result + 'mánuðir';
          }

          return result + (isFuture ? 'mánuði' : 'mánuðum');
        } else if (withoutSuffix) {
          return result + 'mánuður';
        }

        return result + (isFuture ? 'mánuð' : 'mánuði');

      case 'y':
        return withoutSuffix || isFuture ? 'ár' : 'ári';

      case 'yy':
        if (plural(number)) {
          return result + (withoutSuffix || isFuture ? 'ár' : 'árum');
        }

        return result + (withoutSuffix || isFuture ? 'ár' : 'ári');
    }
  }

  var is = moment.defineLocale('is', {
    months: 'janúar_febrúar_mars_apríl_maí_júní_júlí_ágúst_september_október_nóvember_desember'.split('_'),
    monthsShort: 'jan_feb_mar_apr_maí_jún_júl_ágú_sep_okt_nóv_des'.split('_'),
    weekdays: 'sunnudagur_mánudagur_þriðjudagur_miðvikudagur_fimmtudagur_föstudagur_laugardagur'.split('_'),
    weekdaysShort: 'sun_mán_þri_mið_fim_fös_lau'.split('_'),
    weekdaysMin: 'Su_Má_Þr_Mi_Fi_Fö_La'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY [kl.] H:mm',
      LLLL: 'dddd, D. MMMM YYYY [kl.] H:mm'
    },
    calendar: {
      sameDay: '[í dag kl.] LT',
      nextDay: '[á morgun kl.] LT',
      nextWeek: 'dddd [kl.] LT',
      lastDay: '[í gær kl.] LT',
      lastWeek: '[síðasta] dddd [kl.] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'eftir %s',
      past: 'fyrir %s síðan',
      s: translate,
      ss: translate,
      m: translate,
      mm: translate,
      h: 'klukkustund',
      hh: translate,
      d: translate,
      dd: translate,
      M: translate,
      MM: translate,
      y: translate,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return is;
});

/***/ }),

/***/ "BsWD":
/*!*******************************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/unsupportedIterableToArray.js ***!
  \*******************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _unsupportedIterableToArray; });
/* harmony import */ var _arrayLikeToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./arrayLikeToArray */ "a3WO");

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return Object(_arrayLikeToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return Object(_arrayLikeToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(o, minLen);
}

/***/ }),

/***/ "ByF4":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/fo.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Faroese [fo]
//! author : Ragnar Johannesen : https://github.com/ragnar123
//! author : Kristian Sakarisson : https://github.com/sakarisson
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var fo = moment.defineLocale('fo', {
    months: 'januar_februar_mars_apríl_mai_juni_juli_august_september_oktober_november_desember'.split('_'),
    monthsShort: 'jan_feb_mar_apr_mai_jun_jul_aug_sep_okt_nov_des'.split('_'),
    weekdays: 'sunnudagur_mánadagur_týsdagur_mikudagur_hósdagur_fríggjadagur_leygardagur'.split('_'),
    weekdaysShort: 'sun_mán_týs_mik_hós_frí_ley'.split('_'),
    weekdaysMin: 'su_má_tý_mi_hó_fr_le'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D. MMMM, YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Í dag kl.] LT',
      nextDay: '[Í morgin kl.] LT',
      nextWeek: 'dddd [kl.] LT',
      lastDay: '[Í gjár kl.] LT',
      lastWeek: '[síðstu] dddd [kl] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'um %s',
      past: '%s síðani',
      s: 'fá sekund',
      ss: '%d sekundir',
      m: 'ein minuttur',
      mm: '%d minuttir',
      h: 'ein tími',
      hh: '%d tímar',
      d: 'ein dagur',
      dd: '%d dagar',
      M: 'ein mánaður',
      MM: '%d mánaðir',
      y: 'eitt ár',
      yy: '%d ár'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return fo;
});

/***/ }),

/***/ "CMyj":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isIterable.js ***!
  \****************************************************************/
/*! exports provided: isIterable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isIterable", function() { return isIterable; });
/* harmony import */ var _symbol_iterator__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../symbol/iterator */ "Lhse");

function isIterable(input) {
  return input && typeof input[_symbol_iterator__WEBPACK_IMPORTED_MODULE_0__["iterator"]] === 'function';
}

/***/ }),

/***/ "CRDf":
/*!***************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/subscribeToObservable.js ***!
  \***************************************************************************/
/*! exports provided: subscribeToObservable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeToObservable", function() { return subscribeToObservable; });
/* harmony import */ var _symbol_observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../symbol/observable */ "kJWO");

var subscribeToObservable = function subscribeToObservable(obj) {
  return function (subscriber) {
    var obs = obj[_symbol_observable__WEBPACK_IMPORTED_MODULE_0__["observable"]]();

    if (typeof obs.subscribe !== 'function') {
      throw new TypeError('Provided object does not correctly implement Symbol.observable');
    } else {
      return obs.subscribe(subscriber);
    }
  };
};

/***/ }),

/***/ "CfBk":
/*!*************************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/iterableToArrayLimit.js ***!
  \*************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _iterableToArrayLimit; });
function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

/***/ }),

/***/ "Cfvw":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/from.js ***!
  \****************************************************************/
/*! exports provided: from */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "from", function() { return from; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_subscribeTo__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/subscribeTo */ "SeVD");
/* harmony import */ var _scheduled_scheduled__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../scheduled/scheduled */ "7HRe");



function from(input, scheduler) {
  if (!scheduler) {
    if (input instanceof _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"]) {
      return input;
    }

    return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](Object(_util_subscribeTo__WEBPACK_IMPORTED_MODULE_1__["subscribeTo"])(input));
  } else {
    return Object(_scheduled_scheduled__WEBPACK_IMPORTED_MODULE_2__["scheduled"])(input, scheduler);
  }
}

/***/ }),

/***/ "CjzT":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/es-do.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Spanish (Dominican Republic) [es-do]
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortDot = 'ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.'.split('_'),
      _monthsShort = 'ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic'.split('_'),
      monthsParse = [/^ene/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i],
      monthsRegex = /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;

  var esDo = moment.defineLocale('es-do', {
    months: 'enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortDot;
      } else if (/-MMM-/.test(format)) {
        return _monthsShort[m.month()];
      } else {
        return monthsShortDot[m.month()];
      }
    },
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,
    monthsShortStrictRegex: /^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'domingo_lunes_martes_miércoles_jueves_viernes_sábado'.split('_'),
    weekdaysShort: 'dom._lun._mar._mié._jue._vie._sáb.'.split('_'),
    weekdaysMin: 'do_lu_ma_mi_ju_vi_sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY h:mm A',
      LLLL: 'dddd, D [de] MMMM [de] YYYY h:mm A'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[hoy a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextDay: function nextDay() {
        return '[mañana a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastDay: function lastDay() {
        return '[ayer a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastWeek: function lastWeek() {
        return '[el] dddd [pasado a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'en %s',
      past: 'hace %s',
      s: 'unos segundos',
      ss: '%d segundos',
      m: 'un minuto',
      mm: '%d minutos',
      h: 'una hora',
      hh: '%d horas',
      d: 'un día',
      dd: '%d días',
      w: 'una semana',
      ww: '%d semanas',
      M: 'un mes',
      MM: '%d meses',
      y: 'un año',
      yy: '%d años'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return esDo;
});

/***/ }),

/***/ "CoRJ":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ar-ma.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Arabic (Morocco) [ar-ma]
//! author : ElFadili Yassine : https://github.com/ElFadiliY
//! author : Abdel Said : https://github.com/abdelsaid
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var arMa = moment.defineLocale('ar-ma', {
    months: 'يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر'.split('_'),
    monthsShort: 'يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر'.split('_'),
    weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'احد_اثنين_ثلاثاء_اربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[اليوم على الساعة] LT',
      nextDay: '[غدا على الساعة] LT',
      nextWeek: 'dddd [على الساعة] LT',
      lastDay: '[أمس على الساعة] LT',
      lastWeek: 'dddd [على الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'في %s',
      past: 'منذ %s',
      s: 'ثوان',
      ss: '%d ثانية',
      m: 'دقيقة',
      mm: '%d دقائق',
      h: 'ساعة',
      hh: '%d ساعات',
      d: 'يوم',
      dd: '%d أيام',
      M: 'شهر',
      MM: '%d أشهر',
      y: 'سنة',
      yy: '%d سنوات'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return arMa;
});

/***/ }),

/***/ "CqXF":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/mapTo.js ***!
  \****************************************************************/
/*! exports provided: mapTo */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mapTo", function() { return mapTo; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function mapTo(value) {
  return function (source) {
    return source.lift(new MapToOperator(value));
  };
}

var MapToOperator = /*#__PURE__*/function () {
  function MapToOperator(value) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MapToOperator);

    this.value = value;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MapToOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new MapToSubscriber(subscriber, this.value));
    }
  }]);

  return MapToOperator;
}();

var MapToSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(MapToSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(MapToSubscriber);

  function MapToSubscriber(destination, value) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MapToSubscriber);

    _this = _super.call(this, destination);
    _this.value = value;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MapToSubscriber, [{
    key: "_next",
    value: function _next(x) {
      this.destination.next(this.value);
    }
  }]);

  return MapToSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "D/JM":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/eu.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Basque [eu]
//! author : Eneko Illarramendi : https://github.com/eillarra
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var eu = moment.defineLocale('eu', {
    months: 'urtarrila_otsaila_martxoa_apirila_maiatza_ekaina_uztaila_abuztua_iraila_urria_azaroa_abendua'.split('_'),
    monthsShort: 'urt._ots._mar._api._mai._eka._uzt._abu._ira._urr._aza._abe.'.split('_'),
    monthsParseExact: true,
    weekdays: 'igandea_astelehena_asteartea_asteazkena_osteguna_ostirala_larunbata'.split('_'),
    weekdaysShort: 'ig._al._ar._az._og._ol._lr.'.split('_'),
    weekdaysMin: 'ig_al_ar_az_og_ol_lr'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: 'YYYY[ko] MMMM[ren] D[a]',
      LLL: 'YYYY[ko] MMMM[ren] D[a] HH:mm',
      LLLL: 'dddd, YYYY[ko] MMMM[ren] D[a] HH:mm',
      l: 'YYYY-M-D',
      ll: 'YYYY[ko] MMM D[a]',
      lll: 'YYYY[ko] MMM D[a] HH:mm',
      llll: 'ddd, YYYY[ko] MMM D[a] HH:mm'
    },
    calendar: {
      sameDay: '[gaur] LT[etan]',
      nextDay: '[bihar] LT[etan]',
      nextWeek: 'dddd LT[etan]',
      lastDay: '[atzo] LT[etan]',
      lastWeek: '[aurreko] dddd LT[etan]',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s barru',
      past: 'duela %s',
      s: 'segundo batzuk',
      ss: '%d segundo',
      m: 'minutu bat',
      mm: '%d minutu',
      h: 'ordu bat',
      hh: '%d ordu',
      d: 'egun bat',
      dd: '%d egun',
      M: 'hilabete bat',
      MM: '%d hilabete',
      y: 'urte bat',
      yy: '%d urte'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return eu;
});

/***/ }),

/***/ "D0XW":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/async.js ***!
  \****************************************************************/
/*! exports provided: asyncScheduler, async */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "asyncScheduler", function() { return asyncScheduler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "async", function() { return async; });
/* harmony import */ var _AsyncAction__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./AsyncAction */ "3N8a");
/* harmony import */ var _AsyncScheduler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./AsyncScheduler */ "IjjT");


var asyncScheduler = new _AsyncScheduler__WEBPACK_IMPORTED_MODULE_1__["AsyncScheduler"](_AsyncAction__WEBPACK_IMPORTED_MODULE_0__["AsyncAction"]);
var async = asyncScheduler;

/***/ }),

/***/ "DH7j":
/*!*************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isArray.js ***!
  \*************************************************************/
/*! exports provided: isArray */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isArray", function() { return isArray; });
var isArray = function () {
  return Array.isArray || function (x) {
    return x && typeof x.length === 'number';
  };
}();

/***/ }),

/***/ "DKr+":
/*!************************************************!*\
  !*** ./node_modules/moment/locale/gom-latn.js ***!
  \************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Konkani Latin script [gom-latn]
//! author : The Discoverer : https://github.com/WikiDiscoverer
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      s: ['thoddea sekondamni', 'thodde sekond'],
      ss: [number + ' sekondamni', number + ' sekond'],
      m: ['eka mintan', 'ek minut'],
      mm: [number + ' mintamni', number + ' mintam'],
      h: ['eka voran', 'ek vor'],
      hh: [number + ' voramni', number + ' voram'],
      d: ['eka disan', 'ek dis'],
      dd: [number + ' disamni', number + ' dis'],
      M: ['eka mhoinean', 'ek mhoino'],
      MM: [number + ' mhoineamni', number + ' mhoine'],
      y: ['eka vorsan', 'ek voros'],
      yy: [number + ' vorsamni', number + ' vorsam']
    };
    return isFuture ? format[key][0] : format[key][1];
  }

  var gomLatn = moment.defineLocale('gom-latn', {
    months: {
      standalone: 'Janer_Febrer_Mars_Abril_Mai_Jun_Julai_Agost_Setembr_Otubr_Novembr_Dezembr'.split('_'),
      format: 'Janerachea_Febrerachea_Marsachea_Abrilachea_Maiachea_Junachea_Julaiachea_Agostachea_Setembrachea_Otubrachea_Novembrachea_Dezembrachea'.split('_'),
      isFormat: /MMMM(\s)+D[oD]?/
    },
    monthsShort: 'Jan._Feb._Mars_Abr._Mai_Jun_Jul._Ago._Set._Otu._Nov._Dez.'.split('_'),
    monthsParseExact: true,
    weekdays: "Aitar_Somar_Mongllar_Budhvar_Birestar_Sukrar_Son'var".split('_'),
    weekdaysShort: 'Ait._Som._Mon._Bud._Bre._Suk._Son.'.split('_'),
    weekdaysMin: 'Ai_Sm_Mo_Bu_Br_Su_Sn'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'A h:mm [vazta]',
      LTS: 'A h:mm:ss [vazta]',
      L: 'DD-MM-YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY A h:mm [vazta]',
      LLLL: 'dddd, MMMM Do, YYYY, A h:mm [vazta]',
      llll: 'ddd, D MMM YYYY, A h:mm [vazta]'
    },
    calendar: {
      sameDay: '[Aiz] LT',
      nextDay: '[Faleam] LT',
      nextWeek: '[Fuddlo] dddd[,] LT',
      lastDay: '[Kal] LT',
      lastWeek: '[Fattlo] dddd[,] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s',
      past: '%s adim',
      s: processRelativeTime,
      ss: processRelativeTime,
      m: processRelativeTime,
      mm: processRelativeTime,
      h: processRelativeTime,
      hh: processRelativeTime,
      d: processRelativeTime,
      dd: processRelativeTime,
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}(er)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        // the ordinal 'er' only applies to day of the month
        case 'D':
          return number + 'er';

        default:
        case 'M':
        case 'Q':
        case 'DDD':
        case 'd':
        case 'w':
        case 'W':
          return number;
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week
      doy: 3 // The week that contains Jan 4th is the first week of the year (7 + 0 - 4)

    },
    meridiemParse: /rati|sokallim|donparam|sanje/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'rati') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'sokallim') {
        return hour;
      } else if (meridiem === 'donparam') {
        return hour > 12 ? hour : hour + 12;
      } else if (meridiem === 'sanje') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'rati';
      } else if (hour < 12) {
        return 'sokallim';
      } else if (hour < 16) {
        return 'donparam';
      } else if (hour < 20) {
        return 'sanje';
      } else {
        return 'rati';
      }
    }
  });
  return gomLatn;
});

/***/ }),

/***/ "DSFK":
/*!*******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/arrayWithHoles.js ***!
  \*******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _arrayWithHoles; });
function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

/***/ }),

/***/ "Dkky":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/fr-ch.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : French (Switzerland) [fr-ch]
//! author : Gaspard Bucher : https://github.com/gaspard
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var frCh = moment.defineLocale('fr-ch', {
    months: 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
    monthsShort: 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
    monthsParseExact: true,
    weekdays: 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
    weekdaysShort: 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
    weekdaysMin: 'di_lu_ma_me_je_ve_sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Aujourd’hui à] LT',
      nextDay: '[Demain à] LT',
      nextWeek: 'dddd [à] LT',
      lastDay: '[Hier à] LT',
      lastWeek: 'dddd [dernier à] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dans %s',
      past: 'il y a %s',
      s: 'quelques secondes',
      ss: '%d secondes',
      m: 'une minute',
      mm: '%d minutes',
      h: 'une heure',
      hh: '%d heures',
      d: 'un jour',
      dd: '%d jours',
      M: 'un mois',
      MM: '%d mois',
      y: 'un an',
      yy: '%d ans'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(er|e)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        // Words with masculine grammatical gender: mois, trimestre, jour
        default:
        case 'M':
        case 'Q':
        case 'D':
        case 'DDD':
        case 'd':
          return number + (number === 1 ? 'er' : 'e');
        // Words with feminine grammatical gender: semaine

        case 'w':
        case 'W':
          return number + (number === 1 ? 're' : 'e');
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return frCh;
});

/***/ }),

/***/ "Dmvi":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-au.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (Australia) [en-au]
//! author : Jared Morse : https://github.com/jarcoal
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enAu = moment.defineLocale('en-au', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY h:mm A',
      LLLL: 'dddd, D MMMM YYYY h:mm A'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return enAu;
});

/***/ }),

/***/ "DoHr":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/tr.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Turkish [tr]
//! authors : Erhan Gundogan : https://github.com/erhangundogan,
//!           Burak Yiğit Kaya: https://github.com/BYK
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var suffixes = {
    1: "'inci",
    5: "'inci",
    8: "'inci",
    70: "'inci",
    80: "'inci",
    2: "'nci",
    7: "'nci",
    20: "'nci",
    50: "'nci",
    3: "'üncü",
    4: "'üncü",
    100: "'üncü",
    6: "'ncı",
    9: "'uncu",
    10: "'uncu",
    30: "'uncu",
    60: "'ıncı",
    90: "'ıncı"
  };
  var tr = moment.defineLocale('tr', {
    months: 'Ocak_Şubat_Mart_Nisan_Mayıs_Haziran_Temmuz_Ağustos_Eylül_Ekim_Kasım_Aralık'.split('_'),
    monthsShort: 'Oca_Şub_Mar_Nis_May_Haz_Tem_Ağu_Eyl_Eki_Kas_Ara'.split('_'),
    weekdays: 'Pazar_Pazartesi_Salı_Çarşamba_Perşembe_Cuma_Cumartesi'.split('_'),
    weekdaysShort: 'Paz_Pts_Sal_Çar_Per_Cum_Cts'.split('_'),
    weekdaysMin: 'Pz_Pt_Sa_Ça_Pe_Cu_Ct'.split('_'),
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 12) {
        return isLower ? 'öö' : 'ÖÖ';
      } else {
        return isLower ? 'ös' : 'ÖS';
      }
    },
    meridiemParse: /öö|ÖÖ|ös|ÖS/,
    isPM: function isPM(input) {
      return input === 'ös' || input === 'ÖS';
    },
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[bugün saat] LT',
      nextDay: '[yarın saat] LT',
      nextWeek: '[gelecek] dddd [saat] LT',
      lastDay: '[dün] LT',
      lastWeek: '[geçen] dddd [saat] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s sonra',
      past: '%s önce',
      s: 'birkaç saniye',
      ss: '%d saniye',
      m: 'bir dakika',
      mm: '%d dakika',
      h: 'bir saat',
      hh: '%d saat',
      d: 'bir gün',
      dd: '%d gün',
      w: 'bir hafta',
      ww: '%d hafta',
      M: 'bir ay',
      MM: '%d ay',
      y: 'bir yıl',
      yy: '%d yıl'
    },
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'Do':
        case 'DD':
          return number;

        default:
          if (number === 0) {
            // special case for zero
            return number + "'ıncı";
          }

          var a = number % 10,
              b = number % 100 - a,
              c = number >= 100 ? 100 : null;
          return number + (suffixes[a] || suffixes[b] || suffixes[c]);
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return tr;
});

/***/ }),

/***/ "DxQv":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/da.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Danish [da]
//! author : Ulrik Nielsen : https://github.com/mrbase
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var da = moment.defineLocale('da', {
    months: 'januar_februar_marts_april_maj_juni_juli_august_september_oktober_november_december'.split('_'),
    monthsShort: 'jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec'.split('_'),
    weekdays: 'søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag'.split('_'),
    weekdaysShort: 'søn_man_tir_ons_tor_fre_lør'.split('_'),
    weekdaysMin: 'sø_ma_ti_on_to_fr_lø'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY HH:mm',
      LLLL: 'dddd [d.] D. MMMM YYYY [kl.] HH:mm'
    },
    calendar: {
      sameDay: '[i dag kl.] LT',
      nextDay: '[i morgen kl.] LT',
      nextWeek: 'på dddd [kl.] LT',
      lastDay: '[i går kl.] LT',
      lastWeek: '[i] dddd[s kl.] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'om %s',
      past: '%s siden',
      s: 'få sekunder',
      ss: '%d sekunder',
      m: 'et minut',
      mm: '%d minutter',
      h: 'en time',
      hh: '%d timer',
      d: 'en dag',
      dd: '%d dage',
      M: 'en måned',
      MM: '%d måneder',
      y: 'et år',
      yy: '%d år'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return da;
});

/***/ }),

/***/ "Dzi0":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/tl-ph.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Tagalog (Philippines) [tl-ph]
//! author : Dan Hagman : https://github.com/hagmandan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var tlPh = moment.defineLocale('tl-ph', {
    months: 'Enero_Pebrero_Marso_Abril_Mayo_Hunyo_Hulyo_Agosto_Setyembre_Oktubre_Nobyembre_Disyembre'.split('_'),
    monthsShort: 'Ene_Peb_Mar_Abr_May_Hun_Hul_Ago_Set_Okt_Nob_Dis'.split('_'),
    weekdays: 'Linggo_Lunes_Martes_Miyerkules_Huwebes_Biyernes_Sabado'.split('_'),
    weekdaysShort: 'Lin_Lun_Mar_Miy_Huw_Biy_Sab'.split('_'),
    weekdaysMin: 'Li_Lu_Ma_Mi_Hu_Bi_Sab'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'MM/D/YYYY',
      LL: 'MMMM D, YYYY',
      LLL: 'MMMM D, YYYY HH:mm',
      LLLL: 'dddd, MMMM DD, YYYY HH:mm'
    },
    calendar: {
      sameDay: 'LT [ngayong araw]',
      nextDay: '[Bukas ng] LT',
      nextWeek: 'LT [sa susunod na] dddd',
      lastDay: 'LT [kahapon]',
      lastWeek: 'LT [noong nakaraang] dddd',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'sa loob ng %s',
      past: '%s ang nakalipas',
      s: 'ilang segundo',
      ss: '%d segundo',
      m: 'isang minuto',
      mm: '%d minuto',
      h: 'isang oras',
      hh: '%d oras',
      d: 'isang araw',
      dd: '%d araw',
      M: 'isang buwan',
      MM: '%d buwan',
      y: 'isang taon',
      yy: '%d taon'
    },
    dayOfMonthOrdinalParse: /\d{1,2}/,
    ordinal: function ordinal(number) {
      return number;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return tlPh;
});

/***/ }),

/***/ "E+lV":
/*!***********************************************!*\
  !*** ./node_modules/moment/locale/sr-cyrl.js ***!
  \***********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Serbian Cyrillic [sr-cyrl]
//! author : Milan Janačković<milanjanackovic@gmail.com> : https://github.com/milan-j
//! author : Stefan Crnjaković <stefan@hotmail.rs> : https://github.com/crnjakovic
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var translator = {
    words: {
      //Different grammatical cases
      ss: ['секунда', 'секунде', 'секунди'],
      m: ['један минут', 'једне минуте'],
      mm: ['минут', 'минуте', 'минута'],
      h: ['један сат', 'једног сата'],
      hh: ['сат', 'сата', 'сати'],
      dd: ['дан', 'дана', 'дана'],
      MM: ['месец', 'месеца', 'месеци'],
      yy: ['година', 'године', 'година']
    },
    correctGrammaticalCase: function correctGrammaticalCase(number, wordKey) {
      return number === 1 ? wordKey[0] : number >= 2 && number <= 4 ? wordKey[1] : wordKey[2];
    },
    translate: function translate(number, withoutSuffix, key) {
      var wordKey = translator.words[key];

      if (key.length === 1) {
        return withoutSuffix ? wordKey[0] : wordKey[1];
      } else {
        return number + ' ' + translator.correctGrammaticalCase(number, wordKey);
      }
    }
  };
  var srCyrl = moment.defineLocale('sr-cyrl', {
    months: 'јануар_фебруар_март_април_мај_јун_јул_август_септембар_октобар_новембар_децембар'.split('_'),
    monthsShort: 'јан._феб._мар._апр._мај_јун_јул_авг._сеп._окт._нов._дец.'.split('_'),
    monthsParseExact: true,
    weekdays: 'недеља_понедељак_уторак_среда_четвртак_петак_субота'.split('_'),
    weekdaysShort: 'нед._пон._уто._сре._чет._пет._суб.'.split('_'),
    weekdaysMin: 'не_по_ут_ср_че_пе_су'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'D. M. YYYY.',
      LL: 'D. MMMM YYYY.',
      LLL: 'D. MMMM YYYY. H:mm',
      LLLL: 'dddd, D. MMMM YYYY. H:mm'
    },
    calendar: {
      sameDay: '[данас у] LT',
      nextDay: '[сутра у] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[у] [недељу] [у] LT';

          case 3:
            return '[у] [среду] [у] LT';

          case 6:
            return '[у] [суботу] [у] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[у] dddd [у] LT';
        }
      },
      lastDay: '[јуче у] LT',
      lastWeek: function lastWeek() {
        var lastWeekDays = ['[прошле] [недеље] [у] LT', '[прошлог] [понедељка] [у] LT', '[прошлог] [уторка] [у] LT', '[прошле] [среде] [у] LT', '[прошлог] [четвртка] [у] LT', '[прошлог] [петка] [у] LT', '[прошле] [суботе] [у] LT'];
        return lastWeekDays[this.day()];
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'за %s',
      past: 'пре %s',
      s: 'неколико секунди',
      ss: translator.translate,
      m: translator.translate,
      mm: translator.translate,
      h: translator.translate,
      hh: translator.translate,
      d: 'дан',
      dd: translator.translate,
      M: 'месец',
      MM: translator.translate,
      y: 'годину',
      yy: translator.translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 1st is the first week of the year.

    }
  });
  return srCyrl;
});

/***/ }),

/***/ "EOgW":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/th.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Thai [th]
//! author : Kridsada Thanabulpong : https://github.com/sirn
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var th = moment.defineLocale('th', {
    months: 'มกราคม_กุมภาพันธ์_มีนาคม_เมษายน_พฤษภาคม_มิถุนายน_กรกฎาคม_สิงหาคม_กันยายน_ตุลาคม_พฤศจิกายน_ธันวาคม'.split('_'),
    monthsShort: 'ม.ค._ก.พ._มี.ค._เม.ย._พ.ค._มิ.ย._ก.ค._ส.ค._ก.ย._ต.ค._พ.ย._ธ.ค.'.split('_'),
    monthsParseExact: true,
    weekdays: 'อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัสบดี_ศุกร์_เสาร์'.split('_'),
    weekdaysShort: 'อาทิตย์_จันทร์_อังคาร_พุธ_พฤหัส_ศุกร์_เสาร์'.split('_'),
    // yes, three characters difference
    weekdaysMin: 'อา._จ._อ._พ._พฤ._ศ._ส.'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY เวลา H:mm',
      LLLL: 'วันddddที่ D MMMM YYYY เวลา H:mm'
    },
    meridiemParse: /ก่อนเที่ยง|หลังเที่ยง/,
    isPM: function isPM(input) {
      return input === 'หลังเที่ยง';
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ก่อนเที่ยง';
      } else {
        return 'หลังเที่ยง';
      }
    },
    calendar: {
      sameDay: '[วันนี้ เวลา] LT',
      nextDay: '[พรุ่งนี้ เวลา] LT',
      nextWeek: 'dddd[หน้า เวลา] LT',
      lastDay: '[เมื่อวานนี้ เวลา] LT',
      lastWeek: '[วัน]dddd[ที่แล้ว เวลา] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'อีก %s',
      past: '%sที่แล้ว',
      s: 'ไม่กี่วินาที',
      ss: '%d วินาที',
      m: '1 นาที',
      mm: '%d นาที',
      h: '1 ชั่วโมง',
      hh: '%d ชั่วโมง',
      d: '1 วัน',
      dd: '%d วัน',
      w: '1 สัปดาห์',
      ww: '%d สัปดาห์',
      M: '1 เดือน',
      MM: '%d เดือน',
      y: '1 ปี',
      yy: '%d ปี'
    }
  });
  return th;
});

/***/ }),

/***/ "EQ5u":
/*!*********************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/ConnectableObservable.js ***!
  \*********************************************************************************/
/*! exports provided: ConnectableObservable, connectableObservableDescriptor */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ConnectableObservable", function() { return ConnectableObservable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "connectableObservableDescriptor", function() { return connectableObservableDescriptor; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _operators_refCount__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../operators/refCount */ "x+ZX");











var ConnectableObservable = /*#__PURE__*/function (_Observable) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(ConnectableObservable, _Observable);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(ConnectableObservable);

  function ConnectableObservable(source, subjectFactory) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ConnectableObservable);

    _this = _super.call(this);
    _this.source = source;
    _this.subjectFactory = subjectFactory;
    _this._refCount = 0;
    _this._isComplete = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ConnectableObservable, [{
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      return this.getSubject().subscribe(subscriber);
    }
  }, {
    key: "getSubject",
    value: function getSubject() {
      var subject = this._subject;

      if (!subject || subject.isStopped) {
        this._subject = this.subjectFactory();
      }

      return this._subject;
    }
  }, {
    key: "connect",
    value: function connect() {
      var connection = this._connection;

      if (!connection) {
        this._isComplete = false;
        connection = this._connection = new _Subscription__WEBPACK_IMPORTED_MODULE_9__["Subscription"]();
        connection.add(this.source.subscribe(new ConnectableSubscriber(this.getSubject(), this)));

        if (connection.closed) {
          this._connection = null;
          connection = _Subscription__WEBPACK_IMPORTED_MODULE_9__["Subscription"].EMPTY;
        }
      }

      return connection;
    }
  }, {
    key: "refCount",
    value: function refCount() {
      return Object(_operators_refCount__WEBPACK_IMPORTED_MODULE_10__["refCount"])()(this);
    }
  }]);

  return ConnectableObservable;
}(_Observable__WEBPACK_IMPORTED_MODULE_7__["Observable"]);
var connectableObservableDescriptor = function () {
  var connectableProto = ConnectableObservable.prototype;
  return {
    operator: {
      value: null
    },
    _refCount: {
      value: 0,
      writable: true
    },
    _subject: {
      value: null,
      writable: true
    },
    _connection: {
      value: null,
      writable: true
    },
    _subscribe: {
      value: connectableProto._subscribe
    },
    _isComplete: {
      value: connectableProto._isComplete,
      writable: true
    },
    getSubject: {
      value: connectableProto.getSubject
    },
    connect: {
      value: connectableProto.connect
    },
    refCount: {
      value: connectableProto.refCount
    }
  };
}();

var ConnectableSubscriber = /*#__PURE__*/function (_SubjectSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(ConnectableSubscriber, _SubjectSubscriber);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(ConnectableSubscriber);

  function ConnectableSubscriber(destination, connectable) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ConnectableSubscriber);

    _this2 = _super2.call(this, destination);
    _this2.connectable = connectable;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ConnectableSubscriber, [{
    key: "_error",
    value: function _error(err) {
      this._unsubscribe();

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(ConnectableSubscriber.prototype), "_error", this).call(this, err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.connectable._isComplete = true;

      this._unsubscribe();

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(ConnectableSubscriber.prototype), "_complete", this).call(this);
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var connectable = this.connectable;

      if (connectable) {
        this.connectable = null;
        var connection = connectable._connection;
        connectable._refCount = 0;
        connectable._subject = null;
        connectable._connection = null;

        if (connection) {
          connection.unsubscribe();
        }
      }
    }
  }]);

  return ConnectableSubscriber;
}(_Subject__WEBPACK_IMPORTED_MODULE_6__["SubjectSubscriber"]);

var RefCountOperator = /*#__PURE__*/function () {
  function RefCountOperator(connectable) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RefCountOperator);

    this.connectable = connectable;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RefCountOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      var connectable = this.connectable;
      connectable._refCount++;
      var refCounter = new RefCountSubscriber(subscriber, connectable);
      var subscription = source.subscribe(refCounter);

      if (!refCounter.closed) {
        refCounter.connection = connectable.connect();
      }

      return subscription;
    }
  }]);

  return RefCountOperator;
}();

var RefCountSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(RefCountSubscriber, _Subscriber);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(RefCountSubscriber);

  function RefCountSubscriber(destination, connectable) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RefCountSubscriber);

    _this3 = _super3.call(this, destination);
    _this3.connectable = connectable;
    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RefCountSubscriber, [{
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var connectable = this.connectable;

      if (!connectable) {
        this.connection = null;
        return;
      }

      this.connectable = null;
      var refCount = connectable._refCount;

      if (refCount <= 0) {
        this.connection = null;
        return;
      }

      connectable._refCount = refCount - 1;

      if (refCount > 1) {
        this.connection = null;
        return;
      }

      var connection = this.connection;
      var sharedConnection = connectable._connection;
      this.connection = null;

      if (sharedConnection && (!connection || sharedConnection === connection)) {
        sharedConnection.unsubscribe();
      }
    }
  }]);

  return RefCountSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_8__["Subscriber"]);

/***/ }),

/***/ "EY2u":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/empty.js ***!
  \*****************************************************************/
/*! exports provided: EMPTY, empty */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EMPTY", function() { return EMPTY; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "empty", function() { return empty; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");

var EMPTY = new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
  return subscriber.complete();
});
function empty(scheduler) {
  return scheduler ? emptyScheduled(scheduler) : EMPTY;
}

function emptyScheduled(scheduler) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    return scheduler.schedule(function () {
      return subscriber.complete();
    });
  });
}

/***/ }),

/***/ "F97/":
/*!*********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/not.js ***!
  \*********************************************************/
/*! exports provided: not */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "not", function() { return not; });
function not(pred, thisArg) {
  function notPred() {
    return !notPred.pred.apply(notPred.thisArg, arguments);
  }

  notPred.pred = pred;
  notPred.thisArg = thisArg;
  return notPred;
}

/***/ }),

/***/ "FD9M":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/bufferToggle.js ***!
  \***********************************************************************/
/*! exports provided: bufferToggle */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "bufferToggle", function() { return bufferToggle; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");










function bufferToggle(openings, closingSelector) {
  return function bufferToggleOperatorFunction(source) {
    return source.lift(new BufferToggleOperator(openings, closingSelector));
  };
}

var BufferToggleOperator = /*#__PURE__*/function () {
  function BufferToggleOperator(openings, closingSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BufferToggleOperator);

    this.openings = openings;
    this.closingSelector = closingSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(BufferToggleOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new BufferToggleSubscriber(subscriber, this.openings, this.closingSelector));
    }
  }]);

  return BufferToggleOperator;
}();

var BufferToggleSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(BufferToggleSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(BufferToggleSubscriber);

  function BufferToggleSubscriber(destination, openings, closingSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BufferToggleSubscriber);

    _this = _super.call(this, destination);
    _this.closingSelector = closingSelector;
    _this.contexts = [];

    _this.add(Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_8__["subscribeToResult"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this), openings));

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(BufferToggleSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var contexts = this.contexts;
      var len = contexts.length;

      for (var i = 0; i < len; i++) {
        contexts[i].buffer.push(value);
      }
    }
  }, {
    key: "_error",
    value: function _error(err) {
      var contexts = this.contexts;

      while (contexts.length > 0) {
        var context = contexts.shift();
        context.subscription.unsubscribe();
        context.buffer = null;
        context.subscription = null;
      }

      this.contexts = null;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferToggleSubscriber.prototype), "_error", this).call(this, err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var contexts = this.contexts;

      while (contexts.length > 0) {
        var context = contexts.shift();
        this.destination.next(context.buffer);
        context.subscription.unsubscribe();
        context.buffer = null;
        context.subscription = null;
      }

      this.contexts = null;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferToggleSubscriber.prototype), "_complete", this).call(this);
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(outerValue, innerValue) {
      outerValue ? this.closeBuffer(outerValue) : this.openBuffer(innerValue);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(innerSub) {
      this.closeBuffer(innerSub.context);
    }
  }, {
    key: "openBuffer",
    value: function openBuffer(value) {
      try {
        var closingSelector = this.closingSelector;
        var closingNotifier = closingSelector.call(this, value);

        if (closingNotifier) {
          this.trySubscribe(closingNotifier);
        }
      } catch (err) {
        this._error(err);
      }
    }
  }, {
    key: "closeBuffer",
    value: function closeBuffer(context) {
      var contexts = this.contexts;

      if (contexts && context) {
        var buffer = context.buffer,
            subscription = context.subscription;
        this.destination.next(buffer);
        contexts.splice(contexts.indexOf(context), 1);
        this.remove(subscription);
        subscription.unsubscribe();
      }
    }
  }, {
    key: "trySubscribe",
    value: function trySubscribe(closingNotifier) {
      var contexts = this.contexts;
      var buffer = [];
      var subscription = new _Subscription__WEBPACK_IMPORTED_MODULE_7__["Subscription"]();
      var context = {
        buffer: buffer,
        subscription: subscription
      };
      contexts.push(context);
      var innerSubscription = Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_8__["subscribeToResult"])(this, closingNotifier, context);

      if (!innerSubscription || innerSubscription.closed) {
        this.closeBuffer(context);
      } else {
        innerSubscription.context = context;
        this.add(innerSubscription);
        subscription.add(innerSubscription);
      }
    }
  }]);

  return BufferToggleSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_9__["OuterSubscriber"]);

/***/ }),

/***/ "FQpF":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/expand.js ***!
  \*****************************************************************/
/*! exports provided: expand, ExpandOperator, ExpandSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "expand", function() { return expand; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExpandOperator", function() { return ExpandOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ExpandSubscriber", function() { return ExpandSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





function expand(project) {
  var concurrent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Number.POSITIVE_INFINITY;
  var scheduler = arguments.length > 2 ? arguments[2] : undefined;
  concurrent = (concurrent || 0) < 1 ? Number.POSITIVE_INFINITY : concurrent;
  return function (source) {
    return source.lift(new ExpandOperator(project, concurrent, scheduler));
  };
}
var ExpandOperator = /*#__PURE__*/function () {
  function ExpandOperator(project, concurrent, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ExpandOperator);

    this.project = project;
    this.concurrent = concurrent;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ExpandOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ExpandSubscriber(subscriber, this.project, this.concurrent, this.scheduler));
    }
  }]);

  return ExpandOperator;
}();
var ExpandSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ExpandSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ExpandSubscriber);

  function ExpandSubscriber(destination, project, concurrent, scheduler) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ExpandSubscriber);

    _this = _super.call(this, destination);
    _this.project = project;
    _this.concurrent = concurrent;
    _this.scheduler = scheduler;
    _this.index = 0;
    _this.active = 0;
    _this.hasCompleted = false;

    if (concurrent < Number.POSITIVE_INFINITY) {
      _this.buffer = [];
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ExpandSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var destination = this.destination;

      if (destination.closed) {
        this._complete();

        return;
      }

      var index = this.index++;

      if (this.active < this.concurrent) {
        destination.next(value);

        try {
          var project = this.project;
          var result = project(value, index);

          if (!this.scheduler) {
            this.subscribeToProjection(result, value, index);
          } else {
            var state = {
              subscriber: this,
              result: result,
              value: value,
              index: index
            };
            var _destination = this.destination;

            _destination.add(this.scheduler.schedule(ExpandSubscriber.dispatch, 0, state));
          }
        } catch (e) {
          destination.error(e);
        }
      } else {
        this.buffer.push(value);
      }
    }
  }, {
    key: "subscribeToProjection",
    value: function subscribeToProjection(result, value, index) {
      this.active++;
      var destination = this.destination;
      destination.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(result, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](this)));
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.hasCompleted = true;

      if (this.hasCompleted && this.active === 0) {
        this.destination.complete();
      }

      this.unsubscribe();
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      this._next(innerValue);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      var buffer = this.buffer;
      this.active--;

      if (buffer && buffer.length > 0) {
        this._next(buffer.shift());
      }

      if (this.hasCompleted && this.active === 0) {
        this.destination.complete();
      }
    }
  }], [{
    key: "dispatch",
    value: function dispatch(arg) {
      var subscriber = arg.subscriber,
          result = arg.result,
          value = arg.value,
          index = arg.index;
      subscriber.subscribeToProjection(result, value, index);
    }
  }]);

  return ExpandSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "FZB8":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/min.js ***!
  \**************************************************************/
/*! exports provided: min */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "min", function() { return min; });
/* harmony import */ var _reduce__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce */ "128B");

function min(comparer) {
  var min = typeof comparer === 'function' ? function (x, y) {
    return comparer(x, y) < 0 ? x : y;
  } : function (x, y) {
    return x < y ? x : y;
  };
  return Object(_reduce__WEBPACK_IMPORTED_MODULE_0__["reduce"])(min);
}

/***/ }),

/***/ "Fnuy":
/*!**********************************************!*\
  !*** ./node_modules/moment/locale/oc-lnc.js ***!
  \**********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Occitan, lengadocian dialecte [oc-lnc]
//! author : Quentin PAGÈS : https://github.com/Quenty31
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ocLnc = moment.defineLocale('oc-lnc', {
    months: {
      standalone: 'genièr_febrièr_març_abril_mai_junh_julhet_agost_setembre_octòbre_novembre_decembre'.split('_'),
      format: "de genièr_de febrièr_de març_d'abril_de mai_de junh_de julhet_d'agost_de setembre_d'octòbre_de novembre_de decembre".split('_'),
      isFormat: /D[oD]?(\s)+MMMM/
    },
    monthsShort: 'gen._febr._març_abr._mai_junh_julh._ago._set._oct._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'dimenge_diluns_dimars_dimècres_dijòus_divendres_dissabte'.split('_'),
    weekdaysShort: 'dg._dl._dm._dc._dj._dv._ds.'.split('_'),
    weekdaysMin: 'dg_dl_dm_dc_dj_dv_ds'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM [de] YYYY',
      ll: 'D MMM YYYY',
      LLL: 'D MMMM [de] YYYY [a] H:mm',
      lll: 'D MMM YYYY, H:mm',
      LLLL: 'dddd D MMMM [de] YYYY [a] H:mm',
      llll: 'ddd D MMM YYYY, H:mm'
    },
    calendar: {
      sameDay: '[uèi a] LT',
      nextDay: '[deman a] LT',
      nextWeek: 'dddd [a] LT',
      lastDay: '[ièr a] LT',
      lastWeek: 'dddd [passat a] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: "d'aquí %s",
      past: 'fa %s',
      s: 'unas segondas',
      ss: '%d segondas',
      m: 'una minuta',
      mm: '%d minutas',
      h: 'una ora',
      hh: '%d oras',
      d: 'un jorn',
      dd: '%d jorns',
      M: 'un mes',
      MM: '%d meses',
      y: 'un an',
      yy: '%d ans'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(r|n|t|è|a)/,
    ordinal: function ordinal(number, period) {
      var output = number === 1 ? 'r' : number === 2 ? 'n' : number === 3 ? 'r' : number === 4 ? 't' : 'è';

      if (period === 'w' || period === 'W') {
        output = 'a';
      }

      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4
    }
  });
  return ocLnc;
});

/***/ }),

/***/ "G0Uy":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/mt.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Maltese (Malta) [mt]
//! author : Alessandro Maruccia : https://github.com/alesma
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var mt = moment.defineLocale('mt', {
    months: 'Jannar_Frar_Marzu_April_Mejju_Ġunju_Lulju_Awwissu_Settembru_Ottubru_Novembru_Diċembru'.split('_'),
    monthsShort: 'Jan_Fra_Mar_Apr_Mej_Ġun_Lul_Aww_Set_Ott_Nov_Diċ'.split('_'),
    weekdays: 'Il-Ħadd_It-Tnejn_It-Tlieta_L-Erbgħa_Il-Ħamis_Il-Ġimgħa_Is-Sibt'.split('_'),
    weekdaysShort: 'Ħad_Tne_Tli_Erb_Ħam_Ġim_Sib'.split('_'),
    weekdaysMin: 'Ħa_Tn_Tl_Er_Ħa_Ġi_Si'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Illum fil-]LT',
      nextDay: '[Għada fil-]LT',
      nextWeek: 'dddd [fil-]LT',
      lastDay: '[Il-bieraħ fil-]LT',
      lastWeek: 'dddd [li għadda] [fil-]LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'f’ %s',
      past: '%s ilu',
      s: 'ftit sekondi',
      ss: '%d sekondi',
      m: 'minuta',
      mm: '%d minuti',
      h: 'siegħa',
      hh: '%d siegħat',
      d: 'ġurnata',
      dd: '%d ġranet',
      M: 'xahar',
      MM: '%d xhur',
      y: 'sena',
      yy: '%d sni'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return mt;
});

/***/ }),

/***/ "GJmQ":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/takeWhile.js ***!
  \********************************************************************/
/*! exports provided: takeWhile */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "takeWhile", function() { return takeWhile; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function takeWhile(predicate) {
  var inclusive = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  return function (source) {
    return source.lift(new TakeWhileOperator(predicate, inclusive));
  };
}

var TakeWhileOperator = /*#__PURE__*/function () {
  function TakeWhileOperator(predicate, inclusive) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeWhileOperator);

    this.predicate = predicate;
    this.inclusive = inclusive;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeWhileOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new TakeWhileSubscriber(subscriber, this.predicate, this.inclusive));
    }
  }]);

  return TakeWhileOperator;
}();

var TakeWhileSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(TakeWhileSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(TakeWhileSubscriber);

  function TakeWhileSubscriber(destination, predicate, inclusive) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeWhileSubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.inclusive = inclusive;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeWhileSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var destination = this.destination;
      var result;

      try {
        result = this.predicate(value, this.index++);
      } catch (err) {
        destination.error(err);
        return;
      }

      this.nextOrComplete(value, result);
    }
  }, {
    key: "nextOrComplete",
    value: function nextOrComplete(value, predicateResult) {
      var destination = this.destination;

      if (Boolean(predicateResult)) {
        destination.next(value);
      } else {
        if (this.inclusive) {
          destination.next(value);
        }

        destination.complete();
      }
    }
  }]);

  return TakeWhileSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "Gi4w":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/every.js ***!
  \****************************************************************/
/*! exports provided: every */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "every", function() { return every; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");






function every(predicate, thisArg) {
  return function (source) {
    return source.lift(new EveryOperator(predicate, thisArg, source));
  };
}

var EveryOperator = /*#__PURE__*/function () {
  function EveryOperator(predicate, thisArg, source) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, EveryOperator);

    this.predicate = predicate;
    this.thisArg = thisArg;
    this.source = source;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(EveryOperator, [{
    key: "call",
    value: function call(observer, source) {
      return source.subscribe(new EverySubscriber(observer, this.predicate, this.thisArg, this.source));
    }
  }]);

  return EveryOperator;
}();

var EverySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(EverySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(EverySubscriber);

  function EverySubscriber(destination, predicate, thisArg, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, EverySubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.thisArg = thisArg;
    _this.source = source;
    _this.index = 0;
    _this.thisArg = thisArg || Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this);
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(EverySubscriber, [{
    key: "notifyComplete",
    value: function notifyComplete(everyValueMatch) {
      this.destination.next(everyValueMatch);
      this.destination.complete();
    }
  }, {
    key: "_next",
    value: function _next(value) {
      var result = false;

      try {
        result = this.predicate.call(this.thisArg, value, this.index++, this.source);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      if (!result) {
        this.notifyComplete(false);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.notifyComplete(true);
    }
  }]);

  return EverySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

/***/ }),

/***/ "GjHo":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/zip.js ***!
  \**************************************************************/
/*! exports provided: zip */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "zip", function() { return zip; });
/* harmony import */ var _observable_zip__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/zip */ "1uah");

function zip() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  return function zipOperatorFunction(source) {
    return source.lift.call(_observable_zip__WEBPACK_IMPORTED_MODULE_0__["zip"].apply(void 0, [source].concat(observables)));
  };
}

/***/ }),

/***/ "Gqsl":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/repeatWhen.js ***!
  \*********************************************************************/
/*! exports provided: repeatWhen */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "repeatWhen", function() { return repeatWhen; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");








function repeatWhen(notifier) {
  return function (source) {
    return source.lift(new RepeatWhenOperator(notifier));
  };
}

var RepeatWhenOperator = /*#__PURE__*/function () {
  function RepeatWhenOperator(notifier) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RepeatWhenOperator);

    this.notifier = notifier;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RepeatWhenOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new RepeatWhenSubscriber(subscriber, this.notifier, source));
    }
  }]);

  return RepeatWhenOperator;
}();

var RepeatWhenSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(RepeatWhenSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(RepeatWhenSubscriber);

  function RepeatWhenSubscriber(destination, notifier, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RepeatWhenSubscriber);

    _this = _super.call(this, destination);
    _this.notifier = notifier;
    _this.source = source;
    _this.sourceIsBeingSubscribedTo = true;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RepeatWhenSubscriber, [{
    key: "notifyNext",
    value: function notifyNext() {
      this.sourceIsBeingSubscribedTo = true;
      this.source.subscribe(this);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      if (this.sourceIsBeingSubscribedTo === false) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RepeatWhenSubscriber.prototype), "complete", this).call(this);
      }
    }
  }, {
    key: "complete",
    value: function complete() {
      this.sourceIsBeingSubscribedTo = false;

      if (!this.isStopped) {
        if (!this.retries) {
          this.subscribeToRetries();
        }

        if (!this.retriesSubscription || this.retriesSubscription.closed) {
          return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RepeatWhenSubscriber.prototype), "complete", this).call(this);
        }

        this._unsubscribeAndRecycle();

        this.notifications.next(undefined);
      }
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var notifications = this.notifications,
          retriesSubscription = this.retriesSubscription;

      if (notifications) {
        notifications.unsubscribe();
        this.notifications = undefined;
      }

      if (retriesSubscription) {
        retriesSubscription.unsubscribe();
        this.retriesSubscription = undefined;
      }

      this.retries = undefined;
    }
  }, {
    key: "_unsubscribeAndRecycle",
    value: function _unsubscribeAndRecycle() {
      var _unsubscribe = this._unsubscribe;
      this._unsubscribe = null;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RepeatWhenSubscriber.prototype), "_unsubscribeAndRecycle", this).call(this);

      this._unsubscribe = _unsubscribe;
      return this;
    }
  }, {
    key: "subscribeToRetries",
    value: function subscribeToRetries() {
      this.notifications = new _Subject__WEBPACK_IMPORTED_MODULE_6__["Subject"]();
      var retries;

      try {
        var notifier = this.notifier;
        retries = notifier(this.notifications);
      } catch (e) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RepeatWhenSubscriber.prototype), "complete", this).call(this);
      }

      this.retries = retries;
      this.retriesSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["innerSubscribe"])(retries, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleInnerSubscriber"](this));
    }
  }]);

  return RepeatWhenSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "GyhO":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/concat.js ***!
  \******************************************************************/
/*! exports provided: concat */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "concat", function() { return concat; });
/* harmony import */ var _of__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./of */ "LRne");
/* harmony import */ var _operators_concatAll__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../operators/concatAll */ "0EUg");


function concat() {
  return Object(_operators_concatAll__WEBPACK_IMPORTED_MODULE_1__["concatAll"])()(_of__WEBPACK_IMPORTED_MODULE_0__["of"].apply(void 0, arguments));
}

/***/ }),

/***/ "H8ED":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/be.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Belarusian [be]
//! author : Dmitry Demidov : https://github.com/demidov91
//! author: Praleska: http://praleska.pro/
//! Author : Menelion Elensúle : https://github.com/Oire
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function plural(word, num) {
    var forms = word.split('_');
    return num % 10 === 1 && num % 100 !== 11 ? forms[0] : num % 10 >= 2 && num % 10 <= 4 && (num % 100 < 10 || num % 100 >= 20) ? forms[1] : forms[2];
  }

  function relativeTimeWithPlural(number, withoutSuffix, key) {
    var format = {
      ss: withoutSuffix ? 'секунда_секунды_секунд' : 'секунду_секунды_секунд',
      mm: withoutSuffix ? 'хвіліна_хвіліны_хвілін' : 'хвіліну_хвіліны_хвілін',
      hh: withoutSuffix ? 'гадзіна_гадзіны_гадзін' : 'гадзіну_гадзіны_гадзін',
      dd: 'дзень_дні_дзён',
      MM: 'месяц_месяцы_месяцаў',
      yy: 'год_гады_гадоў'
    };

    if (key === 'm') {
      return withoutSuffix ? 'хвіліна' : 'хвіліну';
    } else if (key === 'h') {
      return withoutSuffix ? 'гадзіна' : 'гадзіну';
    } else {
      return number + ' ' + plural(format[key], +number);
    }
  }

  var be = moment.defineLocale('be', {
    months: {
      format: 'студзеня_лютага_сакавіка_красавіка_траўня_чэрвеня_ліпеня_жніўня_верасня_кастрычніка_лістапада_снежня'.split('_'),
      standalone: 'студзень_люты_сакавік_красавік_травень_чэрвень_ліпень_жнівень_верасень_кастрычнік_лістапад_снежань'.split('_')
    },
    monthsShort: 'студ_лют_сак_крас_трав_чэрв_ліп_жнів_вер_каст_ліст_снеж'.split('_'),
    weekdays: {
      format: 'нядзелю_панядзелак_аўторак_сераду_чацвер_пятніцу_суботу'.split('_'),
      standalone: 'нядзеля_панядзелак_аўторак_серада_чацвер_пятніца_субота'.split('_'),
      isFormat: /\[ ?[Ууў] ?(?:мінулую|наступную)? ?\] ?dddd/
    },
    weekdaysShort: 'нд_пн_ат_ср_чц_пт_сб'.split('_'),
    weekdaysMin: 'нд_пн_ат_ср_чц_пт_сб'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY г.',
      LLL: 'D MMMM YYYY г., HH:mm',
      LLLL: 'dddd, D MMMM YYYY г., HH:mm'
    },
    calendar: {
      sameDay: '[Сёння ў] LT',
      nextDay: '[Заўтра ў] LT',
      lastDay: '[Учора ў] LT',
      nextWeek: function nextWeek() {
        return '[У] dddd [ў] LT';
      },
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
          case 3:
          case 5:
          case 6:
            return '[У мінулую] dddd [ў] LT';

          case 1:
          case 2:
          case 4:
            return '[У мінулы] dddd [ў] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'праз %s',
      past: '%s таму',
      s: 'некалькі секунд',
      m: relativeTimeWithPlural,
      mm: relativeTimeWithPlural,
      h: relativeTimeWithPlural,
      hh: relativeTimeWithPlural,
      d: 'дзень',
      dd: relativeTimeWithPlural,
      M: 'месяц',
      MM: relativeTimeWithPlural,
      y: 'год',
      yy: relativeTimeWithPlural
    },
    meridiemParse: /ночы|раніцы|дня|вечара/,
    isPM: function isPM(input) {
      return /^(дня|вечара)$/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'ночы';
      } else if (hour < 12) {
        return 'раніцы';
      } else if (hour < 17) {
        return 'дня';
      } else {
        return 'вечара';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(і|ы|га)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'M':
        case 'd':
        case 'DDD':
        case 'w':
        case 'W':
          return (number % 10 === 2 || number % 10 === 3) && number % 100 !== 12 && number % 100 !== 13 ? number + '-і' : number + '-ы';

        case 'D':
          return number + '-га';

        default:
          return number;
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return be;
});

/***/ }),

/***/ "HDdC":
/*!***********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Observable.js ***!
  \***********************************************************/
/*! exports provided: Observable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Observable", function() { return Observable; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _util_canReportError__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util/canReportError */ "8Qeq");
/* harmony import */ var _util_toSubscriber__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util/toSubscriber */ "WyKG");
/* harmony import */ var _symbol_observable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./symbol/observable */ "kJWO");
/* harmony import */ var _util_pipe__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./util/pipe */ "mCNh");
/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./config */ "2fFW");







var Observable = /*#__PURE__*/function () {
  function Observable(subscribe) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Observable);

    this._isScalar = false;

    if (subscribe) {
      this._subscribe = subscribe;
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Observable, [{
    key: "lift",
    value: function lift(operator) {
      var observable = new Observable();
      observable.source = this;
      observable.operator = operator;
      return observable;
    }
  }, {
    key: "subscribe",
    value: function subscribe(observerOrNext, error, complete) {
      var operator = this.operator;
      var sink = Object(_util_toSubscriber__WEBPACK_IMPORTED_MODULE_3__["toSubscriber"])(observerOrNext, error, complete);

      if (operator) {
        sink.add(operator.call(sink, this.source));
      } else {
        sink.add(this.source || _config__WEBPACK_IMPORTED_MODULE_6__["config"].useDeprecatedSynchronousErrorHandling && !sink.syncErrorThrowable ? this._subscribe(sink) : this._trySubscribe(sink));
      }

      if (_config__WEBPACK_IMPORTED_MODULE_6__["config"].useDeprecatedSynchronousErrorHandling) {
        if (sink.syncErrorThrowable) {
          sink.syncErrorThrowable = false;

          if (sink.syncErrorThrown) {
            throw sink.syncErrorValue;
          }
        }
      }

      return sink;
    }
  }, {
    key: "_trySubscribe",
    value: function _trySubscribe(sink) {
      try {
        return this._subscribe(sink);
      } catch (err) {
        if (_config__WEBPACK_IMPORTED_MODULE_6__["config"].useDeprecatedSynchronousErrorHandling) {
          sink.syncErrorThrown = true;
          sink.syncErrorValue = err;
        }

        if (Object(_util_canReportError__WEBPACK_IMPORTED_MODULE_2__["canReportError"])(sink)) {
          sink.error(err);
        } else {
          console.warn(err);
        }
      }
    }
  }, {
    key: "forEach",
    value: function forEach(next, promiseCtor) {
      var _this = this;

      promiseCtor = getPromiseCtor(promiseCtor);
      return new promiseCtor(function (resolve, reject) {
        var subscription;
        subscription = _this.subscribe(function (value) {
          try {
            next(value);
          } catch (err) {
            reject(err);

            if (subscription) {
              subscription.unsubscribe();
            }
          }
        }, reject, resolve);
      });
    }
  }, {
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      var source = this.source;
      return source && source.subscribe(subscriber);
    }
  }, {
    key: _symbol_observable__WEBPACK_IMPORTED_MODULE_4__["observable"],
    value: function value() {
      return this;
    }
  }, {
    key: "pipe",
    value: function pipe() {
      for (var _len = arguments.length, operations = new Array(_len), _key = 0; _key < _len; _key++) {
        operations[_key] = arguments[_key];
      }

      if (operations.length === 0) {
        return this;
      }

      return Object(_util_pipe__WEBPACK_IMPORTED_MODULE_5__["pipeFromArray"])(operations)(this);
    }
  }, {
    key: "toPromise",
    value: function toPromise(promiseCtor) {
      var _this2 = this;

      promiseCtor = getPromiseCtor(promiseCtor);
      return new promiseCtor(function (resolve, reject) {
        var value;

        _this2.subscribe(function (x) {
          return value = x;
        }, function (err) {
          return reject(err);
        }, function () {
          return resolve(value);
        });
      });
    }
  }]);

  return Observable;
}();

Observable.create = function (subscribe) {
  return new Observable(subscribe);
};

function getPromiseCtor(promiseCtor) {
  if (!promiseCtor) {
    promiseCtor = _config__WEBPACK_IMPORTED_MODULE_6__["config"].Promise || Promise;
  }

  if (!promiseCtor) {
    throw new Error('no Promise impl found');
  }

  return promiseCtor;
}

/***/ }),

/***/ "HP3h":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ar-ly.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Arabic (Lybia) [ar-ly]
//! author : Ali Hmer: https://github.com/kikoanis
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '1',
    2: '2',
    3: '3',
    4: '4',
    5: '5',
    6: '6',
    7: '7',
    8: '8',
    9: '9',
    0: '0'
  },
      pluralForm = function pluralForm(n) {
    return n === 0 ? 0 : n === 1 ? 1 : n === 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5;
  },
      plurals = {
    s: ['أقل من ثانية', 'ثانية واحدة', ['ثانيتان', 'ثانيتين'], '%d ثوان', '%d ثانية', '%d ثانية'],
    m: ['أقل من دقيقة', 'دقيقة واحدة', ['دقيقتان', 'دقيقتين'], '%d دقائق', '%d دقيقة', '%d دقيقة'],
    h: ['أقل من ساعة', 'ساعة واحدة', ['ساعتان', 'ساعتين'], '%d ساعات', '%d ساعة', '%d ساعة'],
    d: ['أقل من يوم', 'يوم واحد', ['يومان', 'يومين'], '%d أيام', '%d يومًا', '%d يوم'],
    M: ['أقل من شهر', 'شهر واحد', ['شهران', 'شهرين'], '%d أشهر', '%d شهرا', '%d شهر'],
    y: ['أقل من عام', 'عام واحد', ['عامان', 'عامين'], '%d أعوام', '%d عامًا', '%d عام']
  },
      pluralize = function pluralize(u) {
    return function (number, withoutSuffix, string, isFuture) {
      var f = pluralForm(number),
          str = plurals[u][pluralForm(number)];

      if (f === 2) {
        str = str[withoutSuffix ? 0 : 1];
      }

      return str.replace(/%d/i, number);
    };
  },
      months = ['يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'];

  var arLy = moment.defineLocale('ar-ly', {
    months: months,
    monthsShort: months,
    weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: "D/\u200FM/\u200FYYYY",
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    meridiemParse: /ص|م/,
    isPM: function isPM(input) {
      return 'م' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ص';
      } else {
        return 'م';
      }
    },
    calendar: {
      sameDay: '[اليوم عند الساعة] LT',
      nextDay: '[غدًا عند الساعة] LT',
      nextWeek: 'dddd [عند الساعة] LT',
      lastDay: '[أمس عند الساعة] LT',
      lastWeek: 'dddd [عند الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'بعد %s',
      past: 'منذ %s',
      s: pluralize('s'),
      ss: pluralize('s'),
      m: pluralize('m'),
      mm: pluralize('m'),
      h: pluralize('h'),
      hh: pluralize('h'),
      d: pluralize('d'),
      dd: pluralize('d'),
      M: pluralize('M'),
      MM: pluralize('M'),
      y: pluralize('y'),
      yy: pluralize('y')
    },
    preparse: function preparse(string) {
      return string.replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      }).replace(/,/g, '،');
    },
    week: {
      dow: 6,
      // Saturday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return arLy;
});

/***/ }),

/***/ "Hh5Z":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/QueueScheduler.js ***!
  \*************************************************************************/
/*! exports provided: QueueScheduler */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "QueueScheduler", function() { return QueueScheduler; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _AsyncScheduler__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./AsyncScheduler */ "IjjT");




var QueueScheduler = /*#__PURE__*/function (_AsyncScheduler) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(QueueScheduler, _AsyncScheduler);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(QueueScheduler);

  function QueueScheduler() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, QueueScheduler);

    return _super.apply(this, arguments);
  }

  return QueueScheduler;
}(_AsyncScheduler__WEBPACK_IMPORTED_MODULE_3__["AsyncScheduler"]);

/***/ }),

/***/ "Hkhx":
/*!*****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/onErrorResumeNext.js ***!
  \*****************************************************************************/
/*! exports provided: onErrorResumeNext */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "onErrorResumeNext", function() { return onErrorResumeNext; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _from__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./from */ "Cfvw");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _empty__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./empty */ "EY2u");





function onErrorResumeNext() {
  for (var _len = arguments.length, sources = new Array(_len), _key = 0; _key < _len; _key++) {
    sources[_key] = arguments[_key];
  }

  if (sources.length === 0) {
    return _empty__WEBPACK_IMPORTED_MODULE_4__["EMPTY"];
  }

  var first = sources[0],
      remainder = sources.slice(1);

  if (sources.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_3__["isArray"])(first)) {
    return onErrorResumeNext.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(first));
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_1__["Observable"](function (subscriber) {
    var subNext = function subNext() {
      return subscriber.add(onErrorResumeNext.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(remainder)).subscribe(subscriber));
    };

    return Object(_from__WEBPACK_IMPORTED_MODULE_2__["from"])(first).subscribe({
      next: function next(value) {
        subscriber.next(value);
      },
      error: subNext,
      complete: subNext
    });
  });
}

/***/ }),

/***/ "HrJb":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/count.js ***!
  \****************************************************************/
/*! exports provided: count */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "count", function() { return count; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function count(predicate) {
  return function (source) {
    return source.lift(new CountOperator(predicate, source));
  };
}

var CountOperator = /*#__PURE__*/function () {
  function CountOperator(predicate, source) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, CountOperator);

    this.predicate = predicate;
    this.source = source;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(CountOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new CountSubscriber(subscriber, this.predicate, this.source));
    }
  }]);

  return CountOperator;
}();

var CountSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(CountSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(CountSubscriber);

  function CountSubscriber(destination, predicate, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, CountSubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.source = source;
    _this.count = 0;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(CountSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (this.predicate) {
        this._tryPredicate(value);
      } else {
        this.count++;
      }
    }
  }, {
    key: "_tryPredicate",
    value: function _tryPredicate(value) {
      var result;

      try {
        result = this.predicate(value, this.index++, this.source);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      if (result) {
        this.count++;
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.destination.next(this.count);
      this.destination.complete();
    }
  }]);

  return CountSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "I55L":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isArrayLike.js ***!
  \*****************************************************************/
/*! exports provided: isArrayLike */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isArrayLike", function() { return isArrayLike; });
var isArrayLike = function isArrayLike(x) {
  return x && typeof x.length === 'number' && typeof x !== 'function';
};

/***/ }),

/***/ "IAdc":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/toArray.js ***!
  \******************************************************************/
/*! exports provided: toArray */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "toArray", function() { return toArray; });
/* harmony import */ var _reduce__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce */ "128B");


function toArrayReducer(arr, item, index) {
  if (index === 0) {
    return [item];
  }

  arr.push(item);
  return arr;
}

function toArray() {
  return Object(_reduce__WEBPACK_IMPORTED_MODULE_0__["reduce"])(toArrayReducer, []);
}

/***/ }),

/***/ "IBtZ":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ka.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Georgian [ka]
//! author : Irakli Janiashvili : https://github.com/IrakliJani
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ka = moment.defineLocale('ka', {
    months: 'იანვარი_თებერვალი_მარტი_აპრილი_მაისი_ივნისი_ივლისი_აგვისტო_სექტემბერი_ოქტომბერი_ნოემბერი_დეკემბერი'.split('_'),
    monthsShort: 'იან_თებ_მარ_აპრ_მაი_ივნ_ივლ_აგვ_სექ_ოქტ_ნოე_დეკ'.split('_'),
    weekdays: {
      standalone: 'კვირა_ორშაბათი_სამშაბათი_ოთხშაბათი_ხუთშაბათი_პარასკევი_შაბათი'.split('_'),
      format: 'კვირას_ორშაბათს_სამშაბათს_ოთხშაბათს_ხუთშაბათს_პარასკევს_შაბათს'.split('_'),
      isFormat: /(წინა|შემდეგ)/
    },
    weekdaysShort: 'კვი_ორშ_სამ_ოთხ_ხუთ_პარ_შაბ'.split('_'),
    weekdaysMin: 'კვ_ორ_სა_ოთ_ხუ_პა_შა'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[დღეს] LT[-ზე]',
      nextDay: '[ხვალ] LT[-ზე]',
      lastDay: '[გუშინ] LT[-ზე]',
      nextWeek: '[შემდეგ] dddd LT[-ზე]',
      lastWeek: '[წინა] dddd LT-ზე',
      sameElse: 'L'
    },
    relativeTime: {
      future: function future(s) {
        return s.replace(/(წამ|წუთ|საათ|წელ|დღ|თვ)(ი|ე)/, function ($0, $1, $2) {
          return $2 === 'ი' ? $1 + 'ში' : $1 + $2 + 'ში';
        });
      },
      past: function past(s) {
        if (/(წამი|წუთი|საათი|დღე|თვე)/.test(s)) {
          return s.replace(/(ი|ე)$/, 'ის წინ');
        }

        if (/წელი/.test(s)) {
          return s.replace(/წელი$/, 'წლის წინ');
        }

        return s;
      },
      s: 'რამდენიმე წამი',
      ss: '%d წამი',
      m: 'წუთი',
      mm: '%d წუთი',
      h: 'საათი',
      hh: '%d საათი',
      d: 'დღე',
      dd: '%d დღე',
      M: 'თვე',
      MM: '%d თვე',
      y: 'წელი',
      yy: '%d წელი'
    },
    dayOfMonthOrdinalParse: /0|1-ლი|მე-\d{1,2}|\d{1,2}-ე/,
    ordinal: function ordinal(number) {
      if (number === 0) {
        return number;
      }

      if (number === 1) {
        return number + '-ლი';
      }

      if (number < 20 || number <= 100 && number % 20 === 0 || number % 100 === 0) {
        return 'მე-' + number;
      }

      return number + '-ე';
    },
    week: {
      dow: 1,
      doy: 7
    }
  });
  return ka;
});

/***/ }),

/***/ "IjjT":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/AsyncScheduler.js ***!
  \*************************************************************************/
/*! exports provided: AsyncScheduler */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AsyncScheduler", function() { return AsyncScheduler; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Scheduler__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Scheduler */ "Y/cZ");








var AsyncScheduler = /*#__PURE__*/function (_Scheduler) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(AsyncScheduler, _Scheduler);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(AsyncScheduler);

  function AsyncScheduler(SchedulerAction) {
    var _this;

    var now = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _Scheduler__WEBPACK_IMPORTED_MODULE_7__["Scheduler"].now;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AsyncScheduler);

    _this = _super.call(this, SchedulerAction, function () {
      if (AsyncScheduler.delegate && AsyncScheduler.delegate !== Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this)) {
        return AsyncScheduler.delegate.now();
      } else {
        return now();
      }
    });
    _this.actions = [];
    _this.active = false;
    _this.scheduled = undefined;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AsyncScheduler, [{
    key: "schedule",
    value: function schedule(work) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var state = arguments.length > 2 ? arguments[2] : undefined;

      if (AsyncScheduler.delegate && AsyncScheduler.delegate !== this) {
        return AsyncScheduler.delegate.schedule(work, delay, state);
      } else {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_3__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_4__["default"])(AsyncScheduler.prototype), "schedule", this).call(this, work, delay, state);
      }
    }
  }, {
    key: "flush",
    value: function flush(action) {
      var actions = this.actions;

      if (this.active) {
        actions.push(action);
        return;
      }

      var error;
      this.active = true;

      do {
        if (error = action.execute(action.state, action.delay)) {
          break;
        }
      } while (action = actions.shift());

      this.active = false;

      if (error) {
        while (action = actions.shift()) {
          action.unsubscribe();
        }

        throw error;
      }
    }
  }]);

  return AsyncScheduler;
}(_Scheduler__WEBPACK_IMPORTED_MODULE_7__["Scheduler"]);

/***/ }),

/***/ "Ivi+":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ko.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Korean [ko]
//! author : Kyungwook, Park : https://github.com/kyungw00k
//! author : Jeeeyul Lee <jeeeyul@gmail.com>
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ko = moment.defineLocale('ko', {
    months: '1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월'.split('_'),
    monthsShort: '1월_2월_3월_4월_5월_6월_7월_8월_9월_10월_11월_12월'.split('_'),
    weekdays: '일요일_월요일_화요일_수요일_목요일_금요일_토요일'.split('_'),
    weekdaysShort: '일_월_화_수_목_금_토'.split('_'),
    weekdaysMin: '일_월_화_수_목_금_토'.split('_'),
    longDateFormat: {
      LT: 'A h:mm',
      LTS: 'A h:mm:ss',
      L: 'YYYY.MM.DD.',
      LL: 'YYYY년 MMMM D일',
      LLL: 'YYYY년 MMMM D일 A h:mm',
      LLLL: 'YYYY년 MMMM D일 dddd A h:mm',
      l: 'YYYY.MM.DD.',
      ll: 'YYYY년 MMMM D일',
      lll: 'YYYY년 MMMM D일 A h:mm',
      llll: 'YYYY년 MMMM D일 dddd A h:mm'
    },
    calendar: {
      sameDay: '오늘 LT',
      nextDay: '내일 LT',
      nextWeek: 'dddd LT',
      lastDay: '어제 LT',
      lastWeek: '지난주 dddd LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s 후',
      past: '%s 전',
      s: '몇 초',
      ss: '%d초',
      m: '1분',
      mm: '%d분',
      h: '한 시간',
      hh: '%d시간',
      d: '하루',
      dd: '%d일',
      M: '한 달',
      MM: '%d달',
      y: '일 년',
      yy: '%d년'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(일|월|주)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + '일';

        case 'M':
          return number + '월';

        case 'w':
        case 'W':
          return number + '주';

        default:
          return number;
      }
    },
    meridiemParse: /오전|오후/,
    isPM: function isPM(token) {
      return token === '오후';
    },
    meridiem: function meridiem(hour, minute, isUpper) {
      return hour < 12 ? '오전' : '오후';
    }
  });
  return ko;
});

/***/ }),

/***/ "IzEk":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/take.js ***!
  \***************************************************************/
/*! exports provided: take */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "take", function() { return take; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/ArgumentOutOfRangeError */ "4I5i");
/* harmony import */ var _observable_empty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../observable/empty */ "EY2u");







function take(count) {
  return function (source) {
    if (count === 0) {
      return Object(_observable_empty__WEBPACK_IMPORTED_MODULE_6__["empty"])();
    } else {
      return source.lift(new TakeOperator(count));
    }
  };
}

var TakeOperator = /*#__PURE__*/function () {
  function TakeOperator(total) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeOperator);

    this.total = total;

    if (this.total < 0) {
      throw new _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_5__["ArgumentOutOfRangeError"]();
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new TakeSubscriber(subscriber, this.total));
    }
  }]);

  return TakeOperator;
}();

var TakeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(TakeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(TakeSubscriber);

  function TakeSubscriber(destination, total) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TakeSubscriber);

    _this = _super.call(this, destination);
    _this.total = total;
    _this.count = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TakeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var total = this.total;
      var count = ++this.count;

      if (count <= total) {
        this.destination.next(value);

        if (count === total) {
          this.destination.complete();
          this.unsubscribe();
        }
      }
    }
  }]);

  return TakeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "JCF/":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ku.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Kurdish [ku]
//! author : Shahram Mebashar : https://github.com/ShahramMebashar
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '١',
    2: '٢',
    3: '٣',
    4: '٤',
    5: '٥',
    6: '٦',
    7: '٧',
    8: '٨',
    9: '٩',
    0: '٠'
  },
      numberMap = {
    '١': '1',
    '٢': '2',
    '٣': '3',
    '٤': '4',
    '٥': '5',
    '٦': '6',
    '٧': '7',
    '٨': '8',
    '٩': '9',
    '٠': '0'
  },
      months = ['کانونی دووەم', 'شوبات', 'ئازار', 'نیسان', 'ئایار', 'حوزەیران', 'تەمموز', 'ئاب', 'ئەیلوول', 'تشرینی یەكەم', 'تشرینی دووەم', 'كانونی یەکەم'];
  var ku = moment.defineLocale('ku', {
    months: months,
    monthsShort: months,
    weekdays: 'یه‌كشه‌ممه‌_دووشه‌ممه‌_سێشه‌ممه‌_چوارشه‌ممه‌_پێنجشه‌ممه‌_هه‌ینی_شه‌ممه‌'.split('_'),
    weekdaysShort: 'یه‌كشه‌م_دووشه‌م_سێشه‌م_چوارشه‌م_پێنجشه‌م_هه‌ینی_شه‌ممه‌'.split('_'),
    weekdaysMin: 'ی_د_س_چ_پ_ه_ش'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    meridiemParse: /ئێواره‌|به‌یانی/,
    isPM: function isPM(input) {
      return /ئێواره‌/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'به‌یانی';
      } else {
        return 'ئێواره‌';
      }
    },
    calendar: {
      sameDay: '[ئه‌مرۆ كاتژمێر] LT',
      nextDay: '[به‌یانی كاتژمێر] LT',
      nextWeek: 'dddd [كاتژمێر] LT',
      lastDay: '[دوێنێ كاتژمێر] LT',
      lastWeek: 'dddd [كاتژمێر] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'له‌ %s',
      past: '%s',
      s: 'چه‌ند چركه‌یه‌ك',
      ss: 'چركه‌ %d',
      m: 'یه‌ك خوله‌ك',
      mm: '%d خوله‌ك',
      h: 'یه‌ك كاتژمێر',
      hh: '%d كاتژمێر',
      d: 'یه‌ك ڕۆژ',
      dd: '%d ڕۆژ',
      M: 'یه‌ك مانگ',
      MM: '%d مانگ',
      y: 'یه‌ك ساڵ',
      yy: '%d ساڵ'
    },
    preparse: function preparse(string) {
      return string.replace(/[١٢٣٤٥٦٧٨٩٠]/g, function (match) {
        return numberMap[match];
      }).replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      }).replace(/,/g, '،');
    },
    week: {
      dow: 6,
      // Saturday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return ku;
});

/***/ }),

/***/ "JIr8":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/catchError.js ***!
  \*********************************************************************/
/*! exports provided: catchError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "catchError", function() { return catchError; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");







function catchError(selector) {
  return function catchErrorOperatorFunction(source) {
    var operator = new CatchOperator(selector);
    var caught = source.lift(operator);
    return operator.caught = caught;
  };
}

var CatchOperator = /*#__PURE__*/function () {
  function CatchOperator(selector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, CatchOperator);

    this.selector = selector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(CatchOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new CatchSubscriber(subscriber, this.selector, this.caught));
    }
  }]);

  return CatchOperator;
}();

var CatchSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(CatchSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(CatchSubscriber);

  function CatchSubscriber(destination, selector, caught) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, CatchSubscriber);

    _this = _super.call(this, destination);
    _this.selector = selector;
    _this.caught = caught;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(CatchSubscriber, [{
    key: "error",
    value: function error(err) {
      if (!this.isStopped) {
        var result;

        try {
          result = this.selector(err, this.caught);
        } catch (err2) {
          Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(CatchSubscriber.prototype), "error", this).call(this, err2);

          return;
        }

        this._unsubscribeAndRecycle();

        var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleInnerSubscriber"](this);
        this.add(innerSubscriber);
        var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["innerSubscribe"])(result, innerSubscriber);

        if (innerSubscription !== innerSubscriber) {
          this.add(innerSubscription);
        }
      }
    }
  }]);

  return CatchSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "JVSJ":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/bs.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Bosnian [bs]
//! author : Nedim Cholich : https://github.com/frontyard
//! based on (hr) translation by Bojan Marković
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function translate(number, withoutSuffix, key) {
    var result = number + ' ';

    switch (key) {
      case 'ss':
        if (number === 1) {
          result += 'sekunda';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'sekunde';
        } else {
          result += 'sekundi';
        }

        return result;

      case 'm':
        return withoutSuffix ? 'jedna minuta' : 'jedne minute';

      case 'mm':
        if (number === 1) {
          result += 'minuta';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'minute';
        } else {
          result += 'minuta';
        }

        return result;

      case 'h':
        return withoutSuffix ? 'jedan sat' : 'jednog sata';

      case 'hh':
        if (number === 1) {
          result += 'sat';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'sata';
        } else {
          result += 'sati';
        }

        return result;

      case 'dd':
        if (number === 1) {
          result += 'dan';
        } else {
          result += 'dana';
        }

        return result;

      case 'MM':
        if (number === 1) {
          result += 'mjesec';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'mjeseca';
        } else {
          result += 'mjeseci';
        }

        return result;

      case 'yy':
        if (number === 1) {
          result += 'godina';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'godine';
        } else {
          result += 'godina';
        }

        return result;
    }
  }

  var bs = moment.defineLocale('bs', {
    months: 'januar_februar_mart_april_maj_juni_juli_august_septembar_oktobar_novembar_decembar'.split('_'),
    monthsShort: 'jan._feb._mar._apr._maj._jun._jul._aug._sep._okt._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota'.split('_'),
    weekdaysShort: 'ned._pon._uto._sri._čet._pet._sub.'.split('_'),
    weekdaysMin: 'ne_po_ut_sr_če_pe_su'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm',
      LLLL: 'dddd, D. MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[danas u] LT',
      nextDay: '[sutra u] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[u] [nedjelju] [u] LT';

          case 3:
            return '[u] [srijedu] [u] LT';

          case 6:
            return '[u] [subotu] [u] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[u] dddd [u] LT';
        }
      },
      lastDay: '[jučer u] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
          case 3:
            return '[prošlu] dddd [u] LT';

          case 6:
            return '[prošle] [subote] [u] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[prošli] dddd [u] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: 'prije %s',
      s: 'par sekundi',
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: 'dan',
      dd: translate,
      M: 'mjesec',
      MM: translate,
      y: 'godinu',
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return bs;
});

/***/ }),

/***/ "JX7q":
/*!**************************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized.js ***!
  \**************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _assertThisInitialized; });
function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

/***/ }),

/***/ "JX91":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/startWith.js ***!
  \********************************************************************/
/*! exports provided: startWith */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "startWith", function() { return startWith; });
/* harmony import */ var _observable_concat__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/concat */ "GyhO");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");


function startWith() {
  for (var _len = arguments.length, array = new Array(_len), _key = 0; _key < _len; _key++) {
    array[_key] = arguments[_key];
  }

  var scheduler = array[array.length - 1];

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_1__["isScheduler"])(scheduler)) {
    array.pop();
    return function (source) {
      return Object(_observable_concat__WEBPACK_IMPORTED_MODULE_0__["concat"])(array, source, scheduler);
    };
  } else {
    return function (source) {
      return Object(_observable_concat__WEBPACK_IMPORTED_MODULE_0__["concat"])(array, source);
    };
  }
}

/***/ }),

/***/ "Ji7U":
/*!*************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/inherits.js ***!
  \*************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _inherits; });
/* harmony import */ var _setPrototypeOf__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./setPrototypeOf */ "s4An");

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object(_setPrototypeOf__WEBPACK_IMPORTED_MODULE_0__["default"])(subClass, superClass);
}

/***/ }),

/***/ "JmF6":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/zipAll.js ***!
  \*****************************************************************/
/*! exports provided: zipAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "zipAll", function() { return zipAll; });
/* harmony import */ var _observable_zip__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/zip */ "1uah");

function zipAll(project) {
  return function (source) {
    return source.lift(new _observable_zip__WEBPACK_IMPORTED_MODULE_0__["ZipOperator"](project));
  };
}

/***/ }),

/***/ "JvlW":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/lt.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Lithuanian [lt]
//! author : Mindaugas Mozūras : https://github.com/mmozuras
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var units = {
    ss: 'sekundė_sekundžių_sekundes',
    m: 'minutė_minutės_minutę',
    mm: 'minutės_minučių_minutes',
    h: 'valanda_valandos_valandą',
    hh: 'valandos_valandų_valandas',
    d: 'diena_dienos_dieną',
    dd: 'dienos_dienų_dienas',
    M: 'mėnuo_mėnesio_mėnesį',
    MM: 'mėnesiai_mėnesių_mėnesius',
    y: 'metai_metų_metus',
    yy: 'metai_metų_metus'
  };

  function translateSeconds(number, withoutSuffix, key, isFuture) {
    if (withoutSuffix) {
      return 'kelios sekundės';
    } else {
      return isFuture ? 'kelių sekundžių' : 'kelias sekundes';
    }
  }

  function translateSingular(number, withoutSuffix, key, isFuture) {
    return withoutSuffix ? forms(key)[0] : isFuture ? forms(key)[1] : forms(key)[2];
  }

  function special(number) {
    return number % 10 === 0 || number > 10 && number < 20;
  }

  function forms(key) {
    return units[key].split('_');
  }

  function translate(number, withoutSuffix, key, isFuture) {
    var result = number + ' ';

    if (number === 1) {
      return result + translateSingular(number, withoutSuffix, key[0], isFuture);
    } else if (withoutSuffix) {
      return result + (special(number) ? forms(key)[1] : forms(key)[0]);
    } else {
      if (isFuture) {
        return result + forms(key)[1];
      } else {
        return result + (special(number) ? forms(key)[1] : forms(key)[2]);
      }
    }
  }

  var lt = moment.defineLocale('lt', {
    months: {
      format: 'sausio_vasario_kovo_balandžio_gegužės_birželio_liepos_rugpjūčio_rugsėjo_spalio_lapkričio_gruodžio'.split('_'),
      standalone: 'sausis_vasaris_kovas_balandis_gegužė_birželis_liepa_rugpjūtis_rugsėjis_spalis_lapkritis_gruodis'.split('_'),
      isFormat: /D[oD]?(\[[^\[\]]*\]|\s)+MMMM?|MMMM?(\[[^\[\]]*\]|\s)+D[oD]?/
    },
    monthsShort: 'sau_vas_kov_bal_geg_bir_lie_rgp_rgs_spa_lap_grd'.split('_'),
    weekdays: {
      format: 'sekmadienį_pirmadienį_antradienį_trečiadienį_ketvirtadienį_penktadienį_šeštadienį'.split('_'),
      standalone: 'sekmadienis_pirmadienis_antradienis_trečiadienis_ketvirtadienis_penktadienis_šeštadienis'.split('_'),
      isFormat: /dddd HH:mm/
    },
    weekdaysShort: 'Sek_Pir_Ant_Tre_Ket_Pen_Šeš'.split('_'),
    weekdaysMin: 'S_P_A_T_K_Pn_Š'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: 'YYYY [m.] MMMM D [d.]',
      LLL: 'YYYY [m.] MMMM D [d.], HH:mm [val.]',
      LLLL: 'YYYY [m.] MMMM D [d.], dddd, HH:mm [val.]',
      l: 'YYYY-MM-DD',
      ll: 'YYYY [m.] MMMM D [d.]',
      lll: 'YYYY [m.] MMMM D [d.], HH:mm [val.]',
      llll: 'YYYY [m.] MMMM D [d.], ddd, HH:mm [val.]'
    },
    calendar: {
      sameDay: '[Šiandien] LT',
      nextDay: '[Rytoj] LT',
      nextWeek: 'dddd LT',
      lastDay: '[Vakar] LT',
      lastWeek: '[Praėjusį] dddd LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'po %s',
      past: 'prieš %s',
      s: translateSeconds,
      ss: translate,
      m: translateSingular,
      mm: translate,
      h: translateSingular,
      hh: translate,
      d: translateSingular,
      dd: translate,
      M: translateSingular,
      MM: translate,
      y: translateSingular,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}-oji/,
    ordinal: function ordinal(number) {
      return number + '-oji';
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return lt;
});

/***/ }),

/***/ "K/tc":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/af.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Afrikaans [af]
//! author : Werner Mollentze : https://github.com/wernerm
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var af = moment.defineLocale('af', {
    months: 'Januarie_Februarie_Maart_April_Mei_Junie_Julie_Augustus_September_Oktober_November_Desember'.split('_'),
    monthsShort: 'Jan_Feb_Mrt_Apr_Mei_Jun_Jul_Aug_Sep_Okt_Nov_Des'.split('_'),
    weekdays: 'Sondag_Maandag_Dinsdag_Woensdag_Donderdag_Vrydag_Saterdag'.split('_'),
    weekdaysShort: 'Son_Maa_Din_Woe_Don_Vry_Sat'.split('_'),
    weekdaysMin: 'So_Ma_Di_Wo_Do_Vr_Sa'.split('_'),
    meridiemParse: /vm|nm/i,
    isPM: function isPM(input) {
      return /^nm$/i.test(input);
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 12) {
        return isLower ? 'vm' : 'VM';
      } else {
        return isLower ? 'nm' : 'NM';
      }
    },
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Vandag om] LT',
      nextDay: '[Môre om] LT',
      nextWeek: 'dddd [om] LT',
      lastDay: '[Gister om] LT',
      lastWeek: '[Laas] dddd [om] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'oor %s',
      past: '%s gelede',
      s: "'n paar sekondes",
      ss: '%d sekondes',
      m: "'n minuut",
      mm: '%d minute',
      h: "'n uur",
      hh: '%d ure',
      d: "'n dag",
      dd: '%d dae',
      M: "'n maand",
      MM: '%d maande',
      y: "'n jaar",
      yy: '%d jaar'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(ste|de)/,
    ordinal: function ordinal(number) {
      return number + (number === 1 || number === 8 || number >= 20 ? 'ste' : 'de'); // Thanks to Joris Röling : https://github.com/jjupiter
    },
    week: {
      dow: 1,
      // Maandag is die eerste dag van die week.
      doy: 4 // Die week wat die 4de Januarie bevat is die eerste week van die jaar.

    }
  });
  return af;
});

/***/ }),

/***/ "K7De":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/findIndex.js ***!
  \********************************************************************/
/*! exports provided: findIndex */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "findIndex", function() { return findIndex; });
/* harmony import */ var _operators_find__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../operators/find */ "cBqT");

function findIndex(predicate, thisArg) {
  return function (source) {
    return source.lift(new _operators_find__WEBPACK_IMPORTED_MODULE_0__["FindValueOperator"](predicate, source, true, thisArg));
  };
}

/***/ }),

/***/ "KQm4":
/*!**********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/toConsumableArray.js ***!
  \**********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _toConsumableArray; });
/* harmony import */ var _arrayWithoutHoles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./arrayWithoutHoles */ "YAWx");
/* harmony import */ var _iterableToArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./iterableToArray */ "25BE");
/* harmony import */ var _unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./unsupportedIterableToArray */ "BsWD");
/* harmony import */ var _nonIterableSpread__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./nonIterableSpread */ "NCdM");




function _toConsumableArray(arr) {
  return Object(_arrayWithoutHoles__WEBPACK_IMPORTED_MODULE_0__["default"])(arr) || Object(_iterableToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(arr) || Object(_unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(arr) || Object(_nonIterableSpread__WEBPACK_IMPORTED_MODULE_3__["default"])();
}

/***/ }),

/***/ "KSF8":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/vi.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Vietnamese [vi]
//! author : Bang Nguyen : https://github.com/bangnk
//! author : Chien Kira : https://github.com/chienkira
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var vi = moment.defineLocale('vi', {
    months: 'tháng 1_tháng 2_tháng 3_tháng 4_tháng 5_tháng 6_tháng 7_tháng 8_tháng 9_tháng 10_tháng 11_tháng 12'.split('_'),
    monthsShort: 'Thg 01_Thg 02_Thg 03_Thg 04_Thg 05_Thg 06_Thg 07_Thg 08_Thg 09_Thg 10_Thg 11_Thg 12'.split('_'),
    monthsParseExact: true,
    weekdays: 'chủ nhật_thứ hai_thứ ba_thứ tư_thứ năm_thứ sáu_thứ bảy'.split('_'),
    weekdaysShort: 'CN_T2_T3_T4_T5_T6_T7'.split('_'),
    weekdaysMin: 'CN_T2_T3_T4_T5_T6_T7'.split('_'),
    weekdaysParseExact: true,
    meridiemParse: /sa|ch/i,
    isPM: function isPM(input) {
      return /^ch$/i.test(input);
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 12) {
        return isLower ? 'sa' : 'SA';
      } else {
        return isLower ? 'ch' : 'CH';
      }
    },
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM [năm] YYYY',
      LLL: 'D MMMM [năm] YYYY HH:mm',
      LLLL: 'dddd, D MMMM [năm] YYYY HH:mm',
      l: 'DD/M/YYYY',
      ll: 'D MMM YYYY',
      lll: 'D MMM YYYY HH:mm',
      llll: 'ddd, D MMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Hôm nay lúc] LT',
      nextDay: '[Ngày mai lúc] LT',
      nextWeek: 'dddd [tuần tới lúc] LT',
      lastDay: '[Hôm qua lúc] LT',
      lastWeek: 'dddd [tuần trước lúc] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s tới',
      past: '%s trước',
      s: 'vài giây',
      ss: '%d giây',
      m: 'một phút',
      mm: '%d phút',
      h: 'một giờ',
      hh: '%d giờ',
      d: 'một ngày',
      dd: '%d ngày',
      w: 'một tuần',
      ww: '%d tuần',
      M: 'một tháng',
      MM: '%d tháng',
      y: 'một năm',
      yy: '%d năm'
    },
    dayOfMonthOrdinalParse: /\d{1,2}/,
    ordinal: function ordinal(number) {
      return number;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return vi;
});

/***/ }),

/***/ "KTz0":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/me.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Montenegrin [me]
//! author : Miodrag Nikač <miodrag@restartit.me> : https://github.com/miodragnikac
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var translator = {
    words: {
      //Different grammatical cases
      ss: ['sekund', 'sekunda', 'sekundi'],
      m: ['jedan minut', 'jednog minuta'],
      mm: ['minut', 'minuta', 'minuta'],
      h: ['jedan sat', 'jednog sata'],
      hh: ['sat', 'sata', 'sati'],
      dd: ['dan', 'dana', 'dana'],
      MM: ['mjesec', 'mjeseca', 'mjeseci'],
      yy: ['godina', 'godine', 'godina']
    },
    correctGrammaticalCase: function correctGrammaticalCase(number, wordKey) {
      return number === 1 ? wordKey[0] : number >= 2 && number <= 4 ? wordKey[1] : wordKey[2];
    },
    translate: function translate(number, withoutSuffix, key) {
      var wordKey = translator.words[key];

      if (key.length === 1) {
        return withoutSuffix ? wordKey[0] : wordKey[1];
      } else {
        return number + ' ' + translator.correctGrammaticalCase(number, wordKey);
      }
    }
  };
  var me = moment.defineLocale('me', {
    months: 'januar_februar_mart_april_maj_jun_jul_avgust_septembar_oktobar_novembar_decembar'.split('_'),
    monthsShort: 'jan._feb._mar._apr._maj_jun_jul_avg._sep._okt._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota'.split('_'),
    weekdaysShort: 'ned._pon._uto._sri._čet._pet._sub.'.split('_'),
    weekdaysMin: 'ne_po_ut_sr_če_pe_su'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm',
      LLLL: 'dddd, D. MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[danas u] LT',
      nextDay: '[sjutra u] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[u] [nedjelju] [u] LT';

          case 3:
            return '[u] [srijedu] [u] LT';

          case 6:
            return '[u] [subotu] [u] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[u] dddd [u] LT';
        }
      },
      lastDay: '[juče u] LT',
      lastWeek: function lastWeek() {
        var lastWeekDays = ['[prošle] [nedjelje] [u] LT', '[prošlog] [ponedjeljka] [u] LT', '[prošlog] [utorka] [u] LT', '[prošle] [srijede] [u] LT', '[prošlog] [četvrtka] [u] LT', '[prošlog] [petka] [u] LT', '[prošle] [subote] [u] LT'];
        return lastWeekDays[this.day()];
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: 'prije %s',
      s: 'nekoliko sekundi',
      ss: translator.translate,
      m: translator.translate,
      mm: translator.translate,
      h: translator.translate,
      hh: translator.translate,
      d: 'dan',
      dd: translator.translate,
      M: 'mjesec',
      MM: translator.translate,
      y: 'godinu',
      yy: translator.translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return me;
});

/***/ }),

/***/ "Kj3r":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/debounceTime.js ***!
  \***********************************************************************/
/*! exports provided: debounceTime */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "debounceTime", function() { return debounceTime; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");






function debounceTime(dueTime) {
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_5__["async"];
  return function (source) {
    return source.lift(new DebounceTimeOperator(dueTime, scheduler));
  };
}

var DebounceTimeOperator = /*#__PURE__*/function () {
  function DebounceTimeOperator(dueTime, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DebounceTimeOperator);

    this.dueTime = dueTime;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DebounceTimeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DebounceTimeSubscriber(subscriber, this.dueTime, this.scheduler));
    }
  }]);

  return DebounceTimeOperator;
}();

var DebounceTimeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(DebounceTimeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(DebounceTimeSubscriber);

  function DebounceTimeSubscriber(destination, dueTime, scheduler) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DebounceTimeSubscriber);

    _this = _super.call(this, destination);
    _this.dueTime = dueTime;
    _this.scheduler = scheduler;
    _this.debouncedSubscription = null;
    _this.lastValue = null;
    _this.hasValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DebounceTimeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.clearDebounce();
      this.lastValue = value;
      this.hasValue = true;
      this.add(this.debouncedSubscription = this.scheduler.schedule(dispatchNext, this.dueTime, this));
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.debouncedNext();
      this.destination.complete();
    }
  }, {
    key: "debouncedNext",
    value: function debouncedNext() {
      this.clearDebounce();

      if (this.hasValue) {
        var lastValue = this.lastValue;
        this.lastValue = null;
        this.hasValue = false;
        this.destination.next(lastValue);
      }
    }
  }, {
    key: "clearDebounce",
    value: function clearDebounce() {
      var debouncedSubscription = this.debouncedSubscription;

      if (debouncedSubscription !== null) {
        this.remove(debouncedSubscription);
        debouncedSubscription.unsubscribe();
        this.debouncedSubscription = null;
      }
    }
  }]);

  return DebounceTimeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

function dispatchNext(subscriber) {
  subscriber.debouncedNext();
}

/***/ }),

/***/ "Kqap":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/scan.js ***!
  \***************************************************************/
/*! exports provided: scan */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "scan", function() { return scan; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function scan(accumulator, seed) {
  var hasSeed = false;

  if (arguments.length >= 2) {
    hasSeed = true;
  }

  return function scanOperatorFunction(source) {
    return source.lift(new ScanOperator(accumulator, seed, hasSeed));
  };
}

var ScanOperator = /*#__PURE__*/function () {
  function ScanOperator(accumulator, seed) {
    var hasSeed = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ScanOperator);

    this.accumulator = accumulator;
    this.seed = seed;
    this.hasSeed = hasSeed;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ScanOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ScanSubscriber(subscriber, this.accumulator, this.seed, this.hasSeed));
    }
  }]);

  return ScanOperator;
}();

var ScanSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ScanSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ScanSubscriber);

  function ScanSubscriber(destination, accumulator, _seed, hasSeed) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ScanSubscriber);

    _this = _super.call(this, destination);
    _this.accumulator = accumulator;
    _this._seed = _seed;
    _this.hasSeed = hasSeed;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ScanSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (!this.hasSeed) {
        this.seed = value;
        this.destination.next(value);
      } else {
        return this._tryNext(value);
      }
    }
  }, {
    key: "_tryNext",
    value: function _tryNext(value) {
      var index = this.index++;
      var result;

      try {
        result = this.accumulator(this.seed, value, index);
      } catch (err) {
        this.destination.error(err);
      }

      this.seed = result;
      this.destination.next(result);
    }
  }, {
    key: "seed",
    get: function get() {
      return this._seed;
    },
    set: function set(value) {
      this.hasSeed = true;
      this._seed = value;
    }
  }]);

  return ScanSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "KqfI":
/*!**********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/noop.js ***!
  \**********************************************************/
/*! exports provided: noop */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "noop", function() { return noop; });
function noop() {}

/***/ }),

/***/ "LK+K":
/*!****************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/createSuper.js ***!
  \****************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _createSuper; });
/* harmony import */ var _getPrototypeOf__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./getPrototypeOf */ "foSv");
/* harmony import */ var _isNativeReflectConstruct__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./isNativeReflectConstruct */ "2WcH");
/* harmony import */ var _possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./possibleConstructorReturn */ "md7G");



function _createSuper(Derived) {
  var hasNativeReflectConstruct = Object(_isNativeReflectConstruct__WEBPACK_IMPORTED_MODULE_1__["default"])();
  return function _createSuperInternal() {
    var Super = Object(_getPrototypeOf__WEBPACK_IMPORTED_MODULE_0__["default"])(Derived),
        result;

    if (hasNativeReflectConstruct) {
      var NewTarget = Object(_getPrototypeOf__WEBPACK_IMPORTED_MODULE_0__["default"])(this).constructor;
      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return Object(_possibleConstructorReturn__WEBPACK_IMPORTED_MODULE_2__["default"])(this, result);
  };
}

/***/ }),

/***/ "LRne":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/of.js ***!
  \**************************************************************/
/*! exports provided: of */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "of", function() { return of; });
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");
/* harmony import */ var _fromArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./fromArray */ "yCtX");
/* harmony import */ var _scheduled_scheduleArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../scheduled/scheduleArray */ "jZKg");



function of() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  var scheduler = args[args.length - 1];

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_0__["isScheduler"])(scheduler)) {
    args.pop();
    return Object(_scheduled_scheduleArray__WEBPACK_IMPORTED_MODULE_2__["scheduleArray"])(args, scheduler);
  } else {
    return Object(_fromArray__WEBPACK_IMPORTED_MODULE_1__["fromArray"])(args);
  }
}

/***/ }),

/***/ "Lhse":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/symbol/iterator.js ***!
  \****************************************************************/
/*! exports provided: getSymbolIterator, iterator, $$iterator */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getSymbolIterator", function() { return getSymbolIterator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "iterator", function() { return iterator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "$$iterator", function() { return $$iterator; });
function getSymbolIterator() {
  if (typeof Symbol !== 'function' || !Symbol.iterator) {
    return '@@iterator';
  }

  return Symbol.iterator;
}
var iterator = getSymbolIterator();
var $$iterator = iterator;

/***/ }),

/***/ "Loxo":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/uz.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Uzbek [uz]
//! author : Sardor Muminov : https://github.com/muminoff
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var uz = moment.defineLocale('uz', {
    months: 'январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр'.split('_'),
    monthsShort: 'янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек'.split('_'),
    weekdays: 'Якшанба_Душанба_Сешанба_Чоршанба_Пайшанба_Жума_Шанба'.split('_'),
    weekdaysShort: 'Якш_Душ_Сеш_Чор_Пай_Жум_Шан'.split('_'),
    weekdaysMin: 'Як_Ду_Се_Чо_Па_Жу_Ша'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'D MMMM YYYY, dddd HH:mm'
    },
    calendar: {
      sameDay: '[Бугун соат] LT [да]',
      nextDay: '[Эртага] LT [да]',
      nextWeek: 'dddd [куни соат] LT [да]',
      lastDay: '[Кеча соат] LT [да]',
      lastWeek: '[Утган] dddd [куни соат] LT [да]',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'Якин %s ичида',
      past: 'Бир неча %s олдин',
      s: 'фурсат',
      ss: '%d фурсат',
      m: 'бир дакика',
      mm: '%d дакика',
      h: 'бир соат',
      hh: '%d соат',
      d: 'бир кун',
      dd: '%d кун',
      M: 'бир ой',
      MM: '%d ой',
      y: 'бир йил',
      yy: '%d йил'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return uz;
});

/***/ }),

/***/ "MBAA":
/*!***************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduled/scheduleIterable.js ***!
  \***************************************************************************/
/*! exports provided: scheduleIterable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "scheduleIterable", function() { return scheduleIterable; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _symbol_iterator__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../symbol/iterator */ "Lhse");



function scheduleIterable(input, scheduler) {
  if (!input) {
    throw new Error('Iterable cannot be null');
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var sub = new _Subscription__WEBPACK_IMPORTED_MODULE_1__["Subscription"]();
    var iterator;
    sub.add(function () {
      if (iterator && typeof iterator.return === 'function') {
        iterator.return();
      }
    });
    sub.add(scheduler.schedule(function () {
      iterator = input[_symbol_iterator__WEBPACK_IMPORTED_MODULE_2__["iterator"]]();
      sub.add(scheduler.schedule(function () {
        if (subscriber.closed) {
          return;
        }

        var value;
        var done;

        try {
          var result = iterator.next();
          value = result.value;
          done = result.done;
        } catch (err) {
          subscriber.error(err);
          return;
        }

        if (done) {
          subscriber.complete();
        } else {
          subscriber.next(value);
          this.schedule();
        }
      }));
    }));
    return sub;
  });
}

/***/ }),

/***/ "MtjB":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/retryWhen.js ***!
  \********************************************************************/
/*! exports provided: retryWhen */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "retryWhen", function() { return retryWhen; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");








function retryWhen(notifier) {
  return function (source) {
    return source.lift(new RetryWhenOperator(notifier, source));
  };
}

var RetryWhenOperator = /*#__PURE__*/function () {
  function RetryWhenOperator(notifier, source) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RetryWhenOperator);

    this.notifier = notifier;
    this.source = source;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RetryWhenOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new RetryWhenSubscriber(subscriber, this.notifier, this.source));
    }
  }]);

  return RetryWhenOperator;
}();

var RetryWhenSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(RetryWhenSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(RetryWhenSubscriber);

  function RetryWhenSubscriber(destination, notifier, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RetryWhenSubscriber);

    _this = _super.call(this, destination);
    _this.notifier = notifier;
    _this.source = source;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RetryWhenSubscriber, [{
    key: "error",
    value: function error(err) {
      if (!this.isStopped) {
        var errors = this.errors;
        var retries = this.retries;
        var retriesSubscription = this.retriesSubscription;

        if (!retries) {
          errors = new _Subject__WEBPACK_IMPORTED_MODULE_6__["Subject"]();

          try {
            var notifier = this.notifier;
            retries = notifier(errors);
          } catch (e) {
            return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RetryWhenSubscriber.prototype), "error", this).call(this, e);
          }

          retriesSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["innerSubscribe"])(retries, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleInnerSubscriber"](this));
        } else {
          this.errors = undefined;
          this.retriesSubscription = undefined;
        }

        this._unsubscribeAndRecycle();

        this.errors = errors;
        this.retries = retries;
        this.retriesSubscription = retriesSubscription;
        errors.next(err);
      }
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var errors = this.errors,
          retriesSubscription = this.retriesSubscription;

      if (errors) {
        errors.unsubscribe();
        this.errors = undefined;
      }

      if (retriesSubscription) {
        retriesSubscription.unsubscribe();
        this.retriesSubscription = undefined;
      }

      this.retries = undefined;
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      var _unsubscribe = this._unsubscribe;
      this._unsubscribe = null;

      this._unsubscribeAndRecycle();

      this._unsubscribe = _unsubscribe;
      this.source.subscribe(this);
    }
  }]);

  return RetryWhenSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "NCdM":
/*!**********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/nonIterableSpread.js ***!
  \**********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _nonIterableSpread; });
function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

/***/ }),

/***/ "NHP+":
/*!*************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/AsyncSubject.js ***!
  \*************************************************************/
/*! exports provided: AsyncSubject */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AsyncSubject", function() { return AsyncSubject; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./Subject */ "XNiG");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./Subscription */ "quSY");








var AsyncSubject = /*#__PURE__*/function (_Subject) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(AsyncSubject, _Subject);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(AsyncSubject);

  function AsyncSubject() {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AsyncSubject);

    _this = _super.apply(this, arguments);
    _this.value = null;
    _this.hasNext = false;
    _this.hasCompleted = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AsyncSubject, [{
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      if (this.hasError) {
        subscriber.error(this.thrownError);
        return _Subscription__WEBPACK_IMPORTED_MODULE_7__["Subscription"].EMPTY;
      } else if (this.hasCompleted && this.hasNext) {
        subscriber.next(this.value);
        subscriber.complete();
        return _Subscription__WEBPACK_IMPORTED_MODULE_7__["Subscription"].EMPTY;
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AsyncSubject.prototype), "_subscribe", this).call(this, subscriber);
    }
  }, {
    key: "next",
    value: function next(value) {
      if (!this.hasCompleted) {
        this.value = value;
        this.hasNext = true;
      }
    }
  }, {
    key: "error",
    value: function error(_error) {
      if (!this.hasCompleted) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AsyncSubject.prototype), "error", this).call(this, _error);
      }
    }
  }, {
    key: "complete",
    value: function complete() {
      this.hasCompleted = true;

      if (this.hasNext) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AsyncSubject.prototype), "next", this).call(this, this.value);
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AsyncSubject.prototype), "complete", this).call(this);
    }
  }]);

  return AsyncSubject;
}(_Subject__WEBPACK_IMPORTED_MODULE_6__["Subject"]);

/***/ }),

/***/ "NJ4a":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/hostReportError.js ***!
  \*********************************************************************/
/*! exports provided: hostReportError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "hostReportError", function() { return hostReportError; });
function hostReportError(err) {
  setTimeout(function () {
    throw err;
  }, 0);
}

/***/ }),

/***/ "NJ9Y":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/last.js ***!
  \***************************************************************/
/*! exports provided: last */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "last", function() { return last; });
/* harmony import */ var _util_EmptyError__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/EmptyError */ "sVev");
/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./filter */ "pLZG");
/* harmony import */ var _takeLast__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./takeLast */ "BFxc");
/* harmony import */ var _throwIfEmpty__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./throwIfEmpty */ "XDbj");
/* harmony import */ var _defaultIfEmpty__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./defaultIfEmpty */ "xbPD");
/* harmony import */ var _util_identity__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/identity */ "SpAZ");






function last(predicate, defaultValue) {
  var hasDefaultValue = arguments.length >= 2;
  return function (source) {
    return source.pipe(predicate ? Object(_filter__WEBPACK_IMPORTED_MODULE_1__["filter"])(function (v, i) {
      return predicate(v, i, source);
    }) : _util_identity__WEBPACK_IMPORTED_MODULE_5__["identity"], Object(_takeLast__WEBPACK_IMPORTED_MODULE_2__["takeLast"])(1), hasDefaultValue ? Object(_defaultIfEmpty__WEBPACK_IMPORTED_MODULE_4__["defaultIfEmpty"])(defaultValue) : Object(_throwIfEmpty__WEBPACK_IMPORTED_MODULE_3__["throwIfEmpty"])(function () {
      return new _util_EmptyError__WEBPACK_IMPORTED_MODULE_0__["EmptyError"]();
    }));
  };
}

/***/ }),

/***/ "NNCq":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/range.js ***!
  \*****************************************************************/
/*! exports provided: range, dispatch */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "range", function() { return range; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "dispatch", function() { return dispatch; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");

function range() {
  var start = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var count = arguments.length > 1 ? arguments[1] : undefined;
  var scheduler = arguments.length > 2 ? arguments[2] : undefined;
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    if (count === undefined) {
      count = start;
      start = 0;
    }

    var index = 0;
    var current = start;

    if (scheduler) {
      return scheduler.schedule(dispatch, 0, {
        index: index,
        count: count,
        start: start,
        subscriber: subscriber
      });
    } else {
      do {
        if (index++ >= count) {
          subscriber.complete();
          break;
        }

        subscriber.next(current++);

        if (subscriber.closed) {
          break;
        }
      } while (true);
    }

    return undefined;
  });
}
function dispatch(state) {
  var start = state.start,
      index = state.index,
      count = state.count,
      subscriber = state.subscriber;

  if (index >= count) {
    subscriber.complete();
    return;
  }

  subscriber.next(start);

  if (subscriber.closed) {
    return;
  }

  state.index = index + 1;
  state.start = start + 1;
  this.schedule(state);
}

/***/ }),

/***/ "NXyV":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/defer.js ***!
  \*****************************************************************/
/*! exports provided: defer */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "defer", function() { return defer; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _from__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./from */ "Cfvw");
/* harmony import */ var _empty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./empty */ "EY2u");



function defer(observableFactory) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var input;

    try {
      input = observableFactory();
    } catch (err) {
      subscriber.error(err);
      return undefined;
    }

    var source = input ? Object(_from__WEBPACK_IMPORTED_MODULE_1__["from"])(input) : Object(_empty__WEBPACK_IMPORTED_MODULE_2__["empty"])();
    return source.subscribe(subscriber);
  });
}

/***/ }),

/***/ "NfdI":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/publish.js ***!
  \******************************************************************/
/*! exports provided: publish */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "publish", function() { return publish; });
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _multicast__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./multicast */ "oB13");


function publish(selector) {
  return selector ? Object(_multicast__WEBPACK_IMPORTED_MODULE_1__["multicast"])(function () {
    return new _Subject__WEBPACK_IMPORTED_MODULE_0__["Subject"]();
  }, selector) : Object(_multicast__WEBPACK_IMPORTED_MODULE_1__["multicast"])(new _Subject__WEBPACK_IMPORTED_MODULE_0__["Subject"]());
}

/***/ }),

/***/ "Nv8m":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/race.js ***!
  \****************************************************************/
/*! exports provided: race, RaceOperator, RaceSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "race", function() { return race; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RaceOperator", function() { return RaceOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RaceSubscriber", function() { return RaceSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _fromArray__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./fromArray */ "yCtX");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");








function race() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  if (observables.length === 1) {
    if (Object(_util_isArray__WEBPACK_IMPORTED_MODULE_4__["isArray"])(observables[0])) {
      observables = observables[0];
    } else {
      return observables[0];
    }
  }

  return Object(_fromArray__WEBPACK_IMPORTED_MODULE_5__["fromArray"])(observables, undefined).lift(new RaceOperator());
}
var RaceOperator = /*#__PURE__*/function () {
  function RaceOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RaceOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RaceOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new RaceSubscriber(subscriber));
    }
  }]);

  return RaceOperator;
}();
var RaceSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(RaceSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(RaceSubscriber);

  function RaceSubscriber(destination) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RaceSubscriber);

    _this = _super.call(this, destination);
    _this.hasFirst = false;
    _this.observables = [];
    _this.subscriptions = [];
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RaceSubscriber, [{
    key: "_next",
    value: function _next(observable) {
      this.observables.push(observable);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var observables = this.observables;
      var len = observables.length;

      if (len === 0) {
        this.destination.complete();
      } else {
        for (var i = 0; i < len && !this.hasFirst; i++) {
          var observable = observables[i];
          var subscription = Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__["subscribeToResult"])(this, observable, undefined, i);

          if (this.subscriptions) {
            this.subscriptions.push(subscription);
          }

          this.add(subscription);
        }

        this.observables = null;
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(_outerValue, innerValue, outerIndex) {
      if (!this.hasFirst) {
        this.hasFirst = true;

        for (var i = 0; i < this.subscriptions.length; i++) {
          if (i !== outerIndex) {
            var subscription = this.subscriptions[i];
            subscription.unsubscribe();
            this.remove(subscription);
          }
        }

        this.subscriptions = null;
      }

      this.destination.next(innerValue);
    }
  }]);

  return RaceSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__["OuterSubscriber"]);

/***/ }),

/***/ "O4y0":
/*!*********************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/SubscribeOnObservable.js ***!
  \*********************************************************************************/
/*! exports provided: SubscribeOnObservable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SubscribeOnObservable", function() { return SubscribeOnObservable; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _scheduler_asap__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../scheduler/asap */ "7Hc7");
/* harmony import */ var _util_isNumeric__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/isNumeric */ "Y7HM");







var SubscribeOnObservable = /*#__PURE__*/function (_Observable) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(SubscribeOnObservable, _Observable);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(SubscribeOnObservable);

  function SubscribeOnObservable(source) {
    var _this;

    var delayTime = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    var scheduler = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _scheduler_asap__WEBPACK_IMPORTED_MODULE_5__["asap"];

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SubscribeOnObservable);

    _this = _super.call(this);
    _this.source = source;
    _this.delayTime = delayTime;
    _this.scheduler = scheduler;

    if (!Object(_util_isNumeric__WEBPACK_IMPORTED_MODULE_6__["isNumeric"])(delayTime) || delayTime < 0) {
      _this.delayTime = 0;
    }

    if (!scheduler || typeof scheduler.schedule !== 'function') {
      _this.scheduler = _scheduler_asap__WEBPACK_IMPORTED_MODULE_5__["asap"];
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SubscribeOnObservable, [{
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      var delay = this.delayTime;
      var source = this.source;
      var scheduler = this.scheduler;
      return scheduler.schedule(SubscribeOnObservable.dispatch, delay, {
        source: source,
        subscriber: subscriber
      });
    }
  }], [{
    key: "create",
    value: function create(source) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var scheduler = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _scheduler_asap__WEBPACK_IMPORTED_MODULE_5__["asap"];
      return new SubscribeOnObservable(source, delay, scheduler);
    }
  }, {
    key: "dispatch",
    value: function dispatch(arg) {
      var source = arg.source,
          subscriber = arg.subscriber;
      return this.add(source.subscribe(subscriber));
    }
  }]);

  return SubscribeOnObservable;
}(_Observable__WEBPACK_IMPORTED_MODULE_4__["Observable"]);

/***/ }),

/***/ "ODXe":
/*!******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/slicedToArray.js ***!
  \******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _slicedToArray; });
/* harmony import */ var _arrayWithHoles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./arrayWithHoles */ "DSFK");
/* harmony import */ var _iterableToArrayLimit__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./iterableToArrayLimit */ "CfBk");
/* harmony import */ var _unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./unsupportedIterableToArray */ "BsWD");
/* harmony import */ var _nonIterableRest__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./nonIterableRest */ "PYwp");




function _slicedToArray(arr, i) {
  return Object(_arrayWithHoles__WEBPACK_IMPORTED_MODULE_0__["default"])(arr) || Object(_iterableToArrayLimit__WEBPACK_IMPORTED_MODULE_1__["default"])(arr, i) || Object(_unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(arr, i) || Object(_nonIterableRest__WEBPACK_IMPORTED_MODULE_3__["default"])();
}

/***/ }),

/***/ "OIYi":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-ca.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (Canada) [en-ca]
//! author : Jonathan Abourbih : https://github.com/jonbca
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enCa = moment.defineLocale('en-ca', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'YYYY-MM-DD',
      LL: 'MMMM D, YYYY',
      LLL: 'MMMM D, YYYY h:mm A',
      LLLL: 'dddd, MMMM D, YYYY h:mm A'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    }
  });
  return enCa;
});

/***/ }),

/***/ "OQgR":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/groupBy.js ***!
  \******************************************************************/
/*! exports provided: groupBy, GroupedObservable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "groupBy", function() { return groupBy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "GroupedObservable", function() { return GroupedObservable; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../Subject */ "XNiG");










function groupBy(keySelector, elementSelector, durationSelector, subjectSelector) {
  return function (source) {
    return source.lift(new GroupByOperator(keySelector, elementSelector, durationSelector, subjectSelector));
  };
}

var GroupByOperator = /*#__PURE__*/function () {
  function GroupByOperator(keySelector, elementSelector, durationSelector, subjectSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, GroupByOperator);

    this.keySelector = keySelector;
    this.elementSelector = elementSelector;
    this.durationSelector = durationSelector;
    this.subjectSelector = subjectSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(GroupByOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new GroupBySubscriber(subscriber, this.keySelector, this.elementSelector, this.durationSelector, this.subjectSelector));
    }
  }]);

  return GroupByOperator;
}();

var GroupBySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(GroupBySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(GroupBySubscriber);

  function GroupBySubscriber(destination, keySelector, elementSelector, durationSelector, subjectSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, GroupBySubscriber);

    _this = _super.call(this, destination);
    _this.keySelector = keySelector;
    _this.elementSelector = elementSelector;
    _this.durationSelector = durationSelector;
    _this.subjectSelector = subjectSelector;
    _this.groups = null;
    _this.attemptedToUnsubscribe = false;
    _this.count = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(GroupBySubscriber, [{
    key: "_next",
    value: function _next(value) {
      var key;

      try {
        key = this.keySelector(value);
      } catch (err) {
        this.error(err);
        return;
      }

      this._group(value, key);
    }
  }, {
    key: "_group",
    value: function _group(value, key) {
      var groups = this.groups;

      if (!groups) {
        groups = this.groups = new Map();
      }

      var group = groups.get(key);
      var element;

      if (this.elementSelector) {
        try {
          element = this.elementSelector(value);
        } catch (err) {
          this.error(err);
        }
      } else {
        element = value;
      }

      if (!group) {
        group = this.subjectSelector ? this.subjectSelector() : new _Subject__WEBPACK_IMPORTED_MODULE_9__["Subject"]();
        groups.set(key, group);
        var groupedObservable = new GroupedObservable(key, group, this);
        this.destination.next(groupedObservable);

        if (this.durationSelector) {
          var duration;

          try {
            duration = this.durationSelector(new GroupedObservable(key, group));
          } catch (err) {
            this.error(err);
            return;
          }

          this.add(duration.subscribe(new GroupDurationSubscriber(key, group, this)));
        }
      }

      if (!group.closed) {
        group.next(element);
      }
    }
  }, {
    key: "_error",
    value: function _error(err) {
      var groups = this.groups;

      if (groups) {
        groups.forEach(function (group, key) {
          group.error(err);
        });
        groups.clear();
      }

      this.destination.error(err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var groups = this.groups;

      if (groups) {
        groups.forEach(function (group, key) {
          group.complete();
        });
        groups.clear();
      }

      this.destination.complete();
    }
  }, {
    key: "removeGroup",
    value: function removeGroup(key) {
      this.groups.delete(key);
    }
  }, {
    key: "unsubscribe",
    value: function unsubscribe() {
      if (!this.closed) {
        this.attemptedToUnsubscribe = true;

        if (this.count === 0) {
          Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(GroupBySubscriber.prototype), "unsubscribe", this).call(this);
        }
      }
    }
  }]);

  return GroupBySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

var GroupDurationSubscriber = /*#__PURE__*/function (_Subscriber2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(GroupDurationSubscriber, _Subscriber2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(GroupDurationSubscriber);

  function GroupDurationSubscriber(key, group, parent) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, GroupDurationSubscriber);

    _this2 = _super2.call(this, group);
    _this2.key = key;
    _this2.group = group;
    _this2.parent = parent;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(GroupDurationSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.complete();
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var parent = this.parent,
          key = this.key;
      this.key = this.parent = null;

      if (parent) {
        parent.removeGroup(key);
      }
    }
  }]);

  return GroupDurationSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

var GroupedObservable = /*#__PURE__*/function (_Observable) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(GroupedObservable, _Observable);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(GroupedObservable);

  function GroupedObservable(key, groupSubject, refCountSubscription) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, GroupedObservable);

    _this3 = _super3.call(this);
    _this3.key = key;
    _this3.groupSubject = groupSubject;
    _this3.refCountSubscription = refCountSubscription;
    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(GroupedObservable, [{
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      var subscription = new _Subscription__WEBPACK_IMPORTED_MODULE_7__["Subscription"]();
      var refCountSubscription = this.refCountSubscription,
          groupSubject = this.groupSubject;

      if (refCountSubscription && !refCountSubscription.closed) {
        subscription.add(new InnerRefCountSubscription(refCountSubscription));
      }

      subscription.add(groupSubject.subscribe(subscriber));
      return subscription;
    }
  }]);

  return GroupedObservable;
}(_Observable__WEBPACK_IMPORTED_MODULE_8__["Observable"]);

var InnerRefCountSubscription = /*#__PURE__*/function (_Subscription) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(InnerRefCountSubscription, _Subscription);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(InnerRefCountSubscription);

  function InnerRefCountSubscription(parent) {
    var _this4;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, InnerRefCountSubscription);

    _this4 = _super4.call(this);
    _this4.parent = parent;
    parent.count++;
    return _this4;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(InnerRefCountSubscription, [{
    key: "unsubscribe",
    value: function unsubscribe() {
      var parent = this.parent;

      if (!parent.closed && !this.closed) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(InnerRefCountSubscription.prototype), "unsubscribe", this).call(this);

        parent.count -= 1;

        if (parent.count === 0 && parent.attemptedToUnsubscribe) {
          parent.unsubscribe();
        }
      }
    }
  }]);

  return InnerRefCountSubscription;
}(_Subscription__WEBPACK_IMPORTED_MODULE_7__["Subscription"]);

/***/ }),

/***/ "Oaa7":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-gb.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (United Kingdom) [en-gb]
//! author : Chris Gedrim : https://github.com/chrisgedrim
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enGb = moment.defineLocale('en-gb', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return enGb;
});

/***/ }),

/***/ "Ob0Z":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/mr.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Marathi [mr]
//! author : Harshad Kale : https://github.com/kalehv
//! author : Vivek Athalye : https://github.com/vnathalye
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '१',
    2: '२',
    3: '३',
    4: '४',
    5: '५',
    6: '६',
    7: '७',
    8: '८',
    9: '९',
    0: '०'
  },
      numberMap = {
    '१': '1',
    '२': '2',
    '३': '3',
    '४': '4',
    '५': '5',
    '६': '6',
    '७': '7',
    '८': '8',
    '९': '9',
    '०': '0'
  };

  function relativeTimeMr(number, withoutSuffix, string, isFuture) {
    var output = '';

    if (withoutSuffix) {
      switch (string) {
        case 's':
          output = 'काही सेकंद';
          break;

        case 'ss':
          output = '%d सेकंद';
          break;

        case 'm':
          output = 'एक मिनिट';
          break;

        case 'mm':
          output = '%d मिनिटे';
          break;

        case 'h':
          output = 'एक तास';
          break;

        case 'hh':
          output = '%d तास';
          break;

        case 'd':
          output = 'एक दिवस';
          break;

        case 'dd':
          output = '%d दिवस';
          break;

        case 'M':
          output = 'एक महिना';
          break;

        case 'MM':
          output = '%d महिने';
          break;

        case 'y':
          output = 'एक वर्ष';
          break;

        case 'yy':
          output = '%d वर्षे';
          break;
      }
    } else {
      switch (string) {
        case 's':
          output = 'काही सेकंदां';
          break;

        case 'ss':
          output = '%d सेकंदां';
          break;

        case 'm':
          output = 'एका मिनिटा';
          break;

        case 'mm':
          output = '%d मिनिटां';
          break;

        case 'h':
          output = 'एका तासा';
          break;

        case 'hh':
          output = '%d तासां';
          break;

        case 'd':
          output = 'एका दिवसा';
          break;

        case 'dd':
          output = '%d दिवसां';
          break;

        case 'M':
          output = 'एका महिन्या';
          break;

        case 'MM':
          output = '%d महिन्यां';
          break;

        case 'y':
          output = 'एका वर्षा';
          break;

        case 'yy':
          output = '%d वर्षां';
          break;
      }
    }

    return output.replace(/%d/i, number);
  }

  var mr = moment.defineLocale('mr', {
    months: 'जानेवारी_फेब्रुवारी_मार्च_एप्रिल_मे_जून_जुलै_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर'.split('_'),
    monthsShort: 'जाने._फेब्रु._मार्च._एप्रि._मे._जून._जुलै._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.'.split('_'),
    monthsParseExact: true,
    weekdays: 'रविवार_सोमवार_मंगळवार_बुधवार_गुरूवार_शुक्रवार_शनिवार'.split('_'),
    weekdaysShort: 'रवि_सोम_मंगळ_बुध_गुरू_शुक्र_शनि'.split('_'),
    weekdaysMin: 'र_सो_मं_बु_गु_शु_श'.split('_'),
    longDateFormat: {
      LT: 'A h:mm वाजता',
      LTS: 'A h:mm:ss वाजता',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm वाजता',
      LLLL: 'dddd, D MMMM YYYY, A h:mm वाजता'
    },
    calendar: {
      sameDay: '[आज] LT',
      nextDay: '[उद्या] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[काल] LT',
      lastWeek: '[मागील] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%sमध्ये',
      past: '%sपूर्वी',
      s: relativeTimeMr,
      ss: relativeTimeMr,
      m: relativeTimeMr,
      mm: relativeTimeMr,
      h: relativeTimeMr,
      hh: relativeTimeMr,
      d: relativeTimeMr,
      dd: relativeTimeMr,
      M: relativeTimeMr,
      MM: relativeTimeMr,
      y: relativeTimeMr,
      yy: relativeTimeMr
    },
    preparse: function preparse(string) {
      return string.replace(/[१२३४५६७८९०]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    meridiemParse: /पहाटे|सकाळी|दुपारी|सायंकाळी|रात्री/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'पहाटे' || meridiem === 'सकाळी') {
        return hour;
      } else if (meridiem === 'दुपारी' || meridiem === 'सायंकाळी' || meridiem === 'रात्री') {
        return hour >= 12 ? hour : hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour >= 0 && hour < 6) {
        return 'पहाटे';
      } else if (hour < 12) {
        return 'सकाळी';
      } else if (hour < 17) {
        return 'दुपारी';
      } else if (hour < 20) {
        return 'सायंकाळी';
      } else {
        return 'रात्री';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return mr;
});

/***/ }),

/***/ "OjkT":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ne.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Nepalese [ne]
//! author : suvash : https://github.com/suvash
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '१',
    2: '२',
    3: '३',
    4: '४',
    5: '५',
    6: '६',
    7: '७',
    8: '८',
    9: '९',
    0: '०'
  },
      numberMap = {
    '१': '1',
    '२': '2',
    '३': '3',
    '४': '4',
    '५': '5',
    '६': '6',
    '७': '7',
    '८': '8',
    '९': '9',
    '०': '0'
  };
  var ne = moment.defineLocale('ne', {
    months: 'जनवरी_फेब्रुवरी_मार्च_अप्रिल_मई_जुन_जुलाई_अगष्ट_सेप्टेम्बर_अक्टोबर_नोभेम्बर_डिसेम्बर'.split('_'),
    monthsShort: 'जन._फेब्रु._मार्च_अप्रि._मई_जुन_जुलाई._अग._सेप्ट._अक्टो._नोभे._डिसे.'.split('_'),
    monthsParseExact: true,
    weekdays: 'आइतबार_सोमबार_मङ्गलबार_बुधबार_बिहिबार_शुक्रबार_शनिबार'.split('_'),
    weekdaysShort: 'आइत._सोम._मङ्गल._बुध._बिहि._शुक्र._शनि.'.split('_'),
    weekdaysMin: 'आ._सो._मं._बु._बि._शु._श.'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'Aको h:mm बजे',
      LTS: 'Aको h:mm:ss बजे',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, Aको h:mm बजे',
      LLLL: 'dddd, D MMMM YYYY, Aको h:mm बजे'
    },
    preparse: function preparse(string) {
      return string.replace(/[१२३४५६७८९०]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    meridiemParse: /राति|बिहान|दिउँसो|साँझ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'राति') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'बिहान') {
        return hour;
      } else if (meridiem === 'दिउँसो') {
        return hour >= 10 ? hour : hour + 12;
      } else if (meridiem === 'साँझ') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 3) {
        return 'राति';
      } else if (hour < 12) {
        return 'बिहान';
      } else if (hour < 16) {
        return 'दिउँसो';
      } else if (hour < 20) {
        return 'साँझ';
      } else {
        return 'राति';
      }
    },
    calendar: {
      sameDay: '[आज] LT',
      nextDay: '[भोलि] LT',
      nextWeek: '[आउँदो] dddd[,] LT',
      lastDay: '[हिजो] LT',
      lastWeek: '[गएको] dddd[,] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%sमा',
      past: '%s अगाडि',
      s: 'केही क्षण',
      ss: '%d सेकेण्ड',
      m: 'एक मिनेट',
      mm: '%d मिनेट',
      h: 'एक घण्टा',
      hh: '%d घण्टा',
      d: 'एक दिन',
      dd: '%d दिन',
      M: 'एक महिना',
      MM: '%d महिना',
      y: 'एक बर्ष',
      yy: '%d बर्ष'
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return ne;
});

/***/ }),

/***/ "OmwH":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/zh-mo.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Chinese (Macau) [zh-mo]
//! author : Ben : https://github.com/ben-lin
//! author : Chris Lam : https://github.com/hehachris
//! author : Tan Yuanhong : https://github.com/le0tan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var zhMo = moment.defineLocale('zh-mo', {
    months: '一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月'.split('_'),
    monthsShort: '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
    weekdays: '星期日_星期一_星期二_星期三_星期四_星期五_星期六'.split('_'),
    weekdaysShort: '週日_週一_週二_週三_週四_週五_週六'.split('_'),
    weekdaysMin: '日_一_二_三_四_五_六'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'YYYY年M月D日',
      LLL: 'YYYY年M月D日 HH:mm',
      LLLL: 'YYYY年M月D日dddd HH:mm',
      l: 'D/M/YYYY',
      ll: 'YYYY年M月D日',
      lll: 'YYYY年M月D日 HH:mm',
      llll: 'YYYY年M月D日dddd HH:mm'
    },
    meridiemParse: /凌晨|早上|上午|中午|下午|晚上/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === '凌晨' || meridiem === '早上' || meridiem === '上午') {
        return hour;
      } else if (meridiem === '中午') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === '下午' || meridiem === '晚上') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      var hm = hour * 100 + minute;

      if (hm < 600) {
        return '凌晨';
      } else if (hm < 900) {
        return '早上';
      } else if (hm < 1130) {
        return '上午';
      } else if (hm < 1230) {
        return '中午';
      } else if (hm < 1800) {
        return '下午';
      } else {
        return '晚上';
      }
    },
    calendar: {
      sameDay: '[今天] LT',
      nextDay: '[明天] LT',
      nextWeek: '[下]dddd LT',
      lastDay: '[昨天] LT',
      lastWeek: '[上]dddd LT',
      sameElse: 'L'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(日|月|週)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + '日';

        case 'M':
          return number + '月';

        case 'w':
        case 'W':
          return number + '週';

        default:
          return number;
      }
    },
    relativeTime: {
      future: '%s內',
      past: '%s前',
      s: '幾秒',
      ss: '%d 秒',
      m: '1 分鐘',
      mm: '%d 分鐘',
      h: '1 小時',
      hh: '%d 小時',
      d: '1 天',
      dd: '%d 天',
      M: '1 個月',
      MM: '%d 個月',
      y: '1 年',
      yy: '%d 年'
    }
  });
  return zhMo;
});

/***/ }),

/***/ "OsX3":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/bufferTime.js ***!
  \*********************************************************************/
/*! exports provided: bufferTime */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "bufferTime", function() { return bufferTime; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");










function bufferTime(bufferTimeSpan) {
  var length = arguments.length;
  var scheduler = _scheduler_async__WEBPACK_IMPORTED_MODULE_7__["async"];

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_9__["isScheduler"])(arguments[arguments.length - 1])) {
    scheduler = arguments[arguments.length - 1];
    length--;
  }

  var bufferCreationInterval = null;

  if (length >= 2) {
    bufferCreationInterval = arguments[1];
  }

  var maxBufferSize = Number.POSITIVE_INFINITY;

  if (length >= 3) {
    maxBufferSize = arguments[2];
  }

  return function bufferTimeOperatorFunction(source) {
    return source.lift(new BufferTimeOperator(bufferTimeSpan, bufferCreationInterval, maxBufferSize, scheduler));
  };
}

var BufferTimeOperator = /*#__PURE__*/function () {
  function BufferTimeOperator(bufferTimeSpan, bufferCreationInterval, maxBufferSize, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BufferTimeOperator);

    this.bufferTimeSpan = bufferTimeSpan;
    this.bufferCreationInterval = bufferCreationInterval;
    this.maxBufferSize = maxBufferSize;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(BufferTimeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new BufferTimeSubscriber(subscriber, this.bufferTimeSpan, this.bufferCreationInterval, this.maxBufferSize, this.scheduler));
    }
  }]);

  return BufferTimeOperator;
}();

var Context = function Context() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, Context);

  this.buffer = [];
};

var BufferTimeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(BufferTimeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(BufferTimeSubscriber);

  function BufferTimeSubscriber(destination, bufferTimeSpan, bufferCreationInterval, maxBufferSize, scheduler) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BufferTimeSubscriber);

    _this = _super.call(this, destination);
    _this.bufferTimeSpan = bufferTimeSpan;
    _this.bufferCreationInterval = bufferCreationInterval;
    _this.maxBufferSize = maxBufferSize;
    _this.scheduler = scheduler;
    _this.contexts = [];

    var context = _this.openContext();

    _this.timespanOnly = bufferCreationInterval == null || bufferCreationInterval < 0;

    if (_this.timespanOnly) {
      var timeSpanOnlyState = {
        subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this),
        context: context,
        bufferTimeSpan: bufferTimeSpan
      };

      _this.add(context.closeAction = scheduler.schedule(dispatchBufferTimeSpanOnly, bufferTimeSpan, timeSpanOnlyState));
    } else {
      var closeState = {
        subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this),
        context: context
      };
      var creationState = {
        bufferTimeSpan: bufferTimeSpan,
        bufferCreationInterval: bufferCreationInterval,
        subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this),
        scheduler: scheduler
      };

      _this.add(context.closeAction = scheduler.schedule(dispatchBufferClose, bufferTimeSpan, closeState));

      _this.add(scheduler.schedule(dispatchBufferCreation, bufferCreationInterval, creationState));
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(BufferTimeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var contexts = this.contexts;
      var len = contexts.length;
      var filledBufferContext;

      for (var i = 0; i < len; i++) {
        var context = contexts[i];
        var buffer = context.buffer;
        buffer.push(value);

        if (buffer.length == this.maxBufferSize) {
          filledBufferContext = context;
        }
      }

      if (filledBufferContext) {
        this.onBufferFull(filledBufferContext);
      }
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.contexts.length = 0;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferTimeSubscriber.prototype), "_error", this).call(this, err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var contexts = this.contexts,
          destination = this.destination;

      while (contexts.length > 0) {
        var context = contexts.shift();
        destination.next(context.buffer);
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferTimeSubscriber.prototype), "_complete", this).call(this);
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      this.contexts = null;
    }
  }, {
    key: "onBufferFull",
    value: function onBufferFull(context) {
      this.closeContext(context);
      var closeAction = context.closeAction;
      closeAction.unsubscribe();
      this.remove(closeAction);

      if (!this.closed && this.timespanOnly) {
        context = this.openContext();
        var bufferTimeSpan = this.bufferTimeSpan;
        var timeSpanOnlyState = {
          subscriber: this,
          context: context,
          bufferTimeSpan: bufferTimeSpan
        };
        this.add(context.closeAction = this.scheduler.schedule(dispatchBufferTimeSpanOnly, bufferTimeSpan, timeSpanOnlyState));
      }
    }
  }, {
    key: "openContext",
    value: function openContext() {
      var context = new Context();
      this.contexts.push(context);
      return context;
    }
  }, {
    key: "closeContext",
    value: function closeContext(context) {
      this.destination.next(context.buffer);
      var contexts = this.contexts;
      var spliceIndex = contexts ? contexts.indexOf(context) : -1;

      if (spliceIndex >= 0) {
        contexts.splice(contexts.indexOf(context), 1);
      }
    }
  }]);

  return BufferTimeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_8__["Subscriber"]);

function dispatchBufferTimeSpanOnly(state) {
  var subscriber = state.subscriber;
  var prevContext = state.context;

  if (prevContext) {
    subscriber.closeContext(prevContext);
  }

  if (!subscriber.closed) {
    state.context = subscriber.openContext();
    state.context.closeAction = this.schedule(state, state.bufferTimeSpan);
  }
}

function dispatchBufferCreation(state) {
  var bufferCreationInterval = state.bufferCreationInterval,
      bufferTimeSpan = state.bufferTimeSpan,
      subscriber = state.subscriber,
      scheduler = state.scheduler;
  var context = subscriber.openContext();
  var action = this;

  if (!subscriber.closed) {
    subscriber.add(context.closeAction = scheduler.schedule(dispatchBufferClose, bufferTimeSpan, {
      subscriber: subscriber,
      context: context
    }));
    action.schedule(state, bufferCreationInterval);
  }
}

function dispatchBufferClose(arg) {
  var subscriber = arg.subscriber,
      context = arg.context;
  subscriber.closeContext(context);
}

/***/ }),

/***/ "Oxv6":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/tg.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Tajik [tg]
//! author : Orif N. Jr. : https://github.com/orif-jr
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var suffixes = {
    0: '-ум',
    1: '-ум',
    2: '-юм',
    3: '-юм',
    4: '-ум',
    5: '-ум',
    6: '-ум',
    7: '-ум',
    8: '-ум',
    9: '-ум',
    10: '-ум',
    12: '-ум',
    13: '-ум',
    20: '-ум',
    30: '-юм',
    40: '-ум',
    50: '-ум',
    60: '-ум',
    70: '-ум',
    80: '-ум',
    90: '-ум',
    100: '-ум'
  };
  var tg = moment.defineLocale('tg', {
    months: {
      format: 'январи_феврали_марти_апрели_майи_июни_июли_августи_сентябри_октябри_ноябри_декабри'.split('_'),
      standalone: 'январ_феврал_март_апрел_май_июн_июл_август_сентябр_октябр_ноябр_декабр'.split('_')
    },
    monthsShort: 'янв_фев_мар_апр_май_июн_июл_авг_сен_окт_ноя_дек'.split('_'),
    weekdays: 'якшанбе_душанбе_сешанбе_чоршанбе_панҷшанбе_ҷумъа_шанбе'.split('_'),
    weekdaysShort: 'яшб_дшб_сшб_чшб_пшб_ҷум_шнб'.split('_'),
    weekdaysMin: 'яш_дш_сш_чш_пш_ҷм_шб'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Имрӯз соати] LT',
      nextDay: '[Фардо соати] LT',
      lastDay: '[Дирӯз соати] LT',
      nextWeek: 'dddd[и] [ҳафтаи оянда соати] LT',
      lastWeek: 'dddd[и] [ҳафтаи гузашта соати] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'баъди %s',
      past: '%s пеш',
      s: 'якчанд сония',
      m: 'як дақиқа',
      mm: '%d дақиқа',
      h: 'як соат',
      hh: '%d соат',
      d: 'як рӯз',
      dd: '%d рӯз',
      M: 'як моҳ',
      MM: '%d моҳ',
      y: 'як сол',
      yy: '%d сол'
    },
    meridiemParse: /шаб|субҳ|рӯз|бегоҳ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'шаб') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'субҳ') {
        return hour;
      } else if (meridiem === 'рӯз') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === 'бегоҳ') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'шаб';
      } else if (hour < 11) {
        return 'субҳ';
      } else if (hour < 16) {
        return 'рӯз';
      } else if (hour < 19) {
        return 'бегоҳ';
      } else {
        return 'шаб';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(ум|юм)/,
    ordinal: function ordinal(number) {
      var a = number % 10,
          b = number >= 100 ? 100 : null;
      return number + (suffixes[number] || suffixes[a] || suffixes[b]);
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 1th is the first week of the year.

    }
  });
  return tg;
});

/***/ }),

/***/ "PA2r":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/cs.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Czech [cs]
//! author : petrbela : https://github.com/petrbela
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = 'leden_únor_březen_duben_květen_červen_červenec_srpen_září_říjen_listopad_prosinec'.split('_'),
      monthsShort = 'led_úno_bře_dub_kvě_čvn_čvc_srp_zář_říj_lis_pro'.split('_'),
      monthsParse = [/^led/i, /^úno/i, /^bře/i, /^dub/i, /^kvě/i, /^(čvn|červen$|června)/i, /^(čvc|červenec|července)/i, /^srp/i, /^zář/i, /^říj/i, /^lis/i, /^pro/i],
      // NOTE: 'červen' is substring of 'červenec'; therefore 'červenec' must precede 'červen' in the regex to be fully matched.
  // Otherwise parser matches '1. červenec' as '1. červen' + 'ec'.
  monthsRegex = /^(leden|únor|březen|duben|květen|červenec|července|červen|června|srpen|září|říjen|listopad|prosinec|led|úno|bře|dub|kvě|čvn|čvc|srp|zář|říj|lis|pro)/i;

  function plural(n) {
    return n > 1 && n < 5 && ~~(n / 10) !== 1;
  }

  function translate(number, withoutSuffix, key, isFuture) {
    var result = number + ' ';

    switch (key) {
      case 's':
        // a few seconds / in a few seconds / a few seconds ago
        return withoutSuffix || isFuture ? 'pár sekund' : 'pár sekundami';

      case 'ss':
        // 9 seconds / in 9 seconds / 9 seconds ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'sekundy' : 'sekund');
        } else {
          return result + 'sekundami';
        }

      case 'm':
        // a minute / in a minute / a minute ago
        return withoutSuffix ? 'minuta' : isFuture ? 'minutu' : 'minutou';

      case 'mm':
        // 9 minutes / in 9 minutes / 9 minutes ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'minuty' : 'minut');
        } else {
          return result + 'minutami';
        }

      case 'h':
        // an hour / in an hour / an hour ago
        return withoutSuffix ? 'hodina' : isFuture ? 'hodinu' : 'hodinou';

      case 'hh':
        // 9 hours / in 9 hours / 9 hours ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'hodiny' : 'hodin');
        } else {
          return result + 'hodinami';
        }

      case 'd':
        // a day / in a day / a day ago
        return withoutSuffix || isFuture ? 'den' : 'dnem';

      case 'dd':
        // 9 days / in 9 days / 9 days ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'dny' : 'dní');
        } else {
          return result + 'dny';
        }

      case 'M':
        // a month / in a month / a month ago
        return withoutSuffix || isFuture ? 'měsíc' : 'měsícem';

      case 'MM':
        // 9 months / in 9 months / 9 months ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'měsíce' : 'měsíců');
        } else {
          return result + 'měsíci';
        }

      case 'y':
        // a year / in a year / a year ago
        return withoutSuffix || isFuture ? 'rok' : 'rokem';

      case 'yy':
        // 9 years / in 9 years / 9 years ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'roky' : 'let');
        } else {
          return result + 'lety';
        }

    }
  }

  var cs = moment.defineLocale('cs', {
    months: months,
    monthsShort: monthsShort,
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    // NOTE: 'červen' is substring of 'červenec'; therefore 'červenec' must precede 'červen' in the regex to be fully matched.
    // Otherwise parser matches '1. červenec' as '1. červen' + 'ec'.
    monthsStrictRegex: /^(leden|ledna|února|únor|březen|března|duben|dubna|květen|května|červenec|července|červen|června|srpen|srpna|září|říjen|října|listopadu|listopad|prosinec|prosince)/i,
    monthsShortStrictRegex: /^(led|úno|bře|dub|kvě|čvn|čvc|srp|zář|říj|lis|pro)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'neděle_pondělí_úterý_středa_čtvrtek_pátek_sobota'.split('_'),
    weekdaysShort: 'ne_po_út_st_čt_pá_so'.split('_'),
    weekdaysMin: 'ne_po_út_st_čt_pá_so'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm',
      LLLL: 'dddd D. MMMM YYYY H:mm',
      l: 'D. M. YYYY'
    },
    calendar: {
      sameDay: '[dnes v] LT',
      nextDay: '[zítra v] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[v neděli v] LT';

          case 1:
          case 2:
            return '[v] dddd [v] LT';

          case 3:
            return '[ve středu v] LT';

          case 4:
            return '[ve čtvrtek v] LT';

          case 5:
            return '[v pátek v] LT';

          case 6:
            return '[v sobotu v] LT';
        }
      },
      lastDay: '[včera v] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[minulou neděli v] LT';

          case 1:
          case 2:
            return '[minulé] dddd [v] LT';

          case 3:
            return '[minulou středu v] LT';

          case 4:
          case 5:
            return '[minulý] dddd [v] LT';

          case 6:
            return '[minulou sobotu v] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: 'před %s',
      s: translate,
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: translate,
      dd: translate,
      M: translate,
      MM: translate,
      y: translate,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return cs;
});

/***/ }),

/***/ "PYwp":
/*!********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/nonIterableRest.js ***!
  \********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _nonIterableRest; });
function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

/***/ }),

/***/ "PZkE":
/*!**********************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/distinctUntilKeyChanged.js ***!
  \**********************************************************************************/
/*! exports provided: distinctUntilKeyChanged */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "distinctUntilKeyChanged", function() { return distinctUntilKeyChanged; });
/* harmony import */ var _distinctUntilChanged__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./distinctUntilChanged */ "/uUt");

function distinctUntilKeyChanged(key, compare) {
  return Object(_distinctUntilChanged__WEBPACK_IMPORTED_MODULE_0__["distinctUntilChanged"])(function (x, y) {
    return compare ? compare(x[key], y[key]) : x[key] === y[key];
  });
}

/***/ }),

/***/ "PeUW":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ta.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Tamil [ta]
//! author : Arjunkumar Krishnamoorthy : https://github.com/tk120404
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '௧',
    2: '௨',
    3: '௩',
    4: '௪',
    5: '௫',
    6: '௬',
    7: '௭',
    8: '௮',
    9: '௯',
    0: '௦'
  },
      numberMap = {
    '௧': '1',
    '௨': '2',
    '௩': '3',
    '௪': '4',
    '௫': '5',
    '௬': '6',
    '௭': '7',
    '௮': '8',
    '௯': '9',
    '௦': '0'
  };
  var ta = moment.defineLocale('ta', {
    months: 'ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்'.split('_'),
    monthsShort: 'ஜனவரி_பிப்ரவரி_மார்ச்_ஏப்ரல்_மே_ஜூன்_ஜூலை_ஆகஸ்ட்_செப்டெம்பர்_அக்டோபர்_நவம்பர்_டிசம்பர்'.split('_'),
    weekdays: 'ஞாயிற்றுக்கிழமை_திங்கட்கிழமை_செவ்வாய்கிழமை_புதன்கிழமை_வியாழக்கிழமை_வெள்ளிக்கிழமை_சனிக்கிழமை'.split('_'),
    weekdaysShort: 'ஞாயிறு_திங்கள்_செவ்வாய்_புதன்_வியாழன்_வெள்ளி_சனி'.split('_'),
    weekdaysMin: 'ஞா_தி_செ_பு_வி_வெ_ச'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, HH:mm',
      LLLL: 'dddd, D MMMM YYYY, HH:mm'
    },
    calendar: {
      sameDay: '[இன்று] LT',
      nextDay: '[நாளை] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[நேற்று] LT',
      lastWeek: '[கடந்த வாரம்] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s இல்',
      past: '%s முன்',
      s: 'ஒரு சில விநாடிகள்',
      ss: '%d விநாடிகள்',
      m: 'ஒரு நிமிடம்',
      mm: '%d நிமிடங்கள்',
      h: 'ஒரு மணி நேரம்',
      hh: '%d மணி நேரம்',
      d: 'ஒரு நாள்',
      dd: '%d நாட்கள்',
      M: 'ஒரு மாதம்',
      MM: '%d மாதங்கள்',
      y: 'ஒரு வருடம்',
      yy: '%d ஆண்டுகள்'
    },
    dayOfMonthOrdinalParse: /\d{1,2}வது/,
    ordinal: function ordinal(number) {
      return number + 'வது';
    },
    preparse: function preparse(string) {
      return string.replace(/[௧௨௩௪௫௬௭௮௯௦]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    // refer http://ta.wikipedia.org/s/1er1
    meridiemParse: /யாமம்|வைகறை|காலை|நண்பகல்|எற்பாடு|மாலை/,
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 2) {
        return ' யாமம்';
      } else if (hour < 6) {
        return ' வைகறை'; // வைகறை
      } else if (hour < 10) {
        return ' காலை'; // காலை
      } else if (hour < 14) {
        return ' நண்பகல்'; // நண்பகல்
      } else if (hour < 18) {
        return ' எற்பாடு'; // எற்பாடு
      } else if (hour < 22) {
        return ' மாலை'; // மாலை
      } else {
        return ' யாமம்';
      }
    },
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'யாமம்') {
        return hour < 2 ? hour : hour + 12;
      } else if (meridiem === 'வைகறை' || meridiem === 'காலை') {
        return hour;
      } else if (meridiem === 'நண்பகல்') {
        return hour >= 10 ? hour : hour + 12;
      } else {
        return hour + 12;
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return ta;
});

/***/ }),

/***/ "PfrF":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/bufferWhen.js ***!
  \*********************************************************************/
/*! exports provided: bufferWhen */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "bufferWhen", function() { return bufferWhen; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");








function bufferWhen(closingSelector) {
  return function (source) {
    return source.lift(new BufferWhenOperator(closingSelector));
  };
}

var BufferWhenOperator = /*#__PURE__*/function () {
  function BufferWhenOperator(closingSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, BufferWhenOperator);

    this.closingSelector = closingSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(BufferWhenOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new BufferWhenSubscriber(subscriber, this.closingSelector));
    }
  }]);

  return BufferWhenOperator;
}();

var BufferWhenSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferWhenSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(BufferWhenSubscriber);

  function BufferWhenSubscriber(destination, closingSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, BufferWhenSubscriber);

    _this = _super.call(this, destination);
    _this.closingSelector = closingSelector;
    _this.subscribing = false;

    _this.openBuffer();

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(BufferWhenSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.buffer.push(value);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var buffer = this.buffer;

      if (buffer) {
        this.destination.next(buffer);
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(BufferWhenSubscriber.prototype), "_complete", this).call(this);
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      this.buffer = undefined;
      this.subscribing = false;
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      this.openBuffer();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      if (this.subscribing) {
        this.complete();
      } else {
        this.openBuffer();
      }
    }
  }, {
    key: "openBuffer",
    value: function openBuffer() {
      var closingSubscription = this.closingSubscription;

      if (closingSubscription) {
        this.remove(closingSubscription);
        closingSubscription.unsubscribe();
      }

      var buffer = this.buffer;

      if (this.buffer) {
        this.destination.next(buffer);
      }

      this.buffer = [];
      var closingNotifier;

      try {
        var closingSelector = this.closingSelector;
        closingNotifier = closingSelector();
      } catch (err) {
        return this.error(err);
      }

      closingSubscription = new _Subscription__WEBPACK_IMPORTED_MODULE_6__["Subscription"]();
      this.closingSubscription = closingSubscription;
      this.add(closingSubscription);
      this.subscribing = true;
      closingSubscription.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["innerSubscribe"])(closingNotifier, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleInnerSubscriber"](this)));
      this.subscribing = false;
    }
  }]);

  return BufferWhenSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "PpIw":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/kn.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Kannada [kn]
//! author : Rajeev Naik : https://github.com/rajeevnaikte
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '೧',
    2: '೨',
    3: '೩',
    4: '೪',
    5: '೫',
    6: '೬',
    7: '೭',
    8: '೮',
    9: '೯',
    0: '೦'
  },
      numberMap = {
    '೧': '1',
    '೨': '2',
    '೩': '3',
    '೪': '4',
    '೫': '5',
    '೬': '6',
    '೭': '7',
    '೮': '8',
    '೯': '9',
    '೦': '0'
  };
  var kn = moment.defineLocale('kn', {
    months: 'ಜನವರಿ_ಫೆಬ್ರವರಿ_ಮಾರ್ಚ್_ಏಪ್ರಿಲ್_ಮೇ_ಜೂನ್_ಜುಲೈ_ಆಗಸ್ಟ್_ಸೆಪ್ಟೆಂಬರ್_ಅಕ್ಟೋಬರ್_ನವೆಂಬರ್_ಡಿಸೆಂಬರ್'.split('_'),
    monthsShort: 'ಜನ_ಫೆಬ್ರ_ಮಾರ್ಚ್_ಏಪ್ರಿಲ್_ಮೇ_ಜೂನ್_ಜುಲೈ_ಆಗಸ್ಟ್_ಸೆಪ್ಟೆಂ_ಅಕ್ಟೋ_ನವೆಂ_ಡಿಸೆಂ'.split('_'),
    monthsParseExact: true,
    weekdays: 'ಭಾನುವಾರ_ಸೋಮವಾರ_ಮಂಗಳವಾರ_ಬುಧವಾರ_ಗುರುವಾರ_ಶುಕ್ರವಾರ_ಶನಿವಾರ'.split('_'),
    weekdaysShort: 'ಭಾನು_ಸೋಮ_ಮಂಗಳ_ಬುಧ_ಗುರು_ಶುಕ್ರ_ಶನಿ'.split('_'),
    weekdaysMin: 'ಭಾ_ಸೋ_ಮಂ_ಬು_ಗು_ಶು_ಶ'.split('_'),
    longDateFormat: {
      LT: 'A h:mm',
      LTS: 'A h:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm',
      LLLL: 'dddd, D MMMM YYYY, A h:mm'
    },
    calendar: {
      sameDay: '[ಇಂದು] LT',
      nextDay: '[ನಾಳೆ] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[ನಿನ್ನೆ] LT',
      lastWeek: '[ಕೊನೆಯ] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s ನಂತರ',
      past: '%s ಹಿಂದೆ',
      s: 'ಕೆಲವು ಕ್ಷಣಗಳು',
      ss: '%d ಸೆಕೆಂಡುಗಳು',
      m: 'ಒಂದು ನಿಮಿಷ',
      mm: '%d ನಿಮಿಷ',
      h: 'ಒಂದು ಗಂಟೆ',
      hh: '%d ಗಂಟೆ',
      d: 'ಒಂದು ದಿನ',
      dd: '%d ದಿನ',
      M: 'ಒಂದು ತಿಂಗಳು',
      MM: '%d ತಿಂಗಳು',
      y: 'ಒಂದು ವರ್ಷ',
      yy: '%d ವರ್ಷ'
    },
    preparse: function preparse(string) {
      return string.replace(/[೧೨೩೪೫೬೭೮೯೦]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    meridiemParse: /ರಾತ್ರಿ|ಬೆಳಿಗ್ಗೆ|ಮಧ್ಯಾಹ್ನ|ಸಂಜೆ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'ರಾತ್ರಿ') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'ಬೆಳಿಗ್ಗೆ') {
        return hour;
      } else if (meridiem === 'ಮಧ್ಯಾಹ್ನ') {
        return hour >= 10 ? hour : hour + 12;
      } else if (meridiem === 'ಸಂಜೆ') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'ರಾತ್ರಿ';
      } else if (hour < 10) {
        return 'ಬೆಳಿಗ್ಗೆ';
      } else if (hour < 17) {
        return 'ಮಧ್ಯಾಹ್ನ';
      } else if (hour < 20) {
        return 'ಸಂಜೆ';
      } else {
        return 'ರಾತ್ರಿ';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}(ನೇ)/,
    ordinal: function ordinal(number) {
      return number + 'ನೇ';
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return kn;
});

/***/ }),

/***/ "PqYM":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/timer.js ***!
  \*****************************************************************/
/*! exports provided: timer */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "timer", function() { return timer; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _util_isNumeric__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/isNumeric */ "Y7HM");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");




function timer() {
  var dueTime = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var periodOrScheduler = arguments.length > 1 ? arguments[1] : undefined;
  var scheduler = arguments.length > 2 ? arguments[2] : undefined;
  var period = -1;

  if (Object(_util_isNumeric__WEBPACK_IMPORTED_MODULE_2__["isNumeric"])(periodOrScheduler)) {
    period = Number(periodOrScheduler) < 1 && 1 || Number(periodOrScheduler);
  } else if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_3__["isScheduler"])(periodOrScheduler)) {
    scheduler = periodOrScheduler;
  }

  if (!Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_3__["isScheduler"])(scheduler)) {
    scheduler = _scheduler_async__WEBPACK_IMPORTED_MODULE_1__["async"];
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var due = Object(_util_isNumeric__WEBPACK_IMPORTED_MODULE_2__["isNumeric"])(dueTime) ? dueTime : +dueTime - scheduler.now();
    return scheduler.schedule(dispatch, due, {
      index: 0,
      period: period,
      subscriber: subscriber
    });
  });
}

function dispatch(state) {
  var index = state.index,
      period = state.period,
      subscriber = state.subscriber;
  subscriber.next(index);

  if (subscriber.closed) {
    return;
  } else if (period === -1) {
    return subscriber.complete();
  }

  state.index = index + 1;
  this.schedule(state, period);
}

/***/ }),

/***/ "Pz8W":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/AsapAction.js ***!
  \*********************************************************************/
/*! exports provided: AsapAction */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AsapAction", function() { return AsapAction; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _util_Immediate__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/Immediate */ "c7jc");
/* harmony import */ var _AsyncAction__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./AsyncAction */ "3N8a");








var AsapAction = /*#__PURE__*/function (_AsyncAction) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(AsapAction, _AsyncAction);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(AsapAction);

  function AsapAction(scheduler, work) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AsapAction);

    _this = _super.call(this, scheduler, work);
    _this.scheduler = scheduler;
    _this.work = work;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AsapAction, [{
    key: "requestAsyncId",
    value: function requestAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

      if (delay !== null && delay > 0) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AsapAction.prototype), "requestAsyncId", this).call(this, scheduler, id, delay);
      }

      scheduler.actions.push(this);
      return scheduler.scheduled || (scheduler.scheduled = _util_Immediate__WEBPACK_IMPORTED_MODULE_6__["Immediate"].setImmediate(scheduler.flush.bind(scheduler, null)));
    }
  }, {
    key: "recycleAsyncId",
    value: function recycleAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

      if (delay !== null && delay > 0 || delay === null && this.delay > 0) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AsapAction.prototype), "recycleAsyncId", this).call(this, scheduler, id, delay);
      }

      if (scheduler.actions.length === 0) {
        _util_Immediate__WEBPACK_IMPORTED_MODULE_6__["Immediate"].clearImmediate(id);
        scheduler.scheduled = undefined;
      }

      return undefined;
    }
  }]);

  return AsapAction;
}(_AsyncAction__WEBPACK_IMPORTED_MODULE_7__["AsyncAction"]);

/***/ }),

/***/ "QIAL":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isInteropObservable.js ***!
  \*************************************************************************/
/*! exports provided: isInteropObservable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isInteropObservable", function() { return isInteropObservable; });
/* harmony import */ var _symbol_observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../symbol/observable */ "kJWO");

function isInteropObservable(input) {
  return input && typeof input[_symbol_observable__WEBPACK_IMPORTED_MODULE_0__["observable"]] === 'function';
}

/***/ }),

/***/ "Qj4J":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ar-kw.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Arabic (Kuwait) [ar-kw]
//! author : Nusret Parlak: https://github.com/nusretparlak
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var arKw = moment.defineLocale('ar-kw', {
    months: 'يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر'.split('_'),
    monthsShort: 'يناير_فبراير_مارس_أبريل_ماي_يونيو_يوليوز_غشت_شتنبر_أكتوبر_نونبر_دجنبر'.split('_'),
    weekdays: 'الأحد_الإتنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'احد_اتنين_ثلاثاء_اربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[اليوم على الساعة] LT',
      nextDay: '[غدا على الساعة] LT',
      nextWeek: 'dddd [على الساعة] LT',
      lastDay: '[أمس على الساعة] LT',
      lastWeek: 'dddd [على الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'في %s',
      past: 'منذ %s',
      s: 'ثوان',
      ss: '%d ثانية',
      m: 'دقيقة',
      mm: '%d دقائق',
      h: 'ساعة',
      hh: '%d ساعات',
      d: 'يوم',
      dd: '%d أيام',
      M: 'شهر',
      MM: '%d أشهر',
      y: 'سنة',
      yy: '%d سنوات'
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return arKw;
});

/***/ }),

/***/ "Qn8I":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/using.js ***!
  \*****************************************************************/
/*! exports provided: using */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "using", function() { return using; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _from__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./from */ "Cfvw");
/* harmony import */ var _empty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./empty */ "EY2u");



function using(resourceFactory, observableFactory) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var resource;

    try {
      resource = resourceFactory();
    } catch (err) {
      subscriber.error(err);
      return undefined;
    }

    var result;

    try {
      result = observableFactory(resource);
    } catch (err) {
      subscriber.error(err);
      return undefined;
    }

    var source = result ? Object(_from__WEBPACK_IMPORTED_MODULE_1__["from"])(result) : _empty__WEBPACK_IMPORTED_MODULE_2__["EMPTY"];
    var subscription = source.subscribe(subscriber);
    return function () {
      subscription.unsubscribe();

      if (resource) {
        resource.unsubscribe();
      }
    };
  });
}

/***/ }),

/***/ "QqCr":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/bindCallback.js ***!
  \************************************************************************/
/*! exports provided: bindCallback */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "bindCallback", function() { return bindCallback; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _AsyncSubject__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../AsyncSubject */ "NHP+");
/* harmony import */ var _operators_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../operators/map */ "lJxs");
/* harmony import */ var _util_canReportError__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/canReportError */ "8Qeq");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");







function bindCallback(callbackFunc, resultSelector, scheduler) {
  if (resultSelector) {
    if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_6__["isScheduler"])(resultSelector)) {
      scheduler = resultSelector;
    } else {
      return function () {
        return bindCallback(callbackFunc, scheduler).apply(void 0, arguments).pipe(Object(_operators_map__WEBPACK_IMPORTED_MODULE_3__["map"])(function (args) {
          return Object(_util_isArray__WEBPACK_IMPORTED_MODULE_5__["isArray"])(args) ? resultSelector.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args)) : resultSelector(args);
        }));
      };
    }
  }

  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var context = this;
    var subject;
    var params = {
      context: context,
      subject: subject,
      callbackFunc: callbackFunc,
      scheduler: scheduler
    };
    return new _Observable__WEBPACK_IMPORTED_MODULE_1__["Observable"](function (subscriber) {
      if (!scheduler) {
        if (!subject) {
          subject = new _AsyncSubject__WEBPACK_IMPORTED_MODULE_2__["AsyncSubject"]();

          var handler = function handler() {
            for (var _len2 = arguments.length, innerArgs = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
              innerArgs[_key2] = arguments[_key2];
            }

            subject.next(innerArgs.length <= 1 ? innerArgs[0] : innerArgs);
            subject.complete();
          };

          try {
            callbackFunc.apply(context, [].concat(args, [handler]));
          } catch (err) {
            if (Object(_util_canReportError__WEBPACK_IMPORTED_MODULE_4__["canReportError"])(subject)) {
              subject.error(err);
            } else {
              console.warn(err);
            }
          }
        }

        return subject.subscribe(subscriber);
      } else {
        var state = {
          args: args,
          subscriber: subscriber,
          params: params
        };
        return scheduler.schedule(dispatch, 0, state);
      }
    });
  };
}

function dispatch(state) {
  var _this = this;

  var self = this;
  var args = state.args,
      subscriber = state.subscriber,
      params = state.params;
  var callbackFunc = params.callbackFunc,
      context = params.context,
      scheduler = params.scheduler;
  var subject = params.subject;

  if (!subject) {
    subject = params.subject = new _AsyncSubject__WEBPACK_IMPORTED_MODULE_2__["AsyncSubject"]();

    var handler = function handler() {
      for (var _len3 = arguments.length, innerArgs = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
        innerArgs[_key3] = arguments[_key3];
      }

      var value = innerArgs.length <= 1 ? innerArgs[0] : innerArgs;

      _this.add(scheduler.schedule(dispatchNext, 0, {
        value: value,
        subject: subject
      }));
    };

    try {
      callbackFunc.apply(context, [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args), [handler]));
    } catch (err) {
      subject.error(err);
    }
  }

  this.add(subject.subscribe(subscriber));
}

function dispatchNext(state) {
  var value = state.value,
      subject = state.subject;
  subject.next(value);
  subject.complete();
}

function dispatchError(state) {
  var err = state.err,
      subject = state.subject;
  subject.error(err);
}

/***/ }),

/***/ "RAwQ":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/lb.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Luxembourgish [lb]
//! author : mweimerskirch : https://github.com/mweimerskirch
//! author : David Raison : https://github.com/kwisatz
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      m: ['eng Minutt', 'enger Minutt'],
      h: ['eng Stonn', 'enger Stonn'],
      d: ['een Dag', 'engem Dag'],
      M: ['ee Mount', 'engem Mount'],
      y: ['ee Joer', 'engem Joer']
    };
    return withoutSuffix ? format[key][0] : format[key][1];
  }

  function processFutureTime(string) {
    var number = string.substr(0, string.indexOf(' '));

    if (eifelerRegelAppliesToNumber(number)) {
      return 'a ' + string;
    }

    return 'an ' + string;
  }

  function processPastTime(string) {
    var number = string.substr(0, string.indexOf(' '));

    if (eifelerRegelAppliesToNumber(number)) {
      return 'viru ' + string;
    }

    return 'virun ' + string;
  }
  /**
   * Returns true if the word before the given number loses the '-n' ending.
   * e.g. 'an 10 Deeg' but 'a 5 Deeg'
   *
   * @param number {integer}
   * @returns {boolean}
   */


  function eifelerRegelAppliesToNumber(number) {
    number = parseInt(number, 10);

    if (isNaN(number)) {
      return false;
    }

    if (number < 0) {
      // Negative Number --> always true
      return true;
    } else if (number < 10) {
      // Only 1 digit
      if (4 <= number && number <= 7) {
        return true;
      }

      return false;
    } else if (number < 100) {
      // 2 digits
      var lastDigit = number % 10,
          firstDigit = number / 10;

      if (lastDigit === 0) {
        return eifelerRegelAppliesToNumber(firstDigit);
      }

      return eifelerRegelAppliesToNumber(lastDigit);
    } else if (number < 10000) {
      // 3 or 4 digits --> recursively check first digit
      while (number >= 10) {
        number = number / 10;
      }

      return eifelerRegelAppliesToNumber(number);
    } else {
      // Anything larger than 4 digits: recursively check first n-3 digits
      number = number / 1000;
      return eifelerRegelAppliesToNumber(number);
    }
  }

  var lb = moment.defineLocale('lb', {
    months: 'Januar_Februar_Mäerz_Abrëll_Mee_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
    monthsShort: 'Jan._Febr._Mrz._Abr._Mee_Jun._Jul._Aug._Sept._Okt._Nov._Dez.'.split('_'),
    monthsParseExact: true,
    weekdays: 'Sonndeg_Méindeg_Dënschdeg_Mëttwoch_Donneschdeg_Freideg_Samschdeg'.split('_'),
    weekdaysShort: 'So._Mé._Dë._Më._Do._Fr._Sa.'.split('_'),
    weekdaysMin: 'So_Mé_Dë_Më_Do_Fr_Sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm [Auer]',
      LTS: 'H:mm:ss [Auer]',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm [Auer]',
      LLLL: 'dddd, D. MMMM YYYY H:mm [Auer]'
    },
    calendar: {
      sameDay: '[Haut um] LT',
      sameElse: 'L',
      nextDay: '[Muer um] LT',
      nextWeek: 'dddd [um] LT',
      lastDay: '[Gëschter um] LT',
      lastWeek: function lastWeek() {
        // Different date string for 'Dënschdeg' (Tuesday) and 'Donneschdeg' (Thursday) due to phonological rule
        switch (this.day()) {
          case 2:
          case 4:
            return '[Leschten] dddd [um] LT';

          default:
            return '[Leschte] dddd [um] LT';
        }
      }
    },
    relativeTime: {
      future: processFutureTime,
      past: processPastTime,
      s: 'e puer Sekonnen',
      ss: '%d Sekonnen',
      m: processRelativeTime,
      mm: '%d Minutten',
      h: processRelativeTime,
      hh: '%d Stonnen',
      d: processRelativeTime,
      dd: '%d Deeg',
      M: processRelativeTime,
      MM: '%d Méint',
      y: processRelativeTime,
      yy: '%d Joer'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return lb;
});

/***/ }),

/***/ "RHh3":
/*!**************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/construct.js ***!
  \**************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _construct; });
/* harmony import */ var _setPrototypeOf__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./setPrototypeOf */ "s4An");
/* harmony import */ var _isNativeReflectConstruct__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./isNativeReflectConstruct */ "2WcH");


function _construct(Parent, args, Class) {
  if (Object(_isNativeReflectConstruct__WEBPACK_IMPORTED_MODULE_1__["default"])()) {
    _construct = Reflect.construct;
  } else {
    _construct = function _construct(Parent, args, Class) {
      var a = [null];
      a.push.apply(a, args);
      var Constructor = Function.bind.apply(Parent, a);
      var instance = new Constructor();
      if (Class) Object(_setPrototypeOf__WEBPACK_IMPORTED_MODULE_0__["default"])(instance, Class.prototype);
      return instance;
    };
  }

  return _construct.apply(null, arguments);
}

/***/ }),

/***/ "RUbi":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/AsapScheduler.js ***!
  \************************************************************************/
/*! exports provided: AsapScheduler */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AsapScheduler", function() { return AsapScheduler; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _AsyncScheduler__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./AsyncScheduler */ "IjjT");





var AsapScheduler = /*#__PURE__*/function (_AsyncScheduler) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(AsapScheduler, _AsyncScheduler);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(AsapScheduler);

  function AsapScheduler() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AsapScheduler);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AsapScheduler, [{
    key: "flush",
    value: function flush(action) {
      this.active = true;
      this.scheduled = undefined;
      var actions = this.actions;
      var error;
      var index = -1;
      var count = actions.length;
      action = action || actions.shift();

      do {
        if (error = action.execute(action.state, action.delay)) {
          break;
        }
      } while (++index < count && (action = actions.shift()));

      this.active = false;

      if (error) {
        while (++index < count && (action = actions.shift())) {
          action.unsubscribe();
        }

        throw error;
      }
    }
  }]);

  return AsapScheduler;
}(_AsyncScheduler__WEBPACK_IMPORTED_MODULE_4__["AsyncScheduler"]);

/***/ }),

/***/ "ReuC":
/*!********************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/get.js ***!
  \********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _get; });
/* harmony import */ var _superPropBase__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./superPropBase */ "XTTE");

function _get(target, property, receiver) {
  if (typeof Reflect !== "undefined" && Reflect.get) {
    _get = Reflect.get;
  } else {
    _get = function _get(target, property, receiver) {
      var base = Object(_superPropBase__WEBPACK_IMPORTED_MODULE_0__["default"])(target, property);
      if (!base) return;
      var desc = Object.getOwnPropertyDescriptor(base, property);

      if (desc.get) {
        return desc.get.call(receiver);
      }

      return desc.value;
    };
  }

  return _get(target, property, receiver || target);
}

/***/ }),

/***/ "S6ln":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/hr.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Croatian [hr]
//! author : Bojan Marković : https://github.com/bmarkovic
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function translate(number, withoutSuffix, key) {
    var result = number + ' ';

    switch (key) {
      case 'ss':
        if (number === 1) {
          result += 'sekunda';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'sekunde';
        } else {
          result += 'sekundi';
        }

        return result;

      case 'm':
        return withoutSuffix ? 'jedna minuta' : 'jedne minute';

      case 'mm':
        if (number === 1) {
          result += 'minuta';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'minute';
        } else {
          result += 'minuta';
        }

        return result;

      case 'h':
        return withoutSuffix ? 'jedan sat' : 'jednog sata';

      case 'hh':
        if (number === 1) {
          result += 'sat';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'sata';
        } else {
          result += 'sati';
        }

        return result;

      case 'dd':
        if (number === 1) {
          result += 'dan';
        } else {
          result += 'dana';
        }

        return result;

      case 'MM':
        if (number === 1) {
          result += 'mjesec';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'mjeseca';
        } else {
          result += 'mjeseci';
        }

        return result;

      case 'yy':
        if (number === 1) {
          result += 'godina';
        } else if (number === 2 || number === 3 || number === 4) {
          result += 'godine';
        } else {
          result += 'godina';
        }

        return result;
    }
  }

  var hr = moment.defineLocale('hr', {
    months: {
      format: 'siječnja_veljače_ožujka_travnja_svibnja_lipnja_srpnja_kolovoza_rujna_listopada_studenoga_prosinca'.split('_'),
      standalone: 'siječanj_veljača_ožujak_travanj_svibanj_lipanj_srpanj_kolovoz_rujan_listopad_studeni_prosinac'.split('_')
    },
    monthsShort: 'sij._velj._ožu._tra._svi._lip._srp._kol._ruj._lis._stu._pro.'.split('_'),
    monthsParseExact: true,
    weekdays: 'nedjelja_ponedjeljak_utorak_srijeda_četvrtak_petak_subota'.split('_'),
    weekdaysShort: 'ned._pon._uto._sri._čet._pet._sub.'.split('_'),
    weekdaysMin: 'ne_po_ut_sr_če_pe_su'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'Do MMMM YYYY',
      LLL: 'Do MMMM YYYY H:mm',
      LLLL: 'dddd, Do MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[danas u] LT',
      nextDay: '[sutra u] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[u] [nedjelju] [u] LT';

          case 3:
            return '[u] [srijedu] [u] LT';

          case 6:
            return '[u] [subotu] [u] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[u] dddd [u] LT';
        }
      },
      lastDay: '[jučer u] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[prošlu] [nedjelju] [u] LT';

          case 3:
            return '[prošlu] [srijedu] [u] LT';

          case 6:
            return '[prošle] [subote] [u] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[prošli] dddd [u] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: 'prije %s',
      s: 'par sekundi',
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: 'dan',
      dd: translate,
      M: 'mjesec',
      MM: translate,
      y: 'godinu',
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return hr;
});

/***/ }),

/***/ "SFxW":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/az.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Azerbaijani [az]
//! author : topchiyev : https://github.com/topchiyev
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var suffixes = {
    1: '-inci',
    5: '-inci',
    8: '-inci',
    70: '-inci',
    80: '-inci',
    2: '-nci',
    7: '-nci',
    20: '-nci',
    50: '-nci',
    3: '-üncü',
    4: '-üncü',
    100: '-üncü',
    6: '-ncı',
    9: '-uncu',
    10: '-uncu',
    30: '-uncu',
    60: '-ıncı',
    90: '-ıncı'
  };
  var az = moment.defineLocale('az', {
    months: 'yanvar_fevral_mart_aprel_may_iyun_iyul_avqust_sentyabr_oktyabr_noyabr_dekabr'.split('_'),
    monthsShort: 'yan_fev_mar_apr_may_iyn_iyl_avq_sen_okt_noy_dek'.split('_'),
    weekdays: 'Bazar_Bazar ertəsi_Çərşənbə axşamı_Çərşənbə_Cümə axşamı_Cümə_Şənbə'.split('_'),
    weekdaysShort: 'Baz_BzE_ÇAx_Çər_CAx_Cüm_Şən'.split('_'),
    weekdaysMin: 'Bz_BE_ÇA_Çə_CA_Cü_Şə'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[bugün saat] LT',
      nextDay: '[sabah saat] LT',
      nextWeek: '[gələn həftə] dddd [saat] LT',
      lastDay: '[dünən] LT',
      lastWeek: '[keçən həftə] dddd [saat] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s sonra',
      past: '%s əvvəl',
      s: 'bir neçə saniyə',
      ss: '%d saniyə',
      m: 'bir dəqiqə',
      mm: '%d dəqiqə',
      h: 'bir saat',
      hh: '%d saat',
      d: 'bir gün',
      dd: '%d gün',
      M: 'bir ay',
      MM: '%d ay',
      y: 'bir il',
      yy: '%d il'
    },
    meridiemParse: /gecə|səhər|gündüz|axşam/,
    isPM: function isPM(input) {
      return /^(gündüz|axşam)$/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'gecə';
      } else if (hour < 12) {
        return 'səhər';
      } else if (hour < 17) {
        return 'gündüz';
      } else {
        return 'axşam';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(ıncı|inci|nci|üncü|ncı|uncu)/,
    ordinal: function ordinal(number) {
      if (number === 0) {
        // special case for zero
        return number + '-ıncı';
      }

      var a = number % 10,
          b = number % 100 - a,
          c = number >= 100 ? 100 : null;
      return number + (suffixes[a] || suffixes[b] || suffixes[c]);
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return az;
});

/***/ }),

/***/ "SatO":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/zh-hk.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Chinese (Hong Kong) [zh-hk]
//! author : Ben : https://github.com/ben-lin
//! author : Chris Lam : https://github.com/hehachris
//! author : Konstantin : https://github.com/skfd
//! author : Anthony : https://github.com/anthonylau
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var zhHk = moment.defineLocale('zh-hk', {
    months: '一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月'.split('_'),
    monthsShort: '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
    weekdays: '星期日_星期一_星期二_星期三_星期四_星期五_星期六'.split('_'),
    weekdaysShort: '週日_週一_週二_週三_週四_週五_週六'.split('_'),
    weekdaysMin: '日_一_二_三_四_五_六'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY/MM/DD',
      LL: 'YYYY年M月D日',
      LLL: 'YYYY年M月D日 HH:mm',
      LLLL: 'YYYY年M月D日dddd HH:mm',
      l: 'YYYY/M/D',
      ll: 'YYYY年M月D日',
      lll: 'YYYY年M月D日 HH:mm',
      llll: 'YYYY年M月D日dddd HH:mm'
    },
    meridiemParse: /凌晨|早上|上午|中午|下午|晚上/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === '凌晨' || meridiem === '早上' || meridiem === '上午') {
        return hour;
      } else if (meridiem === '中午') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === '下午' || meridiem === '晚上') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      var hm = hour * 100 + minute;

      if (hm < 600) {
        return '凌晨';
      } else if (hm < 900) {
        return '早上';
      } else if (hm < 1200) {
        return '上午';
      } else if (hm === 1200) {
        return '中午';
      } else if (hm < 1800) {
        return '下午';
      } else {
        return '晚上';
      }
    },
    calendar: {
      sameDay: '[今天]LT',
      nextDay: '[明天]LT',
      nextWeek: '[下]ddddLT',
      lastDay: '[昨天]LT',
      lastWeek: '[上]ddddLT',
      sameElse: 'L'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(日|月|週)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + '日';

        case 'M':
          return number + '月';

        case 'w':
        case 'W':
          return number + '週';

        default:
          return number;
      }
    },
    relativeTime: {
      future: '%s後',
      past: '%s前',
      s: '幾秒',
      ss: '%d 秒',
      m: '1 分鐘',
      mm: '%d 分鐘',
      h: '1 小時',
      hh: '%d 小時',
      d: '1 天',
      dd: '%d 天',
      M: '1 個月',
      MM: '%d 個月',
      y: '1 年',
      yy: '%d 年'
    }
  });
  return zhHk;
});

/***/ }),

/***/ "SeVD":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/subscribeTo.js ***!
  \*****************************************************************/
/*! exports provided: subscribeTo */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeTo", function() { return subscribeTo; });
/* harmony import */ var _subscribeToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./subscribeToArray */ "ngJS");
/* harmony import */ var _subscribeToPromise__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./subscribeToPromise */ "a7t3");
/* harmony import */ var _subscribeToIterable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./subscribeToIterable */ "pLzU");
/* harmony import */ var _subscribeToObservable__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./subscribeToObservable */ "CRDf");
/* harmony import */ var _isArrayLike__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./isArrayLike */ "I55L");
/* harmony import */ var _isPromise__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./isPromise */ "c2HN");
/* harmony import */ var _isObject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./isObject */ "XoHu");
/* harmony import */ var _symbol_iterator__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../symbol/iterator */ "Lhse");
/* harmony import */ var _symbol_observable__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../symbol/observable */ "kJWO");









var subscribeTo = function subscribeTo(result) {
  if (!!result && typeof result[_symbol_observable__WEBPACK_IMPORTED_MODULE_8__["observable"]] === 'function') {
    return Object(_subscribeToObservable__WEBPACK_IMPORTED_MODULE_3__["subscribeToObservable"])(result);
  } else if (Object(_isArrayLike__WEBPACK_IMPORTED_MODULE_4__["isArrayLike"])(result)) {
    return Object(_subscribeToArray__WEBPACK_IMPORTED_MODULE_0__["subscribeToArray"])(result);
  } else if (Object(_isPromise__WEBPACK_IMPORTED_MODULE_5__["isPromise"])(result)) {
    return Object(_subscribeToPromise__WEBPACK_IMPORTED_MODULE_1__["subscribeToPromise"])(result);
  } else if (!!result && typeof result[_symbol_iterator__WEBPACK_IMPORTED_MODULE_7__["iterator"]] === 'function') {
    return Object(_subscribeToIterable__WEBPACK_IMPORTED_MODULE_2__["subscribeToIterable"])(result);
  } else {
    var value = Object(_isObject__WEBPACK_IMPORTED_MODULE_6__["isObject"])(result) ? 'an invalid object' : "'".concat(result, "'");
    var msg = "You provided ".concat(value, " where a stream was expected.") + ' You can provide an Observable, Promise, Array, or Iterable.';
    throw new TypeError(msg);
  }
};

/***/ }),

/***/ "SpAZ":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/identity.js ***!
  \**************************************************************/
/*! exports provided: identity */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "identity", function() { return identity; });
function identity(x) {
  return x;
}

/***/ }),

/***/ "SxV6":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/first.js ***!
  \****************************************************************/
/*! exports provided: first */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "first", function() { return first; });
/* harmony import */ var _util_EmptyError__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/EmptyError */ "sVev");
/* harmony import */ var _filter__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./filter */ "pLZG");
/* harmony import */ var _take__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./take */ "IzEk");
/* harmony import */ var _defaultIfEmpty__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./defaultIfEmpty */ "xbPD");
/* harmony import */ var _throwIfEmpty__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./throwIfEmpty */ "XDbj");
/* harmony import */ var _util_identity__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/identity */ "SpAZ");






function first(predicate, defaultValue) {
  var hasDefaultValue = arguments.length >= 2;
  return function (source) {
    return source.pipe(predicate ? Object(_filter__WEBPACK_IMPORTED_MODULE_1__["filter"])(function (v, i) {
      return predicate(v, i, source);
    }) : _util_identity__WEBPACK_IMPORTED_MODULE_5__["identity"], Object(_take__WEBPACK_IMPORTED_MODULE_2__["take"])(1), hasDefaultValue ? Object(_defaultIfEmpty__WEBPACK_IMPORTED_MODULE_3__["defaultIfEmpty"])(defaultValue) : Object(_throwIfEmpty__WEBPACK_IMPORTED_MODULE_4__["throwIfEmpty"])(function () {
      return new _util_EmptyError__WEBPACK_IMPORTED_MODULE_0__["EmptyError"]();
    }));
  };
}

/***/ }),

/***/ "T5bk":
/*!************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/toArray.js ***!
  \************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _toArray; });
/* harmony import */ var _arrayWithHoles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./arrayWithHoles */ "DSFK");
/* harmony import */ var _iterableToArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./iterableToArray */ "25BE");
/* harmony import */ var _unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./unsupportedIterableToArray */ "BsWD");
/* harmony import */ var _nonIterableRest__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./nonIterableRest */ "PYwp");




function _toArray(arr) {
  return Object(_arrayWithHoles__WEBPACK_IMPORTED_MODULE_0__["default"])(arr) || Object(_iterableToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(arr) || Object(_unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(arr) || Object(_nonIterableRest__WEBPACK_IMPORTED_MODULE_3__["default"])();
}

/***/ }),

/***/ "U8pU":
/*!***********************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/typeof.js ***!
  \***********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _typeof; });
function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function _typeof(obj) {
      return typeof obj;
    };
  } else {
    _typeof = function _typeof(obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

/***/ }),

/***/ "UDhR":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/id.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Indonesian [id]
//! author : Mohammad Satrio Utomo : https://github.com/tyok
//! reference: http://id.wikisource.org/wiki/Pedoman_Umum_Ejaan_Bahasa_Indonesia_yang_Disempurnakan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var id = moment.defineLocale('id', {
    months: 'Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_November_Desember'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_Mei_Jun_Jul_Agt_Sep_Okt_Nov_Des'.split('_'),
    weekdays: 'Minggu_Senin_Selasa_Rabu_Kamis_Jumat_Sabtu'.split('_'),
    weekdaysShort: 'Min_Sen_Sel_Rab_Kam_Jum_Sab'.split('_'),
    weekdaysMin: 'Mg_Sn_Sl_Rb_Km_Jm_Sb'.split('_'),
    longDateFormat: {
      LT: 'HH.mm',
      LTS: 'HH.mm.ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY [pukul] HH.mm',
      LLLL: 'dddd, D MMMM YYYY [pukul] HH.mm'
    },
    meridiemParse: /pagi|siang|sore|malam/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'pagi') {
        return hour;
      } else if (meridiem === 'siang') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === 'sore' || meridiem === 'malam') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 11) {
        return 'pagi';
      } else if (hours < 15) {
        return 'siang';
      } else if (hours < 19) {
        return 'sore';
      } else {
        return 'malam';
      }
    },
    calendar: {
      sameDay: '[Hari ini pukul] LT',
      nextDay: '[Besok pukul] LT',
      nextWeek: 'dddd [pukul] LT',
      lastDay: '[Kemarin pukul] LT',
      lastWeek: 'dddd [lalu pukul] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dalam %s',
      past: '%s yang lalu',
      s: 'beberapa detik',
      ss: '%d detik',
      m: 'semenit',
      mm: '%d menit',
      h: 'sejam',
      hh: '%d jam',
      d: 'sehari',
      dd: '%d hari',
      M: 'sebulan',
      MM: '%d bulan',
      y: 'setahun',
      yy: '%d tahun'
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return id;
});

/***/ }),

/***/ "UGaM":
/*!**************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/publishBehavior.js ***!
  \**************************************************************************/
/*! exports provided: publishBehavior */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "publishBehavior", function() { return publishBehavior; });
/* harmony import */ var _BehaviorSubject__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../BehaviorSubject */ "2Vo4");
/* harmony import */ var _multicast__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./multicast */ "oB13");


function publishBehavior(value) {
  return function (source) {
    return Object(_multicast__WEBPACK_IMPORTED_MODULE_1__["multicast"])(new _BehaviorSubject__WEBPACK_IMPORTED_MODULE_0__["BehaviorSubject"](value))(source);
  };
}

/***/ }),

/***/ "UHp3":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/windowTime.js ***!
  \*********************************************************************/
/*! exports provided: windowTime */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "windowTime", function() { return windowTime; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_isNumeric__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../util/isNumeric */ "Y7HM");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");












function windowTime(windowTimeSpan) {
  var scheduler = _scheduler_async__WEBPACK_IMPORTED_MODULE_8__["async"];
  var windowCreationInterval = null;
  var maxWindowSize = Number.POSITIVE_INFINITY;

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_11__["isScheduler"])(arguments[3])) {
    scheduler = arguments[3];
  }

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_11__["isScheduler"])(arguments[2])) {
    scheduler = arguments[2];
  } else if (Object(_util_isNumeric__WEBPACK_IMPORTED_MODULE_10__["isNumeric"])(arguments[2])) {
    maxWindowSize = Number(arguments[2]);
  }

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_11__["isScheduler"])(arguments[1])) {
    scheduler = arguments[1];
  } else if (Object(_util_isNumeric__WEBPACK_IMPORTED_MODULE_10__["isNumeric"])(arguments[1])) {
    windowCreationInterval = Number(arguments[1]);
  }

  return function windowTimeOperatorFunction(source) {
    return source.lift(new WindowTimeOperator(windowTimeSpan, windowCreationInterval, maxWindowSize, scheduler));
  };
}

var WindowTimeOperator = /*#__PURE__*/function () {
  function WindowTimeOperator(windowTimeSpan, windowCreationInterval, maxWindowSize, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, WindowTimeOperator);

    this.windowTimeSpan = windowTimeSpan;
    this.windowCreationInterval = windowCreationInterval;
    this.maxWindowSize = maxWindowSize;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(WindowTimeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new WindowTimeSubscriber(subscriber, this.windowTimeSpan, this.windowCreationInterval, this.maxWindowSize, this.scheduler));
    }
  }]);

  return WindowTimeOperator;
}();

var CountedSubject = /*#__PURE__*/function (_Subject) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(CountedSubject, _Subject);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(CountedSubject);

  function CountedSubject() {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, CountedSubject);

    _this = _super.apply(this, arguments);
    _this._numberOfNextedValues = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(CountedSubject, [{
    key: "next",
    value: function next(value) {
      this._numberOfNextedValues++;

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(CountedSubject.prototype), "next", this).call(this, value);
    }
  }, {
    key: "numberOfNextedValues",
    get: function get() {
      return this._numberOfNextedValues;
    }
  }]);

  return CountedSubject;
}(_Subject__WEBPACK_IMPORTED_MODULE_7__["Subject"]);

var WindowTimeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowTimeSubscriber, _Subscriber);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(WindowTimeSubscriber);

  function WindowTimeSubscriber(destination, windowTimeSpan, windowCreationInterval, maxWindowSize, scheduler) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, WindowTimeSubscriber);

    _this2 = _super2.call(this, destination);
    _this2.destination = destination;
    _this2.windowTimeSpan = windowTimeSpan;
    _this2.windowCreationInterval = windowCreationInterval;
    _this2.maxWindowSize = maxWindowSize;
    _this2.scheduler = scheduler;
    _this2.windows = [];

    var window = _this2.openWindow();

    if (windowCreationInterval !== null && windowCreationInterval >= 0) {
      var closeState = {
        subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this2),
        window: window,
        context: null
      };
      var creationState = {
        windowTimeSpan: windowTimeSpan,
        windowCreationInterval: windowCreationInterval,
        subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this2),
        scheduler: scheduler
      };

      _this2.add(scheduler.schedule(dispatchWindowClose, windowTimeSpan, closeState));

      _this2.add(scheduler.schedule(dispatchWindowCreation, windowCreationInterval, creationState));
    } else {
      var timeSpanOnlyState = {
        subscriber: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this2),
        window: window,
        windowTimeSpan: windowTimeSpan
      };

      _this2.add(scheduler.schedule(dispatchWindowTimeSpanOnly, windowTimeSpan, timeSpanOnlyState));
    }

    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(WindowTimeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var windows = this.windows;
      var len = windows.length;

      for (var i = 0; i < len; i++) {
        var window = windows[i];

        if (!window.closed) {
          window.next(value);

          if (window.numberOfNextedValues >= this.maxWindowSize) {
            this.closeWindow(window);
          }
        }
      }
    }
  }, {
    key: "_error",
    value: function _error(err) {
      var windows = this.windows;

      while (windows.length > 0) {
        windows.shift().error(err);
      }

      this.destination.error(err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var windows = this.windows;

      while (windows.length > 0) {
        var window = windows.shift();

        if (!window.closed) {
          window.complete();
        }
      }

      this.destination.complete();
    }
  }, {
    key: "openWindow",
    value: function openWindow() {
      var window = new CountedSubject();
      this.windows.push(window);
      var destination = this.destination;
      destination.next(window);
      return window;
    }
  }, {
    key: "closeWindow",
    value: function closeWindow(window) {
      window.complete();
      var windows = this.windows;
      windows.splice(windows.indexOf(window), 1);
    }
  }]);

  return WindowTimeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_9__["Subscriber"]);

function dispatchWindowTimeSpanOnly(state) {
  var subscriber = state.subscriber,
      windowTimeSpan = state.windowTimeSpan,
      window = state.window;

  if (window) {
    subscriber.closeWindow(window);
  }

  state.window = subscriber.openWindow();
  this.schedule(state, windowTimeSpan);
}

function dispatchWindowCreation(state) {
  var windowTimeSpan = state.windowTimeSpan,
      subscriber = state.subscriber,
      scheduler = state.scheduler,
      windowCreationInterval = state.windowCreationInterval;
  var window = subscriber.openWindow();
  var action = this;
  var context = {
    action: action,
    subscription: null
  };
  var timeSpanState = {
    subscriber: subscriber,
    window: window,
    context: context
  };
  context.subscription = scheduler.schedule(dispatchWindowClose, windowTimeSpan, timeSpanState);
  action.add(context.subscription);
  action.schedule(state, windowCreationInterval);
}

function dispatchWindowClose(state) {
  var subscriber = state.subscriber,
      window = state.window,
      context = state.context;

  if (context && context.action && context.subscription) {
    context.action.remove(context.subscription);
  }

  subscriber.closeWindow(window);
}

/***/ }),

/***/ "USCx":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ga.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Irish or Irish Gaelic [ga]
//! author : André Silva : https://github.com/askpt
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = ['Eanáir', 'Feabhra', 'Márta', 'Aibreán', 'Bealtaine', 'Meitheamh', 'Iúil', 'Lúnasa', 'Meán Fómhair', 'Deireadh Fómhair', 'Samhain', 'Nollaig'],
      monthsShort = ['Ean', 'Feabh', 'Márt', 'Aib', 'Beal', 'Meith', 'Iúil', 'Lún', 'M.F.', 'D.F.', 'Samh', 'Noll'],
      weekdays = ['Dé Domhnaigh', 'Dé Luain', 'Dé Máirt', 'Dé Céadaoin', 'Déardaoin', 'Dé hAoine', 'Dé Sathairn'],
      weekdaysShort = ['Domh', 'Luan', 'Máirt', 'Céad', 'Déar', 'Aoine', 'Sath'],
      weekdaysMin = ['Do', 'Lu', 'Má', 'Cé', 'Dé', 'A', 'Sa'];
  var ga = moment.defineLocale('ga', {
    months: months,
    monthsShort: monthsShort,
    monthsParseExact: true,
    weekdays: weekdays,
    weekdaysShort: weekdaysShort,
    weekdaysMin: weekdaysMin,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Inniu ag] LT',
      nextDay: '[Amárach ag] LT',
      nextWeek: 'dddd [ag] LT',
      lastDay: '[Inné ag] LT',
      lastWeek: 'dddd [seo caite] [ag] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'i %s',
      past: '%s ó shin',
      s: 'cúpla soicind',
      ss: '%d soicind',
      m: 'nóiméad',
      mm: '%d nóiméad',
      h: 'uair an chloig',
      hh: '%d uair an chloig',
      d: 'lá',
      dd: '%d lá',
      M: 'mí',
      MM: '%d míonna',
      y: 'bliain',
      yy: '%d bliain'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(d|na|mh)/,
    ordinal: function ordinal(number) {
      var output = number === 1 ? 'd' : number % 10 === 2 ? 'na' : 'mh';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return ga;
});

/***/ }),

/***/ "UXbc":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/mergeMapTo.js ***!
  \*********************************************************************/
/*! exports provided: mergeMapTo */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mergeMapTo", function() { return mergeMapTo; });
/* harmony import */ var _mergeMap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./mergeMap */ "5+tZ");

function mergeMapTo(innerObservable, resultSelector) {
  var concurrent = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Number.POSITIVE_INFINITY;

  if (typeof resultSelector === 'function') {
    return Object(_mergeMap__WEBPACK_IMPORTED_MODULE_0__["mergeMap"])(function () {
      return innerObservable;
    }, resultSelector, concurrent);
  }

  if (typeof resultSelector === 'number') {
    concurrent = resultSelector;
  }

  return Object(_mergeMap__WEBPACK_IMPORTED_MODULE_0__["mergeMap"])(function () {
    return innerObservable;
  }, concurrent);
}

/***/ }),

/***/ "UXun":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/shareReplay.js ***!
  \**********************************************************************/
/*! exports provided: shareReplay */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "shareReplay", function() { return shareReplay; });
/* harmony import */ var _ReplaySubject__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../ReplaySubject */ "jtHE");

function shareReplay(configOrBufferSize, windowTime, scheduler) {
  var config;

  if (configOrBufferSize && typeof configOrBufferSize === 'object') {
    config = configOrBufferSize;
  } else {
    config = {
      bufferSize: configOrBufferSize,
      windowTime: windowTime,
      refCount: false,
      scheduler: scheduler
    };
  }

  return function (source) {
    return source.lift(shareReplayOperator(config));
  };
}

function shareReplayOperator(_ref) {
  var _ref$bufferSize = _ref.bufferSize,
      bufferSize = _ref$bufferSize === void 0 ? Number.POSITIVE_INFINITY : _ref$bufferSize,
      _ref$windowTime = _ref.windowTime,
      windowTime = _ref$windowTime === void 0 ? Number.POSITIVE_INFINITY : _ref$windowTime,
      useRefCount = _ref.refCount,
      scheduler = _ref.scheduler;
  var subject;
  var refCount = 0;
  var subscription;
  var hasError = false;
  var isComplete = false;
  return function shareReplayOperation(source) {
    refCount++;
    var innerSub;

    if (!subject || hasError) {
      hasError = false;
      subject = new _ReplaySubject__WEBPACK_IMPORTED_MODULE_0__["ReplaySubject"](bufferSize, windowTime, scheduler);
      innerSub = subject.subscribe(this);
      subscription = source.subscribe({
        next: function next(value) {
          subject.next(value);
        },
        error: function error(err) {
          hasError = true;
          subject.error(err);
        },
        complete: function complete() {
          isComplete = true;
          subscription = undefined;
          subject.complete();
        }
      });
    } else {
      innerSub = subject.subscribe(this);
    }

    this.add(function () {
      refCount--;
      innerSub.unsubscribe();

      if (subscription && !isComplete && useRefCount && refCount === 0) {
        subscription.unsubscribe();
        subscription = undefined;
        subject = undefined;
      }
    });
  };
}

/***/ }),

/***/ "UpQW":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ur.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Urdu [ur]
//! author : Sawood Alam : https://github.com/ibnesayeed
//! author : Zack : https://github.com/ZackVision
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = ['جنوری', 'فروری', 'مارچ', 'اپریل', 'مئی', 'جون', 'جولائی', 'اگست', 'ستمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
      days = ['اتوار', 'پیر', 'منگل', 'بدھ', 'جمعرات', 'جمعہ', 'ہفتہ'];
  var ur = moment.defineLocale('ur', {
    months: months,
    monthsShort: months,
    weekdays: days,
    weekdaysShort: days,
    weekdaysMin: days,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd، D MMMM YYYY HH:mm'
    },
    meridiemParse: /صبح|شام/,
    isPM: function isPM(input) {
      return 'شام' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'صبح';
      }

      return 'شام';
    },
    calendar: {
      sameDay: '[آج بوقت] LT',
      nextDay: '[کل بوقت] LT',
      nextWeek: 'dddd [بوقت] LT',
      lastDay: '[گذشتہ روز بوقت] LT',
      lastWeek: '[گذشتہ] dddd [بوقت] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s بعد',
      past: '%s قبل',
      s: 'چند سیکنڈ',
      ss: '%d سیکنڈ',
      m: 'ایک منٹ',
      mm: '%d منٹ',
      h: 'ایک گھنٹہ',
      hh: '%d گھنٹے',
      d: 'ایک دن',
      dd: '%d دن',
      M: 'ایک ماہ',
      MM: '%d ماہ',
      y: 'ایک سال',
      yy: '%d سال'
    },
    preparse: function preparse(string) {
      return string.replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/,/g, '،');
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return ur;
});

/***/ }),

/***/ "Ur1D":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ss.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : siSwati [ss]
//! author : Nicolai Davies<mail@nicolai.io> : https://github.com/nicolaidavies
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ss = moment.defineLocale('ss', {
    months: "Bhimbidvwane_Indlovana_Indlov'lenkhulu_Mabasa_Inkhwekhweti_Inhlaba_Kholwane_Ingci_Inyoni_Imphala_Lweti_Ingongoni".split('_'),
    monthsShort: 'Bhi_Ina_Inu_Mab_Ink_Inh_Kho_Igc_Iny_Imp_Lwe_Igo'.split('_'),
    weekdays: 'Lisontfo_Umsombuluko_Lesibili_Lesitsatfu_Lesine_Lesihlanu_Umgcibelo'.split('_'),
    weekdaysShort: 'Lis_Umb_Lsb_Les_Lsi_Lsh_Umg'.split('_'),
    weekdaysMin: 'Li_Us_Lb_Lt_Ls_Lh_Ug'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY h:mm A',
      LLLL: 'dddd, D MMMM YYYY h:mm A'
    },
    calendar: {
      sameDay: '[Namuhla nga] LT',
      nextDay: '[Kusasa nga] LT',
      nextWeek: 'dddd [nga] LT',
      lastDay: '[Itolo nga] LT',
      lastWeek: 'dddd [leliphelile] [nga] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'nga %s',
      past: 'wenteka nga %s',
      s: 'emizuzwana lomcane',
      ss: '%d mzuzwana',
      m: 'umzuzu',
      mm: '%d emizuzu',
      h: 'lihora',
      hh: '%d emahora',
      d: 'lilanga',
      dd: '%d emalanga',
      M: 'inyanga',
      MM: '%d tinyanga',
      y: 'umnyaka',
      yy: '%d iminyaka'
    },
    meridiemParse: /ekuseni|emini|entsambama|ebusuku/,
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 11) {
        return 'ekuseni';
      } else if (hours < 15) {
        return 'emini';
      } else if (hours < 19) {
        return 'entsambama';
      } else {
        return 'ebusuku';
      }
    },
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'ekuseni') {
        return hour;
      } else if (meridiem === 'emini') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === 'entsambama' || meridiem === 'ebusuku') {
        if (hour === 0) {
          return 0;
        }

        return hour + 12;
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}/,
    ordinal: '%d',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return ss;
});

/***/ }),

/***/ "V2x9":
/*!*******************************************!*\
  !*** ./node_modules/moment/locale/tet.js ***!
  \*******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Tetun Dili (East Timor) [tet]
//! author : Joshua Brooks : https://github.com/joshbrooks
//! author : Onorio De J. Afonso : https://github.com/marobo
//! author : Sonia Simoes : https://github.com/soniasimoes
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var tet = moment.defineLocale('tet', {
    months: 'Janeiru_Fevereiru_Marsu_Abril_Maiu_Juñu_Jullu_Agustu_Setembru_Outubru_Novembru_Dezembru'.split('_'),
    monthsShort: 'Jan_Fev_Mar_Abr_Mai_Jun_Jul_Ago_Set_Out_Nov_Dez'.split('_'),
    weekdays: 'Domingu_Segunda_Tersa_Kuarta_Kinta_Sesta_Sabadu'.split('_'),
    weekdaysShort: 'Dom_Seg_Ters_Kua_Kint_Sest_Sab'.split('_'),
    weekdaysMin: 'Do_Seg_Te_Ku_Ki_Ses_Sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Ohin iha] LT',
      nextDay: '[Aban iha] LT',
      nextWeek: 'dddd [iha] LT',
      lastDay: '[Horiseik iha] LT',
      lastWeek: 'dddd [semana kotuk] [iha] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'iha %s',
      past: '%s liuba',
      s: 'segundu balun',
      ss: 'segundu %d',
      m: 'minutu ida',
      mm: 'minutu %d',
      h: 'oras ida',
      hh: 'oras %d',
      d: 'loron ida',
      dd: 'loron %d',
      M: 'fulan ida',
      MM: 'fulan %d',
      y: 'tinan ida',
      yy: 'tinan %d'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return tet;
});

/***/ }),

/***/ "VRyK":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/merge.js ***!
  \*****************************************************************/
/*! exports provided: merge */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "merge", function() { return merge; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");
/* harmony import */ var _operators_mergeAll__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../operators/mergeAll */ "bHdf");
/* harmony import */ var _fromArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./fromArray */ "yCtX");




function merge() {
  var concurrent = Number.POSITIVE_INFINITY;
  var scheduler = null;

  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  var last = observables[observables.length - 1];

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_1__["isScheduler"])(last)) {
    scheduler = observables.pop();

    if (observables.length > 1 && typeof observables[observables.length - 1] === 'number') {
      concurrent = observables.pop();
    }
  } else if (typeof last === 'number') {
    concurrent = observables.pop();
  }

  if (scheduler === null && observables.length === 1 && observables[0] instanceof _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"]) {
    return observables[0];
  }

  return Object(_operators_mergeAll__WEBPACK_IMPORTED_MODULE_2__["mergeAll"])(concurrent)(Object(_fromArray__WEBPACK_IMPORTED_MODULE_3__["fromArray"])(observables, scheduler));
}

/***/ }),

/***/ "Vclq":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/es-us.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Spanish (United States) [es-us]
//! author : bustta : https://github.com/bustta
//! author : chrisrodz : https://github.com/chrisrodz
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortDot = 'ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.'.split('_'),
      _monthsShort = 'ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic'.split('_'),
      monthsParse = [/^ene/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i],
      monthsRegex = /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;

  var esUs = moment.defineLocale('es-us', {
    months: 'enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortDot;
      } else if (/-MMM-/.test(format)) {
        return _monthsShort[m.month()];
      } else {
        return monthsShortDot[m.month()];
      }
    },
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,
    monthsShortStrictRegex: /^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'domingo_lunes_martes_miércoles_jueves_viernes_sábado'.split('_'),
    weekdaysShort: 'dom._lun._mar._mié._jue._vie._sáb.'.split('_'),
    weekdaysMin: 'do_lu_ma_mi_ju_vi_sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'MM/DD/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY h:mm A',
      LLLL: 'dddd, D [de] MMMM [de] YYYY h:mm A'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[hoy a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextDay: function nextDay() {
        return '[mañana a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastDay: function lastDay() {
        return '[ayer a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastWeek: function lastWeek() {
        return '[el] dddd [pasado a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'en %s',
      past: 'hace %s',
      s: 'unos segundos',
      ss: '%d segundos',
      m: 'un minuto',
      mm: '%d minutos',
      h: 'una hora',
      hh: '%d horas',
      d: 'un día',
      dd: '%d días',
      w: 'una semana',
      ww: '%d semanas',
      M: 'un mes',
      MM: '%d meses',
      y: 'un año',
      yy: '%d años'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return esUs;
});

/***/ }),

/***/ "Vpsf":
/*!*******************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/AnimationFrameAction.js ***!
  \*******************************************************************************/
/*! exports provided: AnimationFrameAction */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AnimationFrameAction", function() { return AnimationFrameAction; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _AsyncAction__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./AsyncAction */ "3N8a");







var AnimationFrameAction = /*#__PURE__*/function (_AsyncAction) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(AnimationFrameAction, _AsyncAction);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(AnimationFrameAction);

  function AnimationFrameAction(scheduler, work) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AnimationFrameAction);

    _this = _super.call(this, scheduler, work);
    _this.scheduler = scheduler;
    _this.work = work;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AnimationFrameAction, [{
    key: "requestAsyncId",
    value: function requestAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

      if (delay !== null && delay > 0) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AnimationFrameAction.prototype), "requestAsyncId", this).call(this, scheduler, id, delay);
      }

      scheduler.actions.push(this);
      return scheduler.scheduled || (scheduler.scheduled = requestAnimationFrame(function () {
        return scheduler.flush(null);
      }));
    }
  }, {
    key: "recycleAsyncId",
    value: function recycleAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

      if (delay !== null && delay > 0 || delay === null && this.delay > 0) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(AnimationFrameAction.prototype), "recycleAsyncId", this).call(this, scheduler, id, delay);
      }

      if (scheduler.actions.length === 0) {
        cancelAnimationFrame(id);
        scheduler.scheduled = undefined;
      }

      return undefined;
    }
  }]);

  return AnimationFrameAction;
}(_AsyncAction__WEBPACK_IMPORTED_MODULE_6__["AsyncAction"]);

/***/ }),

/***/ "WMd4":
/*!*************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Notification.js ***!
  \*************************************************************/
/*! exports provided: NotificationKind, Notification */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NotificationKind", function() { return NotificationKind; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Notification", function() { return Notification; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _observable_empty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./observable/empty */ "EY2u");
/* harmony import */ var _observable_of__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./observable/of */ "LRne");
/* harmony import */ var _observable_throwError__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./observable/throwError */ "z6cu");





var NotificationKind;

(function (NotificationKind) {
  NotificationKind["NEXT"] = "N";
  NotificationKind["ERROR"] = "E";
  NotificationKind["COMPLETE"] = "C";
})(NotificationKind || (NotificationKind = {}));

var Notification = /*#__PURE__*/function () {
  function Notification(kind, value, error) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Notification);

    this.kind = kind;
    this.value = value;
    this.error = error;
    this.hasValue = kind === 'N';
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Notification, [{
    key: "observe",
    value: function observe(observer) {
      switch (this.kind) {
        case 'N':
          return observer.next && observer.next(this.value);

        case 'E':
          return observer.error && observer.error(this.error);

        case 'C':
          return observer.complete && observer.complete();
      }
    }
  }, {
    key: "do",
    value: function _do(next, error, complete) {
      var kind = this.kind;

      switch (kind) {
        case 'N':
          return next && next(this.value);

        case 'E':
          return error && error(this.error);

        case 'C':
          return complete && complete();
      }
    }
  }, {
    key: "accept",
    value: function accept(nextOrObserver, error, complete) {
      if (nextOrObserver && typeof nextOrObserver.next === 'function') {
        return this.observe(nextOrObserver);
      } else {
        return this.do(nextOrObserver, error, complete);
      }
    }
  }, {
    key: "toObservable",
    value: function toObservable() {
      var kind = this.kind;

      switch (kind) {
        case 'N':
          return Object(_observable_of__WEBPACK_IMPORTED_MODULE_3__["of"])(this.value);

        case 'E':
          return Object(_observable_throwError__WEBPACK_IMPORTED_MODULE_4__["throwError"])(this.error);

        case 'C':
          return Object(_observable_empty__WEBPACK_IMPORTED_MODULE_2__["empty"])();
      }

      throw new Error('unexpected notification kind value');
    }
  }], [{
    key: "createNext",
    value: function createNext(value) {
      if (typeof value !== 'undefined') {
        return new Notification('N', value);
      }

      return Notification.undefinedValueNotification;
    }
  }, {
    key: "createError",
    value: function createError(err) {
      return new Notification('E', undefined, err);
    }
  }, {
    key: "createComplete",
    value: function createComplete() {
      return Notification.completeNotification;
    }
  }]);

  return Notification;
}();
Notification.completeNotification = new Notification('C');
Notification.undefinedValueNotification = new Notification('N', undefined);

/***/ }),

/***/ "WPMC":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/generate.js ***!
  \********************************************************************/
/*! exports provided: generate */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "generate", function() { return generate; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_identity__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/identity */ "SpAZ");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");



function generate(initialStateOrOptions, condition, iterate, resultSelectorOrObservable, scheduler) {
  var resultSelector;
  var initialState;

  if (arguments.length == 1) {
    var options = initialStateOrOptions;
    initialState = options.initialState;
    condition = options.condition;
    iterate = options.iterate;
    resultSelector = options.resultSelector || _util_identity__WEBPACK_IMPORTED_MODULE_1__["identity"];
    scheduler = options.scheduler;
  } else if (resultSelectorOrObservable === undefined || Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_2__["isScheduler"])(resultSelectorOrObservable)) {
    initialState = initialStateOrOptions;
    resultSelector = _util_identity__WEBPACK_IMPORTED_MODULE_1__["identity"];
    scheduler = resultSelectorOrObservable;
  } else {
    initialState = initialStateOrOptions;
    resultSelector = resultSelectorOrObservable;
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var state = initialState;

    if (scheduler) {
      return scheduler.schedule(dispatch, 0, {
        subscriber: subscriber,
        iterate: iterate,
        condition: condition,
        resultSelector: resultSelector,
        state: state
      });
    }

    do {
      if (condition) {
        var conditionResult = void 0;

        try {
          conditionResult = condition(state);
        } catch (err) {
          subscriber.error(err);
          return undefined;
        }

        if (!conditionResult) {
          subscriber.complete();
          break;
        }
      }

      var value = void 0;

      try {
        value = resultSelector(state);
      } catch (err) {
        subscriber.error(err);
        return undefined;
      }

      subscriber.next(value);

      if (subscriber.closed) {
        break;
      }

      try {
        state = iterate(state);
      } catch (err) {
        subscriber.error(err);
        return undefined;
      }
    } while (true);

    return undefined;
  });
}

function dispatch(state) {
  var subscriber = state.subscriber,
      condition = state.condition;

  if (subscriber.closed) {
    return undefined;
  }

  if (state.needIterate) {
    try {
      state.state = state.iterate(state.state);
    } catch (err) {
      subscriber.error(err);
      return undefined;
    }
  } else {
    state.needIterate = true;
  }

  if (condition) {
    var conditionResult;

    try {
      conditionResult = condition(state.state);
    } catch (err) {
      subscriber.error(err);
      return undefined;
    }

    if (!conditionResult) {
      subscriber.complete();
      return undefined;
    }

    if (subscriber.closed) {
      return undefined;
    }
  }

  var value;

  try {
    value = state.resultSelector(state.state);
  } catch (err) {
    subscriber.error(err);
    return undefined;
  }

  if (subscriber.closed) {
    return undefined;
  }

  subscriber.next(value);

  if (subscriber.closed) {
    return undefined;
  }

  return this.schedule(state);
}

/***/ }),

/***/ "WYrj":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/dv.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Maldivian [dv]
//! author : Jawish Hameed : https://github.com/jawish
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = ['ޖެނުއަރީ', 'ފެބްރުއަރީ', 'މާރިޗު', 'އޭޕްރީލު', 'މޭ', 'ޖޫން', 'ޖުލައި', 'އޯގަސްޓު', 'ސެޕްޓެމްބަރު', 'އޮކްޓޯބަރު', 'ނޮވެމްބަރު', 'ޑިސެމްބަރު'],
      weekdays = ['އާދިއްތަ', 'ހޯމަ', 'އަންގާރަ', 'ބުދަ', 'ބުރާސްފަތި', 'ހުކުރު', 'ހޮނިހިރު'];
  var dv = moment.defineLocale('dv', {
    months: months,
    monthsShort: months,
    weekdays: weekdays,
    weekdaysShort: weekdays,
    weekdaysMin: 'އާދި_ހޯމަ_އަން_ބުދަ_ބުރާ_ހުކު_ހޮނި'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'D/M/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    meridiemParse: /މކ|މފ/,
    isPM: function isPM(input) {
      return 'މފ' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'މކ';
      } else {
        return 'މފ';
      }
    },
    calendar: {
      sameDay: '[މިއަދު] LT',
      nextDay: '[މާދަމާ] LT',
      nextWeek: 'dddd LT',
      lastDay: '[އިއްޔެ] LT',
      lastWeek: '[ފާއިތުވި] dddd LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'ތެރޭގައި %s',
      past: 'ކުރިން %s',
      s: 'ސިކުންތުކޮޅެއް',
      ss: 'd% ސިކުންތު',
      m: 'މިނިޓެއް',
      mm: 'މިނިޓު %d',
      h: 'ގަޑިއިރެއް',
      hh: 'ގަޑިއިރު %d',
      d: 'ދުވަހެއް',
      dd: 'ދުވަސް %d',
      M: 'މަހެއް',
      MM: 'މަސް %d',
      y: 'އަހަރެއް',
      yy: 'އަހަރު %d'
    },
    preparse: function preparse(string) {
      return string.replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/,/g, '،');
    },
    week: {
      dow: 7,
      // Sunday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return dv;
});

/***/ }),

/***/ "Wv91":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/tk.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Turkmen [tk]
//! author : Atamyrat Abdyrahmanov : https://github.com/atamyratabdy
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var suffixes = {
    1: "'inji",
    5: "'inji",
    8: "'inji",
    70: "'inji",
    80: "'inji",
    2: "'nji",
    7: "'nji",
    20: "'nji",
    50: "'nji",
    3: "'ünji",
    4: "'ünji",
    100: "'ünji",
    6: "'njy",
    9: "'unjy",
    10: "'unjy",
    30: "'unjy",
    60: "'ynjy",
    90: "'ynjy"
  };
  var tk = moment.defineLocale('tk', {
    months: 'Ýanwar_Fewral_Mart_Aprel_Maý_Iýun_Iýul_Awgust_Sentýabr_Oktýabr_Noýabr_Dekabr'.split('_'),
    monthsShort: 'Ýan_Few_Mar_Apr_Maý_Iýn_Iýl_Awg_Sen_Okt_Noý_Dek'.split('_'),
    weekdays: 'Ýekşenbe_Duşenbe_Sişenbe_Çarşenbe_Penşenbe_Anna_Şenbe'.split('_'),
    weekdaysShort: 'Ýek_Duş_Siş_Çar_Pen_Ann_Şen'.split('_'),
    weekdaysMin: 'Ýk_Dş_Sş_Çr_Pn_An_Şn'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[bugün sagat] LT',
      nextDay: '[ertir sagat] LT',
      nextWeek: '[indiki] dddd [sagat] LT',
      lastDay: '[düýn] LT',
      lastWeek: '[geçen] dddd [sagat] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s soň',
      past: '%s öň',
      s: 'birnäçe sekunt',
      m: 'bir minut',
      mm: '%d minut',
      h: 'bir sagat',
      hh: '%d sagat',
      d: 'bir gün',
      dd: '%d gün',
      M: 'bir aý',
      MM: '%d aý',
      y: 'bir ýyl',
      yy: '%d ýyl'
    },
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'Do':
        case 'DD':
          return number;

        default:
          if (number === 0) {
            // special case for zero
            return number + "'unjy";
          }

          var a = number % 10,
              b = number % 100 - a,
              c = number >= 100 ? 100 : null;
          return number + (suffixes[a] || suffixes[b] || suffixes[c]);
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return tk;
});

/***/ }),

/***/ "WxRl":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/hu.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Hungarian [hu]
//! author : Adam Brunner : https://github.com/adambrunner
//! author : Peter Viszt  : https://github.com/passatgt
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var weekEndings = 'vasárnap hétfőn kedden szerdán csütörtökön pénteken szombaton'.split(' ');

  function translate(number, withoutSuffix, key, isFuture) {
    var num = number;

    switch (key) {
      case 's':
        return isFuture || withoutSuffix ? 'néhány másodperc' : 'néhány másodperce';

      case 'ss':
        return num + (isFuture || withoutSuffix) ? ' másodperc' : ' másodperce';

      case 'm':
        return 'egy' + (isFuture || withoutSuffix ? ' perc' : ' perce');

      case 'mm':
        return num + (isFuture || withoutSuffix ? ' perc' : ' perce');

      case 'h':
        return 'egy' + (isFuture || withoutSuffix ? ' óra' : ' órája');

      case 'hh':
        return num + (isFuture || withoutSuffix ? ' óra' : ' órája');

      case 'd':
        return 'egy' + (isFuture || withoutSuffix ? ' nap' : ' napja');

      case 'dd':
        return num + (isFuture || withoutSuffix ? ' nap' : ' napja');

      case 'M':
        return 'egy' + (isFuture || withoutSuffix ? ' hónap' : ' hónapja');

      case 'MM':
        return num + (isFuture || withoutSuffix ? ' hónap' : ' hónapja');

      case 'y':
        return 'egy' + (isFuture || withoutSuffix ? ' év' : ' éve');

      case 'yy':
        return num + (isFuture || withoutSuffix ? ' év' : ' éve');
    }

    return '';
  }

  function week(isFuture) {
    return (isFuture ? '' : '[múlt] ') + '[' + weekEndings[this.day()] + '] LT[-kor]';
  }

  var hu = moment.defineLocale('hu', {
    months: 'január_február_március_április_május_június_július_augusztus_szeptember_október_november_december'.split('_'),
    monthsShort: 'jan._feb._márc._ápr._máj._jún._júl._aug._szept._okt._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'vasárnap_hétfő_kedd_szerda_csütörtök_péntek_szombat'.split('_'),
    weekdaysShort: 'vas_hét_kedd_sze_csüt_pén_szo'.split('_'),
    weekdaysMin: 'v_h_k_sze_cs_p_szo'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'YYYY.MM.DD.',
      LL: 'YYYY. MMMM D.',
      LLL: 'YYYY. MMMM D. H:mm',
      LLLL: 'YYYY. MMMM D., dddd H:mm'
    },
    meridiemParse: /de|du/i,
    isPM: function isPM(input) {
      return input.charAt(1).toLowerCase() === 'u';
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 12) {
        return isLower === true ? 'de' : 'DE';
      } else {
        return isLower === true ? 'du' : 'DU';
      }
    },
    calendar: {
      sameDay: '[ma] LT[-kor]',
      nextDay: '[holnap] LT[-kor]',
      nextWeek: function nextWeek() {
        return week.call(this, true);
      },
      lastDay: '[tegnap] LT[-kor]',
      lastWeek: function lastWeek() {
        return week.call(this, false);
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s múlva',
      past: '%s',
      s: translate,
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: translate,
      dd: translate,
      M: translate,
      MM: translate,
      y: translate,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return hu;
});

/***/ }),

/***/ "WyKG":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/toSubscriber.js ***!
  \******************************************************************/
/*! exports provided: toSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "toSubscriber", function() { return toSubscriber; });
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../symbol/rxSubscriber */ "2QA8");
/* harmony import */ var _Observer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../Observer */ "gRHU");



function toSubscriber(nextOrObserver, error, complete) {
  if (nextOrObserver) {
    if (nextOrObserver instanceof _Subscriber__WEBPACK_IMPORTED_MODULE_0__["Subscriber"]) {
      return nextOrObserver;
    }

    if (nextOrObserver[_symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_1__["rxSubscriber"]]) {
      return nextOrObserver[_symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_1__["rxSubscriber"]]();
    }
  }

  if (!nextOrObserver && !error && !complete) {
    return new _Subscriber__WEBPACK_IMPORTED_MODULE_0__["Subscriber"](_Observer__WEBPACK_IMPORTED_MODULE_2__["empty"]);
  }

  return new _Subscriber__WEBPACK_IMPORTED_MODULE_0__["Subscriber"](nextOrObserver, error, complete);
}

/***/ }),

/***/ "X709":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sv.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Swedish [sv]
//! author : Jens Alm : https://github.com/ulmus
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var sv = moment.defineLocale('sv', {
    months: 'januari_februari_mars_april_maj_juni_juli_augusti_september_oktober_november_december'.split('_'),
    monthsShort: 'jan_feb_mar_apr_maj_jun_jul_aug_sep_okt_nov_dec'.split('_'),
    weekdays: 'söndag_måndag_tisdag_onsdag_torsdag_fredag_lördag'.split('_'),
    weekdaysShort: 'sön_mån_tis_ons_tor_fre_lör'.split('_'),
    weekdaysMin: 'sö_må_ti_on_to_fr_lö'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY [kl.] HH:mm',
      LLLL: 'dddd D MMMM YYYY [kl.] HH:mm',
      lll: 'D MMM YYYY HH:mm',
      llll: 'ddd D MMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Idag] LT',
      nextDay: '[Imorgon] LT',
      lastDay: '[Igår] LT',
      nextWeek: '[På] dddd LT',
      lastWeek: '[I] dddd[s] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'om %s',
      past: 'för %s sedan',
      s: 'några sekunder',
      ss: '%d sekunder',
      m: 'en minut',
      mm: '%d minuter',
      h: 'en timme',
      hh: '%d timmar',
      d: 'en dag',
      dd: '%d dagar',
      M: 'en månad',
      MM: '%d månader',
      y: 'ett år',
      yy: '%d år'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(\:e|\:a)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? ':e' : b === 1 ? ':a' : b === 2 ? ':a' : b === 3 ? ':e' : ':e';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return sv;
});

/***/ }),

/***/ "XDbj":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/throwIfEmpty.js ***!
  \***********************************************************************/
/*! exports provided: throwIfEmpty */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "throwIfEmpty", function() { return throwIfEmpty; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _util_EmptyError__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/EmptyError */ "sVev");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");






function throwIfEmpty() {
  var errorFactory = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultErrorFactory;
  return function (source) {
    return source.lift(new ThrowIfEmptyOperator(errorFactory));
  };
}

var ThrowIfEmptyOperator = /*#__PURE__*/function () {
  function ThrowIfEmptyOperator(errorFactory) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ThrowIfEmptyOperator);

    this.errorFactory = errorFactory;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ThrowIfEmptyOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ThrowIfEmptySubscriber(subscriber, this.errorFactory));
    }
  }]);

  return ThrowIfEmptyOperator;
}();

var ThrowIfEmptySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ThrowIfEmptySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ThrowIfEmptySubscriber);

  function ThrowIfEmptySubscriber(destination, errorFactory) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ThrowIfEmptySubscriber);

    _this = _super.call(this, destination);
    _this.errorFactory = errorFactory;
    _this.hasValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ThrowIfEmptySubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.hasValue = true;
      this.destination.next(value);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      if (!this.hasValue) {
        var err;

        try {
          err = this.errorFactory();
        } catch (e) {
          err = e;
        }

        this.destination.error(err);
      } else {
        return this.destination.complete();
      }
    }
  }]);

  return ThrowIfEmptySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

function defaultErrorFactory() {
  return new _util_EmptyError__WEBPACK_IMPORTED_MODULE_4__["EmptyError"]();
}

/***/ }),

/***/ "XDpg":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/zh-cn.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Chinese (China) [zh-cn]
//! author : suupic : https://github.com/suupic
//! author : Zeno Zeng : https://github.com/zenozeng
//! author : uu109 : https://github.com/uu109
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var zhCn = moment.defineLocale('zh-cn', {
    months: '一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月'.split('_'),
    monthsShort: '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
    weekdays: '星期日_星期一_星期二_星期三_星期四_星期五_星期六'.split('_'),
    weekdaysShort: '周日_周一_周二_周三_周四_周五_周六'.split('_'),
    weekdaysMin: '日_一_二_三_四_五_六'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY/MM/DD',
      LL: 'YYYY年M月D日',
      LLL: 'YYYY年M月D日Ah点mm分',
      LLLL: 'YYYY年M月D日ddddAh点mm分',
      l: 'YYYY/M/D',
      ll: 'YYYY年M月D日',
      lll: 'YYYY年M月D日 HH:mm',
      llll: 'YYYY年M月D日dddd HH:mm'
    },
    meridiemParse: /凌晨|早上|上午|中午|下午|晚上/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === '凌晨' || meridiem === '早上' || meridiem === '上午') {
        return hour;
      } else if (meridiem === '下午' || meridiem === '晚上') {
        return hour + 12;
      } else {
        // '中午'
        return hour >= 11 ? hour : hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      var hm = hour * 100 + minute;

      if (hm < 600) {
        return '凌晨';
      } else if (hm < 900) {
        return '早上';
      } else if (hm < 1130) {
        return '上午';
      } else if (hm < 1230) {
        return '中午';
      } else if (hm < 1800) {
        return '下午';
      } else {
        return '晚上';
      }
    },
    calendar: {
      sameDay: '[今天]LT',
      nextDay: '[明天]LT',
      nextWeek: function nextWeek(now) {
        if (now.week() !== this.week()) {
          return '[下]dddLT';
        } else {
          return '[本]dddLT';
        }
      },
      lastDay: '[昨天]LT',
      lastWeek: function lastWeek(now) {
        if (this.week() !== now.week()) {
          return '[上]dddLT';
        } else {
          return '[本]dddLT';
        }
      },
      sameElse: 'L'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(日|月|周)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + '日';

        case 'M':
          return number + '月';

        case 'w':
        case 'W':
          return number + '周';

        default:
          return number;
      }
    },
    relativeTime: {
      future: '%s后',
      past: '%s前',
      s: '几秒',
      ss: '%d 秒',
      m: '1 分钟',
      mm: '%d 分钟',
      h: '1 小时',
      hh: '%d 小时',
      d: '1 天',
      dd: '%d 天',
      w: '1 周',
      ww: '%d 周',
      M: '1 个月',
      MM: '%d 个月',
      y: '1 年',
      yy: '%d 年'
    },
    week: {
      // GB/T 7408-1994《数据元和交换格式·信息交换·日期和时间表示法》与ISO 8601:1988等效
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return zhCn;
});

/***/ }),

/***/ "XLvN":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/te.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Telugu [te]
//! author : Krishna Chaitanya Thota : https://github.com/kcthota
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var te = moment.defineLocale('te', {
    months: 'జనవరి_ఫిబ్రవరి_మార్చి_ఏప్రిల్_మే_జూన్_జులై_ఆగస్టు_సెప్టెంబర్_అక్టోబర్_నవంబర్_డిసెంబర్'.split('_'),
    monthsShort: 'జన._ఫిబ్ర._మార్చి_ఏప్రి._మే_జూన్_జులై_ఆగ._సెప్._అక్టో._నవ._డిసె.'.split('_'),
    monthsParseExact: true,
    weekdays: 'ఆదివారం_సోమవారం_మంగళవారం_బుధవారం_గురువారం_శుక్రవారం_శనివారం'.split('_'),
    weekdaysShort: 'ఆది_సోమ_మంగళ_బుధ_గురు_శుక్ర_శని'.split('_'),
    weekdaysMin: 'ఆ_సో_మం_బు_గు_శు_శ'.split('_'),
    longDateFormat: {
      LT: 'A h:mm',
      LTS: 'A h:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm',
      LLLL: 'dddd, D MMMM YYYY, A h:mm'
    },
    calendar: {
      sameDay: '[నేడు] LT',
      nextDay: '[రేపు] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[నిన్న] LT',
      lastWeek: '[గత] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s లో',
      past: '%s క్రితం',
      s: 'కొన్ని క్షణాలు',
      ss: '%d సెకన్లు',
      m: 'ఒక నిమిషం',
      mm: '%d నిమిషాలు',
      h: 'ఒక గంట',
      hh: '%d గంటలు',
      d: 'ఒక రోజు',
      dd: '%d రోజులు',
      M: 'ఒక నెల',
      MM: '%d నెలలు',
      y: 'ఒక సంవత్సరం',
      yy: '%d సంవత్సరాలు'
    },
    dayOfMonthOrdinalParse: /\d{1,2}వ/,
    ordinal: '%dవ',
    meridiemParse: /రాత్రి|ఉదయం|మధ్యాహ్నం|సాయంత్రం/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'రాత్రి') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'ఉదయం') {
        return hour;
      } else if (meridiem === 'మధ్యాహ్నం') {
        return hour >= 10 ? hour : hour + 12;
      } else if (meridiem === 'సాయంత్రం') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'రాత్రి';
      } else if (hour < 10) {
        return 'ఉదయం';
      } else if (hour < 17) {
        return 'మధ్యాహ్నం';
      } else if (hour < 20) {
        return 'సాయంత్రం';
      } else {
        return 'రాత్రి';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return te;
});

/***/ }),

/***/ "XNiG":
/*!********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Subject.js ***!
  \********************************************************/
/*! exports provided: SubjectSubscriber, Subject, AnonymousSubject */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SubjectSubscriber", function() { return SubjectSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Subject", function() { return Subject; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AnonymousSubject", function() { return AnonymousSubject; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./Observable */ "HDdC");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./Subscriber */ "7o/Q");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./Subscription */ "quSY");
/* harmony import */ var _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./util/ObjectUnsubscribedError */ "9ppp");
/* harmony import */ var _SubjectSubscription__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./SubjectSubscription */ "Ylt2");
/* harmony import */ var _internal_symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../internal/symbol/rxSubscriber */ "2QA8");












var SubjectSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(SubjectSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(SubjectSubscriber);

  function SubjectSubscriber(destination) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, SubjectSubscriber);

    _this = _super.call(this, destination);
    _this.destination = destination;
    return _this;
  }

  return SubjectSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_7__["Subscriber"]);
var Subject = /*#__PURE__*/function (_Observable) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(Subject, _Observable);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(Subject);

  function Subject() {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, Subject);

    _this2 = _super2.call(this);
    _this2.observers = [];
    _this2.closed = false;
    _this2.isStopped = false;
    _this2.hasError = false;
    _this2.thrownError = null;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_0__["default"])(Subject, [{
    key: _internal_symbol_rxSubscriber__WEBPACK_IMPORTED_MODULE_11__["rxSubscriber"],
    value: function value() {
      return new SubjectSubscriber(this);
    }
  }, {
    key: "lift",
    value: function lift(operator) {
      var subject = new AnonymousSubject(this, this);
      subject.operator = operator;
      return subject;
    }
  }, {
    key: "next",
    value: function next(value) {
      if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_9__["ObjectUnsubscribedError"]();
      }

      if (!this.isStopped) {
        var observers = this.observers;
        var len = observers.length;
        var copy = observers.slice();

        for (var i = 0; i < len; i++) {
          copy[i].next(value);
        }
      }
    }
  }, {
    key: "error",
    value: function error(err) {
      if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_9__["ObjectUnsubscribedError"]();
      }

      this.hasError = true;
      this.thrownError = err;
      this.isStopped = true;
      var observers = this.observers;
      var len = observers.length;
      var copy = observers.slice();

      for (var i = 0; i < len; i++) {
        copy[i].error(err);
      }

      this.observers.length = 0;
    }
  }, {
    key: "complete",
    value: function complete() {
      if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_9__["ObjectUnsubscribedError"]();
      }

      this.isStopped = true;
      var observers = this.observers;
      var len = observers.length;
      var copy = observers.slice();

      for (var i = 0; i < len; i++) {
        copy[i].complete();
      }

      this.observers.length = 0;
    }
  }, {
    key: "unsubscribe",
    value: function unsubscribe() {
      this.isStopped = true;
      this.closed = true;
      this.observers = null;
    }
  }, {
    key: "_trySubscribe",
    value: function _trySubscribe(subscriber) {
      if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_9__["ObjectUnsubscribedError"]();
      } else {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(Subject.prototype), "_trySubscribe", this).call(this, subscriber);
      }
    }
  }, {
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_9__["ObjectUnsubscribedError"]();
      } else if (this.hasError) {
        subscriber.error(this.thrownError);
        return _Subscription__WEBPACK_IMPORTED_MODULE_8__["Subscription"].EMPTY;
      } else if (this.isStopped) {
        subscriber.complete();
        return _Subscription__WEBPACK_IMPORTED_MODULE_8__["Subscription"].EMPTY;
      } else {
        this.observers.push(subscriber);
        return new _SubjectSubscription__WEBPACK_IMPORTED_MODULE_10__["SubjectSubscription"](this, subscriber);
      }
    }
  }, {
    key: "asObservable",
    value: function asObservable() {
      var observable = new _Observable__WEBPACK_IMPORTED_MODULE_6__["Observable"]();
      observable.source = this;
      return observable;
    }
  }]);

  return Subject;
}(_Observable__WEBPACK_IMPORTED_MODULE_6__["Observable"]);

Subject.create = function (destination, source) {
  return new AnonymousSubject(destination, source);
};

var AnonymousSubject = /*#__PURE__*/function (_Subject) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(AnonymousSubject, _Subject);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(AnonymousSubject);

  function AnonymousSubject(destination, source) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, AnonymousSubject);

    _this3 = _super3.call(this);
    _this3.destination = destination;
    _this3.source = source;
    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_0__["default"])(AnonymousSubject, [{
    key: "next",
    value: function next(value) {
      var destination = this.destination;

      if (destination && destination.next) {
        destination.next(value);
      }
    }
  }, {
    key: "error",
    value: function error(err) {
      var destination = this.destination;

      if (destination && destination.error) {
        this.destination.error(err);
      }
    }
  }, {
    key: "complete",
    value: function complete() {
      var destination = this.destination;

      if (destination && destination.complete) {
        this.destination.complete();
      }
    }
  }, {
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      var source = this.source;

      if (source) {
        return this.source.subscribe(subscriber);
      } else {
        return _Subscription__WEBPACK_IMPORTED_MODULE_8__["Subscription"].EMPTY;
      }
    }
  }]);

  return AnonymousSubject;
}(Subject);

/***/ }),

/***/ "XTTE":
/*!******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/superPropBase.js ***!
  \******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _superPropBase; });
/* harmony import */ var _getPrototypeOf__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./getPrototypeOf */ "foSv");

function _superPropBase(object, property) {
  while (!Object.prototype.hasOwnProperty.call(object, property)) {
    object = Object(_getPrototypeOf__WEBPACK_IMPORTED_MODULE_0__["default"])(object);
    if (object === null) break;
  }

  return object;
}

/***/ }),

/***/ "XoHu":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isObject.js ***!
  \**************************************************************/
/*! exports provided: isObject */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isObject", function() { return isObject; });
function isObject(x) {
  return x !== null && typeof x === 'object';
}

/***/ }),

/***/ "XqQ8":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/exhaustMap.js ***!
  \*********************************************************************/
/*! exports provided: exhaustMap */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "exhaustMap", function() { return exhaustMap; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./map */ "lJxs");
/* harmony import */ var _observable_from__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../observable/from */ "Cfvw");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");







function exhaustMap(project, resultSelector) {
  if (resultSelector) {
    return function (source) {
      return source.pipe(exhaustMap(function (a, i) {
        return Object(_observable_from__WEBPACK_IMPORTED_MODULE_5__["from"])(project(a, i)).pipe(Object(_map__WEBPACK_IMPORTED_MODULE_4__["map"])(function (b, ii) {
          return resultSelector(a, b, i, ii);
        }));
      }));
    };
  }

  return function (source) {
    return source.lift(new ExhaustMapOperator(project));
  };
}

var ExhaustMapOperator = /*#__PURE__*/function () {
  function ExhaustMapOperator(project) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ExhaustMapOperator);

    this.project = project;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ExhaustMapOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ExhaustMapSubscriber(subscriber, this.project));
    }
  }]);

  return ExhaustMapOperator;
}();

var ExhaustMapSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ExhaustMapSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ExhaustMapSubscriber);

  function ExhaustMapSubscriber(destination, project) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ExhaustMapSubscriber);

    _this = _super.call(this, destination);
    _this.project = project;
    _this.hasSubscription = false;
    _this.hasCompleted = false;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ExhaustMapSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (!this.hasSubscription) {
        this.tryNext(value);
      }
    }
  }, {
    key: "tryNext",
    value: function tryNext(value) {
      var result;
      var index = this.index++;

      try {
        result = this.project(value, index);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.hasSubscription = true;

      this._innerSub(result);
    }
  }, {
    key: "_innerSub",
    value: function _innerSub(result) {
      var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleInnerSubscriber"](this);
      var destination = this.destination;
      destination.add(innerSubscriber);
      var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["innerSubscribe"])(result, innerSubscriber);

      if (innerSubscription !== innerSubscriber) {
        destination.add(innerSubscription);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.hasCompleted = true;

      if (!this.hasSubscription) {
        this.destination.complete();
      }

      this.unsubscribe();
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      this.destination.next(innerValue);
    }
  }, {
    key: "notifyError",
    value: function notifyError(err) {
      this.destination.error(err);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.hasSubscription = false;

      if (this.hasCompleted) {
        this.destination.complete();
      }
    }
  }]);

  return ExhaustMapSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "Y/cZ":
/*!**********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Scheduler.js ***!
  \**********************************************************/
/*! exports provided: Scheduler */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Scheduler", function() { return Scheduler; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");


var Scheduler = /*#__PURE__*/function () {
  function Scheduler(SchedulerAction) {
    var now = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Scheduler.now;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Scheduler);

    this.SchedulerAction = SchedulerAction;
    this.now = now;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Scheduler, [{
    key: "schedule",
    value: function schedule(work) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var state = arguments.length > 2 ? arguments[2] : undefined;
      return new this.SchedulerAction(this, work).schedule(state, delay);
    }
  }]);

  return Scheduler;
}();

Scheduler.now = function () {
  return Date.now();
};

/***/ }),

/***/ "Y6u4":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/TimeoutError.js ***!
  \******************************************************************/
/*! exports provided: TimeoutError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TimeoutError", function() { return TimeoutError; });
var TimeoutErrorImpl = function () {
  function TimeoutErrorImpl() {
    Error.call(this);
    this.message = 'Timeout has occurred';
    this.name = 'TimeoutError';
    return this;
  }

  TimeoutErrorImpl.prototype = Object.create(Error.prototype);
  return TimeoutErrorImpl;
}();

var TimeoutError = TimeoutErrorImpl;

/***/ }),

/***/ "Y6wi":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/switchAll.js ***!
  \********************************************************************/
/*! exports provided: switchAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "switchAll", function() { return switchAll; });
/* harmony import */ var _switchMap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./switchMap */ "eIep");
/* harmony import */ var _util_identity__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/identity */ "SpAZ");


function switchAll() {
  return Object(_switchMap__WEBPACK_IMPORTED_MODULE_0__["switchMap"])(_util_identity__WEBPACK_IMPORTED_MODULE_1__["identity"]);
}

/***/ }),

/***/ "Y7HM":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isNumeric.js ***!
  \***************************************************************/
/*! exports provided: isNumeric */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isNumeric", function() { return isNumeric; });
/* harmony import */ var _isArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./isArray */ "DH7j");

function isNumeric(val) {
  return !Object(_isArray__WEBPACK_IMPORTED_MODULE_0__["isArray"])(val) && val - parseFloat(val) + 1 >= 0;
}

/***/ }),

/***/ "YAWx":
/*!**********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/arrayWithoutHoles.js ***!
  \**********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _arrayWithoutHoles; });
/* harmony import */ var _arrayLikeToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./arrayLikeToArray */ "a3WO");

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return Object(_arrayLikeToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(arr);
}

/***/ }),

/***/ "YRex":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ug-cn.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Uyghur (China) [ug-cn]
//! author: boyaq : https://github.com/boyaq
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var ugCn = moment.defineLocale('ug-cn', {
    months: 'يانۋار_فېۋرال_مارت_ئاپرېل_ماي_ئىيۇن_ئىيۇل_ئاۋغۇست_سېنتەبىر_ئۆكتەبىر_نويابىر_دېكابىر'.split('_'),
    monthsShort: 'يانۋار_فېۋرال_مارت_ئاپرېل_ماي_ئىيۇن_ئىيۇل_ئاۋغۇست_سېنتەبىر_ئۆكتەبىر_نويابىر_دېكابىر'.split('_'),
    weekdays: 'يەكشەنبە_دۈشەنبە_سەيشەنبە_چارشەنبە_پەيشەنبە_جۈمە_شەنبە'.split('_'),
    weekdaysShort: 'يە_دۈ_سە_چا_پە_جۈ_شە'.split('_'),
    weekdaysMin: 'يە_دۈ_سە_چا_پە_جۈ_شە'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: 'YYYY-يىلىM-ئاينىڭD-كۈنى',
      LLL: 'YYYY-يىلىM-ئاينىڭD-كۈنى، HH:mm',
      LLLL: 'dddd، YYYY-يىلىM-ئاينىڭD-كۈنى، HH:mm'
    },
    meridiemParse: /يېرىم كېچە|سەھەر|چۈشتىن بۇرۇن|چۈش|چۈشتىن كېيىن|كەچ/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'يېرىم كېچە' || meridiem === 'سەھەر' || meridiem === 'چۈشتىن بۇرۇن') {
        return hour;
      } else if (meridiem === 'چۈشتىن كېيىن' || meridiem === 'كەچ') {
        return hour + 12;
      } else {
        return hour >= 11 ? hour : hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      var hm = hour * 100 + minute;

      if (hm < 600) {
        return 'يېرىم كېچە';
      } else if (hm < 900) {
        return 'سەھەر';
      } else if (hm < 1130) {
        return 'چۈشتىن بۇرۇن';
      } else if (hm < 1230) {
        return 'چۈش';
      } else if (hm < 1800) {
        return 'چۈشتىن كېيىن';
      } else {
        return 'كەچ';
      }
    },
    calendar: {
      sameDay: '[بۈگۈن سائەت] LT',
      nextDay: '[ئەتە سائەت] LT',
      nextWeek: '[كېلەركى] dddd [سائەت] LT',
      lastDay: '[تۆنۈگۈن] LT',
      lastWeek: '[ئالدىنقى] dddd [سائەت] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s كېيىن',
      past: '%s بۇرۇن',
      s: 'نەچچە سېكونت',
      ss: '%d سېكونت',
      m: 'بىر مىنۇت',
      mm: '%d مىنۇت',
      h: 'بىر سائەت',
      hh: '%d سائەت',
      d: 'بىر كۈن',
      dd: '%d كۈن',
      M: 'بىر ئاي',
      MM: '%d ئاي',
      y: 'بىر يىل',
      yy: '%d يىل'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(-كۈنى|-ئاي|-ھەپتە)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + '-كۈنى';

        case 'w':
        case 'W':
          return number + '-ھەپتە';

        default:
          return number;
      }
    },
    preparse: function preparse(string) {
      return string.replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/,/g, '،');
    },
    week: {
      // GB/T 7408-1994《数据元和交换格式·信息交换·日期和时间表示法》与ISO 8601:1988等效
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 1st is the first week of the year.

    }
  });
  return ugCn;
});

/***/ }),

/***/ "Ylt2":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/SubjectSubscription.js ***!
  \********************************************************************/
/*! exports provided: SubjectSubscription */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SubjectSubscription", function() { return SubjectSubscription; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Subscription */ "quSY");





var SubjectSubscription = /*#__PURE__*/function (_Subscription) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(SubjectSubscription, _Subscription);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(SubjectSubscription);

  function SubjectSubscription(subject, subscriber) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SubjectSubscription);

    _this = _super.call(this);
    _this.subject = subject;
    _this.subscriber = subscriber;
    _this.closed = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SubjectSubscription, [{
    key: "unsubscribe",
    value: function unsubscribe() {
      if (this.closed) {
        return;
      }

      this.closed = true;
      var subject = this.subject;
      var observers = subject.observers;
      this.subject = null;

      if (!observers || observers.length === 0 || subject.isStopped || subject.closed) {
        return;
      }

      var subscriberIndex = observers.indexOf(this.subscriber);

      if (subscriberIndex !== -1) {
        observers.splice(subscriberIndex, 1);
      }
    }
  }]);

  return SubjectSubscription;
}(_Subscription__WEBPACK_IMPORTED_MODULE_4__["Subscription"]);

/***/ }),

/***/ "YuR2":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/QueueAction.js ***!
  \**********************************************************************/
/*! exports provided: QueueAction */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "QueueAction", function() { return QueueAction; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _AsyncAction__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./AsyncAction */ "3N8a");







var QueueAction = /*#__PURE__*/function (_AsyncAction) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(QueueAction, _AsyncAction);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(QueueAction);

  function QueueAction(scheduler, work) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, QueueAction);

    _this = _super.call(this, scheduler, work);
    _this.scheduler = scheduler;
    _this.work = work;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(QueueAction, [{
    key: "schedule",
    value: function schedule(state) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      if (delay > 0) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(QueueAction.prototype), "schedule", this).call(this, state, delay);
      }

      this.delay = delay;
      this.state = state;
      this.scheduler.flush(this);
      return this;
    }
  }, {
    key: "execute",
    value: function execute(state, delay) {
      return delay > 0 || this.closed ? Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(QueueAction.prototype), "execute", this).call(this, state, delay) : this._execute(state, delay);
    }
  }, {
    key: "requestAsyncId",
    value: function requestAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

      if (delay !== null && delay > 0 || delay === null && this.delay > 0) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(QueueAction.prototype), "requestAsyncId", this).call(this, scheduler, id, delay);
      }

      return scheduler.flush(this);
    }
  }]);

  return QueueAction;
}(_AsyncAction__WEBPACK_IMPORTED_MODULE_6__["AsyncAction"]);

/***/ }),

/***/ "YuTi":
/*!***********************************!*\
  !*** (webpack)/buildin/module.js ***!
  \***********************************/
/*! no static exports found */
/***/ (function(module, exports) {

module.exports = function (module) {
  if (!module.webpackPolyfill) {
    module.deprecate = function () {};

    module.paths = []; // module.parent = undefined by default

    if (!module.children) module.children = [];
    Object.defineProperty(module, "loaded", {
      enumerable: true,
      get: function get() {
        return module.l;
      }
    });
    Object.defineProperty(module, "id", {
      enumerable: true,
      get: function get() {
        return module.i;
      }
    });
    module.webpackPolyfill = 1;
  }

  return module;
};

/***/ }),

/***/ "Z4QM":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sd.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Sindhi [sd]
//! author : Narain Sagar : https://github.com/narainsagar
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = ['جنوري', 'فيبروري', 'مارچ', 'اپريل', 'مئي', 'جون', 'جولاءِ', 'آگسٽ', 'سيپٽمبر', 'آڪٽوبر', 'نومبر', 'ڊسمبر'],
      days = ['آچر', 'سومر', 'اڱارو', 'اربع', 'خميس', 'جمع', 'ڇنڇر'];
  var sd = moment.defineLocale('sd', {
    months: months,
    monthsShort: months,
    weekdays: days,
    weekdaysShort: days,
    weekdaysMin: days,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd، D MMMM YYYY HH:mm'
    },
    meridiemParse: /صبح|شام/,
    isPM: function isPM(input) {
      return 'شام' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'صبح';
      }

      return 'شام';
    },
    calendar: {
      sameDay: '[اڄ] LT',
      nextDay: '[سڀاڻي] LT',
      nextWeek: 'dddd [اڳين هفتي تي] LT',
      lastDay: '[ڪالهه] LT',
      lastWeek: '[گزريل هفتي] dddd [تي] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s پوء',
      past: '%s اڳ',
      s: 'چند سيڪنڊ',
      ss: '%d سيڪنڊ',
      m: 'هڪ منٽ',
      mm: '%d منٽ',
      h: 'هڪ ڪلاڪ',
      hh: '%d ڪلاڪ',
      d: 'هڪ ڏينهن',
      dd: '%d ڏينهن',
      M: 'هڪ مهينو',
      MM: '%d مهينا',
      y: 'هڪ سال',
      yy: '%d سال'
    },
    preparse: function preparse(string) {
      return string.replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/,/g, '،');
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return sd;
});

/***/ }),

/***/ "ZAMP":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ms-my.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Malay [ms-my]
//! note : DEPRECATED, the correct one is [ms]
//! author : Weldan Jamili : https://github.com/weldan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var msMy = moment.defineLocale('ms-my', {
    months: 'Januari_Februari_Mac_April_Mei_Jun_Julai_Ogos_September_Oktober_November_Disember'.split('_'),
    monthsShort: 'Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ogs_Sep_Okt_Nov_Dis'.split('_'),
    weekdays: 'Ahad_Isnin_Selasa_Rabu_Khamis_Jumaat_Sabtu'.split('_'),
    weekdaysShort: 'Ahd_Isn_Sel_Rab_Kha_Jum_Sab'.split('_'),
    weekdaysMin: 'Ah_Is_Sl_Rb_Km_Jm_Sb'.split('_'),
    longDateFormat: {
      LT: 'HH.mm',
      LTS: 'HH.mm.ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY [pukul] HH.mm',
      LLLL: 'dddd, D MMMM YYYY [pukul] HH.mm'
    },
    meridiemParse: /pagi|tengahari|petang|malam/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'pagi') {
        return hour;
      } else if (meridiem === 'tengahari') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === 'petang' || meridiem === 'malam') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 11) {
        return 'pagi';
      } else if (hours < 15) {
        return 'tengahari';
      } else if (hours < 19) {
        return 'petang';
      } else {
        return 'malam';
      }
    },
    calendar: {
      sameDay: '[Hari ini pukul] LT',
      nextDay: '[Esok pukul] LT',
      nextWeek: 'dddd [pukul] LT',
      lastDay: '[Kelmarin pukul] LT',
      lastWeek: 'dddd [lepas pukul] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dalam %s',
      past: '%s yang lepas',
      s: 'beberapa saat',
      ss: '%d saat',
      m: 'seminit',
      mm: '%d minit',
      h: 'sejam',
      hh: '%d jam',
      d: 'sehari',
      dd: '%d hari',
      M: 'sebulan',
      MM: '%d bulan',
      y: 'setahun',
      yy: '%d tahun'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return msMy;
});

/***/ }),

/***/ "ZUHj":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/subscribeToResult.js ***!
  \***********************************************************************/
/*! exports provided: subscribeToResult */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeToResult", function() { return subscribeToResult; });
/* harmony import */ var _InnerSubscriber__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../InnerSubscriber */ "51Dv");
/* harmony import */ var _subscribeTo__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./subscribeTo */ "SeVD");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../Observable */ "HDdC");



function subscribeToResult(outerSubscriber, result, outerValue, outerIndex) {
  var innerSubscriber = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : new _InnerSubscriber__WEBPACK_IMPORTED_MODULE_0__["InnerSubscriber"](outerSubscriber, outerValue, outerIndex);

  if (innerSubscriber.closed) {
    return undefined;
  }

  if (result instanceof _Observable__WEBPACK_IMPORTED_MODULE_2__["Observable"]) {
    return result.subscribe(innerSubscriber);
  }

  return Object(_subscribeTo__WEBPACK_IMPORTED_MODULE_1__["subscribeTo"])(result)(innerSubscriber);
}

/***/ }),

/***/ "Zduo":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/eo.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Esperanto [eo]
//! author : Colin Dean : https://github.com/colindean
//! author : Mia Nordentoft Imperatori : https://github.com/miestasmia
//! comment : miestasmia corrected the translation by colindean
//! comment : Vivakvo corrected the translation by colindean and miestasmia
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var eo = moment.defineLocale('eo', {
    months: 'januaro_februaro_marto_aprilo_majo_junio_julio_aŭgusto_septembro_oktobro_novembro_decembro'.split('_'),
    monthsShort: 'jan_feb_mart_apr_maj_jun_jul_aŭg_sept_okt_nov_dec'.split('_'),
    weekdays: 'dimanĉo_lundo_mardo_merkredo_ĵaŭdo_vendredo_sabato'.split('_'),
    weekdaysShort: 'dim_lun_mard_merk_ĵaŭ_ven_sab'.split('_'),
    weekdaysMin: 'di_lu_ma_me_ĵa_ve_sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: '[la] D[-an de] MMMM, YYYY',
      LLL: '[la] D[-an de] MMMM, YYYY HH:mm',
      LLLL: 'dddd[n], [la] D[-an de] MMMM, YYYY HH:mm',
      llll: 'ddd, [la] D[-an de] MMM, YYYY HH:mm'
    },
    meridiemParse: /[ap]\.t\.m/i,
    isPM: function isPM(input) {
      return input.charAt(0).toLowerCase() === 'p';
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours > 11) {
        return isLower ? 'p.t.m.' : 'P.T.M.';
      } else {
        return isLower ? 'a.t.m.' : 'A.T.M.';
      }
    },
    calendar: {
      sameDay: '[Hodiaŭ je] LT',
      nextDay: '[Morgaŭ je] LT',
      nextWeek: 'dddd[n je] LT',
      lastDay: '[Hieraŭ je] LT',
      lastWeek: '[pasintan] dddd[n je] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'post %s',
      past: 'antaŭ %s',
      s: 'kelkaj sekundoj',
      ss: '%d sekundoj',
      m: 'unu minuto',
      mm: '%d minutoj',
      h: 'unu horo',
      hh: '%d horoj',
      d: 'unu tago',
      //ne 'diurno', ĉar estas uzita por proksimumo
      dd: '%d tagoj',
      M: 'unu monato',
      MM: '%d monatoj',
      y: 'unu jaro',
      yy: '%d jaroj'
    },
    dayOfMonthOrdinalParse: /\d{1,2}a/,
    ordinal: '%da',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return eo;
});

/***/ }),

/***/ "Zy1z":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/pairwise.js ***!
  \*******************************************************************/
/*! exports provided: pairwise */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "pairwise", function() { return pairwise; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function pairwise() {
  return function (source) {
    return source.lift(new PairwiseOperator());
  };
}

var PairwiseOperator = /*#__PURE__*/function () {
  function PairwiseOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, PairwiseOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(PairwiseOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new PairwiseSubscriber(subscriber));
    }
  }]);

  return PairwiseOperator;
}();

var PairwiseSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(PairwiseSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(PairwiseSubscriber);

  function PairwiseSubscriber(destination) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, PairwiseSubscriber);

    _this = _super.call(this, destination);
    _this.hasPrev = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(PairwiseSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var pair;

      if (this.hasPrev) {
        pair = [this.prev, value];
      } else {
        this.hasPrev = true;
      }

      this.prev = value;

      if (pair) {
        this.destination.next(pair);
      }
    }
  }]);

  return PairwiseSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "Zyez":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/sequenceEqual.js ***!
  \************************************************************************/
/*! exports provided: sequenceEqual, SequenceEqualOperator, SequenceEqualSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "sequenceEqual", function() { return sequenceEqual; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SequenceEqualOperator", function() { return SequenceEqualOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SequenceEqualSubscriber", function() { return SequenceEqualSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");






function sequenceEqual(compareTo, comparator) {
  return function (source) {
    return source.lift(new SequenceEqualOperator(compareTo, comparator));
  };
}
var SequenceEqualOperator = /*#__PURE__*/function () {
  function SequenceEqualOperator(compareTo, comparator) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, SequenceEqualOperator);

    this.compareTo = compareTo;
    this.comparator = comparator;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(SequenceEqualOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SequenceEqualSubscriber(subscriber, this.compareTo, this.comparator));
    }
  }]);

  return SequenceEqualOperator;
}();
var SequenceEqualSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(SequenceEqualSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(SequenceEqualSubscriber);

  function SequenceEqualSubscriber(destination, compareTo, comparator) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, SequenceEqualSubscriber);

    _this = _super.call(this, destination);
    _this.compareTo = compareTo;
    _this.comparator = comparator;
    _this._a = [];
    _this._b = [];
    _this._oneComplete = false;

    _this.destination.add(compareTo.subscribe(new SequenceEqualCompareToSubscriber(destination, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this))));

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(SequenceEqualSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (this._oneComplete && this._b.length === 0) {
        this.emit(false);
      } else {
        this._a.push(value);

        this.checkValues();
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      if (this._oneComplete) {
        this.emit(this._a.length === 0 && this._b.length === 0);
      } else {
        this._oneComplete = true;
      }

      this.unsubscribe();
    }
  }, {
    key: "checkValues",
    value: function checkValues() {
      var _a = this._a,
          _b = this._b,
          comparator = this.comparator;

      while (_a.length > 0 && _b.length > 0) {
        var a = _a.shift();

        var b = _b.shift();

        var areEqual = false;

        try {
          areEqual = comparator ? comparator(a, b) : a === b;
        } catch (e) {
          this.destination.error(e);
        }

        if (!areEqual) {
          this.emit(false);
        }
      }
    }
  }, {
    key: "emit",
    value: function emit(value) {
      var destination = this.destination;
      destination.next(value);
      destination.complete();
    }
  }, {
    key: "nextB",
    value: function nextB(value) {
      if (this._oneComplete && this._a.length === 0) {
        this.emit(false);
      } else {
        this._b.push(value);

        this.checkValues();
      }
    }
  }, {
    key: "completeB",
    value: function completeB() {
      if (this._oneComplete) {
        this.emit(this._a.length === 0 && this._b.length === 0);
      } else {
        this._oneComplete = true;
      }
    }
  }]);

  return SequenceEqualSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

var SequenceEqualCompareToSubscriber = /*#__PURE__*/function (_Subscriber2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(SequenceEqualCompareToSubscriber, _Subscriber2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(SequenceEqualCompareToSubscriber);

  function SequenceEqualCompareToSubscriber(destination, parent) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, SequenceEqualCompareToSubscriber);

    _this2 = _super2.call(this, destination);
    _this2.parent = parent;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(SequenceEqualCompareToSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.parent.nextB(value);
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.parent.error(err);
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.parent.completeB();
      this.unsubscribe();
    }
  }]);

  return SequenceEqualCompareToSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

/***/ }),

/***/ "a3WO":
/*!*********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/arrayLikeToArray.js ***!
  \*********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _arrayLikeToArray; });
function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) {
    arr2[i] = arr[i];
  }

  return arr2;
}

/***/ }),

/***/ "a3Wg":
/*!**********************************************************************************************************!*\
  !*** ./node_modules/@angular/platform-browser-dynamic/__ivy_ngcc__/fesm2015/platform-browser-dynamic.js ***!
  \**********************************************************************************************************/
/*! exports provided: JitCompilerFactory, RESOURCE_CACHE_PROVIDER, VERSION, platformBrowserDynamic, ɵCOMPILER_PROVIDERS__POST_R3__, ɵCompilerImpl, ɵINTERNAL_BROWSER_DYNAMIC_PLATFORM_PROVIDERS, ɵResourceLoaderImpl, ɵangular_packages_platform_browser_dynamic_platform_browser_dynamic_a, ɵplatformCoreDynamic */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JitCompilerFactory", function() { return JitCompilerFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RESOURCE_CACHE_PROVIDER", function() { return RESOURCE_CACHE_PROVIDER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "platformBrowserDynamic", function() { return platformBrowserDynamic; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCOMPILER_PROVIDERS__POST_R3__", function() { return COMPILER_PROVIDERS__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCompilerImpl", function() { return CompilerImpl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵINTERNAL_BROWSER_DYNAMIC_PLATFORM_PROVIDERS", function() { return INTERNAL_BROWSER_DYNAMIC_PLATFORM_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵResourceLoaderImpl", function() { return ResourceLoaderImpl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_dynamic_platform_browser_dynamic_a", function() { return CachedResourceLoader; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵplatformCoreDynamic", function() { return platformCoreDynamic; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _angular_compiler__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @angular/compiler */ "1uSB");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @angular/core */ "fXoL");
/* harmony import */ var _angular_common__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @angular/common */ "ofXK");
/* harmony import */ var _angular_platform_browser__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @angular/platform-browser */ "jhN1");






/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */




/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var MODULE_SUFFIX = '';
var builtinExternalReferences = createBuiltinExternalReferencesMap();

var JitReflector = /*#__PURE__*/function () {
  function JitReflector() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, JitReflector);

    this.reflectionCapabilities = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵReflectionCapabilities"]();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(JitReflector, [{
    key: "componentModuleUrl",
    value: function componentModuleUrl(type, cmpMetadata) {
      var moduleId = cmpMetadata.moduleId;

      if (typeof moduleId === 'string') {
        var scheme = Object(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["getUrlScheme"])(moduleId);
        return scheme ? moduleId : "package:".concat(moduleId).concat(MODULE_SUFFIX);
      } else if (moduleId !== null && moduleId !== void 0) {
        throw Object(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["syntaxError"])("moduleId should be a string in \"".concat(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵstringify"])(type), "\". See https://goo.gl/wIDDiL for more information.\n") + "If you're using Webpack you should inline the template and the styles, see https://goo.gl/X2J8zc.");
      }

      return "./".concat(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵstringify"])(type));
    }
  }, {
    key: "parameters",
    value: function parameters(typeOrFunc) {
      return this.reflectionCapabilities.parameters(typeOrFunc);
    }
  }, {
    key: "tryAnnotations",
    value: function tryAnnotations(typeOrFunc) {
      return this.annotations(typeOrFunc);
    }
  }, {
    key: "annotations",
    value: function annotations(typeOrFunc) {
      return this.reflectionCapabilities.annotations(typeOrFunc);
    }
  }, {
    key: "shallowAnnotations",
    value: function shallowAnnotations(typeOrFunc) {
      throw new Error('Not supported in JIT mode');
    }
  }, {
    key: "propMetadata",
    value: function propMetadata(typeOrFunc) {
      return this.reflectionCapabilities.propMetadata(typeOrFunc);
    }
  }, {
    key: "hasLifecycleHook",
    value: function hasLifecycleHook(type, lcProperty) {
      return this.reflectionCapabilities.hasLifecycleHook(type, lcProperty);
    }
  }, {
    key: "guards",
    value: function guards(type) {
      return this.reflectionCapabilities.guards(type);
    }
  }, {
    key: "resolveExternalReference",
    value: function resolveExternalReference(ref) {
      return builtinExternalReferences.get(ref) || ref.runtime;
    }
  }]);

  return JitReflector;
}();

function createBuiltinExternalReferencesMap() {
  var map = new Map();
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ANALYZE_FOR_ENTRY_COMPONENTS, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ANALYZE_FOR_ENTRY_COMPONENTS"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ElementRef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].NgModuleRef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModuleRef"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ViewContainerRef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ChangeDetectorRef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ChangeDetectorRef"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].Renderer2, _angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].QueryList, _angular_core__WEBPACK_IMPORTED_MODULE_6__["QueryList"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].TemplateRef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].CodegenComponentFactoryResolver, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵCodegenComponentFactoryResolver"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ComponentFactoryResolver, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ComponentFactoryResolver"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ComponentFactory, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ComponentFactory"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ComponentRef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ComponentRef"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].NgModuleFactory, _angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModuleFactory"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].createModuleFactory, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵcmf"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].moduleDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵmod"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].moduleProviderDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵmpd"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].RegisterModuleFactoryFn, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵregisterModuleFactory"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].Injector, _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injector"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ViewEncapsulation, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewEncapsulation"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ChangeDetectionStrategy, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ChangeDetectionStrategy"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].SecurityContext, _angular_core__WEBPACK_IMPORTED_MODULE_6__["SecurityContext"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].LOCALE_ID, _angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].TRANSLATIONS_FORMAT, _angular_core__WEBPACK_IMPORTED_MODULE_6__["TRANSLATIONS_FORMAT"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].inlineInterpolate, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵinlineInterpolate"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].interpolate, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵinterpolate"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].EMPTY_ARRAY, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵEMPTY_ARRAY"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].EMPTY_MAP, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵEMPTY_MAP"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].viewDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵvid"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].elementDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵeld"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].anchorDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵand"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].textDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵted"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].directiveDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵdid"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].providerDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵprd"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].queryDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵqud"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].pureArrayDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵpad"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].pureObjectDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵpod"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].purePipeDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵppd"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].pipeDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵpid"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].nodeValue, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵnov"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].ngContentDef, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵncd"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].unwrapValue, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵunv"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].createRendererType2, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵcrt"]);
  map.set(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Identifiers"].createComponentFactory, _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵccf"]);
  return map;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ERROR_COLLECTOR_TOKEN = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('ErrorCollector');
/**
 * A default provider for {@link PACKAGE_ROOT_URL} that maps to '/'.
 */

var DEFAULT_PACKAGE_URL_PROVIDER = {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["PACKAGE_ROOT_URL"],
  useValue: '/'
};
var _NO_RESOURCE_LOADER = {
  get: function get(url) {
    throw new Error("No ResourceLoader implementation has been provided. Can't read the url \"".concat(url, "\""));
  }
};
var baseHtmlParser = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('HtmlParser');

var CompilerImpl = /*#__PURE__*/function () {
  function CompilerImpl(injector, _metadataResolver, templateParser, styleCompiler, viewCompiler, ngModuleCompiler, summaryResolver, compileReflector, jitEvaluator, compilerConfig, console) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, CompilerImpl);

    this._metadataResolver = _metadataResolver;
    this._delegate = new _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["JitCompiler"](_metadataResolver, templateParser, styleCompiler, viewCompiler, ngModuleCompiler, summaryResolver, compileReflector, jitEvaluator, compilerConfig, console, this.getExtraNgModuleProviders.bind(this));
    this.injector = injector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(CompilerImpl, [{
    key: "getExtraNgModuleProviders",
    value: function getExtraNgModuleProviders() {
      return [this._metadataResolver.getProviderMetadata(new _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ProviderMeta"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["Compiler"], {
        useValue: this
      }))];
    }
  }, {
    key: "compileModuleSync",
    value: function compileModuleSync(moduleType) {
      return this._delegate.compileModuleSync(moduleType);
    }
  }, {
    key: "compileModuleAsync",
    value: function compileModuleAsync(moduleType) {
      return this._delegate.compileModuleAsync(moduleType);
    }
  }, {
    key: "compileModuleAndAllComponentsSync",
    value: function compileModuleAndAllComponentsSync(moduleType) {
      var result = this._delegate.compileModuleAndAllComponentsSync(moduleType);

      return {
        ngModuleFactory: result.ngModuleFactory,
        componentFactories: result.componentFactories
      };
    }
  }, {
    key: "compileModuleAndAllComponentsAsync",
    value: function compileModuleAndAllComponentsAsync(moduleType) {
      return this._delegate.compileModuleAndAllComponentsAsync(moduleType).then(function (result) {
        return {
          ngModuleFactory: result.ngModuleFactory,
          componentFactories: result.componentFactories
        };
      });
    }
  }, {
    key: "loadAotSummaries",
    value: function loadAotSummaries(summaries) {
      this._delegate.loadAotSummaries(summaries);
    }
  }, {
    key: "hasAotSummary",
    value: function hasAotSummary(ref) {
      return this._delegate.hasAotSummary(ref);
    }
  }, {
    key: "getComponentFactory",
    value: function getComponentFactory(component) {
      return this._delegate.getComponentFactory(component);
    }
  }, {
    key: "clearCache",
    value: function clearCache() {
      this._delegate.clearCache();
    }
  }, {
    key: "clearCacheFor",
    value: function clearCacheFor(type) {
      this._delegate.clearCacheFor(type);
    }
  }, {
    key: "getModuleId",
    value: function getModuleId(moduleType) {
      var meta = this._metadataResolver.getNgModuleMetadata(moduleType);

      return meta && meta.id || undefined;
    }
  }]);

  return CompilerImpl;
}();

var ɵ0 = new JitReflector(),
    ɵ1 = _NO_RESOURCE_LOADER,
    ɵ2 = function ɵ2(parser, translations, format, config, console) {
  translations = translations || '';
  var missingTranslation = translations ? config.missingTranslation : _angular_core__WEBPACK_IMPORTED_MODULE_6__["MissingTranslationStrategy"].Ignore;
  return new _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["I18NHtmlParser"](parser, translations, format, missingTranslation, console);
},
    ɵ3 = new _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"]();
/**
 * A set of providers that provide `JitCompiler` and its dependencies to use for
 * template compilation.
 */


var COMPILER_PROVIDERS__PRE_R3__ = [{
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"],
  useValue: ɵ0
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ResourceLoader"],
  useValue: ɵ1
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["JitSummaryResolver"],
  deps: []
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["SummaryResolver"],
  useExisting: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["JitSummaryResolver"]
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵConsole"],
  deps: []
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Lexer"],
  deps: []
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Parser"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Lexer"]]
}, {
  provide: baseHtmlParser,
  useClass: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["HtmlParser"],
  deps: []
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["I18NHtmlParser"],
  useFactory: ɵ2,
  deps: [baseHtmlParser, [new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"](), new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TRANSLATIONS"])], [new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"](), new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TRANSLATIONS_FORMAT"])], [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"]], [_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵConsole"]]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["HtmlParser"],
  useExisting: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["I18NHtmlParser"]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["TemplateParser"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["Parser"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ElementSchemaRegistry"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["I18NHtmlParser"], _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵConsole"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["JitEvaluator"],
  useClass: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["JitEvaluator"],
  deps: []
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["DirectiveNormalizer"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ResourceLoader"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["UrlResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["HtmlParser"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileMetadataResolver"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["HtmlParser"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["NgModuleResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["DirectiveResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["PipeResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["SummaryResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ElementSchemaRegistry"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["DirectiveNormalizer"], _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵConsole"], [_angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["StaticSymbolCache"]], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"], [_angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"], ERROR_COLLECTOR_TOKEN]]
}, DEFAULT_PACKAGE_URL_PROVIDER, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["StyleCompiler"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["UrlResolver"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ViewCompiler"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["NgModuleCompiler"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"],
  useValue: ɵ3
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Compiler"],
  useClass: CompilerImpl,
  deps: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["Injector"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileMetadataResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["TemplateParser"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["StyleCompiler"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ViewCompiler"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["NgModuleCompiler"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["SummaryResolver"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["JitEvaluator"], _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"], _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵConsole"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["DomElementSchemaRegistry"],
  deps: []
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ElementSchemaRegistry"],
  useExisting: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["DomElementSchemaRegistry"]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["UrlResolver"],
  deps: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["PACKAGE_ROOT_URL"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["DirectiveResolver"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["PipeResolver"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"]]
}, {
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["NgModuleResolver"],
  deps: [_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompileReflector"]]
}];
var COMPILER_PROVIDERS__POST_R3__ = [{
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Compiler"],
  useFactory: function useFactory() {
    return new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Compiler"]();
  }
}];
var COMPILER_PROVIDERS = COMPILER_PROVIDERS__POST_R3__;
/**
 * @publicApi
 */

var JitCompilerFactory = /*#__PURE__*/function () {
  /* @internal */
  function JitCompilerFactory(defaultOptions) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, JitCompilerFactory);

    var compilerOptions = {
      useJit: true,
      defaultEncapsulation: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewEncapsulation"].Emulated,
      missingTranslation: _angular_core__WEBPACK_IMPORTED_MODULE_6__["MissingTranslationStrategy"].Warning
    };
    this._defaultOptions = [compilerOptions].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_2__["default"])(defaultOptions));
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(JitCompilerFactory, [{
    key: "createCompiler",
    value: function createCompiler() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

      var opts = _mergeOptions(this._defaultOptions.concat(options));

      var injector = _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injector"].create([COMPILER_PROVIDERS, {
        provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"],
        useFactory: function useFactory() {
          return new _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["CompilerConfig"]({
            // let explicit values from the compiler options overwrite options
            // from the app providers
            useJit: opts.useJit,
            jitDevMode: Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["isDevMode"])(),
            // let explicit values from the compiler options overwrite options
            // from the app providers
            defaultEncapsulation: opts.defaultEncapsulation,
            missingTranslation: opts.missingTranslation,
            preserveWhitespaces: opts.preserveWhitespaces
          });
        },
        deps: []
      }, opts.providers]);
      return injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_6__["Compiler"]);
    }
  }]);

  return JitCompilerFactory;
}();

function _mergeOptions(optionsArr) {
  return {
    useJit: _lastDefined(optionsArr.map(function (options) {
      return options.useJit;
    })),
    defaultEncapsulation: _lastDefined(optionsArr.map(function (options) {
      return options.defaultEncapsulation;
    })),
    providers: _mergeArrays(optionsArr.map(function (options) {
      return options.providers;
    })),
    missingTranslation: _lastDefined(optionsArr.map(function (options) {
      return options.missingTranslation;
    })),
    preserveWhitespaces: _lastDefined(optionsArr.map(function (options) {
      return options.preserveWhitespaces;
    }))
  };
}

function _lastDefined(args) {
  for (var i = args.length - 1; i >= 0; i--) {
    if (args[i] !== undefined) {
      return args[i];
    }
  }

  return undefined;
}

function _mergeArrays(parts) {
  var result = [];
  parts.forEach(function (part) {
    return part && result.push.apply(result, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_2__["default"])(part));
  });
  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$1 = {};
/**
 * A platform that included corePlatform and the compiler.
 *
 * @publicApi
 */

var platformCoreDynamic = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["createPlatformFactory"])(_angular_core__WEBPACK_IMPORTED_MODULE_6__["platformCore"], 'coreDynamic', [{
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["COMPILER_OPTIONS"],
  useValue: ɵ0$1,
  multi: true
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["CompilerFactory"],
  useClass: JitCompilerFactory,
  deps: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["COMPILER_OPTIONS"]]
}]);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var ResourceLoaderImpl = /*#__PURE__*/function (_ResourceLoader) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ResourceLoaderImpl, _ResourceLoader);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ResourceLoaderImpl);

  function ResourceLoaderImpl() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, ResourceLoaderImpl);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ResourceLoaderImpl, [{
    key: "get",
    value: function get(url) {
      var resolve;
      var reject;
      var promise = new Promise(function (res, rej) {
        resolve = res;
        reject = rej;
      });
      var xhr = new XMLHttpRequest();
      xhr.open('GET', url, true);
      xhr.responseType = 'text';

      xhr.onload = function () {
        // responseText is the old-school way of retrieving response (supported by IE8 & 9)
        // response/responseType properties were introduced in ResourceLoader Level2 spec (supported
        // by IE10)
        var response = xhr.response || xhr.responseText; // normalize IE9 bug (http://bugs.jquery.com/ticket/1450)

        var status = xhr.status === 1223 ? 204 : xhr.status; // fix status code when it is 0 (0 status is undocumented).
        // Occurs when accessing file resources or on Android 4.1 stock browser
        // while retrieving files from application cache.

        if (status === 0) {
          status = response ? 200 : 0;
        }

        if (200 <= status && status <= 300) {
          resolve(response);
        } else {
          reject("Failed to load ".concat(url));
        }
      };

      xhr.onerror = function () {
        reject("Failed to load ".concat(url));
      };

      xhr.send();
      return promise;
    }
  }]);

  return ResourceLoaderImpl;
}(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ResourceLoader"]);

ResourceLoaderImpl.ɵfac = function ResourceLoaderImpl_Factory(t) {
  return ɵResourceLoaderImpl_BaseFactory(t || ResourceLoaderImpl);
};

ResourceLoaderImpl.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: ResourceLoaderImpl,
  factory: ResourceLoaderImpl.ɵfac
});
var ɵResourceLoaderImpl_BaseFactory = /*@__PURE__*/_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵgetInheritedFactory"](ResourceLoaderImpl);
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](ResourceLoaderImpl, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$2 = {
  providers: [{
    provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ResourceLoader"],
    useClass: ResourceLoaderImpl,
    deps: []
  }]
},
    ɵ1$1 = _angular_common__WEBPACK_IMPORTED_MODULE_7__["ɵPLATFORM_BROWSER_ID"];
/**
 * @publicApi
 */

var INTERNAL_BROWSER_DYNAMIC_PLATFORM_PROVIDERS = [_angular_platform_browser__WEBPACK_IMPORTED_MODULE_8__["ɵINTERNAL_BROWSER_PLATFORM_PROVIDERS"], {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["COMPILER_OPTIONS"],
  useValue: ɵ0$2,
  multi: true
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_6__["PLATFORM_ID"],
  useValue: ɵ1$1
}];
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An implementation of ResourceLoader that uses a template cache to avoid doing an actual
 * ResourceLoader.
 *
 * The template cache needs to be built and loaded into window.$templateCache
 * via a separate mechanism.
 *
 * @publicApi
 */

var CachedResourceLoader = /*#__PURE__*/function (_ResourceLoader2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(CachedResourceLoader, _ResourceLoader2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(CachedResourceLoader);

  function CachedResourceLoader() {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, CachedResourceLoader);

    _this = _super2.call(this);
    _this._cache = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵglobal"].$templateCache;

    if (_this._cache == null) {
      throw new Error('CachedResourceLoader: Template cache was not found in $templateCache.');
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(CachedResourceLoader, [{
    key: "get",
    value: function get(url) {
      if (this._cache.hasOwnProperty(url)) {
        return Promise.resolve(this._cache[url]);
      } else {
        return Promise.reject('CachedResourceLoader: Did not find cached template for ' + url);
      }
    }
  }]);

  return CachedResourceLoader;
}(_angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ResourceLoader"]);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var VERSION = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Version"]('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */

var RESOURCE_CACHE_PROVIDER = [{
  provide: _angular_compiler__WEBPACK_IMPORTED_MODULE_5__["ResourceLoader"],
  useClass: CachedResourceLoader,
  deps: []
}];
/**
 * @publicApi
 */

var platformBrowserDynamic = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["createPlatformFactory"])(platformCoreDynamic, 'browserDynamic', INTERNAL_BROWSER_DYNAMIC_PLATFORM_PROVIDERS);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */



/***/ }),

/***/ "a7t3":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/subscribeToPromise.js ***!
  \************************************************************************/
/*! exports provided: subscribeToPromise */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeToPromise", function() { return subscribeToPromise; });
/* harmony import */ var _hostReportError__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./hostReportError */ "NJ4a");

var subscribeToPromise = function subscribeToPromise(promise) {
  return function (subscriber) {
    promise.then(function (value) {
      if (!subscriber.closed) {
        subscriber.next(value);
        subscriber.complete();
      }
    }, function (err) {
      return subscriber.error(err);
    }).then(null, _hostReportError__WEBPACK_IMPORTED_MODULE_0__["hostReportError"]);
    return subscriber;
  };
};

/***/ }),

/***/ "aGrj":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/switchMapTo.js ***!
  \**********************************************************************/
/*! exports provided: switchMapTo */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "switchMapTo", function() { return switchMapTo; });
/* harmony import */ var _switchMap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./switchMap */ "eIep");

function switchMapTo(innerObservable, resultSelector) {
  return resultSelector ? Object(_switchMap__WEBPACK_IMPORTED_MODULE_0__["switchMap"])(function () {
    return innerObservable;
  }, resultSelector) : Object(_switchMap__WEBPACK_IMPORTED_MODULE_0__["switchMap"])(function () {
    return innerObservable;
  });
}

/***/ }),

/***/ "aIdf":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/br.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Breton [br]
//! author : Jean-Baptiste Le Duigou : https://github.com/jbleduigou
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function relativeTimeWithMutation(number, withoutSuffix, key) {
    var format = {
      mm: 'munutenn',
      MM: 'miz',
      dd: 'devezh'
    };
    return number + ' ' + mutation(format[key], number);
  }

  function specialMutationForYears(number) {
    switch (lastNumber(number)) {
      case 1:
      case 3:
      case 4:
      case 5:
      case 9:
        return number + ' bloaz';

      default:
        return number + ' vloaz';
    }
  }

  function lastNumber(number) {
    if (number > 9) {
      return lastNumber(number % 10);
    }

    return number;
  }

  function mutation(text, number) {
    if (number === 2) {
      return softMutation(text);
    }

    return text;
  }

  function softMutation(text) {
    var mutationTable = {
      m: 'v',
      b: 'v',
      d: 'z'
    };

    if (mutationTable[text.charAt(0)] === undefined) {
      return text;
    }

    return mutationTable[text.charAt(0)] + text.substring(1);
  }

  var monthsParse = [/^gen/i, /^c[ʼ\']hwe/i, /^meu/i, /^ebr/i, /^mae/i, /^(mez|eve)/i, /^gou/i, /^eos/i, /^gwe/i, /^her/i, /^du/i, /^ker/i],
      monthsRegex = /^(genver|c[ʼ\']hwevrer|meurzh|ebrel|mae|mezheven|gouere|eost|gwengolo|here|du|kerzu|gen|c[ʼ\']hwe|meu|ebr|mae|eve|gou|eos|gwe|her|du|ker)/i,
      monthsStrictRegex = /^(genver|c[ʼ\']hwevrer|meurzh|ebrel|mae|mezheven|gouere|eost|gwengolo|here|du|kerzu)/i,
      monthsShortStrictRegex = /^(gen|c[ʼ\']hwe|meu|ebr|mae|eve|gou|eos|gwe|her|du|ker)/i,
      fullWeekdaysParse = [/^sul/i, /^lun/i, /^meurzh/i, /^merc[ʼ\']her/i, /^yaou/i, /^gwener/i, /^sadorn/i],
      shortWeekdaysParse = [/^Sul/i, /^Lun/i, /^Meu/i, /^Mer/i, /^Yao/i, /^Gwe/i, /^Sad/i],
      minWeekdaysParse = [/^Su/i, /^Lu/i, /^Me([^r]|$)/i, /^Mer/i, /^Ya/i, /^Gw/i, /^Sa/i];
  var br = moment.defineLocale('br', {
    months: 'Genver_Cʼhwevrer_Meurzh_Ebrel_Mae_Mezheven_Gouere_Eost_Gwengolo_Here_Du_Kerzu'.split('_'),
    monthsShort: 'Gen_Cʼhwe_Meu_Ebr_Mae_Eve_Gou_Eos_Gwe_Her_Du_Ker'.split('_'),
    weekdays: 'Sul_Lun_Meurzh_Mercʼher_Yaou_Gwener_Sadorn'.split('_'),
    weekdaysShort: 'Sul_Lun_Meu_Mer_Yao_Gwe_Sad'.split('_'),
    weekdaysMin: 'Su_Lu_Me_Mer_Ya_Gw_Sa'.split('_'),
    weekdaysParse: minWeekdaysParse,
    fullWeekdaysParse: fullWeekdaysParse,
    shortWeekdaysParse: shortWeekdaysParse,
    minWeekdaysParse: minWeekdaysParse,
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: monthsStrictRegex,
    monthsShortStrictRegex: monthsShortStrictRegex,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [a viz] MMMM YYYY',
      LLL: 'D [a viz] MMMM YYYY HH:mm',
      LLLL: 'dddd, D [a viz] MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Hiziv da] LT',
      nextDay: '[Warcʼhoazh da] LT',
      nextWeek: 'dddd [da] LT',
      lastDay: '[Decʼh da] LT',
      lastWeek: 'dddd [paset da] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'a-benn %s',
      past: '%s ʼzo',
      s: 'un nebeud segondennoù',
      ss: '%d eilenn',
      m: 'ur vunutenn',
      mm: relativeTimeWithMutation,
      h: 'un eur',
      hh: '%d eur',
      d: 'un devezh',
      dd: relativeTimeWithMutation,
      M: 'ur miz',
      MM: relativeTimeWithMutation,
      y: 'ur bloaz',
      yy: specialMutationForYears
    },
    dayOfMonthOrdinalParse: /\d{1,2}(añ|vet)/,
    ordinal: function ordinal(number) {
      var output = number === 1 ? 'añ' : 'vet';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    },
    meridiemParse: /a.m.|g.m./,
    // goude merenn | a-raok merenn
    isPM: function isPM(token) {
      return token === 'g.m.';
    },
    meridiem: function meridiem(hour, minute, isLower) {
      return hour < 12 ? 'a.m.' : 'g.m.';
    }
  });
  return br;
});

/***/ }),

/***/ "aIsn":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/mi.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Maori [mi]
//! author : John Corrigan <robbiecloset@gmail.com> : https://github.com/johnideal
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var mi = moment.defineLocale('mi', {
    months: 'Kohi-tāte_Hui-tanguru_Poutū-te-rangi_Paenga-whāwhā_Haratua_Pipiri_Hōngoingoi_Here-turi-kōkā_Mahuru_Whiringa-ā-nuku_Whiringa-ā-rangi_Hakihea'.split('_'),
    monthsShort: 'Kohi_Hui_Pou_Pae_Hara_Pipi_Hōngoi_Here_Mahu_Whi-nu_Whi-ra_Haki'.split('_'),
    monthsRegex: /(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,
    monthsStrictRegex: /(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,
    monthsShortRegex: /(?:['a-z\u0101\u014D\u016B]+\-?){1,3}/i,
    monthsShortStrictRegex: /(?:['a-z\u0101\u014D\u016B]+\-?){1,2}/i,
    weekdays: 'Rātapu_Mane_Tūrei_Wenerei_Tāite_Paraire_Hātarei'.split('_'),
    weekdaysShort: 'Ta_Ma_Tū_We_Tāi_Pa_Hā'.split('_'),
    weekdaysMin: 'Ta_Ma_Tū_We_Tāi_Pa_Hā'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY [i] HH:mm',
      LLLL: 'dddd, D MMMM YYYY [i] HH:mm'
    },
    calendar: {
      sameDay: '[i teie mahana, i] LT',
      nextDay: '[apopo i] LT',
      nextWeek: 'dddd [i] LT',
      lastDay: '[inanahi i] LT',
      lastWeek: 'dddd [whakamutunga i] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'i roto i %s',
      past: '%s i mua',
      s: 'te hēkona ruarua',
      ss: '%d hēkona',
      m: 'he meneti',
      mm: '%d meneti',
      h: 'te haora',
      hh: '%d haora',
      d: 'he ra',
      dd: '%d ra',
      M: 'he marama',
      MM: '%d marama',
      y: 'he tau',
      yy: '%d tau'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return mi;
});

/***/ }),

/***/ "aQkU":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/mk.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Macedonian [mk]
//! author : Borislav Mickov : https://github.com/B0k0
//! author : Sashko Todorov : https://github.com/bkyceh
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var mk = moment.defineLocale('mk', {
    months: 'јануари_февруари_март_април_мај_јуни_јули_август_септември_октомври_ноември_декември'.split('_'),
    monthsShort: 'јан_фев_мар_апр_мај_јун_јул_авг_сеп_окт_ное_дек'.split('_'),
    weekdays: 'недела_понеделник_вторник_среда_четврток_петок_сабота'.split('_'),
    weekdaysShort: 'нед_пон_вто_сре_чет_пет_саб'.split('_'),
    weekdaysMin: 'нe_пo_вт_ср_че_пе_сa'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'D.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY H:mm',
      LLLL: 'dddd, D MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[Денес во] LT',
      nextDay: '[Утре во] LT',
      nextWeek: '[Во] dddd [во] LT',
      lastDay: '[Вчера во] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
          case 3:
          case 6:
            return '[Изминатата] dddd [во] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[Изминатиот] dddd [во] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'за %s',
      past: 'пред %s',
      s: 'неколку секунди',
      ss: '%d секунди',
      m: 'една минута',
      mm: '%d минути',
      h: 'еден час',
      hh: '%d часа',
      d: 'еден ден',
      dd: '%d дена',
      M: 'еден месец',
      MM: '%d месеци',
      y: 'една година',
      yy: '%d години'
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(ев|ен|ти|ви|ри|ми)/,
    ordinal: function ordinal(number) {
      var lastDigit = number % 10,
          last2Digits = number % 100;

      if (number === 0) {
        return number + '-ев';
      } else if (last2Digits === 0) {
        return number + '-ен';
      } else if (last2Digits > 10 && last2Digits < 20) {
        return number + '-ти';
      } else if (lastDigit === 1) {
        return number + '-ви';
      } else if (lastDigit === 2) {
        return number + '-ри';
      } else if (lastDigit === 7 || lastDigit === 8) {
        return number + '-ми';
      } else {
        return number + '-ти';
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return mk;
});

/***/ }),

/***/ "b1Dy":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-nz.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (New Zealand) [en-nz]
//! author : Luke McGregor : https://github.com/lukemcgregor
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enNz = moment.defineLocale('en-nz', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY h:mm A',
      LLLL: 'dddd, D MMMM YYYY h:mm A'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return enNz;
});

/***/ }),

/***/ "bHdf":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/mergeAll.js ***!
  \*******************************************************************/
/*! exports provided: mergeAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "mergeAll", function() { return mergeAll; });
/* harmony import */ var _mergeMap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./mergeMap */ "5+tZ");
/* harmony import */ var _util_identity__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/identity */ "SpAZ");


function mergeAll() {
  var concurrent = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Number.POSITIVE_INFINITY;
  return Object(_mergeMap__WEBPACK_IMPORTED_MODULE_0__["mergeMap"])(_util_identity__WEBPACK_IMPORTED_MODULE_1__["identity"], concurrent);
}

/***/ }),

/***/ "bOMt":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/nb.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Norwegian Bokmål [nb]
//! authors : Espen Hovlandsdal : https://github.com/rexxars
//!           Sigurd Gartmann : https://github.com/sigurdga
//!           Stephen Ramthun : https://github.com/stephenramthun
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var nb = moment.defineLocale('nb', {
    months: 'januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember'.split('_'),
    monthsShort: 'jan._feb._mars_apr._mai_juni_juli_aug._sep._okt._nov._des.'.split('_'),
    monthsParseExact: true,
    weekdays: 'søndag_mandag_tirsdag_onsdag_torsdag_fredag_lørdag'.split('_'),
    weekdaysShort: 'sø._ma._ti._on._to._fr._lø.'.split('_'),
    weekdaysMin: 'sø_ma_ti_on_to_fr_lø'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY [kl.] HH:mm',
      LLLL: 'dddd D. MMMM YYYY [kl.] HH:mm'
    },
    calendar: {
      sameDay: '[i dag kl.] LT',
      nextDay: '[i morgen kl.] LT',
      nextWeek: 'dddd [kl.] LT',
      lastDay: '[i går kl.] LT',
      lastWeek: '[forrige] dddd [kl.] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'om %s',
      past: '%s siden',
      s: 'noen sekunder',
      ss: '%d sekunder',
      m: 'ett minutt',
      mm: '%d minutter',
      h: 'en time',
      hh: '%d timer',
      d: 'en dag',
      dd: '%d dager',
      w: 'en uke',
      ww: '%d uker',
      M: 'en måned',
      MM: '%d måneder',
      y: 'ett år',
      yy: '%d år'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return nb;
});

/***/ }),

/***/ "bOdf":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/concatMap.js ***!
  \********************************************************************/
/*! exports provided: concatMap */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "concatMap", function() { return concatMap; });
/* harmony import */ var _mergeMap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./mergeMap */ "5+tZ");

function concatMap(project, resultSelector) {
  return Object(_mergeMap__WEBPACK_IMPORTED_MODULE_0__["mergeMap"])(project, resultSelector, 1);
}

/***/ }),

/***/ "bXm7":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/kk.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Kazakh [kk]
//! authors : Nurlan Rakhimzhanov : https://github.com/nurlan
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var suffixes = {
    0: '-ші',
    1: '-ші',
    2: '-ші',
    3: '-ші',
    4: '-ші',
    5: '-ші',
    6: '-шы',
    7: '-ші',
    8: '-ші',
    9: '-шы',
    10: '-шы',
    20: '-шы',
    30: '-шы',
    40: '-шы',
    50: '-ші',
    60: '-шы',
    70: '-ші',
    80: '-ші',
    90: '-шы',
    100: '-ші'
  };
  var kk = moment.defineLocale('kk', {
    months: 'қаңтар_ақпан_наурыз_сәуір_мамыр_маусым_шілде_тамыз_қыркүйек_қазан_қараша_желтоқсан'.split('_'),
    monthsShort: 'қаң_ақп_нау_сәу_мам_мау_шіл_там_қыр_қаз_қар_жел'.split('_'),
    weekdays: 'жексенбі_дүйсенбі_сейсенбі_сәрсенбі_бейсенбі_жұма_сенбі'.split('_'),
    weekdaysShort: 'жек_дүй_сей_сәр_бей_жұм_сен'.split('_'),
    weekdaysMin: 'жк_дй_сй_ср_бй_жм_сн'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Бүгін сағат] LT',
      nextDay: '[Ертең сағат] LT',
      nextWeek: 'dddd [сағат] LT',
      lastDay: '[Кеше сағат] LT',
      lastWeek: '[Өткен аптаның] dddd [сағат] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s ішінде',
      past: '%s бұрын',
      s: 'бірнеше секунд',
      ss: '%d секунд',
      m: 'бір минут',
      mm: '%d минут',
      h: 'бір сағат',
      hh: '%d сағат',
      d: 'бір күн',
      dd: '%d күн',
      M: 'бір ай',
      MM: '%d ай',
      y: 'бір жыл',
      yy: '%d жыл'
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(ші|шы)/,
    ordinal: function ordinal(number) {
      var a = number % 10,
          b = number >= 100 ? 100 : null;
      return number + (suffixes[number] || suffixes[a] || suffixes[b]);
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return kk;
});

/***/ }),

/***/ "bYM6":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ar-tn.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale  :  Arabic (Tunisia) [ar-tn]
//! author : Nader Toukabri : https://github.com/naderio
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var arTn = moment.defineLocale('ar-tn', {
    months: 'جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
    monthsShort: 'جانفي_فيفري_مارس_أفريل_ماي_جوان_جويلية_أوت_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
    weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[اليوم على الساعة] LT',
      nextDay: '[غدا على الساعة] LT',
      nextWeek: 'dddd [على الساعة] LT',
      lastDay: '[أمس على الساعة] LT',
      lastWeek: 'dddd [على الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'في %s',
      past: 'منذ %s',
      s: 'ثوان',
      ss: '%d ثانية',
      m: 'دقيقة',
      mm: '%d دقائق',
      h: 'ساعة',
      hh: '%d ساعات',
      d: 'يوم',
      dd: '%d أيام',
      M: 'شهر',
      MM: '%d أشهر',
      y: 'سنة',
      yy: '%d سنوات'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return arTn;
});

/***/ }),

/***/ "bpih":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/it.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Italian [it]
//! author : Lorenzo : https://github.com/aliem
//! author: Mattia Larentis: https://github.com/nostalgiaz
//! author: Marco : https://github.com/Manfre98
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var it = moment.defineLocale('it', {
    months: 'gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre'.split('_'),
    monthsShort: 'gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic'.split('_'),
    weekdays: 'domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato'.split('_'),
    weekdaysShort: 'dom_lun_mar_mer_gio_ven_sab'.split('_'),
    weekdaysMin: 'do_lu_ma_me_gi_ve_sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[Oggi a' + (this.hours() > 1 ? 'lle ' : this.hours() === 0 ? ' ' : "ll'") + ']LT';
      },
      nextDay: function nextDay() {
        return '[Domani a' + (this.hours() > 1 ? 'lle ' : this.hours() === 0 ? ' ' : "ll'") + ']LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [a' + (this.hours() > 1 ? 'lle ' : this.hours() === 0 ? ' ' : "ll'") + ']LT';
      },
      lastDay: function lastDay() {
        return '[Ieri a' + (this.hours() > 1 ? 'lle ' : this.hours() === 0 ? ' ' : "ll'") + ']LT';
      },
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[La scorsa] dddd [a' + (this.hours() > 1 ? 'lle ' : this.hours() === 0 ? ' ' : "ll'") + ']LT';

          default:
            return '[Lo scorso] dddd [a' + (this.hours() > 1 ? 'lle ' : this.hours() === 0 ? ' ' : "ll'") + ']LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'tra %s',
      past: '%s fa',
      s: 'alcuni secondi',
      ss: '%d secondi',
      m: 'un minuto',
      mm: '%d minuti',
      h: "un'ora",
      hh: '%d ore',
      d: 'un giorno',
      dd: '%d giorni',
      w: 'una settimana',
      ww: '%d settimane',
      M: 'un mese',
      MM: '%d mesi',
      y: 'un anno',
      yy: '%d anni'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return it;
});

/***/ }),

/***/ "bxKX":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/it-ch.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Italian (Switzerland) [it-ch]
//! author : xfh : https://github.com/xfh
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var itCh = moment.defineLocale('it-ch', {
    months: 'gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre'.split('_'),
    monthsShort: 'gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic'.split('_'),
    weekdays: 'domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato'.split('_'),
    weekdaysShort: 'dom_lun_mar_mer_gio_ven_sab'.split('_'),
    weekdaysMin: 'do_lu_ma_me_gi_ve_sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Oggi alle] LT',
      nextDay: '[Domani alle] LT',
      nextWeek: 'dddd [alle] LT',
      lastDay: '[Ieri alle] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[la scorsa] dddd [alle] LT';

          default:
            return '[lo scorso] dddd [alle] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: function future(s) {
        return (/^[0-9].+$/.test(s) ? 'tra' : 'in') + ' ' + s;
      },
      past: '%s fa',
      s: 'alcuni secondi',
      ss: '%d secondi',
      m: 'un minuto',
      mm: '%d minuti',
      h: "un'ora",
      hh: '%d ore',
      d: 'un giorno',
      dd: '%d giorni',
      M: 'un mese',
      MM: '%d mesi',
      y: 'un anno',
      yy: '%d anni'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return itCh;
});

/***/ }),

/***/ "c2HN":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isPromise.js ***!
  \***************************************************************/
/*! exports provided: isPromise */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isPromise", function() { return isPromise; });
function isPromise(value) {
  return !!value && typeof value.subscribe !== 'function' && typeof value.then === 'function';
}

/***/ }),

/***/ "c6ID":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/sample.js ***!
  \*****************************************************************/
/*! exports provided: sample */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "sample", function() { return sample; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





function sample(notifier) {
  return function (source) {
    return source.lift(new SampleOperator(notifier));
  };
}

var SampleOperator = /*#__PURE__*/function () {
  function SampleOperator(notifier) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SampleOperator);

    this.notifier = notifier;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SampleOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      var sampleSubscriber = new SampleSubscriber(subscriber);
      var subscription = source.subscribe(sampleSubscriber);
      subscription.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(this.notifier, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](sampleSubscriber)));
      return subscription;
    }
  }]);

  return SampleOperator;
}();

var SampleSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SampleSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SampleSubscriber);

  function SampleSubscriber() {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SampleSubscriber);

    _this = _super.apply(this, arguments);
    _this.hasValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SampleSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.value = value;
      this.hasValue = true;
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      this.emitValue();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.emitValue();
    }
  }, {
    key: "emitValue",
    value: function emitValue() {
      if (this.hasValue) {
        this.hasValue = false;
        this.destination.next(this.value);
      }
    }
  }]);

  return SampleSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "c7jc":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/Immediate.js ***!
  \***************************************************************/
/*! exports provided: Immediate, TestTools */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Immediate", function() { return Immediate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TestTools", function() { return TestTools; });
var nextHandle = 1;

var RESOLVED = function () {
  return Promise.resolve();
}();

var activeHandles = {};

function findAndClearHandle(handle) {
  if (handle in activeHandles) {
    delete activeHandles[handle];
    return true;
  }

  return false;
}

var Immediate = {
  setImmediate: function setImmediate(cb) {
    var handle = nextHandle++;
    activeHandles[handle] = true;
    RESOLVED.then(function () {
      return findAndClearHandle(handle) && cb();
    });
    return handle;
  },
  clearImmediate: function clearImmediate(handle) {
    findAndClearHandle(handle);
  }
};
var TestTools = {
  pending: function pending() {
    return Object.keys(activeHandles).length;
  }
};

/***/ }),

/***/ "cBqT":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/find.js ***!
  \***************************************************************/
/*! exports provided: find, FindValueOperator, FindValueSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "find", function() { return find; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FindValueOperator", function() { return FindValueOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FindValueSubscriber", function() { return FindValueSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function find(predicate, thisArg) {
  if (typeof predicate !== 'function') {
    throw new TypeError('predicate is not a function');
  }

  return function (source) {
    return source.lift(new FindValueOperator(predicate, source, false, thisArg));
  };
}
var FindValueOperator = /*#__PURE__*/function () {
  function FindValueOperator(predicate, source, yieldIndex, thisArg) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, FindValueOperator);

    this.predicate = predicate;
    this.source = source;
    this.yieldIndex = yieldIndex;
    this.thisArg = thisArg;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(FindValueOperator, [{
    key: "call",
    value: function call(observer, source) {
      return source.subscribe(new FindValueSubscriber(observer, this.predicate, this.source, this.yieldIndex, this.thisArg));
    }
  }]);

  return FindValueOperator;
}();
var FindValueSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(FindValueSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(FindValueSubscriber);

  function FindValueSubscriber(destination, predicate, source, yieldIndex, thisArg) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, FindValueSubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.source = source;
    _this.yieldIndex = yieldIndex;
    _this.thisArg = thisArg;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(FindValueSubscriber, [{
    key: "notifyComplete",
    value: function notifyComplete(value) {
      var destination = this.destination;
      destination.next(value);
      destination.complete();
      this.unsubscribe();
    }
  }, {
    key: "_next",
    value: function _next(value) {
      var predicate = this.predicate,
          thisArg = this.thisArg;
      var index = this.index++;

      try {
        var result = predicate.call(thisArg || this, value, index, this.source);

        if (result) {
          this.notifyComplete(this.yieldIndex ? index : value);
        }
      } catch (err) {
        this.destination.error(err);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.notifyComplete(this.yieldIndex ? -1 : undefined);
    }
  }]);

  return FindValueSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "cRix":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/fy.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Frisian [fy]
//! author : Robin van der Vliet : https://github.com/robin0van0der0v
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortWithDots = 'jan._feb._mrt._apr._mai_jun._jul._aug._sep._okt._nov._des.'.split('_'),
      monthsShortWithoutDots = 'jan_feb_mrt_apr_mai_jun_jul_aug_sep_okt_nov_des'.split('_');
  var fy = moment.defineLocale('fy', {
    months: 'jannewaris_febrewaris_maart_april_maaie_juny_july_augustus_septimber_oktober_novimber_desimber'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortWithDots;
      } else if (/-MMM-/.test(format)) {
        return monthsShortWithoutDots[m.month()];
      } else {
        return monthsShortWithDots[m.month()];
      }
    },
    monthsParseExact: true,
    weekdays: 'snein_moandei_tiisdei_woansdei_tongersdei_freed_sneon'.split('_'),
    weekdaysShort: 'si._mo._ti._wo._to._fr._so.'.split('_'),
    weekdaysMin: 'Si_Mo_Ti_Wo_To_Fr_So'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD-MM-YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[hjoed om] LT',
      nextDay: '[moarn om] LT',
      nextWeek: 'dddd [om] LT',
      lastDay: '[juster om] LT',
      lastWeek: '[ôfrûne] dddd [om] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'oer %s',
      past: '%s lyn',
      s: 'in pear sekonden',
      ss: '%d sekonden',
      m: 'ien minút',
      mm: '%d minuten',
      h: 'ien oere',
      hh: '%d oeren',
      d: 'ien dei',
      dd: '%d dagen',
      M: 'ien moanne',
      MM: '%d moannen',
      y: 'ien jier',
      yy: '%d jierren'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(ste|de)/,
    ordinal: function ordinal(number) {
      return number + (number === 1 || number === 8 || number >= 20 ? 'ste' : 'de');
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return fy;
});

/***/ }),

/***/ "coGc":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/delayWhen.js ***!
  \********************************************************************/
/*! exports provided: delayWhen */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "delayWhen", function() { return delayWhen; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");








function delayWhen(delayDurationSelector, subscriptionDelay) {
  if (subscriptionDelay) {
    return function (source) {
      return new SubscriptionDelayObservable(source, subscriptionDelay).lift(new DelayWhenOperator(delayDurationSelector));
    };
  }

  return function (source) {
    return source.lift(new DelayWhenOperator(delayDurationSelector));
  };
}

var DelayWhenOperator = /*#__PURE__*/function () {
  function DelayWhenOperator(delayDurationSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DelayWhenOperator);

    this.delayDurationSelector = delayDurationSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DelayWhenOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DelayWhenSubscriber(subscriber, this.delayDurationSelector));
    }
  }]);

  return DelayWhenOperator;
}();

var DelayWhenSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(DelayWhenSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(DelayWhenSubscriber);

  function DelayWhenSubscriber(destination, delayDurationSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DelayWhenSubscriber);

    _this = _super.call(this, destination);
    _this.delayDurationSelector = delayDurationSelector;
    _this.completed = false;
    _this.delayNotifierSubscriptions = [];
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DelayWhenSubscriber, [{
    key: "notifyNext",
    value: function notifyNext(outerValue, _innerValue, _outerIndex, _innerIndex, innerSub) {
      this.destination.next(outerValue);
      this.removeSubscription(innerSub);
      this.tryComplete();
    }
  }, {
    key: "notifyError",
    value: function notifyError(error, innerSub) {
      this._error(error);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(innerSub) {
      var value = this.removeSubscription(innerSub);

      if (value) {
        this.destination.next(value);
      }

      this.tryComplete();
    }
  }, {
    key: "_next",
    value: function _next(value) {
      var index = this.index++;

      try {
        var delayNotifier = this.delayDurationSelector(value, index);

        if (delayNotifier) {
          this.tryDelay(delayNotifier, value);
        }
      } catch (err) {
        this.destination.error(err);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.completed = true;
      this.tryComplete();
      this.unsubscribe();
    }
  }, {
    key: "removeSubscription",
    value: function removeSubscription(subscription) {
      subscription.unsubscribe();
      var subscriptionIdx = this.delayNotifierSubscriptions.indexOf(subscription);

      if (subscriptionIdx !== -1) {
        this.delayNotifierSubscriptions.splice(subscriptionIdx, 1);
      }

      return subscription.outerValue;
    }
  }, {
    key: "tryDelay",
    value: function tryDelay(delayNotifier, value) {
      var notifierSubscription = Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__["subscribeToResult"])(this, delayNotifier, value);

      if (notifierSubscription && !notifierSubscription.closed) {
        var destination = this.destination;
        destination.add(notifierSubscription);
        this.delayNotifierSubscriptions.push(notifierSubscription);
      }
    }
  }, {
    key: "tryComplete",
    value: function tryComplete() {
      if (this.completed && this.delayNotifierSubscriptions.length === 0) {
        this.destination.complete();
      }
    }
  }]);

  return DelayWhenSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__["OuterSubscriber"]);

var SubscriptionDelayObservable = /*#__PURE__*/function (_Observable) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SubscriptionDelayObservable, _Observable);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SubscriptionDelayObservable);

  function SubscriptionDelayObservable(source, subscriptionDelay) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SubscriptionDelayObservable);

    _this2 = _super2.call(this);
    _this2.source = source;
    _this2.subscriptionDelay = subscriptionDelay;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SubscriptionDelayObservable, [{
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      this.subscriptionDelay.subscribe(new SubscriptionDelaySubscriber(subscriber, this.source));
    }
  }]);

  return SubscriptionDelayObservable;
}(_Observable__WEBPACK_IMPORTED_MODULE_5__["Observable"]);

var SubscriptionDelaySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SubscriptionDelaySubscriber, _Subscriber);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SubscriptionDelaySubscriber);

  function SubscriptionDelaySubscriber(parent, source) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SubscriptionDelaySubscriber);

    _this3 = _super3.call(this);
    _this3.parent = parent;
    _this3.source = source;
    _this3.sourceSubscribed = false;
    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SubscriptionDelaySubscriber, [{
    key: "_next",
    value: function _next(unused) {
      this.subscribeToSource();
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.unsubscribe();
      this.parent.error(err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.unsubscribe();
      this.subscribeToSource();
    }
  }, {
    key: "subscribeToSource",
    value: function subscribeToSource() {
      if (!this.sourceSubscribed) {
        this.sourceSubscribed = true;
        this.unsubscribe();
        this.source.subscribe(this.parent);
      }
    }
  }]);

  return SubscriptionDelaySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "cp0P":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/forkJoin.js ***!
  \********************************************************************/
/*! exports provided: forkJoin */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "forkJoin", function() { return forkJoin; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _operators_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../operators/map */ "lJxs");
/* harmony import */ var _util_isObject__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/isObject */ "XoHu");
/* harmony import */ var _from__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./from */ "Cfvw");






function forkJoin() {
  for (var _len = arguments.length, sources = new Array(_len), _key = 0; _key < _len; _key++) {
    sources[_key] = arguments[_key];
  }

  if (sources.length === 1) {
    var first = sources[0];

    if (Object(_util_isArray__WEBPACK_IMPORTED_MODULE_2__["isArray"])(first)) {
      return forkJoinInternal(first, null);
    }

    if (Object(_util_isObject__WEBPACK_IMPORTED_MODULE_4__["isObject"])(first) && Object.getPrototypeOf(first) === Object.prototype) {
      var keys = Object.keys(first);
      return forkJoinInternal(keys.map(function (key) {
        return first[key];
      }), keys);
    }
  }

  if (typeof sources[sources.length - 1] === 'function') {
    var resultSelector = sources.pop();
    sources = sources.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_2__["isArray"])(sources[0]) ? sources[0] : sources;
    return forkJoinInternal(sources, null).pipe(Object(_operators_map__WEBPACK_IMPORTED_MODULE_3__["map"])(function (args) {
      return resultSelector.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args));
    }));
  }

  return forkJoinInternal(sources, null);
}

function forkJoinInternal(sources, keys) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_1__["Observable"](function (subscriber) {
    var len = sources.length;

    if (len === 0) {
      subscriber.complete();
      return;
    }

    var values = new Array(len);
    var completed = 0;
    var emitted = 0;

    var _loop = function _loop(i) {
      var source = Object(_from__WEBPACK_IMPORTED_MODULE_5__["from"])(sources[i]);
      var hasValue = false;
      subscriber.add(source.subscribe({
        next: function next(value) {
          if (!hasValue) {
            hasValue = true;
            emitted++;
          }

          values[i] = value;
        },
        error: function error(err) {
          return subscriber.error(err);
        },
        complete: function complete() {
          completed++;

          if (completed === len || !hasValue) {
            if (emitted === len) {
              subscriber.next(keys ? keys.reduce(function (result, key, i) {
                return result[key] = values[i], result;
              }, {}) : values);
            }

            subscriber.complete();
          }
        }
      }));
    };

    for (var i = 0; i < len; i++) {
      _loop(i);
    }
  });
}

/***/ }),

/***/ "cx9U":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/single.js ***!
  \*****************************************************************/
/*! exports provided: single */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "single", function() { return single; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_EmptyError__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/EmptyError */ "sVev");






function single(predicate) {
  return function (source) {
    return source.lift(new SingleOperator(predicate, source));
  };
}

var SingleOperator = /*#__PURE__*/function () {
  function SingleOperator(predicate, source) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SingleOperator);

    this.predicate = predicate;
    this.source = source;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SingleOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SingleSubscriber(subscriber, this.predicate, this.source));
    }
  }]);

  return SingleOperator;
}();

var SingleSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SingleSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SingleSubscriber);

  function SingleSubscriber(destination, predicate, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SingleSubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.source = source;
    _this.seenValue = false;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SingleSubscriber, [{
    key: "applySingleValue",
    value: function applySingleValue(value) {
      if (this.seenValue) {
        this.destination.error('Sequence contains more than one element');
      } else {
        this.seenValue = true;
        this.singleValue = value;
      }
    }
  }, {
    key: "_next",
    value: function _next(value) {
      var index = this.index++;

      if (this.predicate) {
        this.tryNext(value, index);
      } else {
        this.applySingleValue(value);
      }
    }
  }, {
    key: "tryNext",
    value: function tryNext(value, index) {
      try {
        if (this.predicate(value, index, this.source)) {
          this.applySingleValue(value);
        }
      } catch (err) {
        this.destination.error(err);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var destination = this.destination;

      if (this.index > 0) {
        destination.next(this.seenValue ? this.singleValue : undefined);
        destination.complete();
      } else {
        destination.error(new _util_EmptyError__WEBPACK_IMPORTED_MODULE_5__["EmptyError"]());
      }
    }
  }]);

  return SingleSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "czMo":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-il.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (Israel) [en-il]
//! author : Chris Gedrim : https://github.com/chrisgedrim
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enIl = moment.defineLocale('en-il', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    }
  });
  return enIl;
});

/***/ }),

/***/ "dNwA":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sw.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Swahili [sw]
//! author : Fahad Kassim : https://github.com/fadsel
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var sw = moment.defineLocale('sw', {
    months: 'Januari_Februari_Machi_Aprili_Mei_Juni_Julai_Agosti_Septemba_Oktoba_Novemba_Desemba'.split('_'),
    monthsShort: 'Jan_Feb_Mac_Apr_Mei_Jun_Jul_Ago_Sep_Okt_Nov_Des'.split('_'),
    weekdays: 'Jumapili_Jumatatu_Jumanne_Jumatano_Alhamisi_Ijumaa_Jumamosi'.split('_'),
    weekdaysShort: 'Jpl_Jtat_Jnne_Jtan_Alh_Ijm_Jmos'.split('_'),
    weekdaysMin: 'J2_J3_J4_J5_Al_Ij_J1'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'hh:mm A',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[leo saa] LT',
      nextDay: '[kesho saa] LT',
      nextWeek: '[wiki ijayo] dddd [saat] LT',
      lastDay: '[jana] LT',
      lastWeek: '[wiki iliyopita] dddd [saat] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s baadaye',
      past: 'tokea %s',
      s: 'hivi punde',
      ss: 'sekunde %d',
      m: 'dakika moja',
      mm: 'dakika %d',
      h: 'saa limoja',
      hh: 'masaa %d',
      d: 'siku moja',
      dd: 'siku %d',
      M: 'mwezi mmoja',
      MM: 'miezi %d',
      y: 'mwaka mmoja',
      yy: 'miaka %d'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return sw;
});

/***/ }),

/***/ "dkDA":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/materialize.js ***!
  \**********************************************************************/
/*! exports provided: materialize */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "materialize", function() { return materialize; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Notification__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Notification */ "WMd4");






function materialize() {
  return function materializeOperatorFunction(source) {
    return source.lift(new MaterializeOperator());
  };
}

var MaterializeOperator = /*#__PURE__*/function () {
  function MaterializeOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MaterializeOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MaterializeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new MaterializeSubscriber(subscriber));
    }
  }]);

  return MaterializeOperator;
}();

var MaterializeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(MaterializeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(MaterializeSubscriber);

  function MaterializeSubscriber(destination) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, MaterializeSubscriber);

    return _super.call(this, destination);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(MaterializeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.destination.next(_Notification__WEBPACK_IMPORTED_MODULE_5__["Notification"].createNext(value));
    }
  }, {
    key: "_error",
    value: function _error(err) {
      var destination = this.destination;
      destination.next(_Notification__WEBPACK_IMPORTED_MODULE_5__["Notification"].createError(err));
      destination.complete();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var destination = this.destination;
      destination.next(_Notification__WEBPACK_IMPORTED_MODULE_5__["Notification"].createComplete());
      destination.complete();
    }
  }]);

  return MaterializeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "e+ae":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sk.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Slovak [sk]
//! author : Martin Minka : https://github.com/k2s
//! based on work of petrbela : https://github.com/petrbela
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var months = 'január_február_marec_apríl_máj_jún_júl_august_september_október_november_december'.split('_'),
      monthsShort = 'jan_feb_mar_apr_máj_jún_júl_aug_sep_okt_nov_dec'.split('_');

  function plural(n) {
    return n > 1 && n < 5;
  }

  function translate(number, withoutSuffix, key, isFuture) {
    var result = number + ' ';

    switch (key) {
      case 's':
        // a few seconds / in a few seconds / a few seconds ago
        return withoutSuffix || isFuture ? 'pár sekúnd' : 'pár sekundami';

      case 'ss':
        // 9 seconds / in 9 seconds / 9 seconds ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'sekundy' : 'sekúnd');
        } else {
          return result + 'sekundami';
        }

      case 'm':
        // a minute / in a minute / a minute ago
        return withoutSuffix ? 'minúta' : isFuture ? 'minútu' : 'minútou';

      case 'mm':
        // 9 minutes / in 9 minutes / 9 minutes ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'minúty' : 'minút');
        } else {
          return result + 'minútami';
        }

      case 'h':
        // an hour / in an hour / an hour ago
        return withoutSuffix ? 'hodina' : isFuture ? 'hodinu' : 'hodinou';

      case 'hh':
        // 9 hours / in 9 hours / 9 hours ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'hodiny' : 'hodín');
        } else {
          return result + 'hodinami';
        }

      case 'd':
        // a day / in a day / a day ago
        return withoutSuffix || isFuture ? 'deň' : 'dňom';

      case 'dd':
        // 9 days / in 9 days / 9 days ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'dni' : 'dní');
        } else {
          return result + 'dňami';
        }

      case 'M':
        // a month / in a month / a month ago
        return withoutSuffix || isFuture ? 'mesiac' : 'mesiacom';

      case 'MM':
        // 9 months / in 9 months / 9 months ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'mesiace' : 'mesiacov');
        } else {
          return result + 'mesiacmi';
        }

      case 'y':
        // a year / in a year / a year ago
        return withoutSuffix || isFuture ? 'rok' : 'rokom';

      case 'yy':
        // 9 years / in 9 years / 9 years ago
        if (withoutSuffix || isFuture) {
          return result + (plural(number) ? 'roky' : 'rokov');
        } else {
          return result + 'rokmi';
        }

    }
  }

  var sk = moment.defineLocale('sk', {
    months: months,
    monthsShort: monthsShort,
    weekdays: 'nedeľa_pondelok_utorok_streda_štvrtok_piatok_sobota'.split('_'),
    weekdaysShort: 'ne_po_ut_st_št_pi_so'.split('_'),
    weekdaysMin: 'ne_po_ut_st_št_pi_so'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm',
      LLLL: 'dddd D. MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[dnes o] LT',
      nextDay: '[zajtra o] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[v nedeľu o] LT';

          case 1:
          case 2:
            return '[v] dddd [o] LT';

          case 3:
            return '[v stredu o] LT';

          case 4:
            return '[vo štvrtok o] LT';

          case 5:
            return '[v piatok o] LT';

          case 6:
            return '[v sobotu o] LT';
        }
      },
      lastDay: '[včera o] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[minulú nedeľu o] LT';

          case 1:
          case 2:
            return '[minulý] dddd [o] LT';

          case 3:
            return '[minulú stredu o] LT';

          case 4:
          case 5:
            return '[minulý] dddd [o] LT';

          case 6:
            return '[minulú sobotu o] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: 'pred %s',
      s: translate,
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: translate,
      dd: translate,
      M: translate,
      MM: translate,
      y: translate,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return sk;
});

/***/ }),

/***/ "eIep":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/switchMap.js ***!
  \********************************************************************/
/*! exports provided: switchMap */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "switchMap", function() { return switchMap; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./map */ "lJxs");
/* harmony import */ var _observable_from__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../observable/from */ "Cfvw");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");









function switchMap(project, resultSelector) {
  if (typeof resultSelector === 'function') {
    return function (source) {
      return source.pipe(switchMap(function (a, i) {
        return Object(_observable_from__WEBPACK_IMPORTED_MODULE_7__["from"])(project(a, i)).pipe(Object(_map__WEBPACK_IMPORTED_MODULE_6__["map"])(function (b, ii) {
          return resultSelector(a, b, i, ii);
        }));
      }));
    };
  }

  return function (source) {
    return source.lift(new SwitchMapOperator(project));
  };
}

var SwitchMapOperator = /*#__PURE__*/function () {
  function SwitchMapOperator(project) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, SwitchMapOperator);

    this.project = project;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(SwitchMapOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SwitchMapSubscriber(subscriber, this.project));
    }
  }]);

  return SwitchMapOperator;
}();

var SwitchMapSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(SwitchMapSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(SwitchMapSubscriber);

  function SwitchMapSubscriber(destination, project) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, SwitchMapSubscriber);

    _this = _super.call(this, destination);
    _this.project = project;
    _this.index = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(SwitchMapSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var result;
      var index = this.index++;

      try {
        result = this.project(value, index);
      } catch (error) {
        this.destination.error(error);
        return;
      }

      this._innerSub(result);
    }
  }, {
    key: "_innerSub",
    value: function _innerSub(result) {
      var innerSubscription = this.innerSubscription;

      if (innerSubscription) {
        innerSubscription.unsubscribe();
      }

      var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["SimpleInnerSubscriber"](this);
      var destination = this.destination;
      destination.add(innerSubscriber);
      this.innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["innerSubscribe"])(result, innerSubscriber);

      if (this.innerSubscription !== innerSubscriber) {
        destination.add(this.innerSubscription);
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var innerSubscription = this.innerSubscription;

      if (!innerSubscription || innerSubscription.closed) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(SwitchMapSubscriber.prototype), "_complete", this).call(this);
      }

      this.unsubscribe();
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      this.innerSubscription = undefined;
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.innerSubscription = undefined;

      if (this.isStopped) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(SwitchMapSubscriber.prototype), "_complete", this).call(this);
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      this.destination.next(innerValue);
    }
  }]);

  return SwitchMapSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "eNwd":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/animationFrame.js ***!
  \*************************************************************************/
/*! exports provided: animationFrameScheduler, animationFrame */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "animationFrameScheduler", function() { return animationFrameScheduler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "animationFrame", function() { return animationFrame; });
/* harmony import */ var _AnimationFrameAction__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./AnimationFrameAction */ "Vpsf");
/* harmony import */ var _AnimationFrameScheduler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./AnimationFrameScheduler */ "znLP");


var animationFrameScheduler = new _AnimationFrameScheduler__WEBPACK_IMPORTED_MODULE_1__["AnimationFrameScheduler"](_AnimationFrameAction__WEBPACK_IMPORTED_MODULE_0__["AnimationFrameAction"]);
var animationFrame = animationFrameScheduler;

/***/ }),

/***/ "eZdR":
/*!*****************************************************!*\
  !*** ./node_modules/ng-event-source/eventsource.js ***!
  \*****************************************************/
/*! exports provided: EventSourcePolyfill */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EventSourcePolyfill", function() { return EventSourcePolyfill; });
/** @license
 * eventsource.js
 * Available under MIT License (MIT)
 * https://github.com/Yaffle/EventSource/
 */

/*jslint indent: 2, vars: true, plusplus: true */

/*global setTimeout, clearTimeout */
var EventSourcePolyfill = function (global) {
  "use strict";

  var setTimeout = global.setTimeout;
  var clearTimeout = global.clearTimeout;

  function Map() {
    this.data = {};
  }

  Map.prototype.get = function (key) {
    return this.data[key + "~"];
  };

  Map.prototype.set = function (key, value) {
    this.data[key + "~"] = value;
  };

  Map.prototype["delete"] = function (key) {
    delete this.data[key + "~"];
  };

  function EventTarget() {
    this.listeners = new Map();
  }

  function throwError(e) {
    setTimeout(function () {
      throw e;
    }, 0);
  }

  EventTarget.prototype.dispatchEvent = function (event) {
    event.target = this;
    var type = event.type.toString();
    var listeners = this.listeners;
    var typeListeners = listeners.get(type);

    if (typeListeners == undefined) {
      return;
    }

    var length = typeListeners.length;
    var i = -1;
    var listener = undefined;

    while (++i < length) {
      listener = typeListeners[i];

      try {
        listener.call(this, event);
      } catch (e) {
        throwError(e);
      }
    }
  };

  EventTarget.prototype.addEventListener = function (type, callback) {
    type = type.toString();
    var listeners = this.listeners;
    var typeListeners = listeners.get(type);

    if (typeListeners == undefined) {
      typeListeners = [];
      listeners.set(type, typeListeners);
    }

    var i = typeListeners.length;

    while (--i >= 0) {
      if (typeListeners[i] === callback) {
        return;
      }
    }

    typeListeners.push(callback);
  };

  EventTarget.prototype.removeEventListener = function (type, callback) {
    type = type.toString();
    var listeners = this.listeners;
    var typeListeners = listeners.get(type);

    if (typeListeners == undefined) {
      return;
    }

    var length = typeListeners.length;
    var filtered = [];
    var i = -1;

    while (++i < length) {
      if (typeListeners[i] !== callback) {
        filtered.push(typeListeners[i]);
      }
    }

    if (filtered.length === 0) {
      listeners["delete"](type);
    } else {
      listeners.set(type, filtered);
    }
  };

  function Event(type, code, msg) {
    this.type = type;
    this.target = undefined;
    this.errorCode = code;
    this.errorMessage = msg;
  }

  function MessageEvent(type, options) {
    Event.call(this, type);
    this.data = options.data;
    this.lastEventId = options.lastEventId;
  }

  MessageEvent.prototype = Event.prototype;
  var XHR = global.XMLHttpRequest;
  var XDR = global.XDomainRequest;
  var isCORSSupported = XHR != undefined && new XHR().withCredentials != undefined;
  var Transport = isCORSSupported || XHR != undefined && XDR == undefined ? XHR : XDR;
  var WAITING = -1;
  var CONNECTING = 0;
  var OPEN = 1;
  var CLOSED = 2;
  var AFTER_CR = 3;
  var FIELD_START = 4;
  var FIELD = 5;
  var VALUE_START = 6;
  var VALUE = 7;
  var contentTypeRegExp = /^text\/event\-stream;?(\s*charset\=utf\-8)?$/i;
  var MINIMUM_DURATION = 1000;
  var MAXIMUM_DURATION = 18000000;

  function getDuration(value, def) {
    var n = value;

    if (n !== n) {
      n = def;
    }

    return n < MINIMUM_DURATION ? MINIMUM_DURATION : n > MAXIMUM_DURATION ? MAXIMUM_DURATION : n;
  }

  function fire(that, f, event) {
    try {
      if (typeof f === "function") {
        f.call(that, event);
      }
    } catch (e) {
      throwError(e);
    }
  }

  function EventSourcePolyfill(url, options) {
    var url = url.toString();
    var withCredentials = isCORSSupported && options != undefined && Boolean(options.withCredentials);
    var initialRetry = getDuration(1000, 0);
    var heartbeatTimeout = getDuration(options.heartbeatTimeout || 45000, 0);
    var checkActivity = true;

    if (options && options.checkActivity != null) {
      checkActivity = Boolean(options.checkActivity);
    }

    var connectionTimeout = 0;

    if (options && options.connectionTimeout) {
      connectionTimeout = options.connectionTimeout;
    }

    var lastEventId = "";
    var headers = options && options.headers || {};
    var that = this;
    var retry = initialRetry;
    var wasActivity = false;
    var CurrentTransport = options != undefined && options.Transport != undefined ? options.Transport : Transport;
    var xhr = new CurrentTransport();
    var timeout = 0;
    var timeout0 = 0;
    var timeoutConnection = 0;
    var charOffset = 0;
    var currentState = WAITING;
    var dataBuffer = [];
    var lastEventIdBuffer = "";
    var eventTypeBuffer = "";
    var _onTimeout = undefined;
    var errorOnTimeout = true;

    if (options && options.errorOnTimeout !== undefined && options.errorOnTimeout !== null) {
      errorOnTimeout = options.errorOnTimeout;
    }

    var state = FIELD_START;
    var field = "";
    var value = "";

    function close() {
      currentState = CLOSED;

      if (xhr != undefined) {
        xhr.abort();
        xhr = undefined;
      }

      if (timeout !== 0) {
        clearTimeout(timeout);
        timeout = 0;
      }

      if (timeout0 !== 0) {
        clearTimeout(timeout0);
        timeout0 = 0;
      }

      if (timeoutConnection !== 0) {
        clearTimeout(timeoutConnection);
        timeoutConnection = 0;
      }

      that.readyState = CLOSED;
    }

    function onEvent(type) {
      if (currentState === CLOSED) {
        if (xhr != null) {
          xhr.abort();
          xhr = undefined;
        }

        return;
      }

      if (xhr.status >= 500) {
        setTimeout(function () {
          if (errorOnTimeout) {
            throw new Error("Reconnecting");
          }

          return;
        }, 0);
        currentState = WAITING;
        xhr.abort();

        if (timeout !== 0) {
          clearTimeout(timeout);
          timeout = 0;
        }

        if (retry > initialRetry * 16) {
          retry = initialRetry * 16;
        }

        if (retry > MAXIMUM_DURATION) {
          retry = MAXIMUM_DURATION;
        }

        timeout = setTimeout(_onTimeout, retry);
        retry = retry * 2 + 1;
        that.readyState = CONNECTING;
        event = new Event("error", xhr.status, "");
        that.dispatchEvent(event);
        fire(that, that.onerror, event);
      } else {
        var responseText = "";

        if (currentState === OPEN || currentState === CONNECTING) {
          try {
            responseText = xhr.responseText;
          } catch (error) {// IE 8 - 9 with XMLHttpRequest
          }
        }

        var event = undefined;
        var isWrongStatusCodeOrContentType = false;

        if (currentState === CONNECTING) {
          var status = 0;
          var statusText = "";
          var contentType = undefined;

          if (!("contentType" in xhr)) {
            try {
              status = xhr.status;
              statusText = xhr.statusText;
              contentType = xhr.getResponseHeader("Content-Type");
            } catch (error) {
              // https://bugs.webkit.org/show_bug.cgi?id=29121
              status = 0;
              statusText = "";
              contentType = undefined; // FF < 14, WebKit
              // https://bugs.webkit.org/show_bug.cgi?id=29658
              // https://bugs.webkit.org/show_bug.cgi?id=77854
            }
          } else if (type !== "" && type !== "error") {
            status = 200;
            statusText = "OK";
            contentType = xhr.contentType;
          }

          if (contentType == undefined) {
            contentType = "";
          }

          if (status === 0 && statusText === "" && type === "load" && responseText !== "") {
            status = 200;
            statusText = "OK";

            if (contentType === "") {
              // Opera 12
              var tmp = /^data\:([^,]*?)(?:;base64)?,[\S]*$/.exec(url);

              if (tmp != undefined) {
                contentType = tmp[1];
              }
            }
          }

          if (status === 200 && contentTypeRegExp.test(contentType)) {
            currentState = OPEN;
            wasActivity = true;
            retry = initialRetry;
            that.readyState = OPEN;
            event = new Event("open", status, "");
            that.dispatchEvent(event);
            fire(that, that.onopen, event);

            if (currentState === CLOSED) {
              return;
            }
          } else {
            // Opera 12
            if (status !== 0 && (status !== 200 || contentType !== "")) {
              var message = "";

              if (status !== 200) {
                message = "EventSource's response has a status " + status + " " + statusText.replace(/\s+/g, " ") + " that is not 200. Aborting the connection.";
              } else {
                message = "EventSource's response has a Content-Type specifying an unsupported type: " + contentType.replace(/\s+/g, " ") + ". Aborting the connection.";
              }

              setTimeout(function () {
                var ev = new Event("error", status, message);
                fire(that, that.onerror, ev);
                throw new Error(message);
              }, 0);
              isWrongStatusCodeOrContentType = true;
            }
          }
        }

        if (currentState === OPEN) {
          if (responseText.length > charOffset) {
            wasActivity = true;
          }

          var i = charOffset - 1;
          var length = responseText.length;
          var c = "\n";

          while (++i < length) {
            c = responseText.charAt(i);

            if (state === AFTER_CR && c === "\n") {
              state = FIELD_START;
            } else {
              if (state === AFTER_CR) {
                state = FIELD_START;
              }

              if (c === "\r" || c === "\n") {
                if (field === "data") {
                  dataBuffer.push(value);
                } else if (field === "id") {
                  lastEventIdBuffer = value;
                } else if (field === "event") {
                  eventTypeBuffer = value;
                } else if (field === "retry") {
                  initialRetry = getDuration(Number(value), initialRetry);
                  retry = initialRetry;
                } else if (field === "heartbeatTimeout") {
                  heartbeatTimeout = getDuration(Number(value), heartbeatTimeout);

                  if (timeout !== 0) {
                    clearTimeout(timeout);
                    timeout = setTimeout(_onTimeout, heartbeatTimeout);
                  }
                }

                value = "";
                field = "";

                if (state === FIELD_START) {
                  if (dataBuffer.length !== 0) {
                    lastEventId = lastEventIdBuffer;

                    if (eventTypeBuffer === "") {
                      eventTypeBuffer = "message";
                    }

                    event = new MessageEvent(eventTypeBuffer, {
                      data: dataBuffer.join("\n"),
                      lastEventId: lastEventIdBuffer
                    });
                    that.dispatchEvent(event);

                    if (eventTypeBuffer === "message") {
                      fire(that, that.onmessage, event);
                    }

                    if (currentState === CLOSED) {
                      return;
                    }
                  }

                  dataBuffer.length = 0;
                  eventTypeBuffer = "";
                }

                state = c === "\r" ? AFTER_CR : FIELD_START;
              } else {
                if (state === FIELD_START) {
                  state = FIELD;
                }

                if (state === FIELD) {
                  if (c === ":") {
                    state = VALUE_START;
                  } else {
                    field += c;
                  }
                } else if (state === VALUE_START) {
                  if (c !== " ") {
                    value += c;
                  }

                  state = VALUE;
                } else if (state === VALUE) {
                  value += c;
                }
              }
            }
          }

          charOffset = length;
        }

        if ((currentState === OPEN || currentState === CONNECTING) && (type === "load" || type === "error" || isWrongStatusCodeOrContentType || timeout === 0 && (!wasActivity || !checkActivity))) {
          if (isWrongStatusCodeOrContentType) {
            close();
          } else {
            if (type === "" && timeout === 0 && (!wasActivity || !checkActivity)) {
              setTimeout(function () {
                if (errorOnTimeout) {
                  throw new Error("No activity within " + heartbeatTimeout + " milliseconds. Reconnecting.");
                }

                return;
              }, 0);
            }

            currentState = WAITING;
            xhr.abort();

            if (timeout !== 0) {
              clearTimeout(timeout);
              timeout = 0;
            }

            if (retry > initialRetry * 16) {
              retry = initialRetry * 16;
            }

            if (retry > MAXIMUM_DURATION) {
              retry = MAXIMUM_DURATION;
            }

            timeout = setTimeout(_onTimeout, retry);
            retry = retry * 2 + 1;
            that.readyState = CONNECTING;
          }

          var statusCode = 0;

          if (xhr && xhr.status) {
            statusCode = xhr.status;
          }

          event = new Event("error", statusCode, "");
          that.dispatchEvent(event);
          fire(that, that.onerror, event);
        } else {
          if (timeout === 0) {
            wasActivity = false;
            timeout = setTimeout(_onTimeout, heartbeatTimeout);
          }
        }
      }
    }

    function onProgress() {
      onEvent("progress");
    }

    function onLoad() {
      onEvent("load");
    }

    function onError() {
      onEvent("error");
    }

    function onReadyStateChange() {
      if (xhr && xhr.readyState === 4) {
        if (xhr.status === 0) {
          onEvent("error");
        } else {
          onEvent("load");
        }
      } else {
        onEvent("progress");
      }
    }

    if ("readyState" in xhr && global.opera != undefined) {
      // workaround for Opera issue with "progress" events
      timeout0 = setTimeout(function f() {
        if (xhr.readyState === 3) {
          onEvent("progress");
        }

        timeout0 = setTimeout(f, 500);
      }, 0);
    }

    that = this;

    _onTimeout = function onTimeout() {
      timeout = 0;

      if (currentState !== WAITING) {
        onEvent("");
        return;
      } // loading indicator in Safari, Chrome < 14
      // loading indicator in Firefox
      // https://bugzilla.mozilla.org/show_bug.cgi?id=736723


      if ((!("ontimeout" in xhr) || "sendAsBinary" in xhr || "mozAnon" in xhr) && global.document != undefined && global.document.readyState != undefined && global.document.readyState !== "complete") {
        timeout = setTimeout(_onTimeout, 4);
        return;
      } // XDomainRequest#abort removes onprogress, onerror, onload


      xhr.onload = onLoad;
      xhr.onerror = onError;

      if ("onabort" in xhr) {
        // improper fix to match Firefox behaviour, but it is better than just ignore abort
        // see https://bugzilla.mozilla.org/show_bug.cgi?id=768596
        // https://bugzilla.mozilla.org/show_bug.cgi?id=880200
        // https://code.google.com/p/chromium/issues/detail?id=153570
        xhr.onabort = onError;
      }

      if ("onprogress" in xhr) {
        xhr.onprogress = onProgress;
      } // IE 8-9 (XMLHTTPRequest)
      // Firefox 3.5 - 3.6 - ? < 9.0
      // onprogress is not fired sometimes or delayed
      // see also #64


      if ("onreadystatechange" in xhr) {
        xhr.onreadystatechange = onReadyStateChange;
      }

      wasActivity = false;
      timeout = setTimeout(_onTimeout, heartbeatTimeout);

      if (connectionTimeout && connectionTimeout > 0) {
        timeoutConnection = setTimeout(function () {
          if (xhr.status === 0) {
            xhr.timeout = 1;

            if (errorOnTimeout) {
              console.log('No ack received');
            }
          }
        }, connectionTimeout);
      }

      charOffset = 0;
      currentState = CONNECTING;
      dataBuffer.length = 0;
      eventTypeBuffer = "";
      lastEventIdBuffer = lastEventId;
      value = "";
      field = "";
      state = FIELD_START;
      var s = that.url.slice(0, 5);

      if (s !== "data:" && s !== "blob:") {
        s = that.url + ((that.url.indexOf("?", 0) === -1 ? "?" : "&") + "lastEventId=" + encodeURIComponent(lastEventId) + "&r=" + (Math.random() + 1).toString().slice(2));
      } else {
        s = that.url;
      }

      xhr.open("GET", s, true);
      xhr.timeout = 0;

      if ("withCredentials" in xhr) {
        // withCredentials should be set after "open" for Safari and Chrome (< 19 ?)
        xhr.withCredentials = withCredentials;
      }

      if ("responseType" in xhr) {
        xhr.responseType = "text";
      }

      if ("setRequestHeader" in xhr) {
        // Request header field Cache-Control is not allowed by Access-Control-Allow-Headers.
        // "Cache-control: no-cache" are not honored in Chrome and Firefox
        // https://bugzilla.mozilla.org/show_bug.cgi?id=428916
        //xhr.setRequestHeader("Cache-Control", "no-cache");
        xhr.setRequestHeader("Accept", "text/event-stream"); // Request header field Last-Event-ID is not allowed by Access-Control-Allow-Headers.
        //xhr.setRequestHeader("Last-Event-ID", lastEventId);
        // Add the headers to the transport.

        var headerKeys = Object.keys(headers);

        for (var i = 0; i < headerKeys.length; i++) {
          xhr.setRequestHeader(headerKeys[i], headers[headerKeys[i]]);
        }
      }

      xhr.send(undefined);
    };

    this.update = function (options) {
      if (xhr && options && options.headers) {
        // Add the headers to the transport.
        headers = options.headers;
      }
    };

    EventTarget.call(this);
    this.close = close;
    this.url = url;
    this.readyState = CONNECTING;
    this.withCredentials = withCredentials;
    this.onopen = undefined;
    this.onmessage = undefined;
    this.onerror = undefined;

    _onTimeout();
  }

  function F() {
    this.CONNECTING = CONNECTING;
    this.OPEN = OPEN;
    this.CLOSED = CLOSED;
  }

  F.prototype = EventTarget.prototype;
  EventSourcePolyfill.prototype = new F();
  F.call(EventSourcePolyfill);

  if (isCORSSupported) {
    EventSourcePolyfill.prototype.withCredentials = undefined;
  }

  return EventSourcePolyfill;
}(typeof window !== 'undefined' ? window : undefined);



/***/ }),

/***/ "f15z":
/*!***************************************************************************!*\
  !*** ./node_modules/dgp-oauth2-ng/__ivy_ngcc__/fesm2015/dgp-oauth2-ng.js ***!
  \***************************************************************************/
/*! exports provided: AuthComponent, AuthService, DgpOauth2Module */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AuthComponent", function() { return AuthComponent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AuthService", function() { return AuthService; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DgpOauth2Module", function() { return DgpOauth2Module; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @angular/core */ "fXoL");
/* harmony import */ var _angular_common_http__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @angular/common/http */ "tk/3");
/* harmony import */ var rxjs__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! rxjs */ "qCKp");
/* harmony import */ var rxjs_operators__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! rxjs/operators */ "kU1M");
/* harmony import */ var _angular_platform_browser__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @angular/platform-browser */ "jhN1");
/* harmony import */ var _angular_common__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @angular/common */ "ofXK");











function AuthComponent_div_1_Template(rf, ctx) {
  if (rf & 1) {
    var _r4 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵgetCurrentView"]();

    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](0, "div", 3);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](1, "span", 4);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵlistener"]("click", function AuthComponent_div_1_Template_span_click_1_listener() {
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵrestoreView"](_r4);
      var ctx_r3 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵnextContext"]();
      return ctx_r3.login();
    });
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtext"](2, "\u05D4\u05EA\u05D7\u05D1\u05E8\u05D5\u05EA");
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
  }
}

function AuthComponent_div_2_Template(rf, ctx) {
  if (rf & 1) {
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](0, "div", 3);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](1, "div", 5);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelement"](2, "img", 6);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵnamespaceSVG"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](3, "svg", 7);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelement"](4, "path", 8);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
  }

  if (rf & 2) {
    var ctx_r1 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵnextContext"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵadvance"](2);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵproperty"]("src", ctx_r1.user.profile.avatar_url, _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵsanitizeUrl"]);
  }
}

function AuthComponent_div_3_Template(rf, ctx) {
  if (rf & 1) {
    var _r6 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵgetCurrentView"]();

    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](0, "div", 9);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](1, "span", 10);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵlistener"]("click", function AuthComponent_div_3_Template_span_click_1_listener() {
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵrestoreView"](_r6);
      var ctx_r5 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵnextContext"]();
      return ctx_r5.profile();
    });
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtext"](2, "\u05D4\u05EA\u05E8\u05D0\u05D5\u05EA \u05E9\u05DE\u05D5\u05E8\u05D5\u05EA");
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](3, "span", 10);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵlistener"]("click", function AuthComponent_div_3_Template_span_click_3_listener() {
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵrestoreView"](_r6);
      var ctx_r7 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵnextContext"]();
      return ctx_r7.profile();
    });
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtext"](4, "\u05E4\u05E8\u05D5\u05E4\u05D9\u05DC \u05D0\u05D9\u05E9\u05D9");
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](5, "span", 10);
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵlistener"]("click", function AuthComponent_div_3_Template_span_click_5_listener() {
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵrestoreView"](_r6);
      var ctx_r8 = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵnextContext"]();
      return ctx_r8.logout();
    });
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtext"](6, "\u05D4\u05EA\u05E0\u05EA\u05E7\u05D5\u05EA");
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
  }
}

var AuthService = /*#__PURE__*/function () {
  function AuthService(http) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AuthService);

    this.http = http;
    this.user = new rxjs__WEBPACK_IMPORTED_MODULE_4__["BehaviorSubject"](null);
    this.jwt = new rxjs__WEBPACK_IMPORTED_MODULE_4__["BehaviorSubject"](null);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AuthService, [{
    key: "configure",
    value: function configure(authConfig) {
      this.authServerUrl = authConfig.authServerUrl;
      this.jwtLocalStorageKey = authConfig.jwtLocalStorageKey;
      this.jwtQueryParam = authConfig.jwtQueryParam;
      this.profilePagePath = authConfig.profilePagePath;
    }
    /**
     * gets the jwt token, first tries from URL, then from local storage
     */

  }, {
    key: "resolveToken",
    value: function resolveToken() {
      var search = document.location.search.trim();

      if (search.startsWith('?')) {
        search = search.substring(1);
      }

      var params = new URLSearchParams(search);
      var jwt = params.get(this.jwtQueryParam);

      if (jwt) {
        // remove the jwt query param from the URL
        params.delete(this.jwtQueryParam);
        search = params.toString();
        history.replaceState(null, document.title, document.location.href.split('?')[0] + '?' + search);
        return jwt;
      } else {
        return this.getToken();
      }
    }
    /**
     * get the token from local storage
     */

  }, {
    key: "getToken",
    value: function getToken() {
      return localStorage.getItem(this.jwtLocalStorageKey);
    }
    /**
     * set the token in local storage
     */

  }, {
    key: "setToken",
    value: function setToken(jwt) {
      this.jwt.next(jwt);
      localStorage.setItem(this.jwtLocalStorageKey, jwt);
    }
    /**
     * delete the token from local storage
     */

  }, {
    key: "deleteToken",
    value: function deleteToken() {
      this.jwt.next(null);
      localStorage.removeItem(this.jwtLocalStorageKey);
    }
  }, {
    key: "getUser",
    value: function getUser() {
      return this.user;
    }
  }, {
    key: "getJwt",
    value: function getJwt() {
      return this.jwt;
    }
  }, {
    key: "check",
    value: function check(next) {
      var _this = this;

      var jwt = this.resolveToken();

      if (jwt) {
        this.setToken(jwt);
      }

      var resp = this.http.get(this.authServerUrl + '/auth/check?jwt=' + (jwt ? jwt : '') + '&next=' + encodeURIComponent(next));
      resp.subscribe(function (user) {
        _this.user.next(user);
      });
      return this.user;
    }
  }, {
    key: "logout",
    value: function logout(next) {
      this.deleteToken();
      return this.check(next);
    }
  }, {
    key: "permission",
    value: function permission(service) {
      var _this2 = this;

      return this.jwt.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_5__["filter"])(function (token) {
        return token !== null;
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_5__["switchMap"])(function (token) {
        return _this2.http.get(_this2.authServerUrl + '/auth/authorize?service=' + service + '&jwt=' + token);
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_5__["first"])());
    }
  }]);

  return AuthService;
}();

AuthService.ɵfac = function AuthService_Factory(t) {
  return new (t || AuthService)(_angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵinject"](_angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClient"]));
};

AuthService.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵdefineInjectable"])({
  factory: function AuthService_Factory() {
    return new AuthService(Object(_angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵinject"])(_angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClient"]));
  },
  token: AuthService,
  providedIn: "root"
});

AuthService.ctorParameters = function () {
  return [{
    type: _angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClient"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵsetClassMetadata"](AuthService, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_2__["Injectable"],
    args: [{
      providedIn: 'root'
    }]
  }], function () {
    return [{
      type: _angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClient"]
    }];
  }, null);
})();

var AuthComponent = /*#__PURE__*/function () {
  function AuthComponent(auth) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AuthComponent);

    this.auth = auth;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AuthComponent, [{
    key: "ngOnInit",
    value: function ngOnInit() {
      this.next = document.location.href;
      this.setUser(this.auth.check(this.next));
    }
  }, {
    key: "setUser",
    value: function setUser(o) {
      var _this3 = this;

      o.subscribe(function (user) {
        _this3.user = user;
      });
    }
  }, {
    key: "login",
    value: function login() {
      var _this4 = this;

      if (this.user && this.user.providers) {
        var href = this.user.providers.google || this.user.providers.github;

        if (href && href.url) {
          if (document.location.href === this.next) {
            window.location.href = href.url;
          } else {
            this.next = document.location.href;
            this.auth.check(this.next).subscribe(function (user) {
              _this4.user = user;

              _this4.login();
            });
          }
        }
      }
    }
  }, {
    key: "logout",
    value: function logout() {
      this.auth.logout(document.location.href);
    }
  }, {
    key: "profile",
    value: function profile() {
      if (this.auth.profilePagePath) {
        var params = '';

        if (this.theme && this.theme.themeId) {
          params = '?theme=' + this.theme.themeId;
        }

        window.location.href = this.auth.profilePagePath + params;
      }
    }
  }]);

  return AuthComponent;
}();

AuthComponent.ɵfac = function AuthComponent_Factory(t) {
  return new (t || AuthComponent)(_angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵdirectiveInject"](AuthService));
};

AuthComponent.ɵcmp = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵdefineComponent"]({
  type: AuthComponent,
  selectors: [["dgp-oauth2-ng"]],
  inputs: {
    theme: "theme"
  },
  decls: 4,
  vars: 3,
  consts: [[1, "widget"], ["class", "top-line", 4, "ngIf"], ["class", "menu", 4, "ngIf"], [1, "top-line"], [1, "login", 3, "click"], [1, "profile"], ["width", "100%", "height", "100%", 3, "src"], ["width", "12px", "height", "8px", "viewBox", "0 0 12 8", "version", "1.1", "xmlns", "http://www.w3.org/2000/svg", 0, "xmlns", "xlink", "http://www.w3.org/1999/xlink", 1, "chevron"], ["transform", "translate(0,-2)", "fill", "#FF5A5F", "stoke-width", "0px", "stroke", "#FF5A5F", "d", "M2.53033009,3.46966991 C2.23743687,3.1767767 1.76256313,3.1767767 1.46966991,3.46966991 C1.1767767,3.76256313 1.1767767,4.23743687 1.46966991,4.53033009 L5.46966991,8.53033009 C5.76256313,8.8232233 6.23743687,8.8232233 6.53033009,8.53033009 L10.5303301,4.53033009 C10.8232233,4.23743687 10.8232233,3.76256313 10.5303301,3.46966991 C10.2374369,3.1767767 9.76256313,3.1767767 9.46966991,3.46966991 L6,6.93933983 L2.53033009,3.46966991 Z"], [1, "menu"], [1, "menu-line", 3, "click"]],
  template: function AuthComponent_Template(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementStart"](0, "div", 0);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtemplate"](1, AuthComponent_div_1_Template, 3, 0, "div", 1);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtemplate"](2, AuthComponent_div_2_Template, 5, 1, "div", 1);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵtemplate"](3, AuthComponent_div_3_Template, 7, 0, "div", 2);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵelementEnd"]();
    }

    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵadvance"](1);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵproperty"]("ngIf", !ctx.user || !ctx.user.authenticated);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵadvance"](1);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵproperty"]("ngIf", ctx.user && ctx.user.authenticated);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵadvance"](1);
      _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵproperty"]("ngIf", ctx.user && ctx.user.authenticated);
    }
  },
  directives: [_angular_common__WEBPACK_IMPORTED_MODULE_7__["NgIf"]],
  styles: [".widget[_ngcontent-%COMP%]{font-weight:300;height:40px;min-width:50px;position:relative}.login[_ngcontent-%COMP%]{color:#bdbdbd;cursor:pointer;font-family:Abraham TRIAL;font-size:16px}.top-line[_ngcontent-%COMP%]{align-items:center;display:flex;flex-flow:row;height:100%}.top-line[_ngcontent-%COMP%]   svg[_ngcontent-%COMP%]{margin-right:4px}.profile[_ngcontent-%COMP%]{border:1px solid #ff5a5f;border-radius:15px;height:30px;overflow:hidden;width:30px}.menu[_ngcontent-%COMP%]{align-items:flex-start;background-color:#fff;border:1px solid #eee;border-radius:4px;box-shadow:0 2px 10px 0 rgba(0,0,0,.1);display:none;flex-flow:column;position:absolute;right:-50px;top:40px;width:130px;z-index:10}.widget[_ngcontent-%COMP%]:hover   .menu[_ngcontent-%COMP%]{display:flex}.menu-line[_ngcontent-%COMP%]{color:#7d7d7d;cursor:pointer;font-family:Abraham TRIAL;font-size:14px;padding:6px 10px;width:100%}.menu-line[_ngcontent-%COMP%]:hover{background-color:#fcebec;color:#ff5a5f}"]
});

AuthComponent.ctorParameters = function () {
  return [{
    type: AuthService
  }];
};

AuthComponent.propDecorators = {
  theme: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_2__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵsetClassMetadata"](AuthComponent, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_2__["Component"],
    args: [{
      selector: 'dgp-oauth2-ng',
      template: "<div class='widget'>\n    <div *ngIf=\"!user || !user.authenticated\"\n        class='top-line'>\n    <span class=\"login\"\n            (click)=\"login()\"\n    >\u05D4\u05EA\u05D7\u05D1\u05E8\u05D5\u05EA</span>\n    </div>\n    <div *ngIf=\"user && user.authenticated\"\n        class='top-line'>\n    <div class='profile'>\n        <img width='100%' height='100%' [src]=\"user.profile.avatar_url\">\n    </div>\n    <svg class='chevron' \n            width=\"12px\" height=\"8px\" \n            viewBox=\"0 0 12 8\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n        <path transform=\"translate(0,-2)\" \n                fill=\"#FF5A5F\" stoke-width='0px' stroke=\"#FF5A5F\" \n                d=\"M2.53033009,3.46966991 C2.23743687,3.1767767 1.76256313,3.1767767 1.46966991,3.46966991 C1.1767767,3.76256313 1.1767767,4.23743687 1.46966991,4.53033009 L5.46966991,8.53033009 C5.76256313,8.8232233 6.23743687,8.8232233 6.53033009,8.53033009 L10.5303301,4.53033009 C10.8232233,4.23743687 10.8232233,3.76256313 10.5303301,3.46966991 C10.2374369,3.1767767 9.76256313,3.1767767 9.46966991,3.46966991 L6,6.93933983 L2.53033009,3.46966991 Z\">\n        </path>\n    </svg>\n    </div>\n    <div *ngIf=\"user && user.authenticated\"\n        class='menu'>\n    <span class='menu-line' (click)=\"profile()\">\u05D4\u05EA\u05E8\u05D0\u05D5\u05EA \u05E9\u05DE\u05D5\u05E8\u05D5\u05EA</span>\n    <span class='menu-line' (click)=\"profile()\">\u05E4\u05E8\u05D5\u05E4\u05D9\u05DC \u05D0\u05D9\u05E9\u05D9</span>\n    <span class='menu-line' (click)=\"logout()\">\u05D4\u05EA\u05E0\u05EA\u05E7\u05D5\u05EA</span>\n    </div>\n</div>\n",
      styles: [".widget{font-weight:300;height:40px;min-width:50px;position:relative}.login{color:#bdbdbd;cursor:pointer;font-family:Abraham TRIAL;font-size:16px}.top-line{align-items:center;display:flex;flex-flow:row;height:100%}.top-line svg{margin-right:4px}.profile{border:1px solid #ff5a5f;border-radius:15px;height:30px;overflow:hidden;width:30px}.menu{align-items:flex-start;background-color:#fff;border:1px solid #eee;border-radius:4px;box-shadow:0 2px 10px 0 rgba(0,0,0,.1);display:none;flex-flow:column;position:absolute;right:-50px;top:40px;width:130px;z-index:10}.widget:hover .menu{display:flex}.menu-line{color:#7d7d7d;cursor:pointer;font-family:Abraham TRIAL;font-size:14px;padding:6px 10px;width:100%}.menu-line:hover{background-color:#fcebec;color:#ff5a5f}"]
    }]
  }], function () {
    return [{
      type: AuthService
    }];
  }, {
    theme: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_2__["Input"]
    }]
  });
})();

var DgpOauth2Module = function DgpOauth2Module() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, DgpOauth2Module);
};

DgpOauth2Module.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵdefineNgModule"]({
  type: DgpOauth2Module
});
DgpOauth2Module.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵdefineInjector"]({
  factory: function DgpOauth2Module_Factory(t) {
    return new (t || DgpOauth2Module)();
  },
  providers: [],
  imports: [[_angular_platform_browser__WEBPACK_IMPORTED_MODULE_6__["BrowserModule"], _angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClientModule"]]]
});

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵɵsetNgModuleScope"](DgpOauth2Module, {
    declarations: function declarations() {
      return [AuthComponent];
    },
    imports: function imports() {
      return [_angular_platform_browser__WEBPACK_IMPORTED_MODULE_6__["BrowserModule"], _angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClientModule"]];
    },
    exports: function exports() {
      return [AuthComponent];
    }
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_2__["ɵsetClassMetadata"](DgpOauth2Module, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_2__["NgModule"],
    args: [{
      declarations: [AuthComponent],
      imports: [_angular_platform_browser__WEBPACK_IMPORTED_MODULE_6__["BrowserModule"], _angular_common_http__WEBPACK_IMPORTED_MODULE_3__["HttpClientModule"]],
      exports: [AuthComponent],
      providers: []
    }]
  }], null, null);
})();
/*
 * Public API Surface of dgp-oauth2-ng
 */

/**
 * Generated bundle index. Do not edit.
 */




/***/ }),

/***/ "f29J":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/concat.js ***!
  \*****************************************************************/
/*! exports provided: concat */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "concat", function() { return concat; });
/* harmony import */ var _observable_concat__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/concat */ "GyhO");

function concat() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  return function (source) {
    return source.lift.call(_observable_concat__WEBPACK_IMPORTED_MODULE_0__["concat"].apply(void 0, [source].concat(observables)));
  };
}

/***/ }),

/***/ "fFD9":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/combineLatest.js ***!
  \************************************************************************/
/*! exports provided: combineLatest */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "combineLatest", function() { return combineLatest; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _observable_combineLatest__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../observable/combineLatest */ "itXk");
/* harmony import */ var _observable_from__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../observable/from */ "Cfvw");




var none = {};
function combineLatest() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  var project = null;

  if (typeof observables[observables.length - 1] === 'function') {
    project = observables.pop();
  }

  if (observables.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_1__["isArray"])(observables[0])) {
    observables = observables[0].slice();
  }

  return function (source) {
    return source.lift.call(Object(_observable_from__WEBPACK_IMPORTED_MODULE_3__["from"])([source].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(observables))), new _observable_combineLatest__WEBPACK_IMPORTED_MODULE_2__["CombineLatestOperator"](project));
  };
}

/***/ }),

/***/ "fXoL":
/*!******************************************************************!*\
  !*** ./node_modules/@angular/core/__ivy_ngcc__/fesm2015/core.js ***!
  \******************************************************************/
/*! exports provided: ANALYZE_FOR_ENTRY_COMPONENTS, APP_BOOTSTRAP_LISTENER, APP_ID, APP_INITIALIZER, ApplicationInitStatus, ApplicationModule, ApplicationRef, Attribute, COMPILER_OPTIONS, CUSTOM_ELEMENTS_SCHEMA, ChangeDetectionStrategy, ChangeDetectorRef, Compiler, CompilerFactory, Component, ComponentFactory, ComponentFactoryResolver, ComponentRef, ContentChild, ContentChildren, DEFAULT_CURRENCY_CODE, DebugElement, DebugEventListener, DebugNode, DefaultIterableDiffer, Directive, ElementRef, EmbeddedViewRef, ErrorHandler, EventEmitter, Host, HostBinding, HostListener, INJECTOR, Inject, InjectFlags, Injectable, InjectionToken, Injector, Input, IterableDiffers, KeyValueDiffers, LOCALE_ID, MissingTranslationStrategy, ModuleWithComponentFactories, NO_ERRORS_SCHEMA, NgModule, NgModuleFactory, NgModuleFactoryLoader, NgModuleRef, NgProbeToken, NgZone, Optional, Output, PACKAGE_ROOT_URL, PLATFORM_ID, PLATFORM_INITIALIZER, Pipe, PlatformRef, Query, QueryList, ReflectiveInjector, ReflectiveKey, Renderer2, RendererFactory2, RendererStyleFlags2, ResolvedReflectiveFactory, Sanitizer, SecurityContext, Self, SimpleChange, SkipSelf, SystemJsNgModuleLoader, SystemJsNgModuleLoaderConfig, TRANSLATIONS, TRANSLATIONS_FORMAT, TemplateRef, Testability, TestabilityRegistry, Type, VERSION, Version, ViewChild, ViewChildren, ViewContainerRef, ViewEncapsulation, ViewRef, WrappedValue, asNativeElements, assertPlatform, createPlatform, createPlatformFactory, defineInjectable, destroyPlatform, enableProdMode, forwardRef, getDebugNode, getModuleFactory, getPlatform, inject, isDevMode, platformCore, resolveForwardRef, setTestabilityGetter, ɵ0, ɵ1, ɵALLOW_MULTIPLE_PLATFORMS, ɵAPP_ID_RANDOM_PROVIDER, ɵChangeDetectorStatus, ɵCodegenComponentFactoryResolver, ɵCompiler_compileModuleAndAllComponentsAsync__POST_R3__, ɵCompiler_compileModuleAndAllComponentsSync__POST_R3__, ɵCompiler_compileModuleAsync__POST_R3__, ɵCompiler_compileModuleSync__POST_R3__, ɵComponentFactory, ɵConsole, ɵDEFAULT_LOCALE_ID, ɵEMPTY_ARRAY, ɵEMPTY_MAP, ɵINJECTOR_IMPL__POST_R3__, ɵINJECTOR_SCOPE, ɵLifecycleHooksFeature, ɵLocaleDataIndex, ɵNG_COMP_DEF, ɵNG_DIR_DEF, ɵNG_ELEMENT_ID, ɵNG_INJ_DEF, ɵNG_MOD_DEF, ɵNG_PIPE_DEF, ɵNG_PROV_DEF, ɵNOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR, ɵNO_CHANGE, ɵNgModuleFactory, ɵNoopNgZone, ɵReflectionCapabilities, ɵRender3ComponentFactory, ɵRender3ComponentRef, ɵRender3NgModuleRef, ɵSWITCH_CHANGE_DETECTOR_REF_FACTORY__POST_R3__, ɵSWITCH_COMPILE_COMPONENT__POST_R3__, ɵSWITCH_COMPILE_DIRECTIVE__POST_R3__, ɵSWITCH_COMPILE_INJECTABLE__POST_R3__, ɵSWITCH_COMPILE_NGMODULE__POST_R3__, ɵSWITCH_COMPILE_PIPE__POST_R3__, ɵSWITCH_ELEMENT_REF_FACTORY__POST_R3__, ɵSWITCH_IVY_ENABLED__POST_R3__, ɵSWITCH_RENDERER2_FACTORY__POST_R3__, ɵSWITCH_TEMPLATE_REF_FACTORY__POST_R3__, ɵSWITCH_VIEW_CONTAINER_REF_FACTORY__POST_R3__, ɵ_sanitizeHtml, ɵ_sanitizeUrl, ɵallowSanitizationBypassAndThrow, ɵand, ɵangular_packages_core_core_a, ɵangular_packages_core_core_b, ɵangular_packages_core_core_ba, ɵangular_packages_core_core_bb, ɵangular_packages_core_core_bc, ɵangular_packages_core_core_bd, ɵangular_packages_core_core_bf, ɵangular_packages_core_core_bg, ɵangular_packages_core_core_bh, ɵangular_packages_core_core_bi, ɵangular_packages_core_core_bj, ɵangular_packages_core_core_bk, ɵangular_packages_core_core_bl, ɵangular_packages_core_core_bm, ɵangular_packages_core_core_bn, ɵangular_packages_core_core_bp, ɵangular_packages_core_core_bq, ɵangular_packages_core_core_c, ɵangular_packages_core_core_d, ɵangular_packages_core_core_e, ɵangular_packages_core_core_f, ɵangular_packages_core_core_g, ɵangular_packages_core_core_h, ɵangular_packages_core_core_i, ɵangular_packages_core_core_j, ɵangular_packages_core_core_k, ɵangular_packages_core_core_l, ɵangular_packages_core_core_m, ɵangular_packages_core_core_n, ɵangular_packages_core_core_o, ɵangular_packages_core_core_p, ɵangular_packages_core_core_q, ɵangular_packages_core_core_r, ɵangular_packages_core_core_s, ɵangular_packages_core_core_t, ɵangular_packages_core_core_u, ɵangular_packages_core_core_v, ɵangular_packages_core_core_w, ɵangular_packages_core_core_x, ɵangular_packages_core_core_y, ɵangular_packages_core_core_z, ɵbypassSanitizationTrustHtml, ɵbypassSanitizationTrustResourceUrl, ɵbypassSanitizationTrustScript, ɵbypassSanitizationTrustStyle, ɵbypassSanitizationTrustUrl, ɵccf, ɵclearOverrides, ɵclearResolutionOfComponentResourcesQueue, ɵcmf, ɵcompileComponent, ɵcompileDirective, ɵcompileNgModule, ɵcompileNgModuleDefs, ɵcompileNgModuleFactory__POST_R3__, ɵcompilePipe, ɵcreateInjector, ɵcrt, ɵdefaultIterableDiffers, ɵdefaultKeyValueDiffers, ɵdetectChanges, ɵdevModeEqual, ɵdid, ɵeld, ɵfindLocaleData, ɵflushModuleScopingQueueAsMuchAsPossible, ɵgetComponentViewDefinitionFactory, ɵgetDebugNodeR2, ɵgetDebugNode__POST_R3__, ɵgetDirectives, ɵgetHostElement, ɵgetInjectableDef, ɵgetLContext, ɵgetLocaleCurrencyCode, ɵgetLocalePluralCase, ɵgetModuleFactory__POST_R3__, ɵgetSanitizationBypassType, ɵglobal, ɵinitServicesIfNeeded, ɵinlineInterpolate, ɵinterpolate, ɵisBoundToModule__POST_R3__, ɵisDefaultChangeDetectionStrategy, ɵisListLikeIterable, ɵisObservable, ɵisPromise, ɵivyEnabled, ɵmakeDecorator, ɵmarkDirty, ɵmod, ɵmpd, ɵncd, ɵnoSideEffects, ɵnov, ɵoverrideComponentView, ɵoverrideProvider, ɵpad, ɵpatchComponentDefWithScope, ɵpid, ɵpod, ɵppd, ɵprd, ɵpublishDefaultGlobalUtils, ɵpublishGlobalUtil, ɵqud, ɵregisterLocaleData, ɵregisterModuleFactory, ɵregisterNgModuleType, ɵrenderComponent, ɵresetCompiledComponents, ɵresetJitOptions, ɵresolveComponentResources, ɵsetClassMetadata, ɵsetCurrentInjector, ɵsetDocument, ɵsetLocaleId, ɵstore, ɵstringify, ɵted, ɵtransitiveScopesFor, ɵunregisterLocaleData, ɵunv, ɵunwrapSafeValue, ɵvid, ɵwhenRendered, ɵɵCopyDefinitionFeature, ɵɵInheritDefinitionFeature, ɵɵNgOnChangesFeature, ɵɵProvidersFeature, ɵɵadvance, ɵɵattribute, ɵɵattributeInterpolate1, ɵɵattributeInterpolate2, ɵɵattributeInterpolate3, ɵɵattributeInterpolate4, ɵɵattributeInterpolate5, ɵɵattributeInterpolate6, ɵɵattributeInterpolate7, ɵɵattributeInterpolate8, ɵɵattributeInterpolateV, ɵɵclassMap, ɵɵclassMapInterpolate1, ɵɵclassMapInterpolate2, ɵɵclassMapInterpolate3, ɵɵclassMapInterpolate4, ɵɵclassMapInterpolate5, ɵɵclassMapInterpolate6, ɵɵclassMapInterpolate7, ɵɵclassMapInterpolate8, ɵɵclassMapInterpolateV, ɵɵclassProp, ɵɵcontentQuery, ɵɵdefineComponent, ɵɵdefineDirective, ɵɵdefineInjectable, ɵɵdefineInjector, ɵɵdefineNgModule, ɵɵdefinePipe, ɵɵdirectiveInject, ɵɵdisableBindings, ɵɵelement, ɵɵelementContainer, ɵɵelementContainerEnd, ɵɵelementContainerStart, ɵɵelementEnd, ɵɵelementStart, ɵɵenableBindings, ɵɵgetCurrentView, ɵɵgetFactoryOf, ɵɵgetInheritedFactory, ɵɵhostProperty, ɵɵi18n, ɵɵi18nApply, ɵɵi18nAttributes, ɵɵi18nEnd, ɵɵi18nExp, ɵɵi18nPostprocess, ɵɵi18nStart, ɵɵinject, ɵɵinjectAttribute, ɵɵinjectPipeChangeDetectorRef, ɵɵinvalidFactory, ɵɵinvalidFactoryDep, ɵɵlistener, ɵɵloadQuery, ɵɵnamespaceHTML, ɵɵnamespaceMathML, ɵɵnamespaceSVG, ɵɵnextContext, ɵɵpipe, ɵɵpipeBind1, ɵɵpipeBind2, ɵɵpipeBind3, ɵɵpipeBind4, ɵɵpipeBindV, ɵɵprojection, ɵɵprojectionDef, ɵɵproperty, ɵɵpropertyInterpolate, ɵɵpropertyInterpolate1, ɵɵpropertyInterpolate2, ɵɵpropertyInterpolate3, ɵɵpropertyInterpolate4, ɵɵpropertyInterpolate5, ɵɵpropertyInterpolate6, ɵɵpropertyInterpolate7, ɵɵpropertyInterpolate8, ɵɵpropertyInterpolateV, ɵɵpureFunction0, ɵɵpureFunction1, ɵɵpureFunction2, ɵɵpureFunction3, ɵɵpureFunction4, ɵɵpureFunction5, ɵɵpureFunction6, ɵɵpureFunction7, ɵɵpureFunction8, ɵɵpureFunctionV, ɵɵqueryRefresh, ɵɵreference, ɵɵresolveBody, ɵɵresolveDocument, ɵɵresolveWindow, ɵɵrestoreView, ɵɵsanitizeHtml, ɵɵsanitizeResourceUrl, ɵɵsanitizeScript, ɵɵsanitizeStyle, ɵɵsanitizeUrl, ɵɵsanitizeUrlOrResourceUrl, ɵɵsetComponentScope, ɵɵsetNgModuleScope, ɵɵstaticContentQuery, ɵɵstaticViewQuery, ɵɵstyleMap, ɵɵstyleMapInterpolate1, ɵɵstyleMapInterpolate2, ɵɵstyleMapInterpolate3, ɵɵstyleMapInterpolate4, ɵɵstyleMapInterpolate5, ɵɵstyleMapInterpolate6, ɵɵstyleMapInterpolate7, ɵɵstyleMapInterpolate8, ɵɵstyleMapInterpolateV, ɵɵstyleProp, ɵɵstylePropInterpolate1, ɵɵstylePropInterpolate2, ɵɵstylePropInterpolate3, ɵɵstylePropInterpolate4, ɵɵstylePropInterpolate5, ɵɵstylePropInterpolate6, ɵɵstylePropInterpolate7, ɵɵstylePropInterpolate8, ɵɵstylePropInterpolateV, ɵɵsyntheticHostListener, ɵɵsyntheticHostProperty, ɵɵtemplate, ɵɵtemplateRefExtractor, ɵɵtext, ɵɵtextInterpolate, ɵɵtextInterpolate1, ɵɵtextInterpolate2, ɵɵtextInterpolate3, ɵɵtextInterpolate4, ɵɵtextInterpolate5, ɵɵtextInterpolate6, ɵɵtextInterpolate7, ɵɵtextInterpolate8, ɵɵtextInterpolateV, ɵɵviewQuery */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ANALYZE_FOR_ENTRY_COMPONENTS", function() { return ANALYZE_FOR_ENTRY_COMPONENTS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "APP_BOOTSTRAP_LISTENER", function() { return APP_BOOTSTRAP_LISTENER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "APP_ID", function() { return APP_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "APP_INITIALIZER", function() { return APP_INITIALIZER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ApplicationInitStatus", function() { return ApplicationInitStatus; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ApplicationModule", function() { return ApplicationModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ApplicationRef", function() { return ApplicationRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Attribute", function() { return Attribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "COMPILER_OPTIONS", function() { return COMPILER_OPTIONS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CUSTOM_ELEMENTS_SCHEMA", function() { return CUSTOM_ELEMENTS_SCHEMA; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ChangeDetectionStrategy", function() { return ChangeDetectionStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ChangeDetectorRef", function() { return ChangeDetectorRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Compiler", function() { return Compiler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CompilerFactory", function() { return CompilerFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Component", function() { return Component; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ComponentFactory", function() { return ComponentFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ComponentFactoryResolver", function() { return ComponentFactoryResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ComponentRef", function() { return ComponentRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ContentChild", function() { return ContentChild; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ContentChildren", function() { return ContentChildren; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DEFAULT_CURRENCY_CODE", function() { return DEFAULT_CURRENCY_CODE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DebugElement", function() { return DebugElement; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DebugEventListener", function() { return DebugEventListener; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DebugNode", function() { return DebugNode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DefaultIterableDiffer", function() { return DefaultIterableDiffer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Directive", function() { return Directive; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ElementRef", function() { return ElementRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EmbeddedViewRef", function() { return EmbeddedViewRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ErrorHandler", function() { return ErrorHandler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EventEmitter", function() { return EventEmitter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Host", function() { return Host; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HostBinding", function() { return HostBinding; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HostListener", function() { return HostListener; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "INJECTOR", function() { return INJECTOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Inject", function() { return Inject; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InjectFlags", function() { return InjectFlags; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Injectable", function() { return Injectable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "InjectionToken", function() { return InjectionToken; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Injector", function() { return Injector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Input", function() { return Input; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "IterableDiffers", function() { return IterableDiffers; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "KeyValueDiffers", function() { return KeyValueDiffers; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LOCALE_ID", function() { return LOCALE_ID$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MissingTranslationStrategy", function() { return MissingTranslationStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ModuleWithComponentFactories", function() { return ModuleWithComponentFactories; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NO_ERRORS_SCHEMA", function() { return NO_ERRORS_SCHEMA; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModule", function() { return NgModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModuleFactory", function() { return NgModuleFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModuleFactoryLoader", function() { return NgModuleFactoryLoader; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgModuleRef", function() { return NgModuleRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgProbeToken", function() { return NgProbeToken; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgZone", function() { return NgZone; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Optional", function() { return Optional; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Output", function() { return Output; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PACKAGE_ROOT_URL", function() { return PACKAGE_ROOT_URL; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PLATFORM_ID", function() { return PLATFORM_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PLATFORM_INITIALIZER", function() { return PLATFORM_INITIALIZER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Pipe", function() { return Pipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PlatformRef", function() { return PlatformRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Query", function() { return Query; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "QueryList", function() { return QueryList; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReflectiveInjector", function() { return ReflectiveInjector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReflectiveKey", function() { return ReflectiveKey; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Renderer2", function() { return Renderer2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RendererFactory2", function() { return RendererFactory2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RendererStyleFlags2", function() { return RendererStyleFlags2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ResolvedReflectiveFactory", function() { return ResolvedReflectiveFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Sanitizer", function() { return Sanitizer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SecurityContext", function() { return SecurityContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Self", function() { return Self; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SimpleChange", function() { return SimpleChange; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SkipSelf", function() { return SkipSelf; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SystemJsNgModuleLoader", function() { return SystemJsNgModuleLoader; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SystemJsNgModuleLoaderConfig", function() { return SystemJsNgModuleLoaderConfig; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TRANSLATIONS", function() { return TRANSLATIONS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TRANSLATIONS_FORMAT", function() { return TRANSLATIONS_FORMAT; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TemplateRef", function() { return TemplateRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Testability", function() { return Testability; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TestabilityRegistry", function() { return TestabilityRegistry; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Type", function() { return Type; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Version", function() { return Version; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewChild", function() { return ViewChild; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewChildren", function() { return ViewChildren; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewContainerRef", function() { return ViewContainerRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewEncapsulation", function() { return ViewEncapsulation$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewRef", function() { return ViewRef$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "WrappedValue", function() { return WrappedValue; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "asNativeElements", function() { return asNativeElements; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "assertPlatform", function() { return assertPlatform; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createPlatform", function() { return createPlatform; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "createPlatformFactory", function() { return createPlatformFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "defineInjectable", function() { return defineInjectable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "destroyPlatform", function() { return destroyPlatform; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "enableProdMode", function() { return enableProdMode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "forwardRef", function() { return forwardRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getDebugNode", function() { return getDebugNode$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getModuleFactory", function() { return getModuleFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getPlatform", function() { return getPlatform; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "inject", function() { return inject; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isDevMode", function() { return isDevMode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "platformCore", function() { return platformCore; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "resolveForwardRef", function() { return resolveForwardRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "setTestabilityGetter", function() { return setTestabilityGetter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵ0", function() { return ɵ0; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵ1", function() { return ɵ1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵALLOW_MULTIPLE_PLATFORMS", function() { return ALLOW_MULTIPLE_PLATFORMS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵAPP_ID_RANDOM_PROVIDER", function() { return APP_ID_RANDOM_PROVIDER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵChangeDetectorStatus", function() { return ChangeDetectorStatus; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCodegenComponentFactoryResolver", function() { return CodegenComponentFactoryResolver; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCompiler_compileModuleAndAllComponentsAsync__POST_R3__", function() { return Compiler_compileModuleAndAllComponentsAsync__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCompiler_compileModuleAndAllComponentsSync__POST_R3__", function() { return Compiler_compileModuleAndAllComponentsSync__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCompiler_compileModuleAsync__POST_R3__", function() { return Compiler_compileModuleAsync__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵCompiler_compileModuleSync__POST_R3__", function() { return Compiler_compileModuleSync__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵComponentFactory", function() { return ComponentFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵConsole", function() { return Console; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵDEFAULT_LOCALE_ID", function() { return DEFAULT_LOCALE_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵEMPTY_ARRAY", function() { return EMPTY_ARRAY$4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵEMPTY_MAP", function() { return EMPTY_MAP; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵINJECTOR_IMPL__POST_R3__", function() { return INJECTOR_IMPL__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵINJECTOR_SCOPE", function() { return INJECTOR_SCOPE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵLifecycleHooksFeature", function() { return LifecycleHooksFeature; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵLocaleDataIndex", function() { return LocaleDataIndex; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_COMP_DEF", function() { return NG_COMP_DEF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_DIR_DEF", function() { return NG_DIR_DEF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_ELEMENT_ID", function() { return NG_ELEMENT_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_INJ_DEF", function() { return NG_INJ_DEF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_MOD_DEF", function() { return NG_MOD_DEF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_PIPE_DEF", function() { return NG_PIPE_DEF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNG_PROV_DEF", function() { return NG_PROV_DEF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR", function() { return NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNO_CHANGE", function() { return NO_CHANGE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNgModuleFactory", function() { return NgModuleFactory$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNoopNgZone", function() { return NoopNgZone; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵReflectionCapabilities", function() { return ReflectionCapabilities; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵRender3ComponentFactory", function() { return ComponentFactory$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵRender3ComponentRef", function() { return ComponentRef$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵRender3NgModuleRef", function() { return NgModuleRef$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_CHANGE_DETECTOR_REF_FACTORY__POST_R3__", function() { return SWITCH_CHANGE_DETECTOR_REF_FACTORY__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_COMPILE_COMPONENT__POST_R3__", function() { return SWITCH_COMPILE_COMPONENT__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_COMPILE_DIRECTIVE__POST_R3__", function() { return SWITCH_COMPILE_DIRECTIVE__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_COMPILE_INJECTABLE__POST_R3__", function() { return SWITCH_COMPILE_INJECTABLE__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_COMPILE_NGMODULE__POST_R3__", function() { return SWITCH_COMPILE_NGMODULE__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_COMPILE_PIPE__POST_R3__", function() { return SWITCH_COMPILE_PIPE__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_ELEMENT_REF_FACTORY__POST_R3__", function() { return SWITCH_ELEMENT_REF_FACTORY__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_IVY_ENABLED__POST_R3__", function() { return SWITCH_IVY_ENABLED__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_RENDERER2_FACTORY__POST_R3__", function() { return SWITCH_RENDERER2_FACTORY__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_TEMPLATE_REF_FACTORY__POST_R3__", function() { return SWITCH_TEMPLATE_REF_FACTORY__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSWITCH_VIEW_CONTAINER_REF_FACTORY__POST_R3__", function() { return SWITCH_VIEW_CONTAINER_REF_FACTORY__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵ_sanitizeHtml", function() { return _sanitizeHtml; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵ_sanitizeUrl", function() { return _sanitizeUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵallowSanitizationBypassAndThrow", function() { return allowSanitizationBypassAndThrow; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵand", function() { return anchorDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_a", function() { return isForwardRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_b", function() { return injectInjectorOnly; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_ba", function() { return instructionState; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bb", function() { return getLView; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bc", function() { return getBindingRoot; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bd", function() { return nextContextImpl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bf", function() { return pureFunction1Internal; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bg", function() { return pureFunction2Internal; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bh", function() { return pureFunction3Internal; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bi", function() { return pureFunction4Internal; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bj", function() { return pureFunctionVInternal; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bk", function() { return getUrlSanitizer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bl", function() { return makeParamDecorator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bm", function() { return makePropDecorator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bn", function() { return getClosureSafeProperty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bp", function() { return getRootContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_bq", function() { return i18nPostprocess; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_c", function() { return NullInjector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_d", function() { return ReflectiveInjector_; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_e", function() { return ReflectiveDependency; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_f", function() { return resolveReflectiveProviders; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_g", function() { return _appIdRandomProviderFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_h", function() { return createElementRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_i", function() { return createTemplateRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_j", function() { return getModuleFactory__PRE_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_k", function() { return DebugNode__PRE_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_l", function() { return DebugElement__PRE_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_m", function() { return getDebugNodeR2__PRE_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_n", function() { return DefaultIterableDifferFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_o", function() { return DefaultKeyValueDifferFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_p", function() { return _iterableDiffersFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_q", function() { return _keyValueDiffersFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_r", function() { return _localeFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_s", function() { return APPLICATION_MODULE_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_t", function() { return zoneSchedulerFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_u", function() { return USD_CURRENCY_CODE; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_v", function() { return _def; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_w", function() { return DebugContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_x", function() { return NgOnChangesFeatureImpl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_y", function() { return SCHEDULER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_core_core_z", function() { return injectAttributeImpl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵbypassSanitizationTrustHtml", function() { return bypassSanitizationTrustHtml; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵbypassSanitizationTrustResourceUrl", function() { return bypassSanitizationTrustResourceUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵbypassSanitizationTrustScript", function() { return bypassSanitizationTrustScript; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵbypassSanitizationTrustStyle", function() { return bypassSanitizationTrustStyle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵbypassSanitizationTrustUrl", function() { return bypassSanitizationTrustUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵccf", function() { return createComponentFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵclearOverrides", function() { return clearOverrides; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵclearResolutionOfComponentResourcesQueue", function() { return clearResolutionOfComponentResourcesQueue; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcmf", function() { return createNgModuleFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcompileComponent", function() { return compileComponent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcompileDirective", function() { return compileDirective; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcompileNgModule", function() { return compileNgModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcompileNgModuleDefs", function() { return compileNgModuleDefs; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcompileNgModuleFactory__POST_R3__", function() { return compileNgModuleFactory__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcompilePipe", function() { return compilePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcreateInjector", function() { return createInjector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵcrt", function() { return createRendererType2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵdefaultIterableDiffers", function() { return defaultIterableDiffers; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵdefaultKeyValueDiffers", function() { return defaultKeyValueDiffers; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵdetectChanges", function() { return detectChanges; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵdevModeEqual", function() { return devModeEqual; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵdid", function() { return directiveDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵeld", function() { return elementDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵfindLocaleData", function() { return findLocaleData; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵflushModuleScopingQueueAsMuchAsPossible", function() { return flushModuleScopingQueueAsMuchAsPossible; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetComponentViewDefinitionFactory", function() { return getComponentViewDefinitionFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetDebugNodeR2", function() { return getDebugNodeR2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetDebugNode__POST_R3__", function() { return getDebugNode__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetDirectives", function() { return getDirectives; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetHostElement", function() { return getHostElement; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetInjectableDef", function() { return getInjectableDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetLContext", function() { return getLContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetLocaleCurrencyCode", function() { return getLocaleCurrencyCode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetLocalePluralCase", function() { return getLocalePluralCase; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetModuleFactory__POST_R3__", function() { return getModuleFactory__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetSanitizationBypassType", function() { return getSanitizationBypassType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵglobal", function() { return _global; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵinitServicesIfNeeded", function() { return initServicesIfNeeded; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵinlineInterpolate", function() { return inlineInterpolate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵinterpolate", function() { return interpolate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵisBoundToModule__POST_R3__", function() { return isBoundToModule__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵisDefaultChangeDetectionStrategy", function() { return isDefaultChangeDetectionStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵisListLikeIterable", function() { return isListLikeIterable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵisObservable", function() { return isObservable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵisPromise", function() { return isPromise; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵivyEnabled", function() { return ivyEnabled; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵmakeDecorator", function() { return makeDecorator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵmarkDirty", function() { return markDirty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵmod", function() { return moduleDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵmpd", function() { return moduleProvideDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵncd", function() { return ngContentDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵnoSideEffects", function() { return noSideEffects; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵnov", function() { return nodeValue; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵoverrideComponentView", function() { return overrideComponentView; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵoverrideProvider", function() { return overrideProvider; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵpad", function() { return pureArrayDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵpatchComponentDefWithScope", function() { return patchComponentDefWithScope; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵpid", function() { return pipeDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵpod", function() { return pureObjectDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵppd", function() { return purePipeDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵprd", function() { return providerDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵpublishDefaultGlobalUtils", function() { return publishDefaultGlobalUtils; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵpublishGlobalUtil", function() { return publishGlobalUtil; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵqud", function() { return queryDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵregisterLocaleData", function() { return registerLocaleData; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵregisterModuleFactory", function() { return registerModuleFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵregisterNgModuleType", function() { return registerNgModuleType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵrenderComponent", function() { return renderComponent$1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵresetCompiledComponents", function() { return resetCompiledComponents; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵresetJitOptions", function() { return resetJitOptions; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵresolveComponentResources", function() { return resolveComponentResources; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵsetClassMetadata", function() { return setClassMetadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵsetCurrentInjector", function() { return setCurrentInjector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵsetDocument", function() { return setDocument; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵsetLocaleId", function() { return setLocaleId; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵstore", function() { return store; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵstringify", function() { return stringify; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵted", function() { return textDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵtransitiveScopesFor", function() { return transitiveScopesFor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵunregisterLocaleData", function() { return unregisterAllLocaleData; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵunv", function() { return unwrapValue; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵunwrapSafeValue", function() { return unwrapSafeValue; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵvid", function() { return viewDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵwhenRendered", function() { return whenRendered; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵCopyDefinitionFeature", function() { return ɵɵCopyDefinitionFeature; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵInheritDefinitionFeature", function() { return ɵɵInheritDefinitionFeature; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵNgOnChangesFeature", function() { return ɵɵNgOnChangesFeature; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵProvidersFeature", function() { return ɵɵProvidersFeature; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵadvance", function() { return ɵɵadvance; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattribute", function() { return ɵɵattribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate1", function() { return ɵɵattributeInterpolate1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate2", function() { return ɵɵattributeInterpolate2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate3", function() { return ɵɵattributeInterpolate3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate4", function() { return ɵɵattributeInterpolate4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate5", function() { return ɵɵattributeInterpolate5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate6", function() { return ɵɵattributeInterpolate6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate7", function() { return ɵɵattributeInterpolate7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolate8", function() { return ɵɵattributeInterpolate8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵattributeInterpolateV", function() { return ɵɵattributeInterpolateV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMap", function() { return ɵɵclassMap; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate1", function() { return ɵɵclassMapInterpolate1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate2", function() { return ɵɵclassMapInterpolate2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate3", function() { return ɵɵclassMapInterpolate3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate4", function() { return ɵɵclassMapInterpolate4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate5", function() { return ɵɵclassMapInterpolate5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate6", function() { return ɵɵclassMapInterpolate6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate7", function() { return ɵɵclassMapInterpolate7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolate8", function() { return ɵɵclassMapInterpolate8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassMapInterpolateV", function() { return ɵɵclassMapInterpolateV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵclassProp", function() { return ɵɵclassProp; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵcontentQuery", function() { return ɵɵcontentQuery; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdefineComponent", function() { return ɵɵdefineComponent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdefineDirective", function() { return ɵɵdefineDirective; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdefineInjectable", function() { return ɵɵdefineInjectable; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdefineInjector", function() { return ɵɵdefineInjector; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdefineNgModule", function() { return ɵɵdefineNgModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdefinePipe", function() { return ɵɵdefinePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdirectiveInject", function() { return ɵɵdirectiveInject; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵdisableBindings", function() { return ɵɵdisableBindings; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵelement", function() { return ɵɵelement; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵelementContainer", function() { return ɵɵelementContainer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵelementContainerEnd", function() { return ɵɵelementContainerEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵelementContainerStart", function() { return ɵɵelementContainerStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵelementEnd", function() { return ɵɵelementEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵelementStart", function() { return ɵɵelementStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵenableBindings", function() { return ɵɵenableBindings; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵgetCurrentView", function() { return ɵɵgetCurrentView; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵgetFactoryOf", function() { return ɵɵgetFactoryOf; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵgetInheritedFactory", function() { return ɵɵgetInheritedFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵhostProperty", function() { return ɵɵhostProperty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18n", function() { return ɵɵi18n; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18nApply", function() { return ɵɵi18nApply; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18nAttributes", function() { return ɵɵi18nAttributes; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18nEnd", function() { return ɵɵi18nEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18nExp", function() { return ɵɵi18nExp; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18nPostprocess", function() { return ɵɵi18nPostprocess; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵi18nStart", function() { return ɵɵi18nStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵinject", function() { return ɵɵinject; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵinjectAttribute", function() { return ɵɵinjectAttribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵinjectPipeChangeDetectorRef", function() { return ɵɵinjectPipeChangeDetectorRef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵinvalidFactory", function() { return ɵɵinvalidFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵinvalidFactoryDep", function() { return ɵɵinvalidFactoryDep; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵlistener", function() { return ɵɵlistener; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵloadQuery", function() { return ɵɵloadQuery; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵnamespaceHTML", function() { return ɵɵnamespaceHTML; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵnamespaceMathML", function() { return ɵɵnamespaceMathML; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵnamespaceSVG", function() { return ɵɵnamespaceSVG; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵnextContext", function() { return ɵɵnextContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpipe", function() { return ɵɵpipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpipeBind1", function() { return ɵɵpipeBind1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpipeBind2", function() { return ɵɵpipeBind2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpipeBind3", function() { return ɵɵpipeBind3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpipeBind4", function() { return ɵɵpipeBind4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpipeBindV", function() { return ɵɵpipeBindV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵprojection", function() { return ɵɵprojection; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵprojectionDef", function() { return ɵɵprojectionDef; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵproperty", function() { return ɵɵproperty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate", function() { return ɵɵpropertyInterpolate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate1", function() { return ɵɵpropertyInterpolate1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate2", function() { return ɵɵpropertyInterpolate2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate3", function() { return ɵɵpropertyInterpolate3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate4", function() { return ɵɵpropertyInterpolate4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate5", function() { return ɵɵpropertyInterpolate5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate6", function() { return ɵɵpropertyInterpolate6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate7", function() { return ɵɵpropertyInterpolate7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolate8", function() { return ɵɵpropertyInterpolate8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpropertyInterpolateV", function() { return ɵɵpropertyInterpolateV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction0", function() { return ɵɵpureFunction0; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction1", function() { return ɵɵpureFunction1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction2", function() { return ɵɵpureFunction2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction3", function() { return ɵɵpureFunction3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction4", function() { return ɵɵpureFunction4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction5", function() { return ɵɵpureFunction5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction6", function() { return ɵɵpureFunction6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction7", function() { return ɵɵpureFunction7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunction8", function() { return ɵɵpureFunction8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵpureFunctionV", function() { return ɵɵpureFunctionV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵqueryRefresh", function() { return ɵɵqueryRefresh; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵreference", function() { return ɵɵreference; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵresolveBody", function() { return ɵɵresolveBody; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵresolveDocument", function() { return ɵɵresolveDocument; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵresolveWindow", function() { return ɵɵresolveWindow; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵrestoreView", function() { return ɵɵrestoreView; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsanitizeHtml", function() { return ɵɵsanitizeHtml; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsanitizeResourceUrl", function() { return ɵɵsanitizeResourceUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsanitizeScript", function() { return ɵɵsanitizeScript; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsanitizeStyle", function() { return ɵɵsanitizeStyle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsanitizeUrl", function() { return ɵɵsanitizeUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsanitizeUrlOrResourceUrl", function() { return ɵɵsanitizeUrlOrResourceUrl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsetComponentScope", function() { return ɵɵsetComponentScope; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsetNgModuleScope", function() { return ɵɵsetNgModuleScope; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstaticContentQuery", function() { return ɵɵstaticContentQuery; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstaticViewQuery", function() { return ɵɵstaticViewQuery; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMap", function() { return ɵɵstyleMap; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate1", function() { return ɵɵstyleMapInterpolate1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate2", function() { return ɵɵstyleMapInterpolate2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate3", function() { return ɵɵstyleMapInterpolate3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate4", function() { return ɵɵstyleMapInterpolate4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate5", function() { return ɵɵstyleMapInterpolate5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate6", function() { return ɵɵstyleMapInterpolate6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate7", function() { return ɵɵstyleMapInterpolate7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolate8", function() { return ɵɵstyleMapInterpolate8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleMapInterpolateV", function() { return ɵɵstyleMapInterpolateV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstyleProp", function() { return ɵɵstyleProp; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate1", function() { return ɵɵstylePropInterpolate1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate2", function() { return ɵɵstylePropInterpolate2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate3", function() { return ɵɵstylePropInterpolate3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate4", function() { return ɵɵstylePropInterpolate4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate5", function() { return ɵɵstylePropInterpolate5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate6", function() { return ɵɵstylePropInterpolate6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate7", function() { return ɵɵstylePropInterpolate7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolate8", function() { return ɵɵstylePropInterpolate8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵstylePropInterpolateV", function() { return ɵɵstylePropInterpolateV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsyntheticHostListener", function() { return ɵɵsyntheticHostListener; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵsyntheticHostProperty", function() { return ɵɵsyntheticHostProperty; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtemplate", function() { return ɵɵtemplate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtemplateRefExtractor", function() { return ɵɵtemplateRefExtractor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtext", function() { return ɵɵtext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate", function() { return ɵɵtextInterpolate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate1", function() { return ɵɵtextInterpolate1; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate2", function() { return ɵɵtextInterpolate2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate3", function() { return ɵɵtextInterpolate3; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate4", function() { return ɵɵtextInterpolate4; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate5", function() { return ɵɵtextInterpolate5; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate6", function() { return ɵɵtextInterpolate6; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate7", function() { return ɵɵtextInterpolate7; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolate8", function() { return ɵɵtextInterpolate8; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵtextInterpolateV", function() { return ɵɵtextInterpolateV; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵɵviewQuery", function() { return ɵɵviewQuery; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ "ODXe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/defineProperty */ "rePB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toArray__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toArray */ "T5bk");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createForOfIteratorHelper */ "uFwe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/construct */ "RHh3");
/* harmony import */ var rxjs__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! rxjs */ "qCKp");
/* harmony import */ var rxjs_operators__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! rxjs/operators */ "kU1M");














/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */


/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Convince closure compiler that the wrapped function has no side-effects.
 *
 * Closure compiler always assumes that `toString` has no side-effects. We use this quirk to
 * allow us to execute a function but have closure compiler mark the call as no-side-effects.
 * It is important that the return value for the `noSideEffects` function be assigned
 * to something which is retained otherwise the call to `noSideEffects` will be removed by closure
 * compiler.
 */

function noSideEffects(fn) {
  return {
    toString: fn
  }.toString();
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ANNOTATIONS = '__annotations__';
var PARAMETERS = '__parameters__';
var PROP_METADATA = '__prop__metadata__';
/**
 * @suppress {globalThis}
 */

function makeDecorator(name, props, parentClass, additionalProcessing, typeFn) {
  return noSideEffects(function () {
    var metaCtor = makeMetadataCtor(props);

    function DecoratorFactory() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      if (this instanceof DecoratorFactory) {
        metaCtor.call.apply(metaCtor, [this].concat(args));
        return this;
      }

      var annotationInstance = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(DecoratorFactory, args);

      return function TypeDecorator(cls) {
        if (typeFn) typeFn.apply(void 0, [cls].concat(args)); // Use of Object.defineProperty is important since it creates non-enumerable property which
        // prevents the property is copied during subclassing.

        var annotations = cls.hasOwnProperty(ANNOTATIONS) ? cls[ANNOTATIONS] : Object.defineProperty(cls, ANNOTATIONS, {
          value: []
        })[ANNOTATIONS];
        annotations.push(annotationInstance);
        if (additionalProcessing) additionalProcessing(cls);
        return cls;
      };
    }

    if (parentClass) {
      DecoratorFactory.prototype = Object.create(parentClass.prototype);
    }

    DecoratorFactory.prototype.ngMetadataName = name;
    DecoratorFactory.annotationCls = DecoratorFactory;
    return DecoratorFactory;
  });
}

function makeMetadataCtor(props) {
  return function ctor() {
    if (props) {
      var values = props.apply(void 0, arguments);

      for (var propName in values) {
        this[propName] = values[propName];
      }
    }
  };
}

function makeParamDecorator(name, props, parentClass) {
  return noSideEffects(function () {
    var metaCtor = makeMetadataCtor(props);

    function ParamDecoratorFactory() {
      for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        args[_key2] = arguments[_key2];
      }

      if (this instanceof ParamDecoratorFactory) {
        metaCtor.apply(this, args);
        return this;
      }

      var annotationInstance = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(ParamDecoratorFactory, args);

      ParamDecorator.annotation = annotationInstance;
      return ParamDecorator;

      function ParamDecorator(cls, unusedKey, index) {
        // Use of Object.defineProperty is important since it creates non-enumerable property which
        // prevents the property is copied during subclassing.
        var parameters = cls.hasOwnProperty(PARAMETERS) ? cls[PARAMETERS] : Object.defineProperty(cls, PARAMETERS, {
          value: []
        })[PARAMETERS]; // there might be gaps if some in between parameters do not have annotations.
        // we pad with nulls.

        while (parameters.length <= index) {
          parameters.push(null);
        }

        (parameters[index] = parameters[index] || []).push(annotationInstance);
        return cls;
      }
    }

    if (parentClass) {
      ParamDecoratorFactory.prototype = Object.create(parentClass.prototype);
    }

    ParamDecoratorFactory.prototype.ngMetadataName = name;
    ParamDecoratorFactory.annotationCls = ParamDecoratorFactory;
    return ParamDecoratorFactory;
  });
}

function makePropDecorator(name, props, parentClass, additionalProcessing) {
  return noSideEffects(function () {
    var metaCtor = makeMetadataCtor(props);

    function PropDecoratorFactory() {
      for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
        args[_key3] = arguments[_key3];
      }

      if (this instanceof PropDecoratorFactory) {
        metaCtor.apply(this, args);
        return this;
      }

      var decoratorInstance = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(PropDecoratorFactory, args);

      function PropDecorator(target, name) {
        var constructor = target.constructor; // Use of Object.defineProperty is important because it creates a non-enumerable property
        // which prevents the property from being copied during subclassing.

        var meta = constructor.hasOwnProperty(PROP_METADATA) ? constructor[PROP_METADATA] : Object.defineProperty(constructor, PROP_METADATA, {
          value: {}
        })[PROP_METADATA];
        meta[name] = meta.hasOwnProperty(name) && meta[name] || [];
        meta[name].unshift(decoratorInstance);
        if (additionalProcessing) additionalProcessing.apply(void 0, [target, name].concat(args));
      }

      return PropDecorator;
    }

    if (parentClass) {
      PropDecoratorFactory.prototype = Object.create(parentClass.prototype);
    }

    PropDecoratorFactory.prototype.ngMetadataName = name;
    PropDecoratorFactory.annotationCls = PropDecoratorFactory;
    return PropDecoratorFactory;
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0 = function ɵ0(token) {
  return {
    token: token
  };
};
/**
 * Inject decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */


var Inject = makeParamDecorator('Inject', ɵ0);
/**
 * Optional decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */

var Optional = makeParamDecorator('Optional');
/**
 * Self decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */

var Self = makeParamDecorator('Self');
/**
 * `SkipSelf` decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */

var SkipSelf = makeParamDecorator('SkipSelf');
/**
 * Host decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */

var Host = makeParamDecorator('Host');

var ɵ1 = function ɵ1(attributeName) {
  return {
    attributeName: attributeName
  };
};
/**
 * Attribute decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */


var Attribute = makeParamDecorator('Attribute', ɵ1);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Injection flags for DI.
 *
 * @publicApi
 */

var InjectFlags;

(function (InjectFlags) {
  // TODO(alxhub): make this 'const' when ngc no longer writes exports of it into ngfactory files.

  /** Check self and check parent injector if needed */
  InjectFlags[InjectFlags["Default"] = 0] = "Default";
  /**
   * Specifies that an injector should retrieve a dependency from any injector until reaching the
   * host element of the current component. (Only used with Element Injector)
   */

  InjectFlags[InjectFlags["Host"] = 1] = "Host";
  /** Don't ascend to ancestors of the node requesting injection. */

  InjectFlags[InjectFlags["Self"] = 2] = "Self";
  /** Skip the node that is requesting injection. */

  InjectFlags[InjectFlags["SkipSelf"] = 4] = "SkipSelf";
  /** Inject `defaultValue` instead if token not found. */

  InjectFlags[InjectFlags["Optional"] = 8] = "Optional";
})(InjectFlags || (InjectFlags = {}));
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function getClosureSafeProperty(objWithPropertyToExtract) {
  for (var key in objWithPropertyToExtract) {
    if (objWithPropertyToExtract[key] === getClosureSafeProperty) {
      return key;
    }
  }

  throw Error('Could not find renamed property on target object.');
}
/**
 * Sets properties on a target object from a source object, but only if
 * the property doesn't already exist on the target object.
 * @param target The target to set properties on
 * @param source The source of the property keys and values to set
 */


function fillProperties(target, source) {
  for (var key in source) {
    if (source.hasOwnProperty(key) && !target.hasOwnProperty(key)) {
      target[key] = source[key];
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Construct an `InjectableDef` which defines how a token will be constructed by the DI system, and
 * in which injectors (if any) it will be available.
 *
 * This should be assigned to a static `ɵprov` field on a type, which will then be an
 * `InjectableType`.
 *
 * Options:
 * * `providedIn` determines which injectors will include the injectable, by either associating it
 *   with an `@NgModule` or other `InjectorType`, or by specifying that this injectable should be
 *   provided in the `'root'` injector, which will be the application-level injector in most apps.
 * * `factory` gives the zero argument function which will create an instance of the injectable.
 *   The factory can call `inject` to access the `Injector` and request injection of dependencies.
 *
 * @codeGenApi
 * @publicApi This instruction has been emitted by ViewEngine for some time and is deployed to npm.
 */


function ɵɵdefineInjectable(opts) {
  return {
    token: opts.token,
    providedIn: opts.providedIn || null,
    factory: opts.factory,
    value: undefined
  };
}
/**
 * @deprecated in v8, delete after v10. This API should be used only be generated code, and that
 * code should now use ɵɵdefineInjectable instead.
 * @publicApi
 */


var defineInjectable = ɵɵdefineInjectable;
/**
 * Construct an `InjectorDef` which configures an injector.
 *
 * This should be assigned to a static injector def (`ɵinj`) field on a type, which will then be an
 * `InjectorType`.
 *
 * Options:
 *
 * * `factory`: an `InjectorType` is an instantiable type, so a zero argument `factory` function to
 *   create the type must be provided. If that factory function needs to inject arguments, it can
 *   use the `inject` function.
 * * `providers`: an optional array of providers to add to the injector. Each provider must
 *   either have a factory or point to a type which has a `ɵprov` static property (the
 *   type must be an `InjectableType`).
 * * `imports`: an optional array of imports of other `InjectorType`s or `InjectorTypeWithModule`s
 *   whose providers will also be added to the injector. Locally provided types will override
 *   providers from imports.
 *
 * @codeGenApi
 */

function ɵɵdefineInjector(options) {
  return {
    factory: options.factory,
    providers: options.providers || [],
    imports: options.imports || []
  };
}
/**
 * Read the injectable def (`ɵprov`) for `type` in a way which is immune to accidentally reading
 * inherited value.
 *
 * @param type A type which may have its own (non-inherited) `ɵprov`.
 */


function getInjectableDef(type) {
  return getOwnDefinition(type, type[NG_PROV_DEF]) || getOwnDefinition(type, type[NG_INJECTABLE_DEF]);
}
/**
 * Return `def` only if it is defined directly on `type` and is not inherited from a base
 * class of `type`.
 *
 * The function `Object.hasOwnProperty` is not sufficient to distinguish this case because in older
 * browsers (e.g. IE10) static property inheritance is implemented by copying the properties.
 *
 * Instead, the definition's `token` is compared to the `type`, and if they don't match then the
 * property was not defined directly on the type itself, and was likely inherited. The definition
 * is only returned if the `type` matches the `def.token`.
 */


function getOwnDefinition(type, def) {
  return def && def.token === type ? def : null;
}
/**
 * Read the injectable def (`ɵprov`) for `type` or read the `ɵprov` from one of its ancestors.
 *
 * @param type A type which may have `ɵprov`, via inheritance.
 *
 * @deprecated Will be removed in a future version of Angular, where an error will occur in the
 *     scenario if we find the `ɵprov` on an ancestor only.
 */


function getInheritedInjectableDef(type) {
  // See `jit/injectable.ts#compileInjectable` for context on NG_PROV_DEF_FALLBACK.
  var def = type && (type[NG_PROV_DEF] || type[NG_INJECTABLE_DEF] || type[NG_PROV_DEF_FALLBACK] && type[NG_PROV_DEF_FALLBACK]());

  if (def) {
    var _typeName = getTypeName(type); // TODO(FW-1307): Re-add ngDevMode when closure can handle it
    // ngDevMode &&


    console.warn("DEPRECATED: DI is instantiating a token \"".concat(_typeName, "\" that inherits its @Injectable decorator but does not provide one itself.\n") + "This will become an error in a future version of Angular. Please add @Injectable() to the \"".concat(_typeName, "\" class."));
    return def;
  } else {
    return null;
  }
}
/** Gets the name of a type, accounting for some cross-browser differences. */


function getTypeName(type) {
  // `Function.prototype.name` behaves differently between IE and other browsers. In most browsers
  // it'll always return the name of the function itself, no matter how many other functions it
  // inherits from. On IE the function doesn't have its own `name` property, but it takes it from
  // the lowest level in the prototype chain. E.g. if we have `class Foo extends Parent` most
  // browsers will evaluate `Foo.name` to `Foo` while IE will return `Parent`. We work around
  // the issue by converting the function to a string and parsing its name out that way via a regex.
  if (type.hasOwnProperty('name')) {
    return type.name;
  }

  var match = ('' + type).match(/^function\s*([^\s(]+)/);
  return match === null ? '' : match[1];
}
/**
 * Read the injector def type in a way which is immune to accidentally reading inherited value.
 *
 * @param type type which may have an injector def (`ɵinj`)
 */


function getInjectorDef(type) {
  return type && (type.hasOwnProperty(NG_INJ_DEF) || type.hasOwnProperty(NG_INJECTOR_DEF)) ? type[NG_INJ_DEF] : null;
}

var NG_PROV_DEF = getClosureSafeProperty({
  ɵprov: getClosureSafeProperty
});
var NG_INJ_DEF = getClosureSafeProperty({
  ɵinj: getClosureSafeProperty
}); // On IE10 properties defined via `defineProperty` won't be inherited by child classes,
// which will break inheriting the injectable definition from a grandparent through an
// undecorated parent class. We work around it by defining a fallback method which will be
// used to retrieve the definition. This should only be a problem in JIT mode, because in
// AOT TypeScript seems to have a workaround for static properties. When inheriting from an
// undecorated parent is no longer supported in v10, this can safely be removed.

var NG_PROV_DEF_FALLBACK = getClosureSafeProperty({
  ɵprovFallback: getClosureSafeProperty
}); // We need to keep these around so we can read off old defs if new defs are unavailable

var NG_INJECTABLE_DEF = getClosureSafeProperty({
  ngInjectableDef: getClosureSafeProperty
});
var NG_INJECTOR_DEF = getClosureSafeProperty({
  ngInjectorDef: getClosureSafeProperty
});
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function stringify(token) {
  if (typeof token === 'string') {
    return token;
  }

  if (Array.isArray(token)) {
    return '[' + token.map(stringify).join(', ') + ']';
  }

  if (token == null) {
    return '' + token;
  }

  if (token.overriddenName) {
    return "".concat(token.overriddenName);
  }

  if (token.name) {
    return "".concat(token.name);
  }

  var res = token.toString();

  if (res == null) {
    return '' + res;
  }

  var newLineIndex = res.indexOf('\n');
  return newLineIndex === -1 ? res : res.substring(0, newLineIndex);
}
/**
 * Concatenates two strings with separator, allocating new strings only when necessary.
 *
 * @param before before string.
 * @param separator separator string.
 * @param after after string.
 * @returns concatenated string.
 */


function concatStringsWithSpace(before, after) {
  return before == null || before === '' ? after === null ? '' : after : after == null || after === '' ? before : before + ' ' + after;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var __forward_ref__ = getClosureSafeProperty({
  __forward_ref__: getClosureSafeProperty
});
/**
 * Allows to refer to references which are not yet defined.
 *
 * For instance, `forwardRef` is used when the `token` which we need to refer to for the purposes of
 * DI is declared, but not yet defined. It is also used when the `token` which we use when creating
 * a query is not yet defined.
 *
 * @usageNotes
 * ### Example
 * {@example core/di/ts/forward_ref/forward_ref_spec.ts region='forward_ref'}
 * @publicApi
 */


function forwardRef(forwardRefFn) {
  forwardRefFn.__forward_ref__ = forwardRef;

  forwardRefFn.toString = function () {
    return stringify(this());
  };

  return forwardRefFn;
}
/**
 * Lazily retrieves the reference value from a forwardRef.
 *
 * Acts as the identity function when given a non-forward-ref value.
 *
 * @usageNotes
 * ### Example
 *
 * {@example core/di/ts/forward_ref/forward_ref_spec.ts region='resolve_forward_ref'}
 *
 * @see `forwardRef`
 * @publicApi
 */


function resolveForwardRef(type) {
  return isForwardRef(type) ? type() : type;
}
/** Checks whether a function is wrapped by a `forwardRef`. */


function isForwardRef(fn) {
  return typeof fn === 'function' && fn.hasOwnProperty(__forward_ref__) && fn.__forward_ref__ === forwardRef;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var __globalThis = typeof globalThis !== 'undefined' && globalThis;

var __window = typeof window !== 'undefined' && window;

var __self = typeof self !== 'undefined' && typeof WorkerGlobalScope !== 'undefined' && self instanceof WorkerGlobalScope && self;

var __global = typeof global !== 'undefined' && global; // Always use __globalThis if available, which is the spec-defined global variable across all
// environments, then fallback to __global first, because in Node tests both __global and
// __window may be defined and _global should be __global in that case.


var _global = __globalThis || __global || __window || __self;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var R3ResolvedDependencyType;

(function (R3ResolvedDependencyType) {
  R3ResolvedDependencyType[R3ResolvedDependencyType["Token"] = 0] = "Token";
  R3ResolvedDependencyType[R3ResolvedDependencyType["Attribute"] = 1] = "Attribute";
  R3ResolvedDependencyType[R3ResolvedDependencyType["ChangeDetectorRef"] = 2] = "ChangeDetectorRef";
  R3ResolvedDependencyType[R3ResolvedDependencyType["Invalid"] = 3] = "Invalid";
})(R3ResolvedDependencyType || (R3ResolvedDependencyType = {}));

var R3FactoryTarget;

(function (R3FactoryTarget) {
  R3FactoryTarget[R3FactoryTarget["Directive"] = 0] = "Directive";
  R3FactoryTarget[R3FactoryTarget["Component"] = 1] = "Component";
  R3FactoryTarget[R3FactoryTarget["Injectable"] = 2] = "Injectable";
  R3FactoryTarget[R3FactoryTarget["Pipe"] = 3] = "Pipe";
  R3FactoryTarget[R3FactoryTarget["NgModule"] = 4] = "NgModule";
})(R3FactoryTarget || (R3FactoryTarget = {}));

var ViewEncapsulation;

(function (ViewEncapsulation) {
  ViewEncapsulation[ViewEncapsulation["Emulated"] = 0] = "Emulated";
  ViewEncapsulation[ViewEncapsulation["Native"] = 1] = "Native";
  ViewEncapsulation[ViewEncapsulation["None"] = 2] = "None";
  ViewEncapsulation[ViewEncapsulation["ShadowDom"] = 3] = "ShadowDom";
})(ViewEncapsulation || (ViewEncapsulation = {}));
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function getCompilerFacade() {
  var globalNg = _global['ng'];

  if (!globalNg || !globalNg.ɵcompilerFacade) {
    throw new Error("Angular JIT compilation failed: '@angular/compiler' not loaded!\n" + "  - JIT compilation is discouraged for production use-cases! Consider AOT mode instead.\n" + "  - Did you bootstrap using '@angular/platform-browser-dynamic' or '@angular/platform-server'?\n" + "  - Alternatively provide the compiler with 'import \"@angular/compiler\";' before bootstrapping.");
  }

  return globalNg.ɵcompilerFacade;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NG_COMP_DEF = getClosureSafeProperty({
  ɵcmp: getClosureSafeProperty
});
var NG_DIR_DEF = getClosureSafeProperty({
  ɵdir: getClosureSafeProperty
});
var NG_PIPE_DEF = getClosureSafeProperty({
  ɵpipe: getClosureSafeProperty
});
var NG_MOD_DEF = getClosureSafeProperty({
  ɵmod: getClosureSafeProperty
});
var NG_LOC_ID_DEF = getClosureSafeProperty({
  ɵloc: getClosureSafeProperty
});
var NG_FACTORY_DEF = getClosureSafeProperty({
  ɵfac: getClosureSafeProperty
});
/**
 * If a directive is diPublic, bloomAdd sets a property on the type with this constant as
 * the key and the directive's unique ID as the value. This allows us to map directives to their
 * bloom filter bit for DI.
 */
// TODO(misko): This is wrong. The NG_ELEMENT_ID should never be minified.

var NG_ELEMENT_ID = getClosureSafeProperty({
  __NG_ELEMENT_ID__: getClosureSafeProperty
});
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function ngDevModeResetPerfCounters() {
  var locationString = typeof location !== 'undefined' ? location.toString() : '';
  var newCounters = {
    namedConstructors: locationString.indexOf('ngDevMode=namedConstructors') != -1,
    firstCreatePass: 0,
    tNode: 0,
    tView: 0,
    rendererCreateTextNode: 0,
    rendererSetText: 0,
    rendererCreateElement: 0,
    rendererAddEventListener: 0,
    rendererSetAttribute: 0,
    rendererRemoveAttribute: 0,
    rendererSetProperty: 0,
    rendererSetClassName: 0,
    rendererAddClass: 0,
    rendererRemoveClass: 0,
    rendererSetStyle: 0,
    rendererRemoveStyle: 0,
    rendererDestroy: 0,
    rendererDestroyNode: 0,
    rendererMoveNode: 0,
    rendererRemoveNode: 0,
    rendererAppendChild: 0,
    rendererInsertBefore: 0,
    rendererCreateComment: 0
  }; // Make sure to refer to ngDevMode as ['ngDevMode'] for closure.

  var allowNgDevModeTrue = locationString.indexOf('ngDevMode=false') === -1;
  _global['ngDevMode'] = allowNgDevModeTrue && newCounters;
  return newCounters;
}
/**
 * This function checks to see if the `ngDevMode` has been set. If yes,
 * then we honor it, otherwise we default to dev mode with additional checks.
 *
 * The idea is that unless we are doing production build where we explicitly
 * set `ngDevMode == false` we should be helping the developer by providing
 * as much early warning and errors as possible.
 *
 * `ɵɵdefineComponent` is guaranteed to have been called before any component template functions
 * (and thus Ivy instructions), so a single initialization there is sufficient to ensure ngDevMode
 * is defined for the entire instruction set.
 *
 * When checking `ngDevMode` on toplevel, always init it before referencing it
 * (e.g. `((typeof ngDevMode === 'undefined' || ngDevMode) && initNgDevMode())`), otherwise you can
 *  get a `ReferenceError` like in https://github.com/angular/angular/issues/31595.
 *
 * Details on possible values for `ngDevMode` can be found on its docstring.
 *
 * NOTE:
 * - changes to the `ngDevMode` name must be synced with `compiler-cli/src/tooling.ts`.
 */


function initNgDevMode() {
  // The below checks are to ensure that calling `initNgDevMode` multiple times does not
  // reset the counters.
  // If the `ngDevMode` is not an object, then it means we have not created the perf counters
  // yet.
  if (typeof ngDevMode === 'undefined' || ngDevMode) {
    if (typeof ngDevMode !== 'object') {
      ngDevModeResetPerfCounters();
    }

    return !!ngDevMode;
  }

  return false;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function assertNumber(actual, msg) {
  if (!(typeof actual === 'number')) {
    throwError(msg, typeof actual, 'number', '===');
  }
}

function assertNumberInRange(actual, minInclusive, maxInclusive) {
  assertNumber(actual, 'Expected a number');
  assertLessThanOrEqual(actual, maxInclusive, 'Expected number to be less than or equal to');
  assertGreaterThanOrEqual(actual, minInclusive, 'Expected number to be greater than or equal to');
}

function assertString(actual, msg) {
  if (!(typeof actual === 'string')) {
    throwError(msg, actual === null ? 'null' : typeof actual, 'string', '===');
  }
}

function assertEqual(actual, expected, msg) {
  if (!(actual == expected)) {
    throwError(msg, actual, expected, '==');
  }
}

function assertNotEqual(actual, expected, msg) {
  if (!(actual != expected)) {
    throwError(msg, actual, expected, '!=');
  }
}

function assertSame(actual, expected, msg) {
  if (!(actual === expected)) {
    throwError(msg, actual, expected, '===');
  }
}

function assertNotSame(actual, expected, msg) {
  if (!(actual !== expected)) {
    throwError(msg, actual, expected, '!==');
  }
}

function assertLessThan(actual, expected, msg) {
  if (!(actual < expected)) {
    throwError(msg, actual, expected, '<');
  }
}

function assertLessThanOrEqual(actual, expected, msg) {
  if (!(actual <= expected)) {
    throwError(msg, actual, expected, '<=');
  }
}

function assertGreaterThan(actual, expected, msg) {
  if (!(actual > expected)) {
    throwError(msg, actual, expected, '>');
  }
}

function assertGreaterThanOrEqual(actual, expected, msg) {
  if (!(actual >= expected)) {
    throwError(msg, actual, expected, '>=');
  }
}

function assertNotDefined(actual, msg) {
  if (actual != null) {
    throwError(msg, actual, null, '==');
  }
}

function assertDefined(actual, msg) {
  if (actual == null) {
    throwError(msg, actual, null, '!=');
  }
}

function throwError(msg, actual, expected, comparison) {
  throw new Error("ASSERTION ERROR: ".concat(msg) + (comparison == null ? '' : " [Expected=> ".concat(expected, " ").concat(comparison, " ").concat(actual, " <=Actual]")));
}

function assertDomNode(node) {
  // If we're in a worker, `Node` will not be defined.
  assertEqual(typeof Node !== 'undefined' && node instanceof Node || typeof node === 'object' && node != null && node.constructor.name === 'WebWorkerRenderNode', true, "The provided value must be an instance of a DOM Node but got ".concat(stringify(node)));
}

function assertIndexInRange(arr, index) {
  var maxLen = arr ? arr.length : 0;
  assertLessThan(index, maxLen, "Index expected to be less than ".concat(maxLen, " but got ").concat(index));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Creates a token that can be used in a DI Provider.
 *
 * Use an `InjectionToken` whenever the type you are injecting is not reified (does not have a
 * runtime representation) such as when injecting an interface, callable type, array or
 * parameterized type.
 *
 * `InjectionToken` is parameterized on `T` which is the type of object which will be returned by
 * the `Injector`. This provides additional level of type safety.
 *
 * ```
 * interface MyInterface {...}
 * var myInterface = injector.get(new InjectionToken<MyInterface>('SomeToken'));
 * // myInterface is inferred to be MyInterface.
 * ```
 *
 * When creating an `InjectionToken`, you can optionally specify a factory function which returns
 * (possibly by creating) a default value of the parameterized type `T`. This sets up the
 * `InjectionToken` using this factory as a provider as if it was defined explicitly in the
 * application's root injector. If the factory function, which takes zero arguments, needs to inject
 * dependencies, it can do so using the `inject` function. See below for an example.
 *
 * Additionally, if a `factory` is specified you can also specify the `providedIn` option, which
 * overrides the above behavior and marks the token as belonging to a particular `@NgModule`. As
 * mentioned above, `'root'` is the default value for `providedIn`.
 *
 * @usageNotes
 * ### Basic Example
 *
 * ### Plain InjectionToken
 *
 * {@example core/di/ts/injector_spec.ts region='InjectionToken'}
 *
 * ### Tree-shakable InjectionToken
 *
 * {@example core/di/ts/injector_spec.ts region='ShakableInjectionToken'}
 *
 *
 * @publicApi
 */


var InjectionToken = /*#__PURE__*/function () {
  function InjectionToken(_desc, options) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, InjectionToken);

    this._desc = _desc;
    /** @internal */

    this.ngMetadataName = 'InjectionToken';
    this.ɵprov = undefined;

    if (typeof options == 'number') {
      // This is a special hack to assign __NG_ELEMENT_ID__ to this instance.
      // __NG_ELEMENT_ID__ is Used by Ivy to determine bloom filter id.
      // We are using it to assign `-1` which is used to identify `Injector`.
      this.__NG_ELEMENT_ID__ = options;
    } else if (options !== undefined) {
      this.ɵprov = ɵɵdefineInjectable({
        token: this,
        providedIn: options.providedIn || 'root',
        factory: options.factory
      });
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(InjectionToken, [{
    key: "toString",
    value: function toString() {
      return "InjectionToken ".concat(this._desc);
    }
  }]);

  return InjectionToken;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An InjectionToken that gets the current `Injector` for `createInjector()`-style injectors.
 *
 * Requesting this token instead of `Injector` allows `StaticInjector` to be tree-shaken from a
 * project.
 *
 * @publicApi
 */


var INJECTOR = new InjectionToken('INJECTOR', -1 // `-1` is used by Ivy DI system as special value to recognize it as `Injector`.
);
var _THROW_IF_NOT_FOUND = {};
var THROW_IF_NOT_FOUND = _THROW_IF_NOT_FOUND;
var NG_TEMP_TOKEN_PATH = 'ngTempTokenPath';
var NG_TOKEN_PATH = 'ngTokenPath';
var NEW_LINE = /\n/gm;
var NO_NEW_LINE = 'ɵ';
var SOURCE = '__source';
var ɵ0$1 = getClosureSafeProperty;
var USE_VALUE = getClosureSafeProperty({
  provide: String,
  useValue: ɵ0$1
});
/**
 * Current injector value used by `inject`.
 * - `undefined`: it is an error to call `inject`
 * - `null`: `inject` can be called but there is no injector (limp-mode).
 * - Injector instance: Use the injector for resolution.
 */

var _currentInjector = undefined;

function setCurrentInjector(injector) {
  var former = _currentInjector;
  _currentInjector = injector;
  return former;
}
/**
 * Current implementation of inject.
 *
 * By default, it is `injectInjectorOnly`, which makes it `Injector`-only aware. It can be changed
 * to `directiveInject`, which brings in the `NodeInjector` system of ivy. It is designed this
 * way for two reasons:
 *  1. `Injector` should not depend on ivy logic.
 *  2. To maintain tree shake-ability we don't want to bring in unnecessary code.
 */


var _injectImplementation;
/**
 * Sets the current inject implementation.
 */


function setInjectImplementation(impl) {
  var previous = _injectImplementation;
  _injectImplementation = impl;
  return previous;
}
/**
 * Assert that `_injectImplementation` is not `fn`.
 *
 * This is useful, to prevent infinite recursion.
 *
 * @param fn Function which it should not equal to
 */


function assertInjectImplementationNot(fn) {
  ngDevMode && assertNotEqual(_injectImplementation, fn, 'Calling ɵɵinject would cause infinite recursion');
}

function injectInjectorOnly(token) {
  var flags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : InjectFlags.Default;

  if (_currentInjector === undefined) {
    throw new Error("inject() must be called from an injection context");
  } else if (_currentInjector === null) {
    return injectRootLimpMode(token, undefined, flags);
  } else {
    return _currentInjector.get(token, flags & InjectFlags.Optional ? null : undefined, flags);
  }
}

function ɵɵinject(token) {
  var flags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : InjectFlags.Default;
  return (_injectImplementation || injectInjectorOnly)(resolveForwardRef(token), flags);
}
/**
 * Throws an error indicating that a factory function could not be generated by the compiler for a
 * particular class.
 *
 * This instruction allows the actual error message to be optimized away when ngDevMode is turned
 * off, saving bytes of generated code while still providing a good experience in dev mode.
 *
 * The name of the class is not mentioned here, but will be in the generated factory function name
 * and thus in the stack trace.
 *
 * @codeGenApi
 */


function ɵɵinvalidFactoryDep(index) {
  var msg = ngDevMode ? "This constructor is not compatible with Angular Dependency Injection because its dependency at index ".concat(index, " of the parameter list is invalid.\nThis can happen if the dependency type is a primitive like a string or if an ancestor of this class is missing an Angular decorator.\n\nPlease check that 1) the type for the parameter at index ").concat(index, " is correct and 2) the correct Angular decorators are defined for this class and its ancestors.") : 'invalid';
  throw new Error(msg);
}
/**
 * Injects a token from the currently active injector.
 *
 * Must be used in the context of a factory function such as one defined for an
 * `InjectionToken`. Throws an error if not called from such a context.
 *
 * Within such a factory function, using this function to request injection of a dependency
 * is faster and more type-safe than providing an additional array of dependencies
 * (as has been common with `useFactory` providers).
 *
 * @param token The injection token for the dependency to be injected.
 * @param flags Optional flags that control how injection is executed.
 * The flags correspond to injection strategies that can be specified with
 * parameter decorators `@Host`, `@Self`, `@SkipSef`, and `@Optional`.
 * @returns True if injection is successful, null otherwise.
 *
 * @usageNotes
 *
 * ### Example
 *
 * {@example core/di/ts/injector_spec.ts region='ShakableInjectionToken'}
 *
 * @publicApi
 */


var inject = ɵɵinject;
/**
 * Injects `root` tokens in limp mode.
 *
 * If no injector exists, we can still inject tree-shakable providers which have `providedIn` set to
 * `"root"`. This is known as the limp mode injection. In such case the value is stored in the
 * `InjectableDef`.
 */

function injectRootLimpMode(token, notFoundValue, flags) {
  var injectableDef = getInjectableDef(token);

  if (injectableDef && injectableDef.providedIn == 'root') {
    return injectableDef.value === undefined ? injectableDef.value = injectableDef.factory() : injectableDef.value;
  }

  if (flags & InjectFlags.Optional) return null;
  if (notFoundValue !== undefined) return notFoundValue;
  throw new Error("Injector: NOT_FOUND [".concat(stringify(token), "]"));
}

function injectArgs(types) {
  var args = [];

  for (var i = 0; i < types.length; i++) {
    var arg = resolveForwardRef(types[i]);

    if (Array.isArray(arg)) {
      if (arg.length === 0) {
        throw new Error('Arguments array must have arguments.');
      }

      var type = undefined;
      var flags = InjectFlags.Default;

      for (var j = 0; j < arg.length; j++) {
        var meta = arg[j];

        if (meta instanceof Optional || meta.ngMetadataName === 'Optional' || meta === Optional) {
          flags |= InjectFlags.Optional;
        } else if (meta instanceof SkipSelf || meta.ngMetadataName === 'SkipSelf' || meta === SkipSelf) {
          flags |= InjectFlags.SkipSelf;
        } else if (meta instanceof Self || meta.ngMetadataName === 'Self' || meta === Self) {
          flags |= InjectFlags.Self;
        } else if (meta instanceof Inject || meta === Inject) {
          type = meta.token;
        } else {
          type = meta;
        }
      }

      args.push(ɵɵinject(type, flags));
    } else {
      args.push(ɵɵinject(arg));
    }
  }

  return args;
}

var NullInjector = /*#__PURE__*/function () {
  function NullInjector() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NullInjector);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NullInjector, [{
    key: "get",
    value: function get(token) {
      var notFoundValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : THROW_IF_NOT_FOUND;

      if (notFoundValue === THROW_IF_NOT_FOUND) {
        // Intentionally left behind: With dev tools open the debugger will stop here. There is no
        // reason why correctly written application should cause this exception.
        // TODO(misko): uncomment the next line once `ngDevMode` works with closure.
        // if (ngDevMode) debugger;
        var error = new Error("NullInjectorError: No provider for ".concat(stringify(token), "!"));
        error.name = 'NullInjectorError';
        throw error;
      }

      return notFoundValue;
    }
  }]);

  return NullInjector;
}();

function catchInjectorError(e, token, injectorErrorName, source) {
  var tokenPath = e[NG_TEMP_TOKEN_PATH];

  if (token[SOURCE]) {
    tokenPath.unshift(token[SOURCE]);
  }

  e.message = formatError('\n' + e.message, tokenPath, injectorErrorName, source);
  e[NG_TOKEN_PATH] = tokenPath;
  e[NG_TEMP_TOKEN_PATH] = null;
  throw e;
}

function formatError(text, obj, injectorErrorName) {
  var source = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
  text = text && text.charAt(0) === '\n' && text.charAt(1) == NO_NEW_LINE ? text.substr(2) : text;
  var context = stringify(obj);

  if (Array.isArray(obj)) {
    context = obj.map(stringify).join(' -> ');
  } else if (typeof obj === 'object') {
    var parts = [];

    for (var key in obj) {
      if (obj.hasOwnProperty(key)) {
        var value = obj[key];
        parts.push(key + ':' + (typeof value === 'string' ? JSON.stringify(value) : stringify(value)));
      }
    }

    context = "{".concat(parts.join(', '), "}");
  }

  return "".concat(injectorErrorName).concat(source ? '(' + source + ')' : '', "[").concat(context, "]: ").concat(text.replace(NEW_LINE, '\n  '));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A mapping of the @angular/core API surface used in generated expressions to the actual symbols.
 *
 * This should be kept up to date with the public exports of @angular/core.
 */


var angularCoreDiEnv = {
  'ɵɵdefineInjectable': ɵɵdefineInjectable,
  'ɵɵdefineInjector': ɵɵdefineInjector,
  'ɵɵinject': ɵɵinject,
  'ɵɵgetFactoryOf': getFactoryOf,
  'ɵɵinvalidFactoryDep': ɵɵinvalidFactoryDep
};

function getFactoryOf(type) {
  var typeAny = type;

  if (isForwardRef(type)) {
    return function () {
      var factory = getFactoryOf(resolveForwardRef(typeAny));
      return factory ? factory() : null;
    };
  }

  var def = getInjectableDef(typeAny) || getInjectorDef(typeAny);

  if (!def || def.factory === undefined) {
    return null;
  }

  return def.factory;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents an instance of an `NgModule` created by an `NgModuleFactory`.
 * Provides access to the `NgModule` instance and related objects.
 *
 * @publicApi
 */


var NgModuleRef = function NgModuleRef() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleRef);
};
/**
 * @publicApi
 */


var NgModuleFactory = function NgModuleFactory() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleFactory);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Equivalent to ES6 spread, add each item to an array.
 *
 * @param items The items to add
 * @param arr The array to which you want to add the items
 */


function addAllToArray(items, arr) {
  for (var i = 0; i < items.length; i++) {
    arr.push(items[i]);
  }
}
/**
 * Flattens an array.
 */


function flatten(list, dst) {
  if (dst === undefined) dst = list;

  for (var i = 0; i < list.length; i++) {
    var item = list[i];

    if (Array.isArray(item)) {
      // we need to inline it.
      if (dst === list) {
        // Our assumption that the list was already flat was wrong and
        // we need to clone flat since we need to write to it.
        dst = list.slice(0, i);
      }

      flatten(item, dst);
    } else if (dst !== list) {
      dst.push(item);
    }
  }

  return dst;
}

function deepForEach(input, fn) {
  input.forEach(function (value) {
    return Array.isArray(value) ? deepForEach(value, fn) : fn(value);
  });
}

function addToArray(arr, index, value) {
  // perf: array.push is faster than array.splice!
  if (index >= arr.length) {
    arr.push(value);
  } else {
    arr.splice(index, 0, value);
  }
}

function removeFromArray(arr, index) {
  // perf: array.pop is faster than array.splice!
  if (index >= arr.length - 1) {
    return arr.pop();
  } else {
    return arr.splice(index, 1)[0];
  }
}

function newArray(size, value) {
  var list = [];

  for (var i = 0; i < size; i++) {
    list.push(value);
  }

  return list;
}
/**
 * Remove item from array (Same as `Array.splice()` but faster.)
 *
 * `Array.splice()` is not as fast because it has to allocate an array for the elements which were
 * removed. This causes memory pressure and slows down code when most of the time we don't
 * care about the deleted items array.
 *
 * https://jsperf.com/fast-array-splice (About 20x faster)
 *
 * @param array Array to splice
 * @param index Index of element in array to remove.
 * @param count Number of items to remove.
 */


function arraySplice(array, index, count) {
  var length = array.length - count;

  while (index < length) {
    array[index] = array[index + count];
    index++;
  }

  while (count--) {
    array.pop(); // shrink the array
  }
}
/**
 * Same as `Array.splice(index, 0, value)` but faster.
 *
 * `Array.splice()` is not fast because it has to allocate an array for the elements which were
 * removed. This causes memory pressure and slows down code when most of the time we don't
 * care about the deleted items array.
 *
 * @param array Array to splice.
 * @param index Index in array where the `value` should be added.
 * @param value Value to add to array.
 */


function arrayInsert(array, index, value) {
  ngDevMode && assertLessThanOrEqual(index, array.length, 'Can\'t insert past array end.');
  var end = array.length;

  while (end > index) {
    var previousEnd = end - 1;
    array[end] = array[previousEnd];
    end = previousEnd;
  }

  array[index] = value;
}
/**
 * Same as `Array.splice2(index, 0, value1, value2)` but faster.
 *
 * `Array.splice()` is not fast because it has to allocate an array for the elements which were
 * removed. This causes memory pressure and slows down code when most of the time we don't
 * care about the deleted items array.
 *
 * @param array Array to splice.
 * @param index Index in array where the `value` should be added.
 * @param value1 Value to add to array.
 * @param value2 Value to add to array.
 */


function arrayInsert2(array, index, value1, value2) {
  ngDevMode && assertLessThanOrEqual(index, array.length, 'Can\'t insert past array end.');
  var end = array.length;

  if (end == index) {
    // inserting at the end.
    array.push(value1, value2);
  } else if (end === 1) {
    // corner case when we have less items in array than we have items to insert.
    array.push(value2, array[0]);
    array[0] = value1;
  } else {
    end--;
    array.push(array[end - 1], array[end]);

    while (end > index) {
      var previousEnd = end - 2;
      array[end] = array[previousEnd];
      end--;
    }

    array[index] = value1;
    array[index + 1] = value2;
  }
}
/**
 * Insert a `value` into an `array` so that the array remains sorted.
 *
 * NOTE:
 * - Duplicates are not allowed, and are ignored.
 * - This uses binary search algorithm for fast inserts.
 *
 * @param array A sorted array to insert into.
 * @param value The value to insert.
 * @returns index of the inserted value.
 */


function arrayInsertSorted(array, value) {
  var index = arrayIndexOfSorted(array, value);

  if (index < 0) {
    // if we did not find it insert it.
    index = ~index;
    arrayInsert(array, index, value);
  }

  return index;
}
/**
 * Remove `value` from a sorted `array`.
 *
 * NOTE:
 * - This uses binary search algorithm for fast removals.
 *
 * @param array A sorted array to remove from.
 * @param value The value to remove.
 * @returns index of the removed value.
 *   - positive index if value found and removed.
 *   - negative index if value not found. (`~index` to get the value where it should have been
 *     inserted)
 */


function arrayRemoveSorted(array, value) {
  var index = arrayIndexOfSorted(array, value);

  if (index >= 0) {
    arraySplice(array, index, 1);
  }

  return index;
}
/**
 * Get an index of an `value` in a sorted `array`.
 *
 * NOTE:
 * - This uses binary search algorithm for fast removals.
 *
 * @param array A sorted array to binary search.
 * @param value The value to look for.
 * @returns index of the value.
 *   - positive index if value found.
 *   - negative index if value not found. (`~index` to get the value where it should have been
 *     located)
 */


function arrayIndexOfSorted(array, value) {
  return _arrayIndexOfSorted(array, value, 0);
}
/**
 * Set a `value` for a `key`.
 *
 * @param keyValueArray to modify.
 * @param key The key to locate or create.
 * @param value The value to set for a `key`.
 * @returns index (always even) of where the value vas set.
 */


function keyValueArraySet(keyValueArray, key, value) {
  var index = keyValueArrayIndexOf(keyValueArray, key);

  if (index >= 0) {
    // if we found it set it.
    keyValueArray[index | 1] = value;
  } else {
    index = ~index;
    arrayInsert2(keyValueArray, index, key, value);
  }

  return index;
}
/**
 * Retrieve a `value` for a `key` (on `undefined` if not found.)
 *
 * @param keyValueArray to search.
 * @param key The key to locate.
 * @return The `value` stored at the `key` location or `undefined if not found.
 */


function keyValueArrayGet(keyValueArray, key) {
  var index = keyValueArrayIndexOf(keyValueArray, key);

  if (index >= 0) {
    // if we found it retrieve it.
    return keyValueArray[index | 1];
  }

  return undefined;
}
/**
 * Retrieve a `key` index value in the array or `-1` if not found.
 *
 * @param keyValueArray to search.
 * @param key The key to locate.
 * @returns index of where the key is (or should have been.)
 *   - positive (even) index if key found.
 *   - negative index if key not found. (`~index` (even) to get the index where it should have
 *     been inserted.)
 */


function keyValueArrayIndexOf(keyValueArray, key) {
  return _arrayIndexOfSorted(keyValueArray, key, 1);
}
/**
 * Delete a `key` (and `value`) from the `KeyValueArray`.
 *
 * @param keyValueArray to modify.
 * @param key The key to locate or delete (if exist).
 * @returns index of where the key was (or should have been.)
 *   - positive (even) index if key found and deleted.
 *   - negative index if key not found. (`~index` (even) to get the index where it should have
 *     been.)
 */


function keyValueArrayDelete(keyValueArray, key) {
  var index = keyValueArrayIndexOf(keyValueArray, key);

  if (index >= 0) {
    // if we found it remove it.
    arraySplice(keyValueArray, index, 2);
  }

  return index;
}
/**
 * INTERNAL: Get an index of an `value` in a sorted `array` by grouping search by `shift`.
 *
 * NOTE:
 * - This uses binary search algorithm for fast removals.
 *
 * @param array A sorted array to binary search.
 * @param value The value to look for.
 * @param shift grouping shift.
 *   - `0` means look at every location
 *   - `1` means only look at every other (even) location (the odd locations are to be ignored as
 *         they are values.)
 * @returns index of the value.
 *   - positive index if value found.
 *   - negative index if value not found. (`~index` to get the value where it should have been
 * inserted)
 */


function _arrayIndexOfSorted(array, value, shift) {
  ngDevMode && assertEqual(Array.isArray(array), true, 'Expecting an array');
  var start = 0;
  var end = array.length >> shift;

  while (end !== start) {
    var middle = start + (end - start >> 1); // find the middle.

    var current = array[middle << shift];

    if (value === current) {
      return middle << shift;
    } else if (current > value) {
      end = middle;
    } else {
      start = middle + 1; // We already searched middle so make it non-inclusive by adding 1
    }
  }

  return ~(end << shift);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The strategy that the default change detector uses to detect changes.
 * When set, takes effect the next time change detection is triggered.
 *
 * @see {@link ChangeDetectorRef#usage-notes Change detection usage}
 *
 * @publicApi
 */


var ChangeDetectionStrategy;

(function (ChangeDetectionStrategy) {
  /**
   * Use the `CheckOnce` strategy, meaning that automatic change detection is deactivated
   * until reactivated by setting the strategy to `Default` (`CheckAlways`).
   * Change detection can still be explicitly invoked.
   * This strategy applies to all child directives and cannot be overridden.
   */
  ChangeDetectionStrategy[ChangeDetectionStrategy["OnPush"] = 0] = "OnPush";
  /**
   * Use the default `CheckAlways` strategy, in which change detection is automatic until
   * explicitly deactivated.
   */

  ChangeDetectionStrategy[ChangeDetectionStrategy["Default"] = 1] = "Default";
})(ChangeDetectionStrategy || (ChangeDetectionStrategy = {}));
/**
 * Defines the possible states of the default change detector.
 * @see `ChangeDetectorRef`
 */


var ChangeDetectorStatus;

(function (ChangeDetectorStatus) {
  /**
   * A state in which, after calling `detectChanges()`, the change detector
   * state becomes `Checked`, and must be explicitly invoked or reactivated.
   */
  ChangeDetectorStatus[ChangeDetectorStatus["CheckOnce"] = 0] = "CheckOnce";
  /**
   * A state in which change detection is skipped until the change detector mode
   * becomes `CheckOnce`.
   */

  ChangeDetectorStatus[ChangeDetectorStatus["Checked"] = 1] = "Checked";
  /**
   * A state in which change detection continues automatically until explicitly
   * deactivated.
   */

  ChangeDetectorStatus[ChangeDetectorStatus["CheckAlways"] = 2] = "CheckAlways";
  /**
   * A state in which a change detector sub tree is not a part of the main tree and
   * should be skipped.
   */

  ChangeDetectorStatus[ChangeDetectorStatus["Detached"] = 3] = "Detached";
  /**
   * Indicates that the change detector encountered an error checking a binding
   * or calling a directive lifecycle method and is now in an inconsistent state. Change
   * detectors in this state do not detect changes.
   */

  ChangeDetectorStatus[ChangeDetectorStatus["Errored"] = 4] = "Errored";
  /**
   * Indicates that the change detector has been destroyed.
   */

  ChangeDetectorStatus[ChangeDetectorStatus["Destroyed"] = 5] = "Destroyed";
})(ChangeDetectorStatus || (ChangeDetectorStatus = {}));
/**
 * Reports whether a given strategy is currently the default for change detection.
 * @param changeDetectionStrategy The strategy to check.
 * @returns True if the given strategy is the current default, false otherwise.
 * @see `ChangeDetectorStatus`
 * @see `ChangeDetectorRef`
 */


function isDefaultChangeDetectionStrategy(changeDetectionStrategy) {
  return changeDetectionStrategy == null || changeDetectionStrategy === ChangeDetectionStrategy.Default;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Defines template and style encapsulation options available for Component's {@link Component}.
 *
 * See {@link Component#encapsulation encapsulation}.
 *
 * @usageNotes
 * ### Example
 *
 * {@example core/ts/metadata/encapsulation.ts region='longform'}
 *
 * @publicApi
 */


var ViewEncapsulation$1;

(function (ViewEncapsulation) {
  /**
   * Emulate `Native` scoping of styles by adding an attribute containing surrogate id to the Host
   * Element and pre-processing the style rules provided via {@link Component#styles styles} or
   * {@link Component#styleUrls styleUrls}, and adding the new Host Element attribute to all
   * selectors.
   *
   * This is the default option.
   */
  ViewEncapsulation[ViewEncapsulation["Emulated"] = 0] = "Emulated";
  /**
   * @deprecated v6.1.0 - use {ViewEncapsulation.ShadowDom} instead.
   * Use the native encapsulation mechanism of the renderer.
   *
   * For the DOM this means using the deprecated [Shadow DOM
   * v0](https://w3c.github.io/webcomponents/spec/shadow/) and
   * creating a ShadowRoot for Component's Host Element.
   */

  ViewEncapsulation[ViewEncapsulation["Native"] = 1] = "Native";
  /**
   * Don't provide any template or style encapsulation.
   */

  ViewEncapsulation[ViewEncapsulation["None"] = 2] = "None";
  /**
   * Use Shadow DOM to encapsulate styles.
   *
   * For the DOM this means using modern [Shadow
   * DOM](https://w3c.github.io/webcomponents/spec/shadow/) and
   * creating a ShadowRoot for Component's Host Element.
   */

  ViewEncapsulation[ViewEncapsulation["ShadowDom"] = 3] = "ShadowDom";
})(ViewEncapsulation$1 || (ViewEncapsulation$1 = {}));
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This file contains reuseable "empty" symbols that can be used as default return values
 * in different parts of the rendering code. Because the same symbols are returned, this
 * allows for identity checks against these values to be consistently used by the framework
 * code.
 */


var EMPTY_OBJ = {};
var EMPTY_ARRAY = []; // freezing the values prevents any code from accidentally inserting new values in

if ((typeof ngDevMode === 'undefined' || ngDevMode) && initNgDevMode()) {
  // These property accesses can be ignored because ngDevMode will be set to false
  // when optimizing code and the whole if statement will be dropped.
  // tslint:disable-next-line:no-toplevel-property-access
  Object.freeze(EMPTY_OBJ); // tslint:disable-next-line:no-toplevel-property-access

  Object.freeze(EMPTY_ARRAY);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _renderCompCount = 0;
/**
 * Create a component definition object.
 *
 *
 * # Example
 * ```
 * class MyDirective {
 *   // Generated by Angular Template Compiler
 *   // [Symbol] syntax will not be supported by TypeScript until v2.7
 *   static ɵcmp = defineComponent({
 *     ...
 *   });
 * }
 * ```
 * @codeGenApi
 */

function ɵɵdefineComponent(componentDefinition) {
  return noSideEffects(function () {
    // Initialize ngDevMode. This must be the first statement in ɵɵdefineComponent.
    // See the `initNgDevMode` docstring for more information.
    (typeof ngDevMode === 'undefined' || ngDevMode) && initNgDevMode();
    var type = componentDefinition.type;
    var typePrototype = type.prototype;
    var declaredInputs = {};
    var def = {
      type: type,
      providersResolver: null,
      decls: componentDefinition.decls,
      vars: componentDefinition.vars,
      factory: null,
      template: componentDefinition.template || null,
      consts: componentDefinition.consts || null,
      ngContentSelectors: componentDefinition.ngContentSelectors,
      hostBindings: componentDefinition.hostBindings || null,
      hostVars: componentDefinition.hostVars || 0,
      hostAttrs: componentDefinition.hostAttrs || null,
      contentQueries: componentDefinition.contentQueries || null,
      declaredInputs: declaredInputs,
      inputs: null,
      outputs: null,
      exportAs: componentDefinition.exportAs || null,
      onPush: componentDefinition.changeDetection === ChangeDetectionStrategy.OnPush,
      directiveDefs: null,
      pipeDefs: null,
      selectors: componentDefinition.selectors || EMPTY_ARRAY,
      viewQuery: componentDefinition.viewQuery || null,
      features: componentDefinition.features || null,
      data: componentDefinition.data || {},
      // TODO(misko): convert ViewEncapsulation into const enum so that it can be used
      // directly in the next line. Also `None` should be 0 not 2.
      encapsulation: componentDefinition.encapsulation || ViewEncapsulation$1.Emulated,
      id: 'c',
      styles: componentDefinition.styles || EMPTY_ARRAY,
      _: null,
      setInput: null,
      schemas: componentDefinition.schemas || null,
      tView: null
    };
    var directiveTypes = componentDefinition.directives;
    var feature = componentDefinition.features;
    var pipeTypes = componentDefinition.pipes;
    def.id += _renderCompCount++;
    def.inputs = invertObject(componentDefinition.inputs, declaredInputs), def.outputs = invertObject(componentDefinition.outputs), feature && feature.forEach(function (fn) {
      return fn(def);
    });
    def.directiveDefs = directiveTypes ? function () {
      return (typeof directiveTypes === 'function' ? directiveTypes() : directiveTypes).map(extractDirectiveDef);
    } : null;
    def.pipeDefs = pipeTypes ? function () {
      return (typeof pipeTypes === 'function' ? pipeTypes() : pipeTypes).map(extractPipeDef);
    } : null;
    return def;
  });
}
/**
 * @codeGenApi
 */


function ɵɵsetComponentScope(type, directives, pipes) {
  var def = type.ɵcmp;

  def.directiveDefs = function () {
    return directives.map(extractDirectiveDef);
  };

  def.pipeDefs = function () {
    return pipes.map(extractPipeDef);
  };
}

function extractDirectiveDef(type) {
  var def = getComponentDef(type) || getDirectiveDef(type);

  if (ngDevMode && !def) {
    throw new Error("'".concat(type.name, "' is neither 'ComponentType' or 'DirectiveType'."));
  }

  return def;
}

function extractPipeDef(type) {
  var def = getPipeDef(type);

  if (ngDevMode && !def) {
    throw new Error("'".concat(type.name, "' is not a 'PipeType'."));
  }

  return def;
}

var autoRegisterModuleById = {};
/**
 * @codeGenApi
 */

function ɵɵdefineNgModule(def) {
  var res = {
    type: def.type,
    bootstrap: def.bootstrap || EMPTY_ARRAY,
    declarations: def.declarations || EMPTY_ARRAY,
    imports: def.imports || EMPTY_ARRAY,
    exports: def.exports || EMPTY_ARRAY,
    transitiveCompileScopes: null,
    schemas: def.schemas || null,
    id: def.id || null
  };

  if (def.id != null) {
    noSideEffects(function () {
      autoRegisterModuleById[def.id] = def.type;
    });
  }

  return res;
}
/**
 * Adds the module metadata that is necessary to compute the module's transitive scope to an
 * existing module definition.
 *
 * Scope metadata of modules is not used in production builds, so calls to this function can be
 * marked pure to tree-shake it from the bundle, allowing for all referenced declarations
 * to become eligible for tree-shaking as well.
 *
 * @codeGenApi
 */


function ɵɵsetNgModuleScope(type, scope) {
  return noSideEffects(function () {
    var ngModuleDef = getNgModuleDef(type, true);
    ngModuleDef.declarations = scope.declarations || EMPTY_ARRAY;
    ngModuleDef.imports = scope.imports || EMPTY_ARRAY;
    ngModuleDef.exports = scope.exports || EMPTY_ARRAY;
  });
}
/**
 * Inverts an inputs or outputs lookup such that the keys, which were the
 * minified keys, are part of the values, and the values are parsed so that
 * the publicName of the property is the new key
 *
 * e.g. for
 *
 * ```
 * class Comp {
 *   @Input()
 *   propName1: string;
 *
 *   @Input('publicName2')
 *   declaredPropName2: number;
 * }
 * ```
 *
 * will be serialized as
 *
 * ```
 * {
 *   propName1: 'propName1',
 *   declaredPropName2: ['publicName2', 'declaredPropName2'],
 * }
 * ```
 *
 * which is than translated by the minifier as:
 *
 * ```
 * {
 *   minifiedPropName1: 'propName1',
 *   minifiedPropName2: ['publicName2', 'declaredPropName2'],
 * }
 * ```
 *
 * becomes: (public name => minifiedName)
 *
 * ```
 * {
 *  'propName1': 'minifiedPropName1',
 *  'publicName2': 'minifiedPropName2',
 * }
 * ```
 *
 * Optionally the function can take `secondary` which will result in: (public name => declared name)
 *
 * ```
 * {
 *  'propName1': 'propName1',
 *  'publicName2': 'declaredPropName2',
 * }
 * ```
 *

 */


function invertObject(obj, secondary) {
  if (obj == null) return EMPTY_OBJ;
  var newLookup = {};

  for (var minifiedKey in obj) {
    if (obj.hasOwnProperty(minifiedKey)) {
      var publicName = obj[minifiedKey];
      var declaredName = publicName;

      if (Array.isArray(publicName)) {
        declaredName = publicName[1];
        publicName = publicName[0];
      }

      newLookup[publicName] = minifiedKey;

      if (secondary) {
        secondary[publicName] = declaredName;
      }
    }
  }

  return newLookup;
}
/**
 * Create a directive definition object.
 *
 * # Example
 * ```ts
 * class MyDirective {
 *   // Generated by Angular Template Compiler
 *   // [Symbol] syntax will not be supported by TypeScript until v2.7
 *   static ɵdir = ɵɵdefineDirective({
 *     ...
 *   });
 * }
 * ```
 *
 * @codeGenApi
 */


var ɵɵdefineDirective = ɵɵdefineComponent;
/**
 * Create a pipe definition object.
 *
 * # Example
 * ```
 * class MyPipe implements PipeTransform {
 *   // Generated by Angular Template Compiler
 *   static ɵpipe = definePipe({
 *     ...
 *   });
 * }
 * ```
 * @param pipeDef Pipe definition generated by the compiler
 *
 * @codeGenApi
 */

function ɵɵdefinePipe(pipeDef) {
  return {
    type: pipeDef.type,
    name: pipeDef.name,
    factory: null,
    pure: pipeDef.pure !== false,
    onDestroy: pipeDef.type.prototype.ngOnDestroy || null
  };
}
/**
 * The following getter methods retrieve the definition form the type. Currently the retrieval
 * honors inheritance, but in the future we may change the rule to require that definitions are
 * explicit. This would require some sort of migration strategy.
 */


function getComponentDef(type) {
  return type[NG_COMP_DEF] || null;
}

function getDirectiveDef(type) {
  return type[NG_DIR_DEF] || null;
}

function getPipeDef(type) {
  return type[NG_PIPE_DEF] || null;
}

function getFactoryDef(type, throwNotFound) {
  var hasFactoryDef = type.hasOwnProperty(NG_FACTORY_DEF);

  if (!hasFactoryDef && throwNotFound === true && ngDevMode) {
    throw new Error("Type ".concat(stringify(type), " does not have '\u0275fac' property."));
  }

  return hasFactoryDef ? type[NG_FACTORY_DEF] : null;
}

function getNgModuleDef(type, throwNotFound) {
  var ngModuleDef = type[NG_MOD_DEF] || null;

  if (!ngModuleDef && throwNotFound === true) {
    throw new Error("Type ".concat(stringify(type), " does not have '\u0275mod' property."));
  }

  return ngModuleDef;
}

function getNgLocaleIdDef(type) {
  return type[NG_LOC_ID_DEF] || null;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Below are constants for LView indices to help us look up LView members
// without having to remember the specific indices.
// Uglify will inline these when minifying so there shouldn't be a cost.


var HOST = 0;
var TVIEW = 1;
var FLAGS = 2;
var PARENT = 3;
var NEXT = 4;
var TRANSPLANTED_VIEWS_TO_REFRESH = 5;
var T_HOST = 6;
var CLEANUP = 7;
var CONTEXT = 8;
var INJECTOR$1 = 9;
var RENDERER_FACTORY = 10;
var RENDERER = 11;
var SANITIZER = 12;
var CHILD_HEAD = 13;
var CHILD_TAIL = 14; // FIXME(misko): Investigate if the three declarations aren't all same thing.

var DECLARATION_VIEW = 15;
var DECLARATION_COMPONENT_VIEW = 16;
var DECLARATION_LCONTAINER = 17;
var PREORDER_HOOK_FLAGS = 18;
var QUERIES = 19;
/** Size of LView's header. Necessary to adjust for it when setting slots.  */

var HEADER_OFFSET = 20;
/**
 * Converts `TViewType` into human readable text.
 * Make sure this matches with `TViewType`
 */

var TViewTypeAsString = ['Root', 'Component', 'Embedded']; // Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.

var unusedValueExportToPlacateAjd = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Special location which allows easy identification of type. If we have an array which was
 * retrieved from the `LView` and that array has `true` at `TYPE` location, we know it is
 * `LContainer`.
 */

var TYPE = 1;
/**
 * Below are constants for LContainer indices to help us look up LContainer members
 * without having to remember the specific indices.
 * Uglify will inline these when minifying so there shouldn't be a cost.
 */

/**
 * Flag to signify that this `LContainer` may have transplanted views which need to be change
 * detected. (see: `LView[DECLARATION_COMPONENT_VIEW])`.
 *
 * This flag, once set, is never unset for the `LContainer`. This means that when unset we can skip
 * a lot of work in `refreshEmbeddedViews`. But when set we still need to verify
 * that the `MOVED_VIEWS` are transplanted and on-push.
 */

var HAS_TRANSPLANTED_VIEWS = 2; // PARENT, NEXT, TRANSPLANTED_VIEWS_TO_REFRESH are indices 3, 4, and 5
// As we already have these constants in LView, we don't need to re-create them.
// T_HOST is index 6
// We already have this constants in LView, we don't need to re-create it.

var NATIVE = 7;
var VIEW_REFS = 8;
var MOVED_VIEWS = 9;
/**
 * Size of LContainer's header. Represents the index after which all views in the
 * container will be inserted. We need to keep a record of current views so we know
 * which views are already in the DOM (and don't need to be re-added) and so we can
 * remove views from the DOM when they are no longer required.
 */

var CONTAINER_HEADER_OFFSET = 10; // Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.

var unusedValueExportToPlacateAjd$1 = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * True if `value` is `LView`.
 * @param value wrapped value of `RNode`, `LView`, `LContainer`
 */

function isLView(value) {
  return Array.isArray(value) && typeof value[TYPE] === 'object';
}
/**
 * True if `value` is `LContainer`.
 * @param value wrapped value of `RNode`, `LView`, `LContainer`
 */


function isLContainer(value) {
  return Array.isArray(value) && value[TYPE] === true;
}

function isContentQueryHost(tNode) {
  return (tNode.flags & 8
  /* hasContentQuery */
  ) !== 0;
}

function isComponentHost(tNode) {
  return (tNode.flags & 2
  /* isComponentHost */
  ) === 2
  /* isComponentHost */
  ;
}

function isDirectiveHost(tNode) {
  return (tNode.flags & 1
  /* isDirectiveHost */
  ) === 1
  /* isDirectiveHost */
  ;
}

function isComponentDef(def) {
  return def.template !== null;
}

function isRootView(target) {
  return (target[FLAGS] & 512
  /* IsRoot */
  ) !== 0;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// [Assert functions do not constraint type when they are guarded by a truthy
// expression.](https://github.com/microsoft/TypeScript/issues/37295)


function assertTNodeForLView(tNode, lView) {
  assertTNodeForTView(tNode, lView[TVIEW]);
}

function assertTNodeForTView(tNode, tView) {
  assertDefined(tNode, 'TNode must be defined');
  tNode.hasOwnProperty('tView_') && assertEqual(tNode.tView_, tView, 'This TNode does not belong to this TView.');
}

function assertComponentType(actual) {
  var msg = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'Type passed in is not ComponentType, it does not have \'ɵcmp\' property.';

  if (!getComponentDef(actual)) {
    throwError(msg);
  }
}

function assertNgModuleType(actual) {
  var msg = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'Type passed in is not NgModuleType, it does not have \'ɵmod\' property.';

  if (!getNgModuleDef(actual)) {
    throwError(msg);
  }
}

function assertCurrentTNodeIsParent(isParent) {
  assertEqual(isParent, true, 'currentTNode should be a parent');
}

function assertHasParent(tNode) {
  assertDefined(tNode, 'currentTNode should exist!');
  assertDefined(tNode.parent, 'currentTNode should have a parent');
}

function assertDataNext(lView, index, arr) {
  if (arr == null) arr = lView;
  assertEqual(arr.length, index, "index ".concat(index, " expected to be at the end of arr (length ").concat(arr.length, ")"));
}

function assertLContainer(value) {
  assertDefined(value, 'LContainer must be defined');
  assertEqual(isLContainer(value), true, 'Expecting LContainer');
}

function assertLViewOrUndefined(value) {
  value && assertEqual(isLView(value), true, 'Expecting LView or undefined or null');
}

function assertLView(value) {
  assertDefined(value, 'LView must be defined');
  assertEqual(isLView(value), true, 'Expecting LView');
}

function assertFirstCreatePass(tView, errMessage) {
  assertEqual(tView.firstCreatePass, true, errMessage || 'Should only be called in first create pass.');
}

function assertFirstUpdatePass(tView, errMessage) {
  assertEqual(tView.firstUpdatePass, true, errMessage || 'Should only be called in first update pass.');
}
/**
 * This is a basic sanity check that an object is probably a directive def. DirectiveDef is
 * an interface, so we can't do a direct instanceof check.
 */


function assertDirectiveDef(obj) {
  if (obj.type === undefined || obj.selectors == undefined || obj.inputs === undefined) {
    throwError("Expected a DirectiveDef/ComponentDef and this object does not seem to have the expected shape.");
  }
}

function assertIndexInDeclRange(lView, index) {
  var tView = lView[1];
  assertBetween(HEADER_OFFSET, tView.bindingStartIndex, index);
}

function assertIndexInVarsRange(lView, index) {
  var tView = lView[1];
  assertBetween(tView.bindingStartIndex, tView.i18nStartIndex, index);
}

function assertIndexInI18nRange(lView, index) {
  var tView = lView[1];
  assertBetween(tView.i18nStartIndex, tView.expandoStartIndex, index);
}

function assertIndexInExpandoRange(lView, index) {
  var tView = lView[1];
  assertBetween(tView.expandoStartIndex, lView.length, index);
}

function assertBetween(lower, upper, index) {
  if (!(lower <= index && index < upper)) {
    throwError("Index out of range (expecting ".concat(lower, " <= ").concat(index, " < ").concat(upper, ")"));
  }
}
/**
 * This is a basic sanity check that the `injectorIndex` seems to point to what looks like a
 * NodeInjector data structure.
 *
 * @param lView `LView` which should be checked.
 * @param injectorIndex index into the `LView` where the `NodeInjector` is expected.
 */


function assertNodeInjector(lView, injectorIndex) {
  assertIndexInExpandoRange(lView, injectorIndex);
  assertIndexInExpandoRange(lView, injectorIndex + 8
  /* PARENT */
  );
  assertNumber(lView[injectorIndex + 0], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 1], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 2], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 3], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 4], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 5], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 6], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 7], 'injectorIndex should point to a bloom filter');
  assertNumber(lView[injectorIndex + 8
  /* PARENT */
  ], 'injectorIndex should point to parent injector');
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents a basic change from a previous to a new value for a single
 * property on a directive instance. Passed as a value in a
 * {@link SimpleChanges} object to the `ngOnChanges` hook.
 *
 * @see `OnChanges`
 *
 * @publicApi
 */


var SimpleChange = /*#__PURE__*/function () {
  function SimpleChange(previousValue, currentValue, firstChange) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SimpleChange);

    this.previousValue = previousValue;
    this.currentValue = currentValue;
    this.firstChange = firstChange;
  }
  /**
   * Check whether the new value is the first value assigned.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SimpleChange, [{
    key: "isFirstChange",
    value: function isFirstChange() {
      return this.firstChange;
    }
  }]);

  return SimpleChange;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The NgOnChangesFeature decorates a component with support for the ngOnChanges
 * lifecycle hook, so it should be included in any component that implements
 * that hook.
 *
 * If the component or directive uses inheritance, the NgOnChangesFeature MUST
 * be included as a feature AFTER {@link InheritDefinitionFeature}, otherwise
 * inherited properties will not be propagated to the ngOnChanges lifecycle
 * hook.
 *
 * Example usage:
 *
 * ```
 * static ɵcmp = defineComponent({
 *   ...
 *   inputs: {name: 'publicName'},
 *   features: [NgOnChangesFeature]
 * });
 * ```
 *
 * @codeGenApi
 */


function ɵɵNgOnChangesFeature() {
  return NgOnChangesFeatureImpl;
}

function NgOnChangesFeatureImpl(definition) {
  if (definition.type.prototype.ngOnChanges) {
    definition.setInput = ngOnChangesSetInput;
  }

  return rememberChangeHistoryAndInvokeOnChangesHook;
} // This option ensures that the ngOnChanges lifecycle hook will be inherited
// from superclasses (in InheritDefinitionFeature).

/** @nocollapse */
// tslint:disable-next-line:no-toplevel-property-access


ɵɵNgOnChangesFeature.ngInherit = true;
/**
 * This is a synthetic lifecycle hook which gets inserted into `TView.preOrderHooks` to simulate
 * `ngOnChanges`.
 *
 * The hook reads the `NgSimpleChangesStore` data from the component instance and if changes are
 * found it invokes `ngOnChanges` on the component instance.
 *
 * @param this Component instance. Because this function gets inserted into `TView.preOrderHooks`,
 *     it is guaranteed to be called with component instance.
 */

function rememberChangeHistoryAndInvokeOnChangesHook() {
  var simpleChangesStore = getSimpleChangesStore(this);
  var current = simpleChangesStore === null || simpleChangesStore === void 0 ? void 0 : simpleChangesStore.current;

  if (current) {
    var previous = simpleChangesStore.previous;

    if (previous === EMPTY_OBJ) {
      simpleChangesStore.previous = current;
    } else {
      // New changes are copied to the previous store, so that we don't lose history for inputs
      // which were not changed this time
      for (var key in current) {
        previous[key] = current[key];
      }
    }

    simpleChangesStore.current = null;
    this.ngOnChanges(current);
  }
}

function ngOnChangesSetInput(instance, value, publicName, privateName) {
  var simpleChangesStore = getSimpleChangesStore(instance) || setSimpleChangesStore(instance, {
    previous: EMPTY_OBJ,
    current: null
  });
  var current = simpleChangesStore.current || (simpleChangesStore.current = {});
  var previous = simpleChangesStore.previous;
  var declaredName = this.declaredInputs[publicName];
  var previousChange = previous[declaredName];
  current[declaredName] = new SimpleChange(previousChange && previousChange.currentValue, value, previous === EMPTY_OBJ);
  instance[privateName] = value;
}

var SIMPLE_CHANGES_STORE = '__ngSimpleChanges__';

function getSimpleChangesStore(instance) {
  return instance[SIMPLE_CHANGES_STORE] || null;
}

function setSimpleChangesStore(instance, store) {
  return instance[SIMPLE_CHANGES_STORE] = store;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SVG_NAMESPACE = 'http://www.w3.org/2000/svg';
var MATH_ML_NAMESPACE = 'http://www.w3.org/1998/MathML/';
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This property will be monkey-patched on elements, components and directives
 */

var MONKEY_PATCH_KEY_NAME = '__ngContext__';
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Most of the use of `document` in Angular is from within the DI system so it is possible to simply
 * inject the `DOCUMENT` token and are done.
 *
 * Ivy is special because it does not rely upon the DI and must get hold of the document some other
 * way.
 *
 * The solution is to define `getDocument()` and `setDocument()` top-level functions for ivy.
 * Wherever ivy needs the global document, it calls `getDocument()` instead.
 *
 * When running ivy outside of a browser environment, it is necessary to call `setDocument()` to
 * tell ivy what the global `document` is.
 *
 * Angular does this for us in each of the standard platforms (`Browser`, `Server`, and `WebWorker`)
 * by calling `setDocument()` when providing the `DOCUMENT` token.
 */

var DOCUMENT = undefined;
/**
 * Tell ivy what the `document` is for this platform.
 *
 * It is only necessary to call this if the current platform is not a browser.
 *
 * @param document The object representing the global `document` in this environment.
 */

function setDocument(document) {
  DOCUMENT = document;
}
/**
 * Access the object that represents the `document` for this platform.
 *
 * Ivy calls this whenever it needs to access the `document` object.
 * For example to create the renderer or to do sanitization.
 */


function getDocument() {
  if (DOCUMENT !== undefined) {
    return DOCUMENT;
  } else if (typeof document !== 'undefined') {
    return document;
  } // No "document" can be found. This should only happen if we are running ivy outside Angular and
  // the current platform is not a browser. Since this is not a supported scenario at the moment
  // this should not happen in Angular apps.
  // Once we support running ivy outside of Angular we will need to publish `setDocument()` as a
  // public API. Meanwhile we just return `undefined` and let the application fail.


  return undefined;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// TODO: cleanup once the code is merged in angular/angular


var RendererStyleFlags3;

(function (RendererStyleFlags3) {
  RendererStyleFlags3[RendererStyleFlags3["Important"] = 1] = "Important";
  RendererStyleFlags3[RendererStyleFlags3["DashCase"] = 2] = "DashCase";
})(RendererStyleFlags3 || (RendererStyleFlags3 = {}));
/** Returns whether the `renderer` is a `ProceduralRenderer3` */


function isProceduralRenderer(renderer) {
  return !!renderer.listen;
}

var ɵ0$2 = function ɵ0$2(hostElement, rendererType) {
  return getDocument();
};

var domRendererFactory3 = {
  createRenderer: ɵ0$2
}; // Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.

var unusedValueExportToPlacateAjd$2 = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * For efficiency reasons we often put several different data types (`RNode`, `LView`, `LContainer`)
 * in same location in `LView`. This is because we don't want to pre-allocate space for it
 * because the storage is sparse. This file contains utilities for dealing with such data types.
 *
 * How do we know what is stored at a given location in `LView`.
 * - `Array.isArray(value) === false` => `RNode` (The normal storage value)
 * - `Array.isArray(value) === true` => then the `value[0]` represents the wrapped value.
 *   - `typeof value[TYPE] === 'object'` => `LView`
 *      - This happens when we have a component at a given location
 *   - `typeof value[TYPE] === true` => `LContainer`
 *      - This happens when we have `LContainer` binding at a given location.
 *
 *
 * NOTE: it is assumed that `Array.isArray` and `typeof` operations are very efficient.
 */

/**
 * Returns `RNode`.
 * @param value wrapped value of `RNode`, `LView`, `LContainer`
 */

function unwrapRNode(value) {
  while (Array.isArray(value)) {
    value = value[HOST];
  }

  return value;
}
/**
 * Returns `LView` or `null` if not found.
 * @param value wrapped value of `RNode`, `LView`, `LContainer`
 */


function unwrapLView(value) {
  while (Array.isArray(value)) {
    // This check is same as `isLView()` but we don't call at as we don't want to call
    // `Array.isArray()` twice and give JITer more work for inlining.
    if (typeof value[TYPE] === 'object') return value;
    value = value[HOST];
  }

  return null;
}
/**
 * Returns `LContainer` or `null` if not found.
 * @param value wrapped value of `RNode`, `LView`, `LContainer`
 */


function unwrapLContainer(value) {
  while (Array.isArray(value)) {
    // This check is same as `isLContainer()` but we don't call at as we don't want to call
    // `Array.isArray()` twice and give JITer more work for inlining.
    if (value[TYPE] === true) return value;
    value = value[HOST];
  }

  return null;
}
/**
 * Retrieves an element value from the provided `viewData`, by unwrapping
 * from any containers, component views, or style contexts.
 */


function getNativeByIndex(index, lView) {
  return unwrapRNode(lView[index + HEADER_OFFSET]);
}
/**
 * Retrieve an `RNode` for a given `TNode` and `LView`.
 *
 * This function guarantees in dev mode to retrieve a non-null `RNode`.
 *
 * @param tNode
 * @param lView
 */


function getNativeByTNode(tNode, lView) {
  ngDevMode && assertTNodeForLView(tNode, lView);
  ngDevMode && assertIndexInRange(lView, tNode.index);
  var node = unwrapRNode(lView[tNode.index]);
  ngDevMode && !isProceduralRenderer(lView[RENDERER]) && assertDomNode(node);
  return node;
}
/**
 * Retrieve an `RNode` or `null` for a given `TNode` and `LView`.
 *
 * Some `TNode`s don't have associated `RNode`s. For example `Projection`
 *
 * @param tNode
 * @param lView
 */


function getNativeByTNodeOrNull(tNode, lView) {
  var index = tNode === null ? -1 : tNode.index;

  if (index !== -1) {
    ngDevMode && assertTNodeForLView(tNode, lView);
    var node = unwrapRNode(lView[index]);
    ngDevMode && node !== null && !isProceduralRenderer(lView[RENDERER]) && assertDomNode(node);
    return node;
  }

  return null;
}

function getTNode(tView, index) {
  ngDevMode && assertGreaterThan(index, -1, 'wrong index for TNode');
  ngDevMode && assertLessThan(index, tView.data.length, 'wrong index for TNode');
  return tView.data[index + HEADER_OFFSET];
}
/** Retrieves a value from any `LView` or `TData`. */


function load(view, index) {
  ngDevMode && assertIndexInRange(view, index + HEADER_OFFSET);
  return view[index + HEADER_OFFSET];
}

function getComponentLViewByIndex(nodeIndex, hostView) {
  // Could be an LView or an LContainer. If LContainer, unwrap to find LView.
  ngDevMode && assertIndexInRange(hostView, nodeIndex);
  var slotValue = hostView[nodeIndex];
  var lView = isLView(slotValue) ? slotValue : slotValue[HOST];
  return lView;
}
/**
 * Returns the monkey-patch value data present on the target (which could be
 * a component, directive or a DOM node).
 */


function readPatchedData(target) {
  ngDevMode && assertDefined(target, 'Target expected');
  return target[MONKEY_PATCH_KEY_NAME] || null;
}

function readPatchedLView(target) {
  var value = readPatchedData(target);

  if (value) {
    return Array.isArray(value) ? value : value.lView;
  }

  return null;
}
/** Checks whether a given view is in creation mode */


function isCreationMode(view) {
  return (view[FLAGS] & 4
  /* CreationMode */
  ) === 4
  /* CreationMode */
  ;
}
/**
 * Returns a boolean for whether the view is attached to the change detection tree.
 *
 * Note: This determines whether a view should be checked, not whether it's inserted
 * into a container. For that, you'll want `viewAttachedToContainer` below.
 */


function viewAttachedToChangeDetector(view) {
  return (view[FLAGS] & 128
  /* Attached */
  ) === 128
  /* Attached */
  ;
}
/** Returns a boolean for whether the view is attached to a container. */


function viewAttachedToContainer(view) {
  return isLContainer(view[PARENT]);
}
/** Returns a constant from `TConstants` instance. */


function getConstant(consts, index) {
  return consts === null || index == null ? null : consts[index];
}
/**
 * Resets the pre-order hook flags of the view.
 * @param lView the LView on which the flags are reset
 */


function resetPreOrderHookFlags(lView) {
  lView[PREORDER_HOOK_FLAGS] = 0;
}
/**
 * Updates the `TRANSPLANTED_VIEWS_TO_REFRESH` counter on the `LContainer` as well as the parents
 * whose
 *  1. counter goes from 0 to 1, indicating that there is a new child that has a view to refresh
 *  or
 *  2. counter goes from 1 to 0, indicating there are no more descendant views to refresh
 */


function updateTransplantedViewCount(lContainer, amount) {
  lContainer[TRANSPLANTED_VIEWS_TO_REFRESH] += amount;
  var viewOrContainer = lContainer;
  var parent = lContainer[PARENT];

  while (parent !== null && (amount === 1 && viewOrContainer[TRANSPLANTED_VIEWS_TO_REFRESH] === 1 || amount === -1 && viewOrContainer[TRANSPLANTED_VIEWS_TO_REFRESH] === 0)) {
    parent[TRANSPLANTED_VIEWS_TO_REFRESH] += amount;
    viewOrContainer = parent;
    parent = parent[PARENT];
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var instructionState = {
  lFrame: createLFrame(null),
  bindingsEnabled: true,
  checkNoChangesMode: false
};

function getElementDepthCount() {
  return instructionState.lFrame.elementDepthCount;
}

function increaseElementDepthCount() {
  instructionState.lFrame.elementDepthCount++;
}

function decreaseElementDepthCount() {
  instructionState.lFrame.elementDepthCount--;
}

function getBindingsEnabled() {
  return instructionState.bindingsEnabled;
}
/**
 * Enables directive matching on elements.
 *
 *  * Example:
 * ```
 * <my-comp my-directive>
 *   Should match component / directive.
 * </my-comp>
 * <div ngNonBindable>
 *   <!-- ɵɵdisableBindings() -->
 *   <my-comp my-directive>
 *     Should not match component / directive because we are in ngNonBindable.
 *   </my-comp>
 *   <!-- ɵɵenableBindings() -->
 * </div>
 * ```
 *
 * @codeGenApi
 */


function ɵɵenableBindings() {
  instructionState.bindingsEnabled = true;
}
/**
 * Disables directive matching on element.
 *
 *  * Example:
 * ```
 * <my-comp my-directive>
 *   Should match component / directive.
 * </my-comp>
 * <div ngNonBindable>
 *   <!-- ɵɵdisableBindings() -->
 *   <my-comp my-directive>
 *     Should not match component / directive because we are in ngNonBindable.
 *   </my-comp>
 *   <!-- ɵɵenableBindings() -->
 * </div>
 * ```
 *
 * @codeGenApi
 */


function ɵɵdisableBindings() {
  instructionState.bindingsEnabled = false;
}
/**
 * Return the current `LView`.
 */


function getLView() {
  return instructionState.lFrame.lView;
}
/**
 * Return the current `TView`.
 */


function getTView() {
  return instructionState.lFrame.tView;
}
/**
 * Restores `contextViewData` to the given OpaqueViewState instance.
 *
 * Used in conjunction with the getCurrentView() instruction to save a snapshot
 * of the current view and restore it when listeners are invoked. This allows
 * walking the declaration view tree in listeners to get vars from parent views.
 *
 * @param viewToRestore The OpaqueViewState instance to restore.
 *
 * @codeGenApi
 */


function ɵɵrestoreView(viewToRestore) {
  instructionState.lFrame.contextLView = viewToRestore;
}

function getCurrentTNode() {
  return instructionState.lFrame.currentTNode;
}

function setCurrentTNode(tNode, isParent) {
  ngDevMode && assertTNodeForTView(tNode, instructionState.lFrame.tView);
  instructionState.lFrame.currentTNode = tNode;
  instructionState.lFrame.isParent = isParent;
}

function isCurrentTNodeParent() {
  return instructionState.lFrame.isParent;
}

function setCurrentTNodeAsNotParent() {
  instructionState.lFrame.isParent = false;
}

function setCurrentTNodeAsParent() {
  instructionState.lFrame.isParent = true;
}

function getContextLView() {
  return instructionState.lFrame.contextLView;
}

function getCheckNoChangesMode() {
  // TODO(misko): remove this from the LView since it is ngDevMode=true mode only.
  return instructionState.checkNoChangesMode;
}

function setCheckNoChangesMode(mode) {
  instructionState.checkNoChangesMode = mode;
} // top level variables should not be exported for performance reasons (PERF_NOTES.md)


function getBindingRoot() {
  var lFrame = instructionState.lFrame;
  var index = lFrame.bindingRootIndex;

  if (index === -1) {
    index = lFrame.bindingRootIndex = lFrame.tView.bindingStartIndex;
  }

  return index;
}

function getBindingIndex() {
  return instructionState.lFrame.bindingIndex;
}

function setBindingIndex(value) {
  return instructionState.lFrame.bindingIndex = value;
}

function nextBindingIndex() {
  return instructionState.lFrame.bindingIndex++;
}

function incrementBindingIndex(count) {
  var lFrame = instructionState.lFrame;
  var index = lFrame.bindingIndex;
  lFrame.bindingIndex = lFrame.bindingIndex + count;
  return index;
}
/**
 * Set a new binding root index so that host template functions can execute.
 *
 * Bindings inside the host template are 0 index. But because we don't know ahead of time
 * how many host bindings we have we can't pre-compute them. For this reason they are all
 * 0 index and we just shift the root so that they match next available location in the LView.
 *
 * @param bindingRootIndex Root index for `hostBindings`
 * @param currentDirectiveIndex `TData[currentDirectiveIndex]` will point to the current directive
 *        whose `hostBindings` are being processed.
 */


function setBindingRootForHostBindings(bindingRootIndex, currentDirectiveIndex) {
  var lFrame = instructionState.lFrame;
  lFrame.bindingIndex = lFrame.bindingRootIndex = bindingRootIndex;
  setCurrentDirectiveIndex(currentDirectiveIndex);
}
/**
 * When host binding is executing this points to the directive index.
 * `TView.data[getCurrentDirectiveIndex()]` is `DirectiveDef`
 * `LView[getCurrentDirectiveIndex()]` is directive instance.
 */


function getCurrentDirectiveIndex() {
  return instructionState.lFrame.currentDirectiveIndex;
}
/**
 * Sets an index of a directive whose `hostBindings` are being processed.
 *
 * @param currentDirectiveIndex `TData` index where current directive instance can be found.
 */


function setCurrentDirectiveIndex(currentDirectiveIndex) {
  instructionState.lFrame.currentDirectiveIndex = currentDirectiveIndex;
}
/**
 * Retrieve the current `DirectiveDef` which is active when `hostBindings` instruction is being
 * executed.
 *
 * @param tData Current `TData` where the `DirectiveDef` will be looked up at.
 */


function getCurrentDirectiveDef(tData) {
  var currentDirectiveIndex = instructionState.lFrame.currentDirectiveIndex;
  return currentDirectiveIndex === -1 ? null : tData[currentDirectiveIndex];
}

function getCurrentQueryIndex() {
  return instructionState.lFrame.currentQueryIndex;
}

function setCurrentQueryIndex(value) {
  instructionState.lFrame.currentQueryIndex = value;
}
/**
 * This is a light weight version of the `enterView` which is needed by the DI system.
 * @param newView
 * @param tNode
 */


function enterDI(newView, tNode) {
  ngDevMode && assertLViewOrUndefined(newView);
  var newLFrame = allocLFrame();
  instructionState.lFrame = newLFrame;
  newLFrame.currentTNode = tNode;
  newLFrame.lView = newView;
}
/**
 * Swap the current lView with a new lView.
 *
 * For performance reasons we store the lView in the top level of the module.
 * This way we minimize the number of properties to read. Whenever a new view
 * is entered we have to store the lView for later, and when the view is
 * exited the state has to be restored
 *
 * @param newView New lView to become active
 * @returns the previously active lView;
 */


function enterView(newView) {
  ngDevMode && assertLViewOrUndefined(newView);
  var newLFrame = allocLFrame();

  if (ngDevMode) {
    assertEqual(newLFrame.isParent, true, 'Expected clean LFrame');
    assertEqual(newLFrame.lView, null, 'Expected clean LFrame');
    assertEqual(newLFrame.tView, null, 'Expected clean LFrame');
    assertEqual(newLFrame.selectedIndex, 0, 'Expected clean LFrame');
    assertEqual(newLFrame.elementDepthCount, 0, 'Expected clean LFrame');
    assertEqual(newLFrame.currentDirectiveIndex, -1, 'Expected clean LFrame');
    assertEqual(newLFrame.currentNamespace, null, 'Expected clean LFrame');
    assertEqual(newLFrame.bindingRootIndex, -1, 'Expected clean LFrame');
    assertEqual(newLFrame.currentQueryIndex, 0, 'Expected clean LFrame');
  }

  var tView = newView[TVIEW];
  instructionState.lFrame = newLFrame;
  ngDevMode && tView.firstChild && assertTNodeForTView(tView.firstChild, tView);
  newLFrame.currentTNode = tView.firstChild;
  newLFrame.lView = newView;
  newLFrame.tView = tView;
  newLFrame.contextLView = newView;
  newLFrame.bindingIndex = tView.bindingStartIndex;
}
/**
 * Allocates next free LFrame. This function tries to reuse the `LFrame`s to lower memory pressure.
 */


function allocLFrame() {
  var currentLFrame = instructionState.lFrame;
  var childLFrame = currentLFrame === null ? null : currentLFrame.child;
  var newLFrame = childLFrame === null ? createLFrame(currentLFrame) : childLFrame;
  return newLFrame;
}

function createLFrame(parent) {
  var lFrame = {
    currentTNode: null,
    isParent: true,
    lView: null,
    tView: null,
    selectedIndex: 0,
    contextLView: null,
    elementDepthCount: 0,
    currentNamespace: null,
    currentDirectiveIndex: -1,
    bindingRootIndex: -1,
    bindingIndex: -1,
    currentQueryIndex: 0,
    parent: parent,
    child: null
  };
  parent !== null && (parent.child = lFrame); // link the new LFrame for reuse.

  return lFrame;
}
/**
 * A lightweight version of leave which is used with DI.
 *
 * This function only resets `currentTNode` and `LView` as those are the only properties
 * used with DI (`enterDI()`).
 *
 * NOTE: This function is reexported as `leaveDI`. However `leaveDI` has return type of `void` where
 * as `leaveViewLight` has `LFrame`. This is so that `leaveViewLight` can be used in `leaveView`.
 */


function leaveViewLight() {
  var oldLFrame = instructionState.lFrame;
  instructionState.lFrame = oldLFrame.parent;
  oldLFrame.currentTNode = null;
  oldLFrame.lView = null;
  return oldLFrame;
}
/**
 * This is a lightweight version of the `leaveView` which is needed by the DI system.
 *
 * NOTE: this function is an alias so that we can change the type of the function to have `void`
 * return type.
 */


var leaveDI = leaveViewLight;
/**
 * Leave the current `LView`
 *
 * This pops the `LFrame` with the associated `LView` from the stack.
 *
 * IMPORTANT: We must zero out the `LFrame` values here otherwise they will be retained. This is
 * because for performance reasons we don't release `LFrame` but rather keep it for next use.
 */

function leaveView() {
  var oldLFrame = leaveViewLight();
  oldLFrame.isParent = true;
  oldLFrame.tView = null;
  oldLFrame.selectedIndex = 0;
  oldLFrame.contextLView = null;
  oldLFrame.elementDepthCount = 0;
  oldLFrame.currentDirectiveIndex = -1;
  oldLFrame.currentNamespace = null;
  oldLFrame.bindingRootIndex = -1;
  oldLFrame.bindingIndex = -1;
  oldLFrame.currentQueryIndex = 0;
}

function nextContextImpl(level) {
  var contextLView = instructionState.lFrame.contextLView = walkUpViews(level, instructionState.lFrame.contextLView);
  return contextLView[CONTEXT];
}

function walkUpViews(nestingLevel, currentView) {
  while (nestingLevel > 0) {
    ngDevMode && assertDefined(currentView[DECLARATION_VIEW], 'Declaration view should be defined if nesting level is greater than 0.');
    currentView = currentView[DECLARATION_VIEW];
    nestingLevel--;
  }

  return currentView;
}
/**
 * Gets the currently selected element index.
 *
 * Used with {@link property} instruction (and more in the future) to identify the index in the
 * current `LView` to act on.
 */


function getSelectedIndex() {
  return instructionState.lFrame.selectedIndex;
}
/**
 * Sets the most recent index passed to {@link select}
 *
 * Used with {@link property} instruction (and more in the future) to identify the index in the
 * current `LView` to act on.
 *
 * (Note that if an "exit function" was set earlier (via `setElementExitFn()`) then that will be
 * run if and when the provided `index` value is different from the current selected index value.)
 */


function setSelectedIndex(index) {
  instructionState.lFrame.selectedIndex = index;
}
/**
 * Gets the `tNode` that represents currently selected element.
 */


function getSelectedTNode() {
  var lFrame = instructionState.lFrame;
  return getTNode(lFrame.tView, lFrame.selectedIndex);
}
/**
 * Sets the namespace used to create elements to `'http://www.w3.org/2000/svg'` in global state.
 *
 * @codeGenApi
 */


function ɵɵnamespaceSVG() {
  instructionState.lFrame.currentNamespace = SVG_NAMESPACE;
}
/**
 * Sets the namespace used to create elements to `'http://www.w3.org/1998/MathML/'` in global state.
 *
 * @codeGenApi
 */


function ɵɵnamespaceMathML() {
  instructionState.lFrame.currentNamespace = MATH_ML_NAMESPACE;
}
/**
 * Sets the namespace used to create elements to `null`, which forces element creation to use
 * `createElement` rather than `createElementNS`.
 *
 * @codeGenApi
 */


function ɵɵnamespaceHTML() {
  namespaceHTMLInternal();
}
/**
 * Sets the namespace used to create elements to `null`, which forces element creation to use
 * `createElement` rather than `createElementNS`.
 */


function namespaceHTMLInternal() {
  instructionState.lFrame.currentNamespace = null;
}

function getNamespace() {
  return instructionState.lFrame.currentNamespace;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Adds all directive lifecycle hooks from the given `DirectiveDef` to the given `TView`.
 *
 * Must be run *only* on the first template pass.
 *
 * Sets up the pre-order hooks on the provided `tView`,
 * see {@link HookData} for details about the data structure.
 *
 * @param directiveIndex The index of the directive in LView
 * @param directiveDef The definition containing the hooks to setup in tView
 * @param tView The current TView
 */


function registerPreOrderHooks(directiveIndex, directiveDef, tView) {
  ngDevMode && assertFirstCreatePass(tView);
  var _directiveDef$type$pr = directiveDef.type.prototype,
      ngOnChanges = _directiveDef$type$pr.ngOnChanges,
      ngOnInit = _directiveDef$type$pr.ngOnInit,
      ngDoCheck = _directiveDef$type$pr.ngDoCheck;

  if (ngOnChanges) {
    var wrappedOnChanges = NgOnChangesFeatureImpl(directiveDef);
    (tView.preOrderHooks || (tView.preOrderHooks = [])).push(directiveIndex, wrappedOnChanges);
    (tView.preOrderCheckHooks || (tView.preOrderCheckHooks = [])).push(directiveIndex, wrappedOnChanges);
  }

  if (ngOnInit) {
    (tView.preOrderHooks || (tView.preOrderHooks = [])).push(0 - directiveIndex, ngOnInit);
  }

  if (ngDoCheck) {
    (tView.preOrderHooks || (tView.preOrderHooks = [])).push(directiveIndex, ngDoCheck);
    (tView.preOrderCheckHooks || (tView.preOrderCheckHooks = [])).push(directiveIndex, ngDoCheck);
  }
}
/**
 *
 * Loops through the directives on the provided `tNode` and queues hooks to be
 * run that are not initialization hooks.
 *
 * Should be executed during `elementEnd()` and similar to
 * preserve hook execution order. Content, view, and destroy hooks for projected
 * components and directives must be called *before* their hosts.
 *
 * Sets up the content, view, and destroy hooks on the provided `tView`,
 * see {@link HookData} for details about the data structure.
 *
 * NOTE: This does not set up `onChanges`, `onInit` or `doCheck`, those are set up
 * separately at `elementStart`.
 *
 * @param tView The current TView
 * @param tNode The TNode whose directives are to be searched for hooks to queue
 */


function registerPostOrderHooks(tView, tNode) {
  ngDevMode && assertFirstCreatePass(tView); // It's necessary to loop through the directives at elementEnd() (rather than processing in
  // directiveCreate) so we can preserve the current hook order. Content, view, and destroy
  // hooks for projected components and directives must be called *before* their hosts.

  for (var i = tNode.directiveStart, end = tNode.directiveEnd; i < end; i++) {
    var _directiveDef = tView.data[i];
    var lifecycleHooks = _directiveDef.type.prototype;
    var ngAfterContentInit = lifecycleHooks.ngAfterContentInit,
        ngAfterContentChecked = lifecycleHooks.ngAfterContentChecked,
        ngAfterViewInit = lifecycleHooks.ngAfterViewInit,
        ngAfterViewChecked = lifecycleHooks.ngAfterViewChecked,
        ngOnDestroy = lifecycleHooks.ngOnDestroy;

    if (ngAfterContentInit) {
      (tView.contentHooks || (tView.contentHooks = [])).push(-i, ngAfterContentInit);
    }

    if (ngAfterContentChecked) {
      (tView.contentHooks || (tView.contentHooks = [])).push(i, ngAfterContentChecked);
      (tView.contentCheckHooks || (tView.contentCheckHooks = [])).push(i, ngAfterContentChecked);
    }

    if (ngAfterViewInit) {
      (tView.viewHooks || (tView.viewHooks = [])).push(-i, ngAfterViewInit);
    }

    if (ngAfterViewChecked) {
      (tView.viewHooks || (tView.viewHooks = [])).push(i, ngAfterViewChecked);
      (tView.viewCheckHooks || (tView.viewCheckHooks = [])).push(i, ngAfterViewChecked);
    }

    if (ngOnDestroy != null) {
      (tView.destroyHooks || (tView.destroyHooks = [])).push(i, ngOnDestroy);
    }
  }
}
/**
 * Executing hooks requires complex logic as we need to deal with 2 constraints.
 *
 * 1. Init hooks (ngOnInit, ngAfterContentInit, ngAfterViewInit) must all be executed once and only
 * once, across many change detection cycles. This must be true even if some hooks throw, or if
 * some recursively trigger a change detection cycle.
 * To solve that, it is required to track the state of the execution of these init hooks.
 * This is done by storing and maintaining flags in the view: the {@link InitPhaseState},
 * and the index within that phase. They can be seen as a cursor in the following structure:
 * [[onInit1, onInit2], [afterContentInit1], [afterViewInit1, afterViewInit2, afterViewInit3]]
 * They are are stored as flags in LView[FLAGS].
 *
 * 2. Pre-order hooks can be executed in batches, because of the select instruction.
 * To be able to pause and resume their execution, we also need some state about the hook's array
 * that is being processed:
 * - the index of the next hook to be executed
 * - the number of init hooks already found in the processed part of the  array
 * They are are stored as flags in LView[PREORDER_HOOK_FLAGS].
 */

/**
 * Executes pre-order check hooks ( OnChanges, DoChanges) given a view where all the init hooks were
 * executed once. This is a light version of executeInitAndCheckPreOrderHooks where we can skip read
 * / write of the init-hooks related flags.
 * @param lView The LView where hooks are defined
 * @param hooks Hooks to be run
 * @param nodeIndex 3 cases depending on the value:
 * - undefined: all hooks from the array should be executed (post-order case)
 * - null: execute hooks only from the saved index until the end of the array (pre-order case, when
 * flushing the remaining hooks)
 * - number: execute hooks only from the saved index until that node index exclusive (pre-order
 * case, when executing select(number))
 */


function executeCheckHooks(lView, hooks, nodeIndex) {
  callHooks(lView, hooks, 3
  /* InitPhaseCompleted */
  , nodeIndex);
}
/**
 * Executes post-order init and check hooks (one of AfterContentInit, AfterContentChecked,
 * AfterViewInit, AfterViewChecked) given a view where there are pending init hooks to be executed.
 * @param lView The LView where hooks are defined
 * @param hooks Hooks to be run
 * @param initPhase A phase for which hooks should be run
 * @param nodeIndex 3 cases depending on the value:
 * - undefined: all hooks from the array should be executed (post-order case)
 * - null: execute hooks only from the saved index until the end of the array (pre-order case, when
 * flushing the remaining hooks)
 * - number: execute hooks only from the saved index until that node index exclusive (pre-order
 * case, when executing select(number))
 */


function executeInitAndCheckHooks(lView, hooks, initPhase, nodeIndex) {
  ngDevMode && assertNotEqual(initPhase, 3
  /* InitPhaseCompleted */
  , 'Init pre-order hooks should not be called more than once');

  if ((lView[FLAGS] & 3
  /* InitPhaseStateMask */
  ) === initPhase) {
    callHooks(lView, hooks, initPhase, nodeIndex);
  }
}

function incrementInitPhaseFlags(lView, initPhase) {
  ngDevMode && assertNotEqual(initPhase, 3
  /* InitPhaseCompleted */
  , 'Init hooks phase should not be incremented after all init hooks have been run.');
  var flags = lView[FLAGS];

  if ((flags & 3
  /* InitPhaseStateMask */
  ) === initPhase) {
    flags &= 2047
    /* IndexWithinInitPhaseReset */
    ;
    flags += 1
    /* InitPhaseStateIncrementer */
    ;
    lView[FLAGS] = flags;
  }
}
/**
 * Calls lifecycle hooks with their contexts, skipping init hooks if it's not
 * the first LView pass
 *
 * @param currentView The current view
 * @param arr The array in which the hooks are found
 * @param initPhaseState the current state of the init phase
 * @param currentNodeIndex 3 cases depending on the value:
 * - undefined: all hooks from the array should be executed (post-order case)
 * - null: execute hooks only from the saved index until the end of the array (pre-order case, when
 * flushing the remaining hooks)
 * - number: execute hooks only from the saved index until that node index exclusive (pre-order
 * case, when executing select(number))
 */


function callHooks(currentView, arr, initPhase, currentNodeIndex) {
  ngDevMode && assertEqual(getCheckNoChangesMode(), false, 'Hooks should never be run in the check no changes mode.');
  var startIndex = currentNodeIndex !== undefined ? currentView[PREORDER_HOOK_FLAGS] & 65535
  /* IndexOfTheNextPreOrderHookMaskMask */
  : 0;
  var nodeIndexLimit = currentNodeIndex != null ? currentNodeIndex : -1;
  var lastNodeIndexFound = 0;

  for (var i = startIndex; i < arr.length; i++) {
    var hook = arr[i + 1];

    if (typeof hook === 'number') {
      lastNodeIndexFound = arr[i];

      if (currentNodeIndex != null && lastNodeIndexFound >= currentNodeIndex) {
        break;
      }
    } else {
      var isInitHook = arr[i] < 0;
      if (isInitHook) currentView[PREORDER_HOOK_FLAGS] += 65536
      /* NumberOfInitHooksCalledIncrementer */
      ;

      if (lastNodeIndexFound < nodeIndexLimit || nodeIndexLimit == -1) {
        callHook(currentView, initPhase, arr, i);
        currentView[PREORDER_HOOK_FLAGS] = (currentView[PREORDER_HOOK_FLAGS] & 4294901760
        /* NumberOfInitHooksCalledMask */
        ) + i + 2;
      }

      i++;
    }
  }
}
/**
 * Execute one hook against the current `LView`.
 *
 * @param currentView The current view
 * @param initPhaseState the current state of the init phase
 * @param arr The array in which the hooks are found
 * @param i The current index within the hook data array
 */


function callHook(currentView, initPhase, arr, i) {
  var isInitHook = arr[i] < 0;
  var hook = arr[i + 1];
  var directiveIndex = isInitHook ? -arr[i] : arr[i];
  var directive = currentView[directiveIndex];

  if (isInitHook) {
    var indexWithintInitPhase = currentView[FLAGS] >> 11
    /* IndexWithinInitPhaseShift */
    ; // The init phase state must be always checked here as it may have been recursively
    // updated

    if (indexWithintInitPhase < currentView[PREORDER_HOOK_FLAGS] >> 16
    /* NumberOfInitHooksCalledShift */
    && (currentView[FLAGS] & 3
    /* InitPhaseStateMask */
    ) === initPhase) {
      currentView[FLAGS] += 2048
      /* IndexWithinInitPhaseIncrementer */
      ;
      hook.call(directive);
    }
  } else {
    hook.call(directive);
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NO_PARENT_INJECTOR = -1;
/**
 * Each injector is saved in 9 contiguous slots in `LView` and 9 contiguous slots in
 * `TView.data`. This allows us to store information about the current node's tokens (which
 * can be shared in `TView`) as well as the tokens of its ancestor nodes (which cannot be
 * shared, so they live in `LView`).
 *
 * Each of these slots (aside from the last slot) contains a bloom filter. This bloom filter
 * determines whether a directive is available on the associated node or not. This prevents us
 * from searching the directives array at this level unless it's probable the directive is in it.
 *
 * See: https://en.wikipedia.org/wiki/Bloom_filter for more about bloom filters.
 *
 * Because all injectors have been flattened into `LView` and `TViewData`, they cannot typed
 * using interfaces as they were previously. The start index of each `LInjector` and `TInjector`
 * will differ based on where it is flattened into the main array, so it's not possible to know
 * the indices ahead of time and save their types here. The interfaces are still included here
 * for documentation purposes.
 *
 * export interface LInjector extends Array<any> {
 *
 *    // Cumulative bloom for directive IDs 0-31  (IDs are % BLOOM_SIZE)
 *    [0]: number;
 *
 *    // Cumulative bloom for directive IDs 32-63
 *    [1]: number;
 *
 *    // Cumulative bloom for directive IDs 64-95
 *    [2]: number;
 *
 *    // Cumulative bloom for directive IDs 96-127
 *    [3]: number;
 *
 *    // Cumulative bloom for directive IDs 128-159
 *    [4]: number;
 *
 *    // Cumulative bloom for directive IDs 160 - 191
 *    [5]: number;
 *
 *    // Cumulative bloom for directive IDs 192 - 223
 *    [6]: number;
 *
 *    // Cumulative bloom for directive IDs 224 - 255
 *    [7]: number;
 *
 *    // We need to store a reference to the injector's parent so DI can keep looking up
 *    // the injector tree until it finds the dependency it's looking for.
 *    [PARENT_INJECTOR]: number;
 * }
 *
 * export interface TInjector extends Array<any> {
 *
 *    // Shared node bloom for directive IDs 0-31  (IDs are % BLOOM_SIZE)
 *    [0]: number;
 *
 *    // Shared node bloom for directive IDs 32-63
 *    [1]: number;
 *
 *    // Shared node bloom for directive IDs 64-95
 *    [2]: number;
 *
 *    // Shared node bloom for directive IDs 96-127
 *    [3]: number;
 *
 *    // Shared node bloom for directive IDs 128-159
 *    [4]: number;
 *
 *    // Shared node bloom for directive IDs 160 - 191
 *    [5]: number;
 *
 *    // Shared node bloom for directive IDs 192 - 223
 *    [6]: number;
 *
 *    // Shared node bloom for directive IDs 224 - 255
 *    [7]: number;
 *
 *    // Necessary to find directive indices for a particular node.
 *    [TNODE]: TElementNode|TElementContainerNode|TContainerNode;
 *  }
 */

/**
 * Factory for creating instances of injectors in the NodeInjector.
 *
 * This factory is complicated by the fact that it can resolve `multi` factories as well.
 *
 * NOTE: Some of the fields are optional which means that this class has two hidden classes.
 * - One without `multi` support (most common)
 * - One with `multi` values, (rare).
 *
 * Since VMs can cache up to 4 inline hidden classes this is OK.
 *
 * - Single factory: Only `resolving` and `factory` is defined.
 * - `providers` factory: `componentProviders` is a number and `index = -1`.
 * - `viewProviders` factory: `componentProviders` is a number and `index` points to `providers`.
 */

var NodeInjectorFactory = function NodeInjectorFactory(
/**
 * Factory to invoke in order to create a new instance.
 */
factory,
/**
 * Set to `true` if the token is declared in `viewProviders` (or if it is component).
 */
isViewProvider, injectImplementation) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NodeInjectorFactory);

  this.factory = factory;
  /**
   * Marker set to true during factory invocation to see if we get into recursive loop.
   * Recursive loop causes an error to be displayed.
   */

  this.resolving = false;
  ngDevMode && assertDefined(factory, 'Factory not specified');
  ngDevMode && assertEqual(typeof factory, 'function', 'Expected factory function.');
  this.canSeeViewProviders = isViewProvider;
  this.injectImpl = injectImplementation;
};

function isFactory(obj) {
  return obj instanceof NodeInjectorFactory;
} // Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.


var unusedValueExportToPlacateAjd$3 = 1;
/**
 * Converts `TNodeType` into human readable text.
 * Make sure this matches with `TNodeType`
 */

var TNodeTypeAsString = ['Container', 'Projection', 'Element', 'ElementContainer', 'IcuContainer' // 4
]; // Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.

var unusedValueExportToPlacateAjd$4 = 1;
/**
 * Returns `true` if the `TNode` has a directive which has `@Input()` for `class` binding.
 *
 * ```
 * <div my-dir [class]="exp"></div>
 * ```
 * and
 * ```
 * @Directive({
 * })
 * class MyDirective {
 *   @Input()
 *   class: string;
 * }
 * ```
 *
 * In the above case it is necessary to write the reconciled styling information into the
 * directive's input.
 *
 * @param tNode
 */

function hasClassInput(tNode) {
  return (tNode.flags & 16
  /* hasClassInput */
  ) !== 0;
}
/**
 * Returns `true` if the `TNode` has a directive which has `@Input()` for `style` binding.
 *
 * ```
 * <div my-dir [style]="exp"></div>
 * ```
 * and
 * ```
 * @Directive({
 * })
 * class MyDirective {
 *   @Input()
 *   class: string;
 * }
 * ```
 *
 * In the above case it is necessary to write the reconciled styling information into the
 * directive's input.
 *
 * @param tNode
 */


function hasStyleInput(tNode) {
  return (tNode.flags & 32
  /* hasStyleInput */
  ) !== 0;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function assertNodeType(tNode, type) {
  assertDefined(tNode, 'should be called with a TNode');
  assertEqual(tNode.type, type, "should be a ".concat(typeName(type)));
}

function assertNodeOfPossibleTypes(tNode, types, message) {
  assertDefined(tNode, 'should be called with a TNode');
  var found = types.some(function (type) {
    return tNode.type === type;
  });
  assertEqual(found, true, message !== null && message !== void 0 ? message : "Should be one of ".concat(types.map(typeName).join(', '), " but got ").concat(typeName(tNode.type)));
}

function assertNodeNotOfTypes(tNode, types, message) {
  assertDefined(tNode, 'should be called with a TNode');
  var found = types.some(function (type) {
    return tNode.type === type;
  });
  assertEqual(found, false, message !== null && message !== void 0 ? message : "Should not be one of ".concat(types.map(typeName).join(', '), " but got ").concat(typeName(tNode.type)));
}

function typeName(type) {
  return TNodeTypeAsString[type] || '<unknown>';
}
/**
 * Assigns all attribute values to the provided element via the inferred renderer.
 *
 * This function accepts two forms of attribute entries:
 *
 * default: (key, value):
 *  attrs = [key1, value1, key2, value2]
 *
 * namespaced: (NAMESPACE_MARKER, uri, name, value)
 *  attrs = [NAMESPACE_MARKER, uri, name, value, NAMESPACE_MARKER, uri, name, value]
 *
 * The `attrs` array can contain a mix of both the default and namespaced entries.
 * The "default" values are set without a marker, but if the function comes across
 * a marker value then it will attempt to set a namespaced value. If the marker is
 * not of a namespaced value then the function will quit and return the index value
 * where it stopped during the iteration of the attrs array.
 *
 * See [AttributeMarker] to understand what the namespace marker value is.
 *
 * Note that this instruction does not support assigning style and class values to
 * an element. See `elementStart` and `elementHostAttrs` to learn how styling values
 * are applied to an element.
 * @param renderer The renderer to be used
 * @param native The element that the attributes will be assigned to
 * @param attrs The attribute array of values that will be assigned to the element
 * @returns the index value that was last accessed in the attributes array
 */


function setUpAttributes(renderer, native, attrs) {
  var isProc = isProceduralRenderer(renderer);
  var i = 0;

  while (i < attrs.length) {
    var value = attrs[i];

    if (typeof value === 'number') {
      // only namespaces are supported. Other value types (such as style/class
      // entries) are not supported in this function.
      if (value !== 0
      /* NamespaceURI */
      ) {
          break;
        } // we just landed on the marker value ... therefore
      // we should skip to the next entry


      i++;
      var namespaceURI = attrs[i++];
      var attrName = attrs[i++];
      var attrVal = attrs[i++];
      ngDevMode && ngDevMode.rendererSetAttribute++;
      isProc ? renderer.setAttribute(native, attrName, attrVal, namespaceURI) : native.setAttributeNS(namespaceURI, attrName, attrVal);
    } else {
      // attrName is string;
      var _attrName = value;
      var _attrVal = attrs[++i]; // Standard attributes

      ngDevMode && ngDevMode.rendererSetAttribute++;

      if (isAnimationProp(_attrName)) {
        if (isProc) {
          renderer.setProperty(native, _attrName, _attrVal);
        }
      } else {
        isProc ? renderer.setAttribute(native, _attrName, _attrVal) : native.setAttribute(_attrName, _attrVal);
      }

      i++;
    }
  } // another piece of code may iterate over the same attributes array. Therefore
  // it may be helpful to return the exact spot where the attributes array exited
  // whether by running into an unsupported marker or if all the static values were
  // iterated over.


  return i;
}
/**
 * Test whether the given value is a marker that indicates that the following
 * attribute values in a `TAttributes` array are only the names of attributes,
 * and not name-value pairs.
 * @param marker The attribute marker to test.
 * @returns true if the marker is a "name-only" marker (e.g. `Bindings`, `Template` or `I18n`).
 */


function isNameOnlyAttributeMarker(marker) {
  return marker === 3
  /* Bindings */
  || marker === 4
  /* Template */
  || marker === 6
  /* I18n */
  ;
}

function isAnimationProp(name) {
  // Perf note: accessing charCodeAt to check for the first character of a string is faster as
  // compared to accessing a character at index 0 (ex. name[0]). The main reason for this is that
  // charCodeAt doesn't allocate memory to return a substring.
  return name.charCodeAt(0) === 64
  /* AT_SIGN */
  ;
}
/**
 * Merges `src` `TAttributes` into `dst` `TAttributes` removing any duplicates in the process.
 *
 * This merge function keeps the order of attrs same.
 *
 * @param dst Location of where the merged `TAttributes` should end up.
 * @param src `TAttributes` which should be appended to `dst`
 */


function mergeHostAttrs(dst, src) {
  if (src === null || src.length === 0) {// do nothing
  } else if (dst === null || dst.length === 0) {
    // We have source, but dst is empty, just make a copy.
    dst = src.slice();
  } else {
    var srcMarker = -1
    /* ImplicitAttributes */
    ;

    for (var i = 0; i < src.length; i++) {
      var item = src[i];

      if (typeof item === 'number') {
        srcMarker = item;
      } else {
        if (srcMarker === 0
        /* NamespaceURI */
        ) {// Case where we need to consume `key1`, `key2`, `value` items.
          } else if (srcMarker === -1
        /* ImplicitAttributes */
        || srcMarker === 2
        /* Styles */
        ) {
            // Case where we have to consume `key1` and `value` only.
            mergeHostAttribute(dst, srcMarker, item, null, src[++i]);
          } else {
          // Case where we have to consume `key1` only.
          mergeHostAttribute(dst, srcMarker, item, null, null);
        }
      }
    }
  }

  return dst;
}
/**
 * Append `key`/`value` to existing `TAttributes` taking region marker and duplicates into account.
 *
 * @param dst `TAttributes` to append to.
 * @param marker Region where the `key`/`value` should be added.
 * @param key1 Key to add to `TAttributes`
 * @param key2 Key to add to `TAttributes` (in case of `AttributeMarker.NamespaceURI`)
 * @param value Value to add or to overwrite to `TAttributes` Only used if `marker` is not Class.
 */


function mergeHostAttribute(dst, marker, key1, key2, value) {
  var i = 0; // Assume that new markers will be inserted at the end.

  var markerInsertPosition = dst.length; // scan until correct type.

  if (marker === -1
  /* ImplicitAttributes */
  ) {
      markerInsertPosition = -1;
    } else {
    while (i < dst.length) {
      var dstValue = dst[i++];

      if (typeof dstValue === 'number') {
        if (dstValue === marker) {
          markerInsertPosition = -1;
          break;
        } else if (dstValue > marker) {
          // We need to save this as we want the markers to be inserted in specific order.
          markerInsertPosition = i - 1;
          break;
        }
      }
    }
  } // search until you find place of insertion


  while (i < dst.length) {
    var item = dst[i];

    if (typeof item === 'number') {
      // since `i` started as the index after the marker, we did not find it if we are at the next
      // marker
      break;
    } else if (item === key1) {
      // We already have same token
      if (key2 === null) {
        if (value !== null) {
          dst[i + 1] = value;
        }

        return;
      } else if (key2 === dst[i + 1]) {
        dst[i + 2] = value;
        return;
      }
    } // Increment counter.


    i++;
    if (key2 !== null) i++;
    if (value !== null) i++;
  } // insert at location.


  if (markerInsertPosition !== -1) {
    dst.splice(markerInsertPosition, 0, marker);
    i = markerInsertPosition + 1;
  }

  dst.splice(i++, 0, key1);

  if (key2 !== null) {
    dst.splice(i++, 0, key2);
  }

  if (value !== null) {
    dst.splice(i++, 0, value);
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/// Parent Injector Utils ///////////////////////////////////////////////////////////////


function hasParentInjector(parentLocation) {
  return parentLocation !== NO_PARENT_INJECTOR;
}

function getParentInjectorIndex(parentLocation) {
  ngDevMode && assertNumber(parentLocation, 'Number expected');
  ngDevMode && assertNotEqual(parentLocation, -1, 'Not a valid state.');
  var parentInjectorIndex = parentLocation & 32767
  /* InjectorIndexMask */
  ;
  ngDevMode && assertGreaterThan(parentInjectorIndex, HEADER_OFFSET, 'Parent injector must be pointing past HEADER_OFFSET.');
  return parentLocation & 32767
  /* InjectorIndexMask */
  ;
}

function getParentInjectorViewOffset(parentLocation) {
  return parentLocation >> 16
  /* ViewOffsetShift */
  ;
}
/**
 * Unwraps a parent injector location number to find the view offset from the current injector,
 * then walks up the declaration view tree until the view is found that contains the parent
 * injector.
 *
 * @param location The location of the parent injector, which contains the view offset
 * @param startView The LView instance from which to start walking up the view tree
 * @returns The LView instance that contains the parent injector
 */


function getParentInjectorView(location, startView) {
  var viewOffset = getParentInjectorViewOffset(location);
  var parentView = startView; // For most cases, the parent injector can be found on the host node (e.g. for component
  // or container), but we must keep the loop here to support the rarer case of deeply nested
  // <ng-template> tags or inline views, where the parent injector might live many views
  // above the child injector.

  while (viewOffset > 0) {
    parentView = parentView[DECLARATION_VIEW];
    viewOffset--;
  }

  return parentView;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Used for stringify render output in Ivy.
 * Important! This function is very performance-sensitive and we should
 * be extra careful not to introduce megamorphic reads in it.
 */


function renderStringify(value) {
  if (typeof value === 'string') return value;
  if (value == null) return '';
  return '' + value;
}
/**
 * Used to stringify a value so that it can be displayed in an error message.
 * Important! This function contains a megamorphic read and should only be
 * used for error messages.
 */


function stringifyForError(value) {
  if (typeof value === 'function') return value.name || value.toString();

  if (typeof value === 'object' && value != null && typeof value.type === 'function') {
    return value.type.name || value.type.toString();
  }

  return renderStringify(value);
}

var ɵ0$3 = function ɵ0$3() {
  return (typeof requestAnimationFrame !== 'undefined' && requestAnimationFrame || // browser only
  setTimeout // everything else
  ).bind(_global);
};

var defaultScheduler = ɵ0$3();
/**
 *
 * @codeGenApi
 */

function ɵɵresolveWindow(element) {
  return {
    name: 'window',
    target: element.ownerDocument.defaultView
  };
}
/**
 *
 * @codeGenApi
 */


function ɵɵresolveDocument(element) {
  return {
    name: 'document',
    target: element.ownerDocument
  };
}
/**
 *
 * @codeGenApi
 */


function ɵɵresolveBody(element) {
  return {
    name: 'body',
    target: element.ownerDocument.body
  };
}
/**
 * The special delimiter we use to separate property names, prefixes, and suffixes
 * in property binding metadata. See storeBindingMetadata().
 *
 * We intentionally use the Unicode "REPLACEMENT CHARACTER" (U+FFFD) as a delimiter
 * because it is a very uncommon character that is unlikely to be part of a user's
 * property names or interpolation strings. If it is in fact used in a property
 * binding, DebugElement.properties will not return the correct value for that
 * binding. However, there should be no runtime effect for real applications.
 *
 * This character is typically rendered as a question mark inside of a diamond.
 * See https://en.wikipedia.org/wiki/Specials_(Unicode_block)
 *
 */


var INTERPOLATION_DELIMITER = "\uFFFD";
/**
 * Unwrap a value which might be behind a closure (for forward declaration reasons).
 */

function maybeUnwrapFn(value) {
  if (value instanceof Function) {
    return value();
  } else {
    return value;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Defines if the call to `inject` should include `viewProviders` in its resolution.
 *
 * This is set to true when we try to instantiate a component. This value is reset in
 * `getNodeInjectable` to a value which matches the declaration location of the token about to be
 * instantiated. This is done so that if we are injecting a token which was declared outside of
 * `viewProviders` we don't accidentally pull `viewProviders` in.
 *
 * Example:
 *
 * ```
 * @Injectable()
 * class MyService {
 *   constructor(public value: String) {}
 * }
 *
 * @Component({
 *   providers: [
 *     MyService,
 *     {provide: String, value: 'providers' }
 *   ]
 *   viewProviders: [
 *     {provide: String, value: 'viewProviders'}
 *   ]
 * })
 * class MyComponent {
 *   constructor(myService: MyService, value: String) {
 *     // We expect that Component can see into `viewProviders`.
 *     expect(value).toEqual('viewProviders');
 *     // `MyService` was not declared in `viewProviders` hence it can't see it.
 *     expect(myService.value).toEqual('providers');
 *   }
 * }
 *
 * ```
 */


var includeViewProviders = true;

function setIncludeViewProviders(v) {
  var oldValue = includeViewProviders;
  includeViewProviders = v;
  return oldValue;
}
/**
 * The number of slots in each bloom filter (used by DI). The larger this number, the fewer
 * directives that will share slots, and thus, the fewer false positives when checking for
 * the existence of a directive.
 */


var BLOOM_SIZE = 256;
var BLOOM_MASK = BLOOM_SIZE - 1;
/** Counter used to generate unique IDs for directives. */

var nextNgElementId = 0;
/**
 * Registers this directive as present in its node's injector by flipping the directive's
 * corresponding bit in the injector's bloom filter.
 *
 * @param injectorIndex The index of the node injector where this token should be registered
 * @param tView The TView for the injector's bloom filters
 * @param type The directive token to register
 */

function bloomAdd(injectorIndex, tView, type) {
  ngDevMode && assertEqual(tView.firstCreatePass, true, 'expected firstCreatePass to be true');
  var id;

  if (typeof type === 'string') {
    id = type.charCodeAt(0) || 0;
  } else if (type.hasOwnProperty(NG_ELEMENT_ID)) {
    id = type[NG_ELEMENT_ID];
  } // Set a unique ID on the directive type, so if something tries to inject the directive,
  // we can easily retrieve the ID and hash it into the bloom bit that should be checked.


  if (id == null) {
    id = type[NG_ELEMENT_ID] = nextNgElementId++;
  } // We only have BLOOM_SIZE (256) slots in our bloom filter (8 buckets * 32 bits each),
  // so all unique IDs must be modulo-ed into a number from 0 - 255 to fit into the filter.


  var bloomBit = id & BLOOM_MASK; // Create a mask that targets the specific bit associated with the directive.
  // JS bit operations are 32 bits, so this will be a number between 2^0 and 2^31, corresponding
  // to bit positions 0 - 31 in a 32 bit integer.

  var mask = 1 << bloomBit; // Use the raw bloomBit number to determine which bloom filter bucket we should check
  // e.g: bf0 = [0 - 31], bf1 = [32 - 63], bf2 = [64 - 95], bf3 = [96 - 127], etc

  var b7 = bloomBit & 0x80;
  var b6 = bloomBit & 0x40;
  var b5 = bloomBit & 0x20;
  var tData = tView.data;

  if (b7) {
    b6 ? b5 ? tData[injectorIndex + 7] |= mask : tData[injectorIndex + 6] |= mask : b5 ? tData[injectorIndex + 5] |= mask : tData[injectorIndex + 4] |= mask;
  } else {
    b6 ? b5 ? tData[injectorIndex + 3] |= mask : tData[injectorIndex + 2] |= mask : b5 ? tData[injectorIndex + 1] |= mask : tData[injectorIndex] |= mask;
  }
}
/**
 * Creates (or gets an existing) injector for a given element or container.
 *
 * @param tNode for which an injector should be retrieved / created.
 * @param lView View where the node is stored
 * @returns Node injector
 */


function getOrCreateNodeInjectorForNode(tNode, lView) {
  var existingInjectorIndex = getInjectorIndex(tNode, lView);

  if (existingInjectorIndex !== -1) {
    return existingInjectorIndex;
  }

  var tView = lView[TVIEW];

  if (tView.firstCreatePass) {
    tNode.injectorIndex = lView.length;
    insertBloom(tView.data, tNode); // foundation for node bloom

    insertBloom(lView, null); // foundation for cumulative bloom

    insertBloom(tView.blueprint, null);
  }

  var parentLoc = getParentInjectorLocation(tNode, lView);
  var injectorIndex = tNode.injectorIndex; // If a parent injector can't be found, its location is set to -1.
  // In that case, we don't need to set up a cumulative bloom

  if (hasParentInjector(parentLoc)) {
    var parentIndex = getParentInjectorIndex(parentLoc);
    var parentLView = getParentInjectorView(parentLoc, lView);
    var parentData = parentLView[TVIEW].data; // Creates a cumulative bloom filter that merges the parent's bloom filter
    // and its own cumulative bloom (which contains tokens for all ancestors)

    for (var i = 0; i < 8
    /* BLOOM_SIZE */
    ; i++) {
      lView[injectorIndex + i] = parentLView[parentIndex + i] | parentData[parentIndex + i];
    }
  }

  lView[injectorIndex + 8
  /* PARENT */
  ] = parentLoc;
  return injectorIndex;
}

function insertBloom(arr, footer) {
  arr.push(0, 0, 0, 0, 0, 0, 0, 0, footer);
}

function getInjectorIndex(tNode, lView) {
  if (tNode.injectorIndex === -1 || // If the injector index is the same as its parent's injector index, then the index has been
  // copied down from the parent node. No injector has been created yet on this node.
  tNode.parent && tNode.parent.injectorIndex === tNode.injectorIndex || // After the first template pass, the injector index might exist but the parent values
  // might not have been calculated yet for this instance
  lView[tNode.injectorIndex + 8
  /* PARENT */
  ] === null) {
    return -1;
  } else {
    ngDevMode && assertIndexInRange(lView, tNode.injectorIndex);
    return tNode.injectorIndex;
  }
}
/**
 * Finds the index of the parent injector, with a view offset if applicable. Used to set the
 * parent injector initially.
 *
 * @returns Returns a number that is the combination of the number of LViews that we have to go up
 * to find the LView containing the parent inject AND the index of the injector within that LView.
 */


function getParentInjectorLocation(tNode, lView) {
  if (tNode.parent && tNode.parent.injectorIndex !== -1) {
    // If we have a parent `TNode` and there is an injector associated with it we are done, because
    // the parent injector is within the current `LView`.
    return tNode.parent.injectorIndex; // ViewOffset is 0
  } // When parent injector location is computed it may be outside of the current view. (ie it could
  // be pointing to a declared parent location). This variable stores number of declaration parents
  // we need to walk up in order to find the parent injector location.


  var declarationViewOffset = 0;
  var parentTNode = null;
  var lViewCursor = lView; // The parent injector is not in the current `LView`. We will have to walk the declared parent
  // `LView` hierarchy and look for it. If we walk of the top, that means that there is no parent
  // `NodeInjector`.

  while (lViewCursor !== null) {
    // First determine the `parentTNode` location. The parent pointer differs based on `TView.type`.
    var tView = lViewCursor[TVIEW];
    var tViewType = tView.type;

    if (tViewType === 2
    /* Embedded */
    ) {
        ngDevMode && assertDefined(tView.declTNode, 'Embedded TNodes should have declaration parents.');
        parentTNode = tView.declTNode;
      } else if (tViewType === 1
    /* Component */
    ) {
        // Components don't have `TView.declTNode` because each instance of component could be
        // inserted in different location, hence `TView.declTNode` is meaningless.
        parentTNode = lViewCursor[T_HOST];
      } else {
      ngDevMode && assertEqual(tView.type, 0
      /* Root */
      , 'Root type expected');
      parentTNode = null;
    }

    if (parentTNode === null) {
      // If we have no parent, than we are done.
      return NO_PARENT_INJECTOR;
    }

    ngDevMode && parentTNode && assertTNodeForLView(parentTNode, lViewCursor[DECLARATION_VIEW]); // Every iteration of the loop requires that we go to the declared parent.

    declarationViewOffset++;
    lViewCursor = lViewCursor[DECLARATION_VIEW];

    if (parentTNode.injectorIndex !== -1) {
      // We found a NodeInjector which points to something.
      return parentTNode.injectorIndex | declarationViewOffset << 16
      /* ViewOffsetShift */
      ;
    }
  }

  return NO_PARENT_INJECTOR;
}
/**
 * Makes a type or an injection token public to the DI system by adding it to an
 * injector's bloom filter.
 *
 * @param di The node injector in which a directive will be added
 * @param token The type or the injection token to be made public
 */


function diPublicInInjector(injectorIndex, tView, token) {
  bloomAdd(injectorIndex, tView, token);
}
/**
 * Inject static attribute value into directive constructor.
 *
 * This method is used with `factory` functions which are generated as part of
 * `defineDirective` or `defineComponent`. The method retrieves the static value
 * of an attribute. (Dynamic attributes are not supported since they are not resolved
 *  at the time of injection and can change over time.)
 *
 * # Example
 * Given:
 * ```
 * @Component(...)
 * class MyComponent {
 *   constructor(@Attribute('title') title: string) { ... }
 * }
 * ```
 * When instantiated with
 * ```
 * <my-component title="Hello"></my-component>
 * ```
 *
 * Then factory method generated is:
 * ```
 * MyComponent.ɵcmp = defineComponent({
 *   factory: () => new MyComponent(injectAttribute('title'))
 *   ...
 * })
 * ```
 *
 * @publicApi
 */


function injectAttributeImpl(tNode, attrNameToInject) {
  ngDevMode && assertNodeOfPossibleTypes(tNode, [0
  /* Container */
  , 2
  /* Element */
  , 3
  /* ElementContainer */
  ]);
  ngDevMode && assertDefined(tNode, 'expecting tNode');

  if (attrNameToInject === 'class') {
    return tNode.classes;
  }

  if (attrNameToInject === 'style') {
    return tNode.styles;
  }

  var attrs = tNode.attrs;

  if (attrs) {
    var attrsLength = attrs.length;
    var i = 0;

    while (i < attrsLength) {
      var value = attrs[i]; // If we hit a `Bindings` or `Template` marker then we are done.

      if (isNameOnlyAttributeMarker(value)) break; // Skip namespaced attributes

      if (value === 0
      /* NamespaceURI */
      ) {
          // we skip the next two values
          // as namespaced attributes looks like
          // [..., AttributeMarker.NamespaceURI, 'http://someuri.com/test', 'test:exist',
          // 'existValue', ...]
          i = i + 2;
        } else if (typeof value === 'number') {
        // Skip to the first value of the marked attribute.
        i++;

        while (i < attrsLength && typeof attrs[i] === 'string') {
          i++;
        }
      } else if (value === attrNameToInject) {
        return attrs[i + 1];
      } else {
        i = i + 2;
      }
    }
  }

  return null;
}
/**
 * Returns the value associated to the given token from the NodeInjectors => ModuleInjector.
 *
 * Look for the injector providing the token by walking up the node injector tree and then
 * the module injector tree.
 *
 * This function patches `token` with `__NG_ELEMENT_ID__` which contains the id for the bloom
 * filter. Negative values are reserved for special objects.
 *   - `-1` is reserved for injecting `Injector` (implemented by `NodeInjector`)
 *
 * @param tNode The Node where the search for the injector should start
 * @param lView The `LView` that contains the `tNode`
 * @param token The token to look for
 * @param flags Injection flags
 * @param notFoundValue The value to return when the injection flags is `InjectFlags.Optional`
 * @returns the value from the injector, `null` when not found, or `notFoundValue` if provided
 */


function getOrCreateInjectable(tNode, lView, token) {
  var flags = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : InjectFlags.Default;
  var notFoundValue = arguments.length > 4 ? arguments[4] : undefined;

  if (tNode !== null) {
    var bloomHash = bloomHashBitOrFactory(token); // If the ID stored here is a function, this is a special object like ElementRef or TemplateRef
    // so just call the factory function to create it.

    if (typeof bloomHash === 'function') {
      enterDI(lView, tNode);

      try {
        var value = bloomHash();

        if (value == null && !(flags & InjectFlags.Optional)) {
          throw new Error("No provider for ".concat(stringifyForError(token), "!"));
        } else {
          return value;
        }
      } finally {
        leaveDI();
      }
    } else if (typeof bloomHash == 'number') {
      if (bloomHash === -1) {
        // `-1` is a special value used to identify `Injector` types.
        return new NodeInjector(tNode, lView);
      } // If the token has a bloom hash, then it is a token which could be in NodeInjector.
      // A reference to the previous injector TView that was found while climbing the element
      // injector tree. This is used to know if viewProviders can be accessed on the current
      // injector.


      var previousTView = null;
      var injectorIndex = getInjectorIndex(tNode, lView);
      var parentLocation = NO_PARENT_INJECTOR;
      var hostTElementNode = flags & InjectFlags.Host ? lView[DECLARATION_COMPONENT_VIEW][T_HOST] : null; // If we should skip this injector, or if there is no injector on this node, start by
      // searching the parent injector.

      if (injectorIndex === -1 || flags & InjectFlags.SkipSelf) {
        parentLocation = injectorIndex === -1 ? getParentInjectorLocation(tNode, lView) : lView[injectorIndex + 8
        /* PARENT */
        ];

        if (parentLocation === NO_PARENT_INJECTOR || !shouldSearchParent(flags, false)) {
          injectorIndex = -1;
        } else {
          previousTView = lView[TVIEW];
          injectorIndex = getParentInjectorIndex(parentLocation);
          lView = getParentInjectorView(parentLocation, lView);
        }
      } // Traverse up the injector tree until we find a potential match or until we know there
      // *isn't* a match.


      while (injectorIndex !== -1) {
        ngDevMode && assertNodeInjector(lView, injectorIndex); // Check the current injector. If it matches, see if it contains token.

        var tView = lView[TVIEW];
        ngDevMode && assertTNodeForLView(tView.data[injectorIndex + 8
        /* TNODE */
        ], lView);

        if (bloomHasToken(bloomHash, injectorIndex, tView.data)) {
          // At this point, we have an injector which *may* contain the token, so we step through
          // the providers and directives associated with the injector's corresponding node to get
          // the instance.
          var instance = searchTokensOnInjector(injectorIndex, lView, token, previousTView, flags, hostTElementNode);

          if (instance !== NOT_FOUND) {
            return instance;
          }
        }

        parentLocation = lView[injectorIndex + 8
        /* PARENT */
        ];

        if (parentLocation !== NO_PARENT_INJECTOR && shouldSearchParent(flags, lView[TVIEW].data[injectorIndex + 8
        /* TNODE */
        ] === hostTElementNode) && bloomHasToken(bloomHash, injectorIndex, lView)) {
          // The def wasn't found anywhere on this node, so it was a false positive.
          // Traverse up the tree and continue searching.
          previousTView = tView;
          injectorIndex = getParentInjectorIndex(parentLocation);
          lView = getParentInjectorView(parentLocation, lView);
        } else {
          // If we should not search parent OR If the ancestor bloom filter value does not have the
          // bit corresponding to the directive we can give up on traversing up to find the specific
          // injector.
          injectorIndex = -1;
        }
      }
    }
  }

  if (flags & InjectFlags.Optional && notFoundValue === undefined) {
    // This must be set or the NullInjector will throw for optional deps
    notFoundValue = null;
  }

  if ((flags & (InjectFlags.Self | InjectFlags.Host)) === 0) {
    var moduleInjector = lView[INJECTOR$1]; // switch to `injectInjectorOnly` implementation for module injector, since module injector
    // should not have access to Component/Directive DI scope (that may happen through
    // `directiveInject` implementation)

    var previousInjectImplementation = setInjectImplementation(undefined);

    try {
      if (moduleInjector) {
        return moduleInjector.get(token, notFoundValue, flags & InjectFlags.Optional);
      } else {
        return injectRootLimpMode(token, notFoundValue, flags & InjectFlags.Optional);
      }
    } finally {
      setInjectImplementation(previousInjectImplementation);
    }
  }

  if (flags & InjectFlags.Optional) {
    return notFoundValue;
  } else {
    throw new Error("NodeInjector: NOT_FOUND [".concat(stringifyForError(token), "]"));
  }
}

var NOT_FOUND = {};

function searchTokensOnInjector(injectorIndex, lView, token, previousTView, flags, hostTElementNode) {
  var currentTView = lView[TVIEW];
  var tNode = currentTView.data[injectorIndex + 8
  /* TNODE */
  ]; // First, we need to determine if view providers can be accessed by the starting element.
  // There are two possibilities

  var canAccessViewProviders = previousTView == null ? // 1) This is the first invocation `previousTView == null` which means that we are at the
  // `TNode` of where injector is starting to look. In such a case the only time we are allowed
  // to look into the ViewProviders is if:
  // - we are on a component
  // - AND the injector set `includeViewProviders` to true (implying that the token can see
  // ViewProviders because it is the Component or a Service which itself was declared in
  // ViewProviders)
  isComponentHost(tNode) && includeViewProviders : // 2) `previousTView != null` which means that we are now walking across the parent nodes.
  // In such a case we are only allowed to look into the ViewProviders if:
  // - We just crossed from child View to Parent View `previousTView != currentTView`
  // - AND the parent TNode is an Element.
  // This means that we just came from the Component's View and therefore are allowed to see
  // into the ViewProviders.
  previousTView != currentTView && tNode.type === 2
  /* Element */
  ; // This special case happens when there is a @host on the inject and when we are searching
  // on the host element node.

  var isHostSpecialCase = flags & InjectFlags.Host && hostTElementNode === tNode;
  var injectableIdx = locateDirectiveOrProvider(tNode, currentTView, token, canAccessViewProviders, isHostSpecialCase);

  if (injectableIdx !== null) {
    return getNodeInjectable(lView, currentTView, injectableIdx, tNode);
  } else {
    return NOT_FOUND;
  }
}
/**
 * Searches for the given token among the node's directives and providers.
 *
 * @param tNode TNode on which directives are present.
 * @param tView The tView we are currently processing
 * @param token Provider token or type of a directive to look for.
 * @param canAccessViewProviders Whether view providers should be considered.
 * @param isHostSpecialCase Whether the host special case applies.
 * @returns Index of a found directive or provider, or null when none found.
 */


function locateDirectiveOrProvider(tNode, tView, token, canAccessViewProviders, isHostSpecialCase) {
  var nodeProviderIndexes = tNode.providerIndexes;
  var tInjectables = tView.data;
  var injectablesStart = nodeProviderIndexes & 1048575
  /* ProvidersStartIndexMask */
  ;
  var directivesStart = tNode.directiveStart;
  var directiveEnd = tNode.directiveEnd;
  var cptViewProvidersCount = nodeProviderIndexes >> 20
  /* CptViewProvidersCountShift */
  ;
  var startingIndex = canAccessViewProviders ? injectablesStart : injectablesStart + cptViewProvidersCount; // When the host special case applies, only the viewProviders and the component are visible

  var endIndex = isHostSpecialCase ? injectablesStart + cptViewProvidersCount : directiveEnd;

  for (var i = startingIndex; i < endIndex; i++) {
    var providerTokenOrDef = tInjectables[i];

    if (i < directivesStart && token === providerTokenOrDef || i >= directivesStart && providerTokenOrDef.type === token) {
      return i;
    }
  }

  if (isHostSpecialCase) {
    var dirDef = tInjectables[directivesStart];

    if (dirDef && isComponentDef(dirDef) && dirDef.type === token) {
      return directivesStart;
    }
  }

  return null;
}
/**
 * Retrieve or instantiate the injectable from the `LView` at particular `index`.
 *
 * This function checks to see if the value has already been instantiated and if so returns the
 * cached `injectable`. Otherwise if it detects that the value is still a factory it
 * instantiates the `injectable` and caches the value.
 */


function getNodeInjectable(lView, tView, index, tNode) {
  var value = lView[index];
  var tData = tView.data;

  if (isFactory(value)) {
    var factory = value;

    if (factory.resolving) {
      throw new Error("Circular dep for ".concat(stringifyForError(tData[index])));
    }

    var previousIncludeViewProviders = setIncludeViewProviders(factory.canSeeViewProviders);
    factory.resolving = true;
    var previousInjectImplementation = factory.injectImpl ? setInjectImplementation(factory.injectImpl) : null;
    enterDI(lView, tNode);

    try {
      value = lView[index] = factory.factory(undefined, tData, lView, tNode); // This code path is hit for both directives and providers.
      // For perf reasons, we want to avoid searching for hooks on providers.
      // It does no harm to try (the hooks just won't exist), but the extra
      // checks are unnecessary and this is a hot path. So we check to see
      // if the index of the dependency is in the directive range for this
      // tNode. If it's not, we know it's a provider and skip hook registration.

      if (tView.firstCreatePass && index >= tNode.directiveStart) {
        ngDevMode && assertDirectiveDef(tData[index]);
        registerPreOrderHooks(index, tData[index], tView);
      }
    } finally {
      previousInjectImplementation !== null && setInjectImplementation(previousInjectImplementation);
      setIncludeViewProviders(previousIncludeViewProviders);
      factory.resolving = false;
      leaveDI();
    }
  }

  return value;
}
/**
 * Returns the bit in an injector's bloom filter that should be used to determine whether or not
 * the directive might be provided by the injector.
 *
 * When a directive is public, it is added to the bloom filter and given a unique ID that can be
 * retrieved on the Type. When the directive isn't public or the token is not a directive `null`
 * is returned as the node injector can not possibly provide that token.
 *
 * @param token the injection token
 * @returns the matching bit to check in the bloom filter or `null` if the token is not known.
 *   When the returned value is negative then it represents special values such as `Injector`.
 */


function bloomHashBitOrFactory(token) {
  ngDevMode && assertDefined(token, 'token must be defined');

  if (typeof token === 'string') {
    return token.charCodeAt(0) || 0;
  }

  var tokenId = // First check with `hasOwnProperty` so we don't get an inherited ID.
  token.hasOwnProperty(NG_ELEMENT_ID) ? token[NG_ELEMENT_ID] : undefined; // Negative token IDs are used for special objects such as `Injector`

  return typeof tokenId === 'number' && tokenId > 0 ? tokenId & BLOOM_MASK : tokenId;
}

function bloomHasToken(bloomHash, injectorIndex, injectorView) {
  // Create a mask that targets the specific bit associated with the directive we're looking for.
  // JS bit operations are 32 bits, so this will be a number between 2^0 and 2^31, corresponding
  // to bit positions 0 - 31 in a 32 bit integer.
  var mask = 1 << bloomHash;
  var b7 = bloomHash & 0x80;
  var b6 = bloomHash & 0x40;
  var b5 = bloomHash & 0x20; // Our bloom filter size is 256 bits, which is eight 32-bit bloom filter buckets:
  // bf0 = [0 - 31], bf1 = [32 - 63], bf2 = [64 - 95], bf3 = [96 - 127], etc.
  // Get the bloom filter value from the appropriate bucket based on the directive's bloomBit.

  var value;

  if (b7) {
    value = b6 ? b5 ? injectorView[injectorIndex + 7] : injectorView[injectorIndex + 6] : b5 ? injectorView[injectorIndex + 5] : injectorView[injectorIndex + 4];
  } else {
    value = b6 ? b5 ? injectorView[injectorIndex + 3] : injectorView[injectorIndex + 2] : b5 ? injectorView[injectorIndex + 1] : injectorView[injectorIndex];
  } // If the bloom filter value has the bit corresponding to the directive's bloomBit flipped on,
  // this injector is a potential match.


  return !!(value & mask);
}
/** Returns true if flags prevent parent injector from being searched for tokens */


function shouldSearchParent(flags, isFirstHostTNode) {
  return !(flags & InjectFlags.Self) && !(flags & InjectFlags.Host && isFirstHostTNode);
}

var NodeInjector = /*#__PURE__*/function () {
  function NodeInjector(_tNode, _lView) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NodeInjector);

    this._tNode = _tNode;
    this._lView = _lView;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NodeInjector, [{
    key: "get",
    value: function get(token, notFoundValue) {
      return getOrCreateInjectable(this._tNode, this._lView, token, undefined, notFoundValue);
    }
  }]);

  return NodeInjector;
}();
/**
 * @codeGenApi
 */


function ɵɵgetFactoryOf(type) {
  var typeAny = type;

  if (isForwardRef(type)) {
    return function () {
      var factory = ɵɵgetFactoryOf(resolveForwardRef(typeAny));
      return factory ? factory() : null;
    };
  }

  var factory = getFactoryDef(typeAny);

  if (factory === null) {
    var injectorDef = getInjectorDef(typeAny);
    factory = injectorDef && injectorDef.factory;
  }

  return factory || null;
}
/**
 * @codeGenApi
 */


function ɵɵgetInheritedFactory(type) {
  return noSideEffects(function () {
    var ownConstructor = type.prototype.constructor;
    var ownFactory = ownConstructor[NG_FACTORY_DEF] || ɵɵgetFactoryOf(ownConstructor);
    var objectPrototype = Object.prototype;
    var parent = Object.getPrototypeOf(type.prototype).constructor; // Go up the prototype until we hit `Object`.

    while (parent && parent !== objectPrototype) {
      var factory = parent[NG_FACTORY_DEF] || ɵɵgetFactoryOf(parent); // If we hit something that has a factory and the factory isn't the same as the type,
      // we've found the inherited factory. Note the check that the factory isn't the type's
      // own factory is redundant in most cases, but if the user has custom decorators on the
      // class, this lookup will start one level down in the prototype chain, causing us to
      // find the own factory first and potentially triggering an infinite loop downstream.

      if (factory && factory !== ownFactory) {
        return factory;
      }

      parent = Object.getPrototypeOf(parent);
    } // There is no factory defined. Either this was improper usage of inheritance
    // (no Angular decorator on the superclass) or there is no constructor at all
    // in the inheritance chain. Since the two cases cannot be distinguished, the
    // latter has to be assumed.


    return function (t) {
      return new t();
    };
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ERROR_TYPE = 'ngType';
var ERROR_DEBUG_CONTEXT = 'ngDebugContext';
var ERROR_ORIGINAL_ERROR = 'ngOriginalError';
var ERROR_LOGGER = 'ngErrorLogger';

function wrappedError(message, originalError) {
  var msg = "".concat(message, " caused by: ").concat(originalError instanceof Error ? originalError.message : originalError);
  var error = Error(msg);
  error[ERROR_ORIGINAL_ERROR] = originalError;
  return error;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function getType(error) {
  return error[ERROR_TYPE];
}

function getDebugContext(error) {
  return error[ERROR_DEBUG_CONTEXT];
}

function getOriginalError(error) {
  return error[ERROR_ORIGINAL_ERROR];
}

function getErrorLogger(error) {
  return error[ERROR_LOGGER] || defaultErrorLogger;
}

function defaultErrorLogger(console) {
  for (var _len4 = arguments.length, values = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
    values[_key4 - 1] = arguments[_key4];
  }

  console.error.apply(console, values);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Provides a hook for centralized exception handling.
 *
 * The default implementation of `ErrorHandler` prints error messages to the `console`. To
 * intercept error handling, write a custom exception handler that replaces this default as
 * appropriate for your app.
 *
 * @usageNotes
 * ### Example
 *
 * ```
 * class MyErrorHandler implements ErrorHandler {
 *   handleError(error) {
 *     // do something with the exception
 *   }
 * }
 *
 * @NgModule({
 *   providers: [{provide: ErrorHandler, useClass: MyErrorHandler}]
 * })
 * class MyModule {}
 * ```
 *
 * @publicApi
 */


var ErrorHandler = /*#__PURE__*/function () {
  function ErrorHandler() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ErrorHandler);

    /**
     * @internal
     */
    this._console = console;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ErrorHandler, [{
    key: "handleError",
    value: function handleError(error) {
      var originalError = this._findOriginalError(error);

      var context = this._findContext(error); // Note: Browser consoles show the place from where console.error was called.
      // We can use this to give users additional information about the error.


      var errorLogger = getErrorLogger(error);
      errorLogger(this._console, "ERROR", error);

      if (originalError) {
        errorLogger(this._console, "ORIGINAL ERROR", originalError);
      }

      if (context) {
        errorLogger(this._console, 'ERROR CONTEXT', context);
      }
    }
    /** @internal */

  }, {
    key: "_findContext",
    value: function _findContext(error) {
      if (error) {
        return getDebugContext(error) ? getDebugContext(error) : this._findContext(getOriginalError(error));
      }

      return null;
    }
    /** @internal */

  }, {
    key: "_findOriginalError",
    value: function _findOriginalError(error) {
      var e = getOriginalError(error);

      while (e && getOriginalError(e)) {
        e = getOriginalError(e);
      }

      return e;
    }
  }]);

  return ErrorHandler;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Defines a schema that allows an NgModule to contain the following:
 * - Non-Angular elements named with dash case (`-`).
 * - Element properties named with dash case (`-`).
 * Dash case is the naming convention for custom elements.
 *
 * @publicApi
 */


var CUSTOM_ELEMENTS_SCHEMA = {
  name: 'custom-elements'
};
/**
 * Defines a schema that allows any property on any element.
 *
 * @publicApi
 */

var NO_ERRORS_SCHEMA = {
  name: 'no-errors-schema'
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var SafeValueImpl = /*#__PURE__*/function () {
  function SafeValueImpl(changingThisBreaksApplicationSecurity) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SafeValueImpl);

    this.changingThisBreaksApplicationSecurity = changingThisBreaksApplicationSecurity;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SafeValueImpl, [{
    key: "toString",
    value: function toString() {
      return "SafeValue must use [property]=binding: ".concat(this.changingThisBreaksApplicationSecurity) + " (see http://g.co/ng/security#xss)";
    }
  }]);

  return SafeValueImpl;
}();

var SafeHtmlImpl = /*#__PURE__*/function (_SafeValueImpl) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(SafeHtmlImpl, _SafeValueImpl);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(SafeHtmlImpl);

  function SafeHtmlImpl() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SafeHtmlImpl);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SafeHtmlImpl, [{
    key: "getTypeName",
    value: function getTypeName() {
      return "HTML"
      /* Html */
      ;
    }
  }]);

  return SafeHtmlImpl;
}(SafeValueImpl);

var SafeStyleImpl = /*#__PURE__*/function (_SafeValueImpl2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(SafeStyleImpl, _SafeValueImpl2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(SafeStyleImpl);

  function SafeStyleImpl() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SafeStyleImpl);

    return _super2.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SafeStyleImpl, [{
    key: "getTypeName",
    value: function getTypeName() {
      return "Style"
      /* Style */
      ;
    }
  }]);

  return SafeStyleImpl;
}(SafeValueImpl);

var SafeScriptImpl = /*#__PURE__*/function (_SafeValueImpl3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(SafeScriptImpl, _SafeValueImpl3);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(SafeScriptImpl);

  function SafeScriptImpl() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SafeScriptImpl);

    return _super3.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SafeScriptImpl, [{
    key: "getTypeName",
    value: function getTypeName() {
      return "Script"
      /* Script */
      ;
    }
  }]);

  return SafeScriptImpl;
}(SafeValueImpl);

var SafeUrlImpl = /*#__PURE__*/function (_SafeValueImpl4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(SafeUrlImpl, _SafeValueImpl4);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(SafeUrlImpl);

  function SafeUrlImpl() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SafeUrlImpl);

    return _super4.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SafeUrlImpl, [{
    key: "getTypeName",
    value: function getTypeName() {
      return "URL"
      /* Url */
      ;
    }
  }]);

  return SafeUrlImpl;
}(SafeValueImpl);

var SafeResourceUrlImpl = /*#__PURE__*/function (_SafeValueImpl5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(SafeResourceUrlImpl, _SafeValueImpl5);

  var _super5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(SafeResourceUrlImpl);

  function SafeResourceUrlImpl() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SafeResourceUrlImpl);

    return _super5.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SafeResourceUrlImpl, [{
    key: "getTypeName",
    value: function getTypeName() {
      return "ResourceURL"
      /* ResourceUrl */
      ;
    }
  }]);

  return SafeResourceUrlImpl;
}(SafeValueImpl);

function unwrapSafeValue(value) {
  return value instanceof SafeValueImpl ? value.changingThisBreaksApplicationSecurity : value;
}

function allowSanitizationBypassAndThrow(value, type) {
  var actualType = getSanitizationBypassType(value);

  if (actualType != null && actualType !== type) {
    // Allow ResourceURLs in URL contexts, they are strictly more trusted.
    if (actualType === "ResourceURL"
    /* ResourceUrl */
    && type === "URL"
    /* Url */
    ) return true;
    throw new Error("Required a safe ".concat(type, ", got a ").concat(actualType, " (see http://g.co/ng/security#xss)"));
  }

  return actualType === type;
}

function getSanitizationBypassType(value) {
  return value instanceof SafeValueImpl && value.getTypeName() || null;
}
/**
 * Mark `html` string as trusted.
 *
 * This function wraps the trusted string in `String` and brands it in a way which makes it
 * recognizable to {@link htmlSanitizer} to be trusted implicitly.
 *
 * @param trustedHtml `html` string which needs to be implicitly trusted.
 * @returns a `html` which has been branded to be implicitly trusted.
 */


function bypassSanitizationTrustHtml(trustedHtml) {
  return new SafeHtmlImpl(trustedHtml);
}
/**
 * Mark `style` string as trusted.
 *
 * This function wraps the trusted string in `String` and brands it in a way which makes it
 * recognizable to {@link styleSanitizer} to be trusted implicitly.
 *
 * @param trustedStyle `style` string which needs to be implicitly trusted.
 * @returns a `style` hich has been branded to be implicitly trusted.
 */


function bypassSanitizationTrustStyle(trustedStyle) {
  return new SafeStyleImpl(trustedStyle);
}
/**
 * Mark `script` string as trusted.
 *
 * This function wraps the trusted string in `String` and brands it in a way which makes it
 * recognizable to {@link scriptSanitizer} to be trusted implicitly.
 *
 * @param trustedScript `script` string which needs to be implicitly trusted.
 * @returns a `script` which has been branded to be implicitly trusted.
 */


function bypassSanitizationTrustScript(trustedScript) {
  return new SafeScriptImpl(trustedScript);
}
/**
 * Mark `url` string as trusted.
 *
 * This function wraps the trusted string in `String` and brands it in a way which makes it
 * recognizable to {@link urlSanitizer} to be trusted implicitly.
 *
 * @param trustedUrl `url` string which needs to be implicitly trusted.
 * @returns a `url`  which has been branded to be implicitly trusted.
 */


function bypassSanitizationTrustUrl(trustedUrl) {
  return new SafeUrlImpl(trustedUrl);
}
/**
 * Mark `url` string as trusted.
 *
 * This function wraps the trusted string in `String` and brands it in a way which makes it
 * recognizable to {@link resourceUrlSanitizer} to be trusted implicitly.
 *
 * @param trustedResourceUrl `url` string which needs to be implicitly trusted.
 * @returns a `url` which has been branded to be implicitly trusted.
 */


function bypassSanitizationTrustResourceUrl(trustedResourceUrl) {
  return new SafeResourceUrlImpl(trustedResourceUrl);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This file is used to control if the default rendering pipeline should be `ViewEngine` or `Ivy`.
 *
 * For more information on how to run and debug tests with either Ivy or View Engine (legacy),
 * please see [BAZEL.md](./docs/BAZEL.md).
 */


var _devMode = true;
var _runModeLocked = false;
/**
 * Returns whether Angular is in development mode. After called once,
 * the value is locked and won't change any more.
 *
 * By default, this is true, unless a user calls `enableProdMode` before calling this.
 *
 * @publicApi
 */

function isDevMode() {
  _runModeLocked = true;
  return _devMode;
}
/**
 * Disable Angular's development mode, which turns off assertions and other
 * checks within the framework.
 *
 * One important assertion this disables verifies that a change detection pass
 * does not result in additional changes to any bindings (also known as
 * unidirectional data flow).
 *
 * @publicApi
 */


function enableProdMode() {
  if (_runModeLocked) {
    throw new Error('Cannot enable prod mode after platform setup.');
  }

  _devMode = false;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This helper is used to get hold of an inert tree of DOM elements containing dirty HTML
 * that needs sanitizing.
 * Depending upon browser support we use one of two strategies for doing this.
 * Default: DOMParser strategy
 * Fallback: InertDocument strategy
 */


function getInertBodyHelper(defaultDoc) {
  return isDOMParserAvailable() ? new DOMParserHelper() : new InertDocumentHelper(defaultDoc);
}
/**
 * Uses DOMParser to create and fill an inert body element.
 * This is the default strategy used in browsers that support it.
 */


var DOMParserHelper = /*#__PURE__*/function () {
  function DOMParserHelper() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DOMParserHelper);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DOMParserHelper, [{
    key: "getInertBodyElement",
    value: function getInertBodyElement(html) {
      // We add these extra elements to ensure that the rest of the content is parsed as expected
      // e.g. leading whitespace is maintained and tags like `<meta>` do not get hoisted to the
      // `<head>` tag. Note that the `<body>` tag is closed implicitly to prevent unclosed tags
      // in `html` from consuming the otherwise explicit `</body>` tag.
      html = '<body><remove></remove>' + html;

      try {
        var body = new window.DOMParser().parseFromString(html, 'text/html').body;
        body.removeChild(body.firstChild);
        return body;
      } catch (_a) {
        return null;
      }
    }
  }]);

  return DOMParserHelper;
}();
/**
 * Use an HTML5 `template` element, if supported, or an inert body element created via
 * `createHtmlDocument` to create and fill an inert DOM element.
 * This is the fallback strategy if the browser does not support DOMParser.
 */


var InertDocumentHelper = /*#__PURE__*/function () {
  function InertDocumentHelper(defaultDoc) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, InertDocumentHelper);

    this.defaultDoc = defaultDoc;
    this.inertDocument = this.defaultDoc.implementation.createHTMLDocument('sanitization-inert');

    if (this.inertDocument.body == null) {
      // usually there should be only one body element in the document, but IE doesn't have any, so
      // we need to create one.
      var inertHtml = this.inertDocument.createElement('html');
      this.inertDocument.appendChild(inertHtml);
      var inertBodyElement = this.inertDocument.createElement('body');
      inertHtml.appendChild(inertBodyElement);
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(InertDocumentHelper, [{
    key: "getInertBodyElement",
    value: function getInertBodyElement(html) {
      // Prefer using <template> element if supported.
      var templateEl = this.inertDocument.createElement('template');

      if ('content' in templateEl) {
        templateEl.innerHTML = html;
        return templateEl;
      } // Note that previously we used to do something like `this.inertDocument.body.innerHTML = html`
      // and we returned the inert `body` node. This was changed, because IE seems to treat setting
      // `innerHTML` on an inserted element differently, compared to one that hasn't been inserted
      // yet. In particular, IE appears to split some of the text into multiple text nodes rather
      // than keeping them in a single one which ends up messing with Ivy's i18n parsing further
      // down the line. This has been worked around by creating a new inert `body` and using it as
      // the root node in which we insert the HTML.


      var inertBody = this.inertDocument.createElement('body');
      inertBody.innerHTML = html; // Support: IE 9-11 only
      // strip custom-namespaced attributes on IE<=11

      if (this.defaultDoc.documentMode) {
        this.stripCustomNsAttrs(inertBody);
      }

      return inertBody;
    }
    /**
     * When IE9-11 comes across an unknown namespaced attribute e.g. 'xlink:foo' it adds 'xmlns:ns1'
     * attribute to declare ns1 namespace and prefixes the attribute with 'ns1' (e.g.
     * 'ns1:xlink:foo').
     *
     * This is undesirable since we don't want to allow any of these custom attributes. This method
     * strips them all.
     */

  }, {
    key: "stripCustomNsAttrs",
    value: function stripCustomNsAttrs(el) {
      var elAttrs = el.attributes; // loop backwards so that we can support removals.

      for (var i = elAttrs.length - 1; 0 < i; i--) {
        var attrib = elAttrs.item(i);
        var attrName = attrib.name;

        if (attrName === 'xmlns:ns1' || attrName.indexOf('ns1:') === 0) {
          el.removeAttribute(attrName);
        }
      }

      var childNode = el.firstChild;

      while (childNode) {
        if (childNode.nodeType === Node.ELEMENT_NODE) this.stripCustomNsAttrs(childNode);
        childNode = childNode.nextSibling;
      }
    }
  }]);

  return InertDocumentHelper;
}();
/**
 * We need to determine whether the DOMParser exists in the global context and
 * supports parsing HTML; HTML parsing support is not as wide as other formats, see
 * https://developer.mozilla.org/en-US/docs/Web/API/DOMParser#Browser_compatibility.
 *
 * @suppress {uselessCode}
 */


function isDOMParserAvailable() {
  try {
    return !!new window.DOMParser().parseFromString('', 'text/html');
  } catch (_a) {
    return false;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A pattern that recognizes a commonly useful subset of URLs that are safe.
 *
 * This regular expression matches a subset of URLs that will not cause script
 * execution if used in URL context within a HTML document. Specifically, this
 * regular expression matches if (comment from here on and regex copied from
 * Soy's EscapingConventions):
 * (1) Either an allowed protocol (http, https, mailto or ftp).
 * (2) or no protocol.  A protocol must be followed by a colon. The below
 *     allows that by allowing colons only after one of the characters [/?#].
 *     A colon after a hash (#) must be in the fragment.
 *     Otherwise, a colon after a (?) must be in a query.
 *     Otherwise, a colon after a single solidus (/) must be in a path.
 *     Otherwise, a colon after a double solidus (//) must be in the authority
 *     (before port).
 *
 * The pattern disallows &, used in HTML entity declarations before
 * one of the characters in [/?#]. This disallows HTML entities used in the
 * protocol name, which should never happen, e.g. "h&#116;tp" for "http".
 * It also disallows HTML entities in the first path part of a relative path,
 * e.g. "foo&lt;bar/baz".  Our existing escaping functions should not produce
 * that. More importantly, it disallows masking of a colon,
 * e.g. "javascript&#58;...".
 *
 * This regular expression was taken from the Closure sanitization library.
 */


var SAFE_URL_PATTERN = /^(?:(?:https?|mailto|ftp|tel|file|sms):|[^&:/?#]*(?:[/?#]|$))/gi;
/* A pattern that matches safe srcset values */

var SAFE_SRCSET_PATTERN = /^(?:(?:https?|file):|[^&:/?#]*(?:[/?#]|$))/gi;
/** A pattern that matches safe data URLs. Only matches image, video and audio types. */

var DATA_URL_PATTERN = /^data:(?:image\/(?:bmp|gif|jpeg|jpg|png|tiff|webp)|video\/(?:mpeg|mp4|ogg|webm)|audio\/(?:mp3|oga|ogg|opus));base64,[a-z0-9+\/]+=*$/i;

function _sanitizeUrl(url) {
  url = String(url);
  if (url.match(SAFE_URL_PATTERN) || url.match(DATA_URL_PATTERN)) return url;

  if (isDevMode()) {
    console.warn("WARNING: sanitizing unsafe URL value ".concat(url, " (see http://g.co/ng/security#xss)"));
  }

  return 'unsafe:' + url;
}

function sanitizeSrcset(srcset) {
  srcset = String(srcset);
  return srcset.split(',').map(function (srcset) {
    return _sanitizeUrl(srcset.trim());
  }).join(', ');
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function tagSet(tags) {
  var res = {};

  var _iterator = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__["default"])(tags.split(',')),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var t = _step.value;
      res[t] = true;
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  return res;
}

function merge() {
  var res = {};

  for (var _len5 = arguments.length, sets = new Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
    sets[_key5] = arguments[_key5];
  }

  for (var _i = 0, _sets = sets; _i < _sets.length; _i++) {
    var s = _sets[_i];

    for (var v in s) {
      if (s.hasOwnProperty(v)) res[v] = true;
    }
  }

  return res;
} // Good source of info about elements and attributes
// http://dev.w3.org/html5/spec/Overview.html#semantics
// http://simon.html5.org/html-elements
// Safe Void Elements - HTML5
// http://dev.w3.org/html5/spec/Overview.html#void-elements


var VOID_ELEMENTS = tagSet('area,br,col,hr,img,wbr'); // Elements that you can, intentionally, leave open (and which close themselves)
// http://dev.w3.org/html5/spec/Overview.html#optional-tags

var OPTIONAL_END_TAG_BLOCK_ELEMENTS = tagSet('colgroup,dd,dt,li,p,tbody,td,tfoot,th,thead,tr');
var OPTIONAL_END_TAG_INLINE_ELEMENTS = tagSet('rp,rt');
var OPTIONAL_END_TAG_ELEMENTS = merge(OPTIONAL_END_TAG_INLINE_ELEMENTS, OPTIONAL_END_TAG_BLOCK_ELEMENTS); // Safe Block Elements - HTML5

var BLOCK_ELEMENTS = merge(OPTIONAL_END_TAG_BLOCK_ELEMENTS, tagSet('address,article,' + 'aside,blockquote,caption,center,del,details,dialog,dir,div,dl,figure,figcaption,footer,h1,h2,h3,h4,h5,' + 'h6,header,hgroup,hr,ins,main,map,menu,nav,ol,pre,section,summary,table,ul')); // Inline Elements - HTML5

var INLINE_ELEMENTS = merge(OPTIONAL_END_TAG_INLINE_ELEMENTS, tagSet('a,abbr,acronym,audio,b,' + 'bdi,bdo,big,br,cite,code,del,dfn,em,font,i,img,ins,kbd,label,map,mark,picture,q,ruby,rp,rt,s,' + 'samp,small,source,span,strike,strong,sub,sup,time,track,tt,u,var,video'));
var VALID_ELEMENTS = merge(VOID_ELEMENTS, BLOCK_ELEMENTS, INLINE_ELEMENTS, OPTIONAL_END_TAG_ELEMENTS); // Attributes that have href and hence need to be sanitized

var URI_ATTRS = tagSet('background,cite,href,itemtype,longdesc,poster,src,xlink:href'); // Attributes that have special href set hence need to be sanitized

var SRCSET_ATTRS = tagSet('srcset');
var HTML_ATTRS = tagSet('abbr,accesskey,align,alt,autoplay,axis,bgcolor,border,cellpadding,cellspacing,class,clear,color,cols,colspan,' + 'compact,controls,coords,datetime,default,dir,download,face,headers,height,hidden,hreflang,hspace,' + 'ismap,itemscope,itemprop,kind,label,lang,language,loop,media,muted,nohref,nowrap,open,preload,rel,rev,role,rows,rowspan,rules,' + 'scope,scrolling,shape,size,sizes,span,srclang,start,summary,tabindex,target,title,translate,type,usemap,' + 'valign,value,vspace,width'); // Accessibility attributes as per WAI-ARIA 1.1 (W3C Working Draft 14 December 2018)

var ARIA_ATTRS = tagSet('aria-activedescendant,aria-atomic,aria-autocomplete,aria-busy,aria-checked,aria-colcount,aria-colindex,' + 'aria-colspan,aria-controls,aria-current,aria-describedby,aria-details,aria-disabled,aria-dropeffect,' + 'aria-errormessage,aria-expanded,aria-flowto,aria-grabbed,aria-haspopup,aria-hidden,aria-invalid,' + 'aria-keyshortcuts,aria-label,aria-labelledby,aria-level,aria-live,aria-modal,aria-multiline,' + 'aria-multiselectable,aria-orientation,aria-owns,aria-placeholder,aria-posinset,aria-pressed,aria-readonly,' + 'aria-relevant,aria-required,aria-roledescription,aria-rowcount,aria-rowindex,aria-rowspan,aria-selected,' + 'aria-setsize,aria-sort,aria-valuemax,aria-valuemin,aria-valuenow,aria-valuetext'); // NB: This currently consciously doesn't support SVG. SVG sanitization has had several security
// issues in the past, so it seems safer to leave it out if possible. If support for binding SVG via
// innerHTML is required, SVG attributes should be added here.
// NB: Sanitization does not allow <form> elements or other active elements (<button> etc). Those
// can be sanitized, but they increase security surface area without a legitimate use case, so they
// are left out here.

var VALID_ATTRS = merge(URI_ATTRS, SRCSET_ATTRS, HTML_ATTRS, ARIA_ATTRS); // Elements whose content should not be traversed/preserved, if the elements themselves are invalid.
//
// Typically, `<invalid>Some content</invalid>` would traverse (and in this case preserve)
// `Some content`, but strip `invalid-element` opening/closing tags. For some elements, though, we
// don't want to preserve the content, if the elements themselves are going to be removed.

var SKIP_TRAVERSING_CONTENT_IF_INVALID_ELEMENTS = tagSet('script,style,template');
/**
 * SanitizingHtmlSerializer serializes a DOM fragment, stripping out any unsafe elements and unsafe
 * attributes.
 */

var SanitizingHtmlSerializer = /*#__PURE__*/function () {
  function SanitizingHtmlSerializer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SanitizingHtmlSerializer);

    // Explicitly track if something was stripped, to avoid accidentally warning of sanitization just
    // because characters were re-encoded.
    this.sanitizedSomething = false;
    this.buf = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SanitizingHtmlSerializer, [{
    key: "sanitizeChildren",
    value: function sanitizeChildren(el) {
      // This cannot use a TreeWalker, as it has to run on Angular's various DOM adapters.
      // However this code never accesses properties off of `document` before deleting its contents
      // again, so it shouldn't be vulnerable to DOM clobbering.
      var current = el.firstChild;
      var traverseContent = true;

      while (current) {
        if (current.nodeType === Node.ELEMENT_NODE) {
          traverseContent = this.startElement(current);
        } else if (current.nodeType === Node.TEXT_NODE) {
          this.chars(current.nodeValue);
        } else {
          // Strip non-element, non-text nodes.
          this.sanitizedSomething = true;
        }

        if (traverseContent && current.firstChild) {
          current = current.firstChild;
          continue;
        }

        while (current) {
          // Leaving the element. Walk up and to the right, closing tags as we go.
          if (current.nodeType === Node.ELEMENT_NODE) {
            this.endElement(current);
          }

          var next = this.checkClobberedElement(current, current.nextSibling);

          if (next) {
            current = next;
            break;
          }

          current = this.checkClobberedElement(current, current.parentNode);
        }
      }

      return this.buf.join('');
    }
    /**
     * Sanitizes an opening element tag (if valid) and returns whether the element's contents should
     * be traversed. Element content must always be traversed (even if the element itself is not
     * valid/safe), unless the element is one of `SKIP_TRAVERSING_CONTENT_IF_INVALID_ELEMENTS`.
     *
     * @param element The element to sanitize.
     * @return True if the element's contents should be traversed.
     */

  }, {
    key: "startElement",
    value: function startElement(element) {
      var tagName = element.nodeName.toLowerCase();

      if (!VALID_ELEMENTS.hasOwnProperty(tagName)) {
        this.sanitizedSomething = true;
        return !SKIP_TRAVERSING_CONTENT_IF_INVALID_ELEMENTS.hasOwnProperty(tagName);
      }

      this.buf.push('<');
      this.buf.push(tagName);
      var elAttrs = element.attributes;

      for (var i = 0; i < elAttrs.length; i++) {
        var elAttr = elAttrs.item(i);
        var attrName = elAttr.name;
        var lower = attrName.toLowerCase();

        if (!VALID_ATTRS.hasOwnProperty(lower)) {
          this.sanitizedSomething = true;
          continue;
        }

        var value = elAttr.value; // TODO(martinprobst): Special case image URIs for data:image/...

        if (URI_ATTRS[lower]) value = _sanitizeUrl(value);
        if (SRCSET_ATTRS[lower]) value = sanitizeSrcset(value);
        this.buf.push(' ', attrName, '="', encodeEntities(value), '"');
      }

      this.buf.push('>');
      return true;
    }
  }, {
    key: "endElement",
    value: function endElement(current) {
      var tagName = current.nodeName.toLowerCase();

      if (VALID_ELEMENTS.hasOwnProperty(tagName) && !VOID_ELEMENTS.hasOwnProperty(tagName)) {
        this.buf.push('</');
        this.buf.push(tagName);
        this.buf.push('>');
      }
    }
  }, {
    key: "chars",
    value: function chars(_chars) {
      this.buf.push(encodeEntities(_chars));
    }
  }, {
    key: "checkClobberedElement",
    value: function checkClobberedElement(node, nextNode) {
      if (nextNode && (node.compareDocumentPosition(nextNode) & Node.DOCUMENT_POSITION_CONTAINED_BY) === Node.DOCUMENT_POSITION_CONTAINED_BY) {
        throw new Error("Failed to sanitize html because the element is clobbered: ".concat(node.outerHTML));
      }

      return nextNode;
    }
  }]);

  return SanitizingHtmlSerializer;
}(); // Regular Expressions for parsing tags and attributes


var SURROGATE_PAIR_REGEXP = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g; // ! to ~ is the ASCII range.

var NON_ALPHANUMERIC_REGEXP = /([^\#-~ |!])/g;
/**
 * Escapes all potentially dangerous characters, so that the
 * resulting string can be safely inserted into attribute or
 * element text.
 * @param value
 */

function encodeEntities(value) {
  return value.replace(/&/g, '&amp;').replace(SURROGATE_PAIR_REGEXP, function (match) {
    var hi = match.charCodeAt(0);
    var low = match.charCodeAt(1);
    return '&#' + ((hi - 0xD800) * 0x400 + (low - 0xDC00) + 0x10000) + ';';
  }).replace(NON_ALPHANUMERIC_REGEXP, function (match) {
    return '&#' + match.charCodeAt(0) + ';';
  }).replace(/</g, '&lt;').replace(/>/g, '&gt;');
}

var inertBodyHelper;
/**
 * Sanitizes the given unsafe, untrusted HTML fragment, and returns HTML text that is safe to add to
 * the DOM in a browser environment.
 */

function _sanitizeHtml(defaultDoc, unsafeHtmlInput) {
  var inertBodyElement = null;

  try {
    inertBodyHelper = inertBodyHelper || getInertBodyHelper(defaultDoc); // Make sure unsafeHtml is actually a string (TypeScript types are not enforced at runtime).

    var unsafeHtml = unsafeHtmlInput ? String(unsafeHtmlInput) : '';
    inertBodyElement = inertBodyHelper.getInertBodyElement(unsafeHtml); // mXSS protection. Repeatedly parse the document to make sure it stabilizes, so that a browser
    // trying to auto-correct incorrect HTML cannot cause formerly inert HTML to become dangerous.

    var mXSSAttempts = 5;
    var parsedHtml = unsafeHtml;

    do {
      if (mXSSAttempts === 0) {
        throw new Error('Failed to sanitize html because the input is unstable');
      }

      mXSSAttempts--;
      unsafeHtml = parsedHtml;
      parsedHtml = inertBodyElement.innerHTML;
      inertBodyElement = inertBodyHelper.getInertBodyElement(unsafeHtml);
    } while (unsafeHtml !== parsedHtml);

    var sanitizer = new SanitizingHtmlSerializer();
    var safeHtml = sanitizer.sanitizeChildren(getTemplateContent(inertBodyElement) || inertBodyElement);

    if (isDevMode() && sanitizer.sanitizedSomething) {
      console.warn('WARNING: sanitizing HTML stripped some content, see http://g.co/ng/security#xss');
    }

    return safeHtml;
  } finally {
    // In case anything goes wrong, clear out inertElement to reset the entire DOM structure.
    if (inertBodyElement) {
      var parent = getTemplateContent(inertBodyElement) || inertBodyElement;

      while (parent.firstChild) {
        parent.removeChild(parent.firstChild);
      }
    }
  }
}

function getTemplateContent(el) {
  return 'content' in el
  /** Microsoft/TypeScript#21517 */
  && isTemplateElement(el) ? el.content : null;
}

function isTemplateElement(el) {
  return el.nodeType === Node.ELEMENT_NODE && el.nodeName === 'TEMPLATE';
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A SecurityContext marks a location that has dangerous security implications, e.g. a DOM property
 * like `innerHTML` that could cause Cross Site Scripting (XSS) security bugs when improperly
 * handled.
 *
 * See DomSanitizer for more details on security in Angular applications.
 *
 * @publicApi
 */


var SecurityContext;

(function (SecurityContext) {
  SecurityContext[SecurityContext["NONE"] = 0] = "NONE";
  SecurityContext[SecurityContext["HTML"] = 1] = "HTML";
  SecurityContext[SecurityContext["STYLE"] = 2] = "STYLE";
  SecurityContext[SecurityContext["SCRIPT"] = 3] = "SCRIPT";
  SecurityContext[SecurityContext["URL"] = 4] = "URL";
  SecurityContext[SecurityContext["RESOURCE_URL"] = 5] = "RESOURCE_URL";
})(SecurityContext || (SecurityContext = {}));
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An `html` sanitizer which converts untrusted `html` **string** into trusted string by removing
 * dangerous content.
 *
 * This method parses the `html` and locates potentially dangerous content (such as urls and
 * javascript) and removes it.
 *
 * It is possible to mark a string as trusted by calling {@link bypassSanitizationTrustHtml}.
 *
 * @param unsafeHtml untrusted `html`, typically from the user.
 * @returns `html` string which is safe to display to user, because all of the dangerous javascript
 * and urls have been removed.
 *
 * @codeGenApi
 */


function ɵɵsanitizeHtml(unsafeHtml) {
  var sanitizer = getSanitizer();

  if (sanitizer) {
    return sanitizer.sanitize(SecurityContext.HTML, unsafeHtml) || '';
  }

  if (allowSanitizationBypassAndThrow(unsafeHtml, "HTML"
  /* Html */
  )) {
    return unwrapSafeValue(unsafeHtml);
  }

  return _sanitizeHtml(getDocument(), renderStringify(unsafeHtml));
}
/**
 * A `style` sanitizer which converts untrusted `style` **string** into trusted string by removing
 * dangerous content.
 *
 * It is possible to mark a string as trusted by calling {@link bypassSanitizationTrustStyle}.
 *
 * @param unsafeStyle untrusted `style`, typically from the user.
 * @returns `style` string which is safe to bind to the `style` properties.
 *
 * @codeGenApi
 */


function ɵɵsanitizeStyle(unsafeStyle) {
  var sanitizer = getSanitizer();

  if (sanitizer) {
    return sanitizer.sanitize(SecurityContext.STYLE, unsafeStyle) || '';
  }

  if (allowSanitizationBypassAndThrow(unsafeStyle, "Style"
  /* Style */
  )) {
    return unwrapSafeValue(unsafeStyle);
  }

  return renderStringify(unsafeStyle);
}
/**
 * A `url` sanitizer which converts untrusted `url` **string** into trusted string by removing
 * dangerous
 * content.
 *
 * This method parses the `url` and locates potentially dangerous content (such as javascript) and
 * removes it.
 *
 * It is possible to mark a string as trusted by calling {@link bypassSanitizationTrustUrl}.
 *
 * @param unsafeUrl untrusted `url`, typically from the user.
 * @returns `url` string which is safe to bind to the `src` properties such as `<img src>`, because
 * all of the dangerous javascript has been removed.
 *
 * @codeGenApi
 */


function ɵɵsanitizeUrl(unsafeUrl) {
  var sanitizer = getSanitizer();

  if (sanitizer) {
    return sanitizer.sanitize(SecurityContext.URL, unsafeUrl) || '';
  }

  if (allowSanitizationBypassAndThrow(unsafeUrl, "URL"
  /* Url */
  )) {
    return unwrapSafeValue(unsafeUrl);
  }

  return _sanitizeUrl(renderStringify(unsafeUrl));
}
/**
 * A `url` sanitizer which only lets trusted `url`s through.
 *
 * This passes only `url`s marked trusted by calling {@link bypassSanitizationTrustResourceUrl}.
 *
 * @param unsafeResourceUrl untrusted `url`, typically from the user.
 * @returns `url` string which is safe to bind to the `src` properties such as `<img src>`, because
 * only trusted `url`s have been allowed to pass.
 *
 * @codeGenApi
 */


function ɵɵsanitizeResourceUrl(unsafeResourceUrl) {
  var sanitizer = getSanitizer();

  if (sanitizer) {
    return sanitizer.sanitize(SecurityContext.RESOURCE_URL, unsafeResourceUrl) || '';
  }

  if (allowSanitizationBypassAndThrow(unsafeResourceUrl, "ResourceURL"
  /* ResourceUrl */
  )) {
    return unwrapSafeValue(unsafeResourceUrl);
  }

  throw new Error('unsafe value used in a resource URL context (see http://g.co/ng/security#xss)');
}
/**
 * A `script` sanitizer which only lets trusted javascript through.
 *
 * This passes only `script`s marked trusted by calling {@link
 * bypassSanitizationTrustScript}.
 *
 * @param unsafeScript untrusted `script`, typically from the user.
 * @returns `url` string which is safe to bind to the `<script>` element such as `<img src>`,
 * because only trusted `scripts` have been allowed to pass.
 *
 * @codeGenApi
 */


function ɵɵsanitizeScript(unsafeScript) {
  var sanitizer = getSanitizer();

  if (sanitizer) {
    return sanitizer.sanitize(SecurityContext.SCRIPT, unsafeScript) || '';
  }

  if (allowSanitizationBypassAndThrow(unsafeScript, "Script"
  /* Script */
  )) {
    return unwrapSafeValue(unsafeScript);
  }

  throw new Error('unsafe value used in a script context');
}
/**
 * Detects which sanitizer to use for URL property, based on tag name and prop name.
 *
 * The rules are based on the RESOURCE_URL context config from
 * `packages/compiler/src/schema/dom_security_schema.ts`.
 * If tag and prop names don't match Resource URL schema, use URL sanitizer.
 */


function getUrlSanitizer(tag, prop) {
  if (prop === 'src' && (tag === 'embed' || tag === 'frame' || tag === 'iframe' || tag === 'media' || tag === 'script') || prop === 'href' && (tag === 'base' || tag === 'link')) {
    return ɵɵsanitizeResourceUrl;
  }

  return ɵɵsanitizeUrl;
}
/**
 * Sanitizes URL, selecting sanitizer function based on tag and property names.
 *
 * This function is used in case we can't define security context at compile time, when only prop
 * name is available. This happens when we generate host bindings for Directives/Components. The
 * host element is unknown at compile time, so we defer calculation of specific sanitizer to
 * runtime.
 *
 * @param unsafeUrl untrusted `url`, typically from the user.
 * @param tag target element tag name.
 * @param prop name of the property that contains the value.
 * @returns `url` string which is safe to bind.
 *
 * @codeGenApi
 */


function ɵɵsanitizeUrlOrResourceUrl(unsafeUrl, tag, prop) {
  return getUrlSanitizer(tag, prop)(unsafeUrl);
}

function validateAgainstEventProperties(name) {
  if (name.toLowerCase().startsWith('on')) {
    var msg = "Binding to event property '".concat(name, "' is disallowed for security reasons, ") + "please use (".concat(name.slice(2), ")=...") + "\nIf '".concat(name, "' is a directive input, make sure the directive is imported by the") + " current module.";
    throw new Error(msg);
  }
}

function validateAgainstEventAttributes(name) {
  if (name.toLowerCase().startsWith('on')) {
    var msg = "Binding to event attribute '".concat(name, "' is disallowed for security reasons, ") + "please use (".concat(name.slice(2), ")=...");
    throw new Error(msg);
  }
}

function getSanitizer() {
  var lView = getLView();
  return lView && lView[SANITIZER];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * THIS FILE CONTAINS CODE WHICH SHOULD BE TREE SHAKEN AND NEVER CALLED FROM PRODUCTION CODE!!!
 */

/**
 * Creates an `Array` construction with a given name. This is useful when
 * looking for memory consumption to see what time of array it is.
 *
 *
 * @param name Name to give to the constructor
 * @returns A subclass of `Array` if possible. This can only be done in
 *          environments which support `class` construct.
 */


function createNamedArrayType(name) {
  // This should never be called in prod mode, so let's verify that is the case.
  if (ngDevMode) {
    try {
      // We need to do it this way so that TypeScript does not down-level the below code.
      var FunctionConstructor = createNamedArrayType.constructor;
      return new FunctionConstructor('Array', "return class ".concat(name, " extends Array{}"))(Array);
    } catch (e) {
      // If it does not work just give up and fall back to regular Array.
      return Array;
    }
  } else {
    throw new Error('Looks like we are in \'prod mode\', but we are creating a named Array type, which is wrong! Check your code');
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function normalizeDebugBindingName(name) {
  // Attribute names with `$` (eg `x-y$`) are valid per spec, but unsupported by some browsers
  name = camelCaseToDashCase(name.replace(/[$@]/g, '_'));
  return "ng-reflect-".concat(name);
}

var CAMEL_CASE_REGEXP = /([A-Z])/g;

function camelCaseToDashCase(input) {
  return input.replace(CAMEL_CASE_REGEXP, function () {
    for (var _len6 = arguments.length, m = new Array(_len6), _key6 = 0; _key6 < _len6; _key6++) {
      m[_key6] = arguments[_key6];
    }

    return '-' + m[1].toLowerCase();
  });
}

function normalizeDebugBindingValue(value) {
  try {
    // Limit the size of the value as otherwise the DOM just gets polluted.
    return value != null ? value.toString().slice(0, 30) : value;
  } catch (e) {
    return '[ERROR] Exception while trying to serialize the value';
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Returns the matching `LContext` data for a given DOM node, directive or component instance.
 *
 * This function will examine the provided DOM element, component, or directive instance\'s
 * monkey-patched property to derive the `LContext` data. Once called then the monkey-patched
 * value will be that of the newly created `LContext`.
 *
 * If the monkey-patched value is the `LView` instance then the context value for that
 * target will be created and the monkey-patch reference will be updated. Therefore when this
 * function is called it may mutate the provided element\'s, component\'s or any of the associated
 * directive\'s monkey-patch values.
 *
 * If the monkey-patch value is not detected then the code will walk up the DOM until an element
 * is found which contains a monkey-patch reference. When that occurs then the provided element
 * will be updated with a new context (which is then returned). If the monkey-patch value is not
 * detected for a component/directive instance then it will throw an error (all components and
 * directives should be automatically monkey-patched by ivy).
 *
 * @param target Component, Directive or DOM Node.
 */


function getLContext(target) {
  var mpValue = readPatchedData(target);

  if (mpValue) {
    // only when it's an array is it considered an LView instance
    // ... otherwise it's an already constructed LContext instance
    if (Array.isArray(mpValue)) {
      var lView = mpValue;
      var nodeIndex;
      var component = undefined;
      var directives = undefined;

      if (isComponentInstance(target)) {
        nodeIndex = findViaComponent(lView, target);

        if (nodeIndex == -1) {
          throw new Error('The provided component was not found in the application');
        }

        component = target;
      } else if (isDirectiveInstance(target)) {
        nodeIndex = findViaDirective(lView, target);

        if (nodeIndex == -1) {
          throw new Error('The provided directive was not found in the application');
        }

        directives = getDirectivesAtNodeIndex(nodeIndex, lView, false);
      } else {
        nodeIndex = findViaNativeElement(lView, target);

        if (nodeIndex == -1) {
          return null;
        }
      } // the goal is not to fill the entire context full of data because the lookups
      // are expensive. Instead, only the target data (the element, component, container, ICU
      // expression or directive details) are filled into the context. If called multiple times
      // with different target values then the missing target data will be filled in.


      var native = unwrapRNode(lView[nodeIndex]);
      var existingCtx = readPatchedData(native);
      var context = existingCtx && !Array.isArray(existingCtx) ? existingCtx : createLContext(lView, nodeIndex, native); // only when the component has been discovered then update the monkey-patch

      if (component && context.component === undefined) {
        context.component = component;
        attachPatchData(context.component, context);
      } // only when the directives have been discovered then update the monkey-patch


      if (directives && context.directives === undefined) {
        context.directives = directives;

        for (var i = 0; i < directives.length; i++) {
          attachPatchData(directives[i], context);
        }
      }

      attachPatchData(context.native, context);
      mpValue = context;
    }
  } else {
    var rElement = target;
    ngDevMode && assertDomNode(rElement); // if the context is not found then we need to traverse upwards up the DOM
    // to find the nearest element that has already been monkey patched with data

    var parent = rElement;

    while (parent = parent.parentNode) {
      var parentContext = readPatchedData(parent);

      if (parentContext) {
        var _lView2 = void 0;

        if (Array.isArray(parentContext)) {
          _lView2 = parentContext;
        } else {
          _lView2 = parentContext.lView;
        } // the edge of the app was also reached here through another means
        // (maybe because the DOM was changed manually).


        if (!_lView2) {
          return null;
        }

        var index = findViaNativeElement(_lView2, rElement);

        if (index >= 0) {
          var _native = unwrapRNode(_lView2[index]);

          var _context = createLContext(_lView2, index, _native);

          attachPatchData(_native, _context);
          mpValue = _context;
          break;
        }
      }
    }
  }

  return mpValue || null;
}
/**
 * Creates an empty instance of a `LContext` context
 */


function createLContext(lView, nodeIndex, native) {
  return {
    lView: lView,
    nodeIndex: nodeIndex,
    native: native,
    component: undefined,
    directives: undefined,
    localRefs: undefined
  };
}
/**
 * Takes a component instance and returns the view for that component.
 *
 * @param componentInstance
 * @returns The component's view
 */


function getComponentViewByInstance(componentInstance) {
  var lView = readPatchedData(componentInstance);
  var view;

  if (Array.isArray(lView)) {
    var nodeIndex = findViaComponent(lView, componentInstance);
    view = getComponentLViewByIndex(nodeIndex, lView);
    var context = createLContext(lView, nodeIndex, view[HOST]);
    context.component = componentInstance;
    attachPatchData(componentInstance, context);
    attachPatchData(context.native, context);
  } else {
    var _context2 = lView;
    view = getComponentLViewByIndex(_context2.nodeIndex, _context2.lView);
  }

  return view;
}
/**
 * Assigns the given data to the given target (which could be a component,
 * directive or DOM node instance) using monkey-patching.
 */


function attachPatchData(target, data) {
  target[MONKEY_PATCH_KEY_NAME] = data;
}

function isComponentInstance(instance) {
  return instance && instance.constructor && instance.constructor.ɵcmp;
}

function isDirectiveInstance(instance) {
  return instance && instance.constructor && instance.constructor.ɵdir;
}
/**
 * Locates the element within the given LView and returns the matching index
 */


function findViaNativeElement(lView, target) {
  var tView = lView[TVIEW];

  for (var i = HEADER_OFFSET; i < tView.bindingStartIndex; i++) {
    if (unwrapRNode(lView[i]) === target) {
      return i;
    }
  }

  return -1;
}
/**
 * Locates the next tNode (child, sibling or parent).
 */


function traverseNextElement(tNode) {
  if (tNode.child && tNode.child.parent === tNode) {
    // FIXME(misko): checking if `tNode.child.parent === tNode` should not be necessary
    // We have added it here because i18n creates TNode's which are not valid, so this is a work
    // around. The i18n code will be refactored in #39003 and once it lands this extra check can be
    // deleted.
    return tNode.child;
  } else if (tNode.next) {
    return tNode.next;
  } else {
    // Let's take the following template: <div><span>text</span></div><component/>
    // After checking the text node, we need to find the next parent that has a "next" TNode,
    // in this case the parent `div`, so that we can find the component.
    while (tNode.parent && !tNode.parent.next) {
      tNode = tNode.parent;
    }

    return tNode.parent && tNode.parent.next;
  }
}
/**
 * Locates the component within the given LView and returns the matching index
 */


function findViaComponent(lView, componentInstance) {
  var componentIndices = lView[TVIEW].components;

  if (componentIndices) {
    for (var i = 0; i < componentIndices.length; i++) {
      var elementComponentIndex = componentIndices[i];
      var componentView = getComponentLViewByIndex(elementComponentIndex, lView);

      if (componentView[CONTEXT] === componentInstance) {
        return elementComponentIndex;
      }
    }
  } else {
    var rootComponentView = getComponentLViewByIndex(HEADER_OFFSET, lView);
    var rootComponent = rootComponentView[CONTEXT];

    if (rootComponent === componentInstance) {
      // we are dealing with the root element here therefore we know that the
      // element is the very first element after the HEADER data in the lView
      return HEADER_OFFSET;
    }
  }

  return -1;
}
/**
 * Locates the directive within the given LView and returns the matching index
 */


function findViaDirective(lView, directiveInstance) {
  // if a directive is monkey patched then it will (by default)
  // have a reference to the LView of the current view. The
  // element bound to the directive being search lives somewhere
  // in the view data. We loop through the nodes and check their
  // list of directives for the instance.
  var tNode = lView[TVIEW].firstChild;

  while (tNode) {
    var directiveIndexStart = tNode.directiveStart;
    var directiveIndexEnd = tNode.directiveEnd;

    for (var i = directiveIndexStart; i < directiveIndexEnd; i++) {
      if (lView[i] === directiveInstance) {
        return tNode.index;
      }
    }

    tNode = traverseNextElement(tNode);
  }

  return -1;
}
/**
 * Returns a list of directives extracted from the given view based on the
 * provided list of directive index values.
 *
 * @param nodeIndex The node index
 * @param lView The target view data
 * @param includeComponents Whether or not to include components in returned directives
 */


function getDirectivesAtNodeIndex(nodeIndex, lView, includeComponents) {
  var tNode = lView[TVIEW].data[nodeIndex];
  var directiveStartIndex = tNode.directiveStart;
  if (directiveStartIndex == 0) return EMPTY_ARRAY;
  var directiveEndIndex = tNode.directiveEnd;
  if (!includeComponents && tNode.flags & 2
  /* isComponentHost */
  ) directiveStartIndex++;
  return lView.slice(directiveStartIndex, directiveEndIndex);
}

function getComponentAtNodeIndex(nodeIndex, lView) {
  var tNode = lView[TVIEW].data[nodeIndex];
  var directiveStartIndex = tNode.directiveStart;
  return tNode.flags & 2
  /* isComponentHost */
  ? lView[directiveStartIndex] : null;
}
/**
 * Returns a map of local references (local reference name => element or directive instance) that
 * exist on a given element.
 */


function discoverLocalRefs(lView, nodeIndex) {
  var tNode = lView[TVIEW].data[nodeIndex];

  if (tNode && tNode.localNames) {
    var result = {};
    var localIndex = tNode.index + 1;

    for (var i = 0; i < tNode.localNames.length; i += 2) {
      result[tNode.localNames[i]] = lView[localIndex];
      localIndex++;
    }

    return result;
  }

  return null;
}
/** Called when directives inject each other (creating a circular dependency) */


function throwCyclicDependencyError(token) {
  throw new Error("Cannot instantiate cyclic dependency! ".concat(token));
}
/** Called when there are multiple component selectors that match a given node */


function throwMultipleComponentError(tNode) {
  throw new Error("Multiple components match node with tagname ".concat(tNode.tagName));
}

function throwMixedMultiProviderError() {
  throw new Error("Cannot mix multi providers and regular providers");
}

function throwInvalidProviderError(ngModuleType, providers, provider) {
  var ngModuleDetail = '';

  if (ngModuleType && providers) {
    var providerDetail = providers.map(function (v) {
      return v == provider ? '?' + provider + '?' : '...';
    });
    ngModuleDetail = " - only instances of Provider and Type are allowed, got: [".concat(providerDetail.join(', '), "]");
  }

  throw new Error("Invalid provider for the NgModule '".concat(stringify(ngModuleType), "'") + ngModuleDetail);
}
/** Throws an ExpressionChangedAfterChecked error if checkNoChanges mode is on. */


function throwErrorIfNoChangesMode(creationMode, oldValue, currValue, propName) {
  var field = propName ? " for '".concat(propName, "'") : '';
  var msg = "ExpressionChangedAfterItHasBeenCheckedError: Expression has changed after it was checked. Previous value".concat(field, ": '").concat(oldValue, "'. Current value: '").concat(currValue, "'.");

  if (creationMode) {
    msg += " It seems like the view has been created after its parent and its children have been dirty checked." + " Has it been created in a change detection hook?";
  } // TODO: include debug context, see `viewDebugError` function in
  // `packages/core/src/view/errors.ts` for reference.


  throw new Error(msg);
}

function constructDetailsForInterpolation(lView, rootIndex, expressionIndex, meta, changedValue) {
  var _meta$split = meta.split(INTERPOLATION_DELIMITER),
      _meta$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toArray__WEBPACK_IMPORTED_MODULE_6__["default"])(_meta$split),
      propName = _meta$split2[0],
      prefix = _meta$split2[1],
      chunks = _meta$split2.slice(2);

  var oldValue = prefix,
      newValue = prefix;

  for (var i = 0; i < chunks.length; i++) {
    var slotIdx = rootIndex + i;
    oldValue += "".concat(lView[slotIdx]).concat(chunks[i]);
    newValue += "".concat(slotIdx === expressionIndex ? changedValue : lView[slotIdx]).concat(chunks[i]);
  }

  return {
    propName: propName,
    oldValue: oldValue,
    newValue: newValue
  };
}
/**
 * Constructs an object that contains details for the ExpressionChangedAfterItHasBeenCheckedError:
 * - property name (for property bindings or interpolations)
 * - old and new values, enriched using information from metadata
 *
 * More information on the metadata storage format can be found in `storePropertyBindingMetadata`
 * function description.
 */


function getExpressionChangedErrorDetails(lView, bindingIndex, oldValue, newValue) {
  var tData = lView[TVIEW].data;
  var metadata = tData[bindingIndex];

  if (typeof metadata === 'string') {
    // metadata for property interpolation
    if (metadata.indexOf(INTERPOLATION_DELIMITER) > -1) {
      return constructDetailsForInterpolation(lView, bindingIndex, bindingIndex, metadata, newValue);
    } // metadata for property binding


    return {
      propName: metadata,
      oldValue: oldValue,
      newValue: newValue
    };
  } // metadata is not available for this expression, check if this expression is a part of the
  // property interpolation by going from the current binding index left and look for a string that
  // contains INTERPOLATION_DELIMITER, the layout in tView.data for this case will look like this:
  // [..., 'id�Prefix � and � suffix', null, null, null, ...]


  if (metadata === null) {
    var idx = bindingIndex - 1;

    while (typeof tData[idx] !== 'string' && tData[idx + 1] === null) {
      idx--;
    }

    var meta = tData[idx];

    if (typeof meta === 'string') {
      var matches = meta.match(new RegExp(INTERPOLATION_DELIMITER, 'g')); // first interpolation delimiter separates property name from interpolation parts (in case of
      // property interpolations), so we subtract one from total number of found delimiters

      if (matches && matches.length - 1 > bindingIndex - idx) {
        return constructDetailsForInterpolation(lView, idx, bindingIndex, meta, newValue);
      }
    }
  }

  return {
    propName: undefined,
    oldValue: oldValue,
    newValue: newValue
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.


var unusedValueExportToPlacateAjd$5 = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Returns an index of `classToSearch` in `className` taking token boundaries into account.
 *
 * `classIndexOf('AB A', 'A', 0)` will be 3 (not 0 since `AB!==A`)
 *
 * @param className A string containing classes (whitespace separated)
 * @param classToSearch A class name to locate
 * @param startingIndex Starting location of search
 * @returns an index of the located class (or -1 if not found)
 */

function classIndexOf(className, classToSearch, startingIndex) {
  ngDevMode && assertNotEqual(classToSearch, '', 'can not look for "" string.');
  var end = className.length;

  while (true) {
    var foundIndex = className.indexOf(classToSearch, startingIndex);
    if (foundIndex === -1) return foundIndex;

    if (foundIndex === 0 || className.charCodeAt(foundIndex - 1) <= 32
    /* SPACE */
    ) {
        // Ensure that it has leading whitespace
        var length = classToSearch.length;

        if (foundIndex + length === end || className.charCodeAt(foundIndex + length) <= 32
        /* SPACE */
        ) {
            // Ensure that it has trailing whitespace
            return foundIndex;
          }
      } // False positive, keep searching from where we left off.


    startingIndex = foundIndex + 1;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var unusedValueToPlacateAjd = unusedValueExportToPlacateAjd$4 + unusedValueExportToPlacateAjd$5;
var NG_TEMPLATE_SELECTOR = 'ng-template';
/**
 * Search the `TAttributes` to see if it contains `cssClassToMatch` (case insensitive)
 *
 * @param attrs `TAttributes` to search through.
 * @param cssClassToMatch class to match (lowercase)
 * @param isProjectionMode Whether or not class matching should look into the attribute `class` in
 *    addition to the `AttributeMarker.Classes`.
 */

function isCssClassMatching(attrs, cssClassToMatch, isProjectionMode) {
  // TODO(misko): The fact that this function needs to know about `isProjectionMode` seems suspect.
  // It is strange to me that sometimes the class information comes in form of `class` attribute
  // and sometimes in form of `AttributeMarker.Classes`. Some investigation is needed to determine
  // if that is the right behavior.
  ngDevMode && assertEqual(cssClassToMatch, cssClassToMatch.toLowerCase(), 'Class name expected to be lowercase.');
  var i = 0;

  while (i < attrs.length) {
    var item = attrs[i++];

    if (isProjectionMode && item === 'class') {
      item = attrs[i];

      if (classIndexOf(item.toLowerCase(), cssClassToMatch, 0) !== -1) {
        return true;
      }
    } else if (item === 1
    /* Classes */
    ) {
        // We found the classes section. Start searching for the class.
        while (i < attrs.length && typeof (item = attrs[i++]) == 'string') {
          // while we have strings
          if (item.toLowerCase() === cssClassToMatch) return true;
        }

        return false;
      }
  }

  return false;
}
/**
 * Checks whether the `tNode` represents an inline template (e.g. `*ngFor`).
 *
 * @param tNode current TNode
 */


function isInlineTemplate(tNode) {
  return tNode.type === 0
  /* Container */
  && tNode.tagName !== NG_TEMPLATE_SELECTOR;
}
/**
 * Function that checks whether a given tNode matches tag-based selector and has a valid type.
 *
 * Matching can be performed in 2 modes: projection mode (when we project nodes) and regular
 * directive matching mode:
 * - in the "directive matching" mode we do _not_ take TContainer's tagName into account if it is
 * different from NG_TEMPLATE_SELECTOR (value different from NG_TEMPLATE_SELECTOR indicates that a
 * tag name was extracted from * syntax so we would match the same directive twice);
 * - in the "projection" mode, we use a tag name potentially extracted from the * syntax processing
 * (applicable to TNodeType.Container only).
 */


function hasTagAndTypeMatch(tNode, currentSelector, isProjectionMode) {
  var tagNameToCompare = tNode.type === 0
  /* Container */
  && !isProjectionMode ? NG_TEMPLATE_SELECTOR : tNode.tagName;
  return currentSelector === tagNameToCompare;
}
/**
 * A utility function to match an Ivy node static data against a simple CSS selector
 *
 * @param node static data of the node to match
 * @param selector The selector to try matching against the node.
 * @param isProjectionMode if `true` we are matching for content projection, otherwise we are doing
 * directive matching.
 * @returns true if node matches the selector.
 */


function isNodeMatchingSelector(tNode, selector, isProjectionMode) {
  ngDevMode && assertDefined(selector[0], 'Selector should have a tag name');
  var mode = 4
  /* ELEMENT */
  ;
  var nodeAttrs = tNode.attrs || []; // Find the index of first attribute that has no value, only a name.

  var nameOnlyMarkerIdx = getNameOnlyMarkerIndex(nodeAttrs); // When processing ":not" selectors, we skip to the next ":not" if the
  // current one doesn't match

  var skipToNextSelector = false;

  for (var i = 0; i < selector.length; i++) {
    var current = selector[i];

    if (typeof current === 'number') {
      // If we finish processing a :not selector and it hasn't failed, return false
      if (!skipToNextSelector && !isPositive(mode) && !isPositive(current)) {
        return false;
      } // If we are skipping to the next :not() and this mode flag is positive,
      // it's a part of the current :not() selector, and we should keep skipping


      if (skipToNextSelector && isPositive(current)) continue;
      skipToNextSelector = false;
      mode = current | mode & 1
      /* NOT */
      ;
      continue;
    }

    if (skipToNextSelector) continue;

    if (mode & 4
    /* ELEMENT */
    ) {
        mode = 2
        /* ATTRIBUTE */
        | mode & 1
        /* NOT */
        ;

        if (current !== '' && !hasTagAndTypeMatch(tNode, current, isProjectionMode) || current === '' && selector.length === 1) {
          if (isPositive(mode)) return false;
          skipToNextSelector = true;
        }
      } else {
      var selectorAttrValue = mode & 8
      /* CLASS */
      ? current : selector[++i]; // special case for matching against classes when a tNode has been instantiated with
      // class and style values as separate attribute values (e.g. ['title', CLASS, 'foo'])

      if (mode & 8
      /* CLASS */
      && tNode.attrs !== null) {
        if (!isCssClassMatching(tNode.attrs, selectorAttrValue, isProjectionMode)) {
          if (isPositive(mode)) return false;
          skipToNextSelector = true;
        }

        continue;
      }

      var attrName = mode & 8
      /* CLASS */
      ? 'class' : current;
      var attrIndexInNode = findAttrIndexInNode(attrName, nodeAttrs, isInlineTemplate(tNode), isProjectionMode);

      if (attrIndexInNode === -1) {
        if (isPositive(mode)) return false;
        skipToNextSelector = true;
        continue;
      }

      if (selectorAttrValue !== '') {
        var nodeAttrValue = void 0;

        if (attrIndexInNode > nameOnlyMarkerIdx) {
          nodeAttrValue = '';
        } else {
          ngDevMode && assertNotEqual(nodeAttrs[attrIndexInNode], 0
          /* NamespaceURI */
          , 'We do not match directives on namespaced attributes'); // we lowercase the attribute value to be able to match
          // selectors without case-sensitivity
          // (selectors are already in lowercase when generated)

          nodeAttrValue = nodeAttrs[attrIndexInNode + 1].toLowerCase();
        }

        var compareAgainstClassName = mode & 8
        /* CLASS */
        ? nodeAttrValue : null;

        if (compareAgainstClassName && classIndexOf(compareAgainstClassName, selectorAttrValue, 0) !== -1 || mode & 2
        /* ATTRIBUTE */
        && selectorAttrValue !== nodeAttrValue) {
          if (isPositive(mode)) return false;
          skipToNextSelector = true;
        }
      }
    }
  }

  return isPositive(mode) || skipToNextSelector;
}

function isPositive(mode) {
  return (mode & 1
  /* NOT */
  ) === 0;
}
/**
 * Examines the attribute's definition array for a node to find the index of the
 * attribute that matches the given `name`.
 *
 * NOTE: This will not match namespaced attributes.
 *
 * Attribute matching depends upon `isInlineTemplate` and `isProjectionMode`.
 * The following table summarizes which types of attributes we attempt to match:
 *
 * ===========================================================================================================
 * Modes                   | Normal Attributes | Bindings Attributes | Template Attributes | I18n
 * Attributes
 * ===========================================================================================================
 * Inline + Projection     | YES               | YES                 | NO                  | YES
 * -----------------------------------------------------------------------------------------------------------
 * Inline + Directive      | NO                | NO                  | YES                 | NO
 * -----------------------------------------------------------------------------------------------------------
 * Non-inline + Projection | YES               | YES                 | NO                  | YES
 * -----------------------------------------------------------------------------------------------------------
 * Non-inline + Directive  | YES               | YES                 | NO                  | YES
 * ===========================================================================================================
 *
 * @param name the name of the attribute to find
 * @param attrs the attribute array to examine
 * @param isInlineTemplate true if the node being matched is an inline template (e.g. `*ngFor`)
 * rather than a manually expanded template node (e.g `<ng-template>`).
 * @param isProjectionMode true if we are matching against content projection otherwise we are
 * matching against directives.
 */


function findAttrIndexInNode(name, attrs, isInlineTemplate, isProjectionMode) {
  if (attrs === null) return -1;
  var i = 0;

  if (isProjectionMode || !isInlineTemplate) {
    var bindingsMode = false;

    while (i < attrs.length) {
      var maybeAttrName = attrs[i];

      if (maybeAttrName === name) {
        return i;
      } else if (maybeAttrName === 3
      /* Bindings */
      || maybeAttrName === 6
      /* I18n */
      ) {
          bindingsMode = true;
        } else if (maybeAttrName === 1
      /* Classes */
      || maybeAttrName === 2
      /* Styles */
      ) {
          var value = attrs[++i]; // We should skip classes here because we have a separate mechanism for
          // matching classes in projection mode.

          while (typeof value === 'string') {
            value = attrs[++i];
          }

          continue;
        } else if (maybeAttrName === 4
      /* Template */
      ) {
          // We do not care about Template attributes in this scenario.
          break;
        } else if (maybeAttrName === 0
      /* NamespaceURI */
      ) {
          // Skip the whole namespaced attribute and value. This is by design.
          i += 4;
          continue;
        } // In binding mode there are only names, rather than name-value pairs.


      i += bindingsMode ? 1 : 2;
    } // We did not match the attribute


    return -1;
  } else {
    return matchTemplateAttribute(attrs, name);
  }
}

function isNodeMatchingSelectorList(tNode, selector) {
  var isProjectionMode = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  for (var i = 0; i < selector.length; i++) {
    if (isNodeMatchingSelector(tNode, selector[i], isProjectionMode)) {
      return true;
    }
  }

  return false;
}

function getProjectAsAttrValue(tNode) {
  var nodeAttrs = tNode.attrs;

  if (nodeAttrs != null) {
    var ngProjectAsAttrIdx = nodeAttrs.indexOf(5
    /* ProjectAs */
    ); // only check for ngProjectAs in attribute names, don't accidentally match attribute's value
    // (attribute names are stored at even indexes)

    if ((ngProjectAsAttrIdx & 1) === 0) {
      return nodeAttrs[ngProjectAsAttrIdx + 1];
    }
  }

  return null;
}

function getNameOnlyMarkerIndex(nodeAttrs) {
  for (var i = 0; i < nodeAttrs.length; i++) {
    var nodeAttr = nodeAttrs[i];

    if (isNameOnlyAttributeMarker(nodeAttr)) {
      return i;
    }
  }

  return nodeAttrs.length;
}

function matchTemplateAttribute(attrs, name) {
  var i = attrs.indexOf(4
  /* Template */
  );

  if (i > -1) {
    i++;

    while (i < attrs.length) {
      var attr = attrs[i]; // Return in case we checked all template attrs and are switching to the next section in the
      // attrs array (that starts with a number that represents an attribute marker).

      if (typeof attr === 'number') return -1;
      if (attr === name) return i;
      i++;
    }
  }

  return -1;
}
/**
 * Checks whether a selector is inside a CssSelectorList
 * @param selector Selector to be checked.
 * @param list List in which to look for the selector.
 */


function isSelectorInSelectorList(selector, list) {
  selectorListLoop: for (var i = 0; i < list.length; i++) {
    var currentSelectorInList = list[i];

    if (selector.length !== currentSelectorInList.length) {
      continue;
    }

    for (var j = 0; j < selector.length; j++) {
      if (selector[j] !== currentSelectorInList[j]) {
        continue selectorListLoop;
      }
    }

    return true;
  }

  return false;
}

function maybeWrapInNotSelector(isNegativeMode, chunk) {
  return isNegativeMode ? ':not(' + chunk.trim() + ')' : chunk;
}

function stringifyCSSSelector(selector) {
  var result = selector[0];
  var i = 1;
  var mode = 2
  /* ATTRIBUTE */
  ;
  var currentChunk = '';
  var isNegativeMode = false;

  while (i < selector.length) {
    var valueOrMarker = selector[i];

    if (typeof valueOrMarker === 'string') {
      if (mode & 2
      /* ATTRIBUTE */
      ) {
          var attrValue = selector[++i];
          currentChunk += '[' + valueOrMarker + (attrValue.length > 0 ? '="' + attrValue + '"' : '') + ']';
        } else if (mode & 8
      /* CLASS */
      ) {
          currentChunk += '.' + valueOrMarker;
        } else if (mode & 4
      /* ELEMENT */
      ) {
          currentChunk += ' ' + valueOrMarker;
        }
    } else {
      //
      // Append current chunk to the final result in case we come across SelectorFlag, which
      // indicates that the previous section of a selector is over. We need to accumulate content
      // between flags to make sure we wrap the chunk later in :not() selector if needed, e.g.
      // ```
      //  ['', Flags.CLASS, '.classA', Flags.CLASS | Flags.NOT, '.classB', '.classC']
      // ```
      // should be transformed to `.classA :not(.classB .classC)`.
      //
      // Note: for negative selector part, we accumulate content between flags until we find the
      // next negative flag. This is needed to support a case where `:not()` rule contains more than
      // one chunk, e.g. the following selector:
      // ```
      //  ['', Flags.ELEMENT | Flags.NOT, 'p', Flags.CLASS, 'foo', Flags.CLASS | Flags.NOT, 'bar']
      // ```
      // should be stringified to `:not(p.foo) :not(.bar)`
      //
      if (currentChunk !== '' && !isPositive(valueOrMarker)) {
        result += maybeWrapInNotSelector(isNegativeMode, currentChunk);
        currentChunk = '';
      }

      mode = valueOrMarker; // According to CssSelector spec, once we come across `SelectorFlags.NOT` flag, the negative
      // mode is maintained for remaining chunks of a selector.

      isNegativeMode = isNegativeMode || !isPositive(mode);
    }

    i++;
  }

  if (currentChunk !== '') {
    result += maybeWrapInNotSelector(isNegativeMode, currentChunk);
  }

  return result;
}
/**
 * Generates string representation of CSS selector in parsed form.
 *
 * ComponentDef and DirectiveDef are generated with the selector in parsed form to avoid doing
 * additional parsing at runtime (for example, for directive matching). However in some cases (for
 * example, while bootstrapping a component), a string version of the selector is required to query
 * for the host element on the page. This function takes the parsed form of a selector and returns
 * its string representation.
 *
 * @param selectorList selector in parsed form
 * @returns string representation of a given selector
 */


function stringifyCSSSelectorList(selectorList) {
  return selectorList.map(stringifyCSSSelector).join(',');
}
/**
 * Extracts attributes and classes information from a given CSS selector.
 *
 * This function is used while creating a component dynamically. In this case, the host element
 * (that is created dynamically) should contain attributes and classes specified in component's CSS
 * selector.
 *
 * @param selector CSS selector in parsed form (in a form of array)
 * @returns object with `attrs` and `classes` fields that contain extracted information
 */


function extractAttrsAndClassesFromSelector(selector) {
  var attrs = [];
  var classes = [];
  var i = 1;
  var mode = 2
  /* ATTRIBUTE */
  ;

  while (i < selector.length) {
    var valueOrMarker = selector[i];

    if (typeof valueOrMarker === 'string') {
      if (mode === 2
      /* ATTRIBUTE */
      ) {
          if (valueOrMarker !== '') {
            attrs.push(valueOrMarker, selector[++i]);
          }
        } else if (mode === 8
      /* CLASS */
      ) {
          classes.push(valueOrMarker);
        }
    } else {
      // According to CssSelector spec, once we come across `SelectorFlags.NOT` flag, the negative
      // mode is maintained for remaining chunks of a selector. Since attributes and classes are
      // extracted only for "positive" part of the selector, we can stop here.
      if (!isPositive(mode)) break;
      mode = valueOrMarker;
    }

    i++;
  }

  return {
    attrs: attrs,
    classes: classes
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/** A special value which designates that a value has not changed. */


var NO_CHANGE = typeof ngDevMode === 'undefined' || ngDevMode ? {
  __brand__: 'NO_CHANGE'
} : {};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Gets the parent LView of the passed LView, if the PARENT is an LContainer, will get the parent of
 * that LContainer, which is an LView
 * @param lView the lView whose parent to get
 */

function getLViewParent(lView) {
  ngDevMode && assertLView(lView);
  var parent = lView[PARENT];
  return isLContainer(parent) ? parent[PARENT] : parent;
}
/**
 * Retrieve the root view from any component or `LView` by walking the parent `LView` until
 * reaching the root `LView`.
 *
 * @param componentOrLView any component or `LView`
 */


function getRootView(componentOrLView) {
  ngDevMode && assertDefined(componentOrLView, 'component');
  var lView = isLView(componentOrLView) ? componentOrLView : readPatchedLView(componentOrLView);

  while (lView && !(lView[FLAGS] & 512
  /* IsRoot */
  )) {
    lView = getLViewParent(lView);
  }

  ngDevMode && assertLView(lView);
  return lView;
}
/**
 * Returns the `RootContext` instance that is associated with
 * the application where the target is situated. It does this by walking the parent views until it
 * gets to the root view, then getting the context off of that.
 *
 * @param viewOrComponent the `LView` or component to get the root context for.
 */


function getRootContext(viewOrComponent) {
  var rootView = getRootView(viewOrComponent);
  ngDevMode && assertDefined(rootView[CONTEXT], 'RootView has no context. Perhaps it is disconnected?');
  return rootView[CONTEXT];
}
/**
 * Gets the first `LContainer` in the LView or `null` if none exists.
 */


function getFirstLContainer(lView) {
  return getNearestLContainer(lView[CHILD_HEAD]);
}
/**
 * Gets the next `LContainer` that is a sibling of the given container.
 */


function getNextLContainer(container) {
  return getNearestLContainer(container[NEXT]);
}

function getNearestLContainer(viewOrContainer) {
  while (viewOrContainer !== null && !isLContainer(viewOrContainer)) {
    viewOrContainer = viewOrContainer[NEXT];
  }

  return viewOrContainer;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Advances to an element for later binding instructions.
 *
 * Used in conjunction with instructions like {@link property} to act on elements with specified
 * indices, for example those created with {@link element} or {@link elementStart}.
 *
 * ```ts
 * (rf: RenderFlags, ctx: any) => {
 *   if (rf & 1) {
 *     text(0, 'Hello');
 *     text(1, 'Goodbye')
 *     element(2, 'div');
 *   }
 *   if (rf & 2) {
 *     advance(2); // Advance twice to the <div>.
 *     property('title', 'test');
 *   }
 *  }
 * ```
 * @param delta Number of elements to advance forwards by.
 *
 * @codeGenApi
 */


function ɵɵadvance(delta) {
  ngDevMode && assertGreaterThan(delta, 0, 'Can only advance forward');
  selectIndexInternal(getTView(), getLView(), getSelectedIndex() + delta, getCheckNoChangesMode());
}

function selectIndexInternal(tView, lView, index, checkNoChangesMode) {
  ngDevMode && assertGreaterThan(index, -1, 'Invalid index');
  ngDevMode && assertIndexInRange(lView, index + HEADER_OFFSET); // Flush the initial hooks for elements in the view that have been added up to this point.
  // PERF WARNING: do NOT extract this to a separate function without running benchmarks

  if (!checkNoChangesMode) {
    var hooksInitPhaseCompleted = (lView[FLAGS] & 3
    /* InitPhaseStateMask */
    ) === 3
    /* InitPhaseCompleted */
    ;

    if (hooksInitPhaseCompleted) {
      var preOrderCheckHooks = tView.preOrderCheckHooks;

      if (preOrderCheckHooks !== null) {
        executeCheckHooks(lView, preOrderCheckHooks, index);
      }
    } else {
      var preOrderHooks = tView.preOrderHooks;

      if (preOrderHooks !== null) {
        executeInitAndCheckHooks(lView, preOrderHooks, 0
        /* OnInitHooksToBeRun */
        , index);
      }
    }
  } // We must set the selected index *after* running the hooks, because hooks may have side-effects
  // that cause other template functions to run, thus updating the selected index, which is global
  // state. If we run `setSelectedIndex` *before* we run the hooks, in some cases the selected index
  // will be altered by the time we leave the `ɵɵadvance` instruction.


  setSelectedIndex(index);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function toTStylingRange(prev, next) {
  ngDevMode && assertNumberInRange(prev, 0, 32767
  /* UNSIGNED_MASK */
  );
  ngDevMode && assertNumberInRange(next, 0, 32767
  /* UNSIGNED_MASK */
  );
  return prev << 17
  /* PREV_SHIFT */
  | next << 2
  /* NEXT_SHIFT */
  ;
}

function getTStylingRangePrev(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  return tStylingRange >> 17
  /* PREV_SHIFT */
  & 32767
  /* UNSIGNED_MASK */
  ;
}

function getTStylingRangePrevDuplicate(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  return (tStylingRange & 2
  /* PREV_DUPLICATE */
  ) == 2
  /* PREV_DUPLICATE */
  ;
}

function setTStylingRangePrev(tStylingRange, previous) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  ngDevMode && assertNumberInRange(previous, 0, 32767
  /* UNSIGNED_MASK */
  );
  return tStylingRange & ~4294836224
  /* PREV_MASK */
  | previous << 17
  /* PREV_SHIFT */
  ;
}

function setTStylingRangePrevDuplicate(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  return tStylingRange | 2
  /* PREV_DUPLICATE */
  ;
}

function getTStylingRangeNext(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  return (tStylingRange & 131068
  /* NEXT_MASK */
  ) >> 2
  /* NEXT_SHIFT */
  ;
}

function setTStylingRangeNext(tStylingRange, next) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  ngDevMode && assertNumberInRange(next, 0, 32767
  /* UNSIGNED_MASK */
  );
  return tStylingRange & ~131068
  /* NEXT_MASK */
  | //
  next << 2
  /* NEXT_SHIFT */
  ;
}

function getTStylingRangeNextDuplicate(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  return (tStylingRange & 1
  /* NEXT_DUPLICATE */
  ) === 1
  /* NEXT_DUPLICATE */
  ;
}

function setTStylingRangeNextDuplicate(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  return tStylingRange | 1
  /* NEXT_DUPLICATE */
  ;
}

function getTStylingRangeTail(tStylingRange) {
  ngDevMode && assertNumber(tStylingRange, 'expected number');
  var next = getTStylingRangeNext(tStylingRange);
  return next === 0 ? getTStylingRangePrev(tStylingRange) : next;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Patch a `debug` property on top of the existing object.
 *
 * NOTE: always call this method with `ngDevMode && attachDebugObject(...)`
 *
 * @param obj Object to patch
 * @param debug Value to patch
 */


function attachDebugObject(obj, debug) {
  if (ngDevMode) {
    Object.defineProperty(obj, 'debug', {
      value: debug,
      enumerable: false
    });
  } else {
    throw new Error('This method should be guarded with `ngDevMode` so that it can be tree shaken in production!');
  }
}
/**
 * Patch a `debug` property getter on top of the existing object.
 *
 * NOTE: always call this method with `ngDevMode && attachDebugObject(...)`
 *
 * @param obj Object to patch
 * @param debugGetter Getter returning a value to patch
 */


function attachDebugGetter(obj, debugGetter) {
  if (ngDevMode) {
    Object.defineProperty(obj, 'debug', {
      get: debugGetter,
      enumerable: false
    });
  } else {
    throw new Error('This method should be guarded with `ngDevMode` so that it can be tree shaken in production!');
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NG_DEV_MODE = (typeof ngDevMode === 'undefined' || !!ngDevMode) && initNgDevMode();
/*
 * This file contains conditionally attached classes which provide human readable (debug) level
 * information for `LView`, `LContainer` and other internal data structures. These data structures
 * are stored internally as array which makes it very difficult during debugging to reason about the
 * current state of the system.
 *
 * Patching the array with extra property does change the array's hidden class' but it does not
 * change the cost of access, therefore this patching should not have significant if any impact in
 * `ngDevMode` mode. (see: https://jsperf.com/array-vs-monkey-patch-array)
 *
 * So instead of seeing:
 * ```
 * Array(30) [Object, 659, null, …]
 * ```
 *
 * You get to see:
 * ```
 * LViewDebug {
 *   views: [...],
 *   flags: {attached: true, ...}
 *   nodes: [
 *     {html: '<div id="123">', ..., nodes: [
 *       {html: '<span>', ..., nodes: null}
 *     ]}
 *   ]
 * }
 * ```
 */

var LVIEW_COMPONENT_CACHE;
var LVIEW_EMBEDDED_CACHE;
var LVIEW_ROOT;
/**
 * This function clones a blueprint and creates LView.
 *
 * Simple slice will keep the same type, and we need it to be LView
 */

function cloneToLViewFromTViewBlueprint(tView) {
  var debugTView = tView;
  var lView = getLViewToClone(debugTView.type, tView.template && tView.template.name);
  return lView.concat(tView.blueprint);
}

function getLViewToClone(type, name) {
  switch (type) {
    case 0
    /* Root */
    :
      if (LVIEW_ROOT === undefined) LVIEW_ROOT = new (createNamedArrayType('LRootView'))();
      return LVIEW_ROOT;

    case 1
    /* Component */
    :
      if (LVIEW_COMPONENT_CACHE === undefined) LVIEW_COMPONENT_CACHE = new Map();
      var componentArray = LVIEW_COMPONENT_CACHE.get(name);

      if (componentArray === undefined) {
        componentArray = new (createNamedArrayType('LComponentView' + nameSuffix(name)))();
        LVIEW_COMPONENT_CACHE.set(name, componentArray);
      }

      return componentArray;

    case 2
    /* Embedded */
    :
      if (LVIEW_EMBEDDED_CACHE === undefined) LVIEW_EMBEDDED_CACHE = new Map();
      var embeddedArray = LVIEW_EMBEDDED_CACHE.get(name);

      if (embeddedArray === undefined) {
        embeddedArray = new (createNamedArrayType('LEmbeddedView' + nameSuffix(name)))();
        LVIEW_EMBEDDED_CACHE.set(name, embeddedArray);
      }

      return embeddedArray;
  }

  throw new Error('unreachable code');
}

function nameSuffix(text) {
  if (text == null) return '';
  var index = text.lastIndexOf('_Template');
  return '_' + (index === -1 ? text : text.substr(0, index));
}
/**
 * This class is a debug version of Object literal so that we can have constructor name show up
 * in
 * debug tools in ngDevMode.
 */


var TViewConstructor = /*#__PURE__*/function () {
  function TView(type, //
  blueprint, //
  template, //
  queries, //
  viewQuery, //
  declTNode, //
  data, //
  bindingStartIndex, //
  expandoStartIndex, //
  expandoInstructions, //
  firstCreatePass, //
  firstUpdatePass, //
  staticViewQueries, //
  staticContentQueries, //
  preOrderHooks, //
  preOrderCheckHooks, //
  contentHooks, //
  contentCheckHooks, //
  viewHooks, //
  viewCheckHooks, //
  destroyHooks, //
  cleanup, //
  contentQueries, //
  components, //
  directiveRegistry, //
  pipeRegistry, //
  firstChild, //
  schemas, //
  consts, //
  incompleteFirstPass, //
  _decls, //
  _vars) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TView);

    this.type = type;
    this.blueprint = blueprint;
    this.template = template;
    this.queries = queries;
    this.viewQuery = viewQuery;
    this.declTNode = declTNode;
    this.data = data;
    this.bindingStartIndex = bindingStartIndex;
    this.expandoStartIndex = expandoStartIndex;
    this.expandoInstructions = expandoInstructions;
    this.firstCreatePass = firstCreatePass;
    this.firstUpdatePass = firstUpdatePass;
    this.staticViewQueries = staticViewQueries;
    this.staticContentQueries = staticContentQueries;
    this.preOrderHooks = preOrderHooks;
    this.preOrderCheckHooks = preOrderCheckHooks;
    this.contentHooks = contentHooks;
    this.contentCheckHooks = contentCheckHooks;
    this.viewHooks = viewHooks;
    this.viewCheckHooks = viewCheckHooks;
    this.destroyHooks = destroyHooks;
    this.cleanup = cleanup;
    this.contentQueries = contentQueries;
    this.components = components;
    this.directiveRegistry = directiveRegistry;
    this.pipeRegistry = pipeRegistry;
    this.firstChild = firstChild;
    this.schemas = schemas;
    this.consts = consts;
    this.incompleteFirstPass = incompleteFirstPass;
    this._decls = _decls;
    this._vars = _vars;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TView, [{
    key: "template_",
    get: function get() {
      var buf = [];
      processTNodeChildren(this.firstChild, buf);
      return buf.join('');
    }
  }, {
    key: "type_",
    get: function get() {
      return TViewTypeAsString[this.type] || "TViewType.?".concat(this.type, "?");
    }
  }, {
    key: "i18nStartIndex",
    get: function get() {
      return HEADER_OFFSET + this._decls + this._vars;
    }
  }]);

  return TView;
}();

var TNode = /*#__PURE__*/function () {
  function TNode(tView_, //
  type, //
  index, //
  injectorIndex, //
  directiveStart, //
  directiveEnd, //
  directiveStylingLast, //
  propertyBindings, //
  flags, //
  providerIndexes, //
  tagName, //
  attrs, //
  mergedAttrs, //
  localNames, //
  initialInputs, //
  inputs, //
  outputs, //
  tViews, //
  next, //
  projectionNext, //
  child, //
  parent, //
  projection, //
  styles, //
  stylesWithoutHost, //
  residualStyles, //
  classes, //
  classesWithoutHost, //
  residualClasses, //
  classBindings, //
  styleBindings) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TNode);

    this.tView_ = tView_;
    this.type = type;
    this.index = index;
    this.injectorIndex = injectorIndex;
    this.directiveStart = directiveStart;
    this.directiveEnd = directiveEnd;
    this.directiveStylingLast = directiveStylingLast;
    this.propertyBindings = propertyBindings;
    this.flags = flags;
    this.providerIndexes = providerIndexes;
    this.tagName = tagName;
    this.attrs = attrs;
    this.mergedAttrs = mergedAttrs;
    this.localNames = localNames;
    this.initialInputs = initialInputs;
    this.inputs = inputs;
    this.outputs = outputs;
    this.tViews = tViews;
    this.next = next;
    this.projectionNext = projectionNext;
    this.child = child;
    this.parent = parent;
    this.projection = projection;
    this.styles = styles;
    this.stylesWithoutHost = stylesWithoutHost;
    this.residualStyles = residualStyles;
    this.classes = classes;
    this.classesWithoutHost = classesWithoutHost;
    this.residualClasses = residualClasses;
    this.classBindings = classBindings;
    this.styleBindings = styleBindings;
  }
  /**
   * Return a human debug version of the set of `NodeInjector`s which will be consulted when
   * resolving tokens from this `TNode`.
   *
   * When debugging applications, it is often difficult to determine which `NodeInjector`s will be
   * consulted. This method shows a list of `DebugNode`s representing the `TNode`s which will be
   * consulted in order when resolving a token starting at this `TNode`.
   *
   * The original data is stored in `LView` and `TView` with a lot of offset indexes, and so it is
   * difficult to reason about.
   *
   * @param lView The `LView` instance for this `TNode`.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TNode, [{
    key: "debugNodeInjectorPath",
    value: function debugNodeInjectorPath(lView) {
      var path = [];
      var injectorIndex = getInjectorIndex(this, lView);
      ngDevMode && assertNodeInjector(lView, injectorIndex);

      while (injectorIndex !== -1) {
        var tNode = lView[TVIEW].data[injectorIndex + 8
        /* TNODE */
        ];
        path.push(buildDebugNode(tNode, lView));
        var parentLocation = lView[injectorIndex + 8
        /* PARENT */
        ];

        if (parentLocation === NO_PARENT_INJECTOR) {
          injectorIndex = -1;
        } else {
          injectorIndex = getParentInjectorIndex(parentLocation);
          lView = getParentInjectorView(parentLocation, lView);
        }
      }

      return path;
    }
  }, {
    key: "type_",
    get: function get() {
      return TNodeTypeAsString[this.type] || "TNodeType.?".concat(this.type, "?");
    }
  }, {
    key: "flags_",
    get: function get() {
      var flags = [];
      if (this.flags & 16
      /* hasClassInput */
      ) flags.push('TNodeFlags.hasClassInput');
      if (this.flags & 8
      /* hasContentQuery */
      ) flags.push('TNodeFlags.hasContentQuery');
      if (this.flags & 32
      /* hasStyleInput */
      ) flags.push('TNodeFlags.hasStyleInput');
      if (this.flags & 128
      /* hasHostBindings */
      ) flags.push('TNodeFlags.hasHostBindings');
      if (this.flags & 2
      /* isComponentHost */
      ) flags.push('TNodeFlags.isComponentHost');
      if (this.flags & 1
      /* isDirectiveHost */
      ) flags.push('TNodeFlags.isDirectiveHost');
      if (this.flags & 64
      /* isDetached */
      ) flags.push('TNodeFlags.isDetached');
      if (this.flags & 4
      /* isProjected */
      ) flags.push('TNodeFlags.isProjected');
      return flags.join('|');
    }
  }, {
    key: "template_",
    get: function get() {
      var buf = [];
      buf.push('<', this.tagName || this.type_);

      if (this.attrs) {
        for (var i = 0; i < this.attrs.length;) {
          var attrName = this.attrs[i++];

          if (typeof attrName == 'number') {
            break;
          }

          var attrValue = this.attrs[i++];
          buf.push(' ', attrName, '="', attrValue, '"');
        }
      }

      buf.push('>');
      processTNodeChildren(this.child, buf);
      buf.push('</', this.tagName || this.type_, '>');
      return buf.join('');
    }
  }, {
    key: "styleBindings_",
    get: function get() {
      return toDebugStyleBinding(this, false);
    }
  }, {
    key: "classBindings_",
    get: function get() {
      return toDebugStyleBinding(this, true);
    }
  }, {
    key: "providerIndexStart_",
    get: function get() {
      return this.providerIndexes & 1048575
      /* ProvidersStartIndexMask */
      ;
    }
  }, {
    key: "providerIndexEnd_",
    get: function get() {
      return this.providerIndexStart_ + (this.providerIndexes >>> 20
      /* CptViewProvidersCountShift */
      );
    }
  }]);

  return TNode;
}();

var TNodeDebug = TNode;

function toDebugStyleBinding(tNode, isClassBased) {
  var tData = tNode.tView_.data;
  var bindings = [];
  var range = isClassBased ? tNode.classBindings : tNode.styleBindings;
  var prev = getTStylingRangePrev(range);
  var next = getTStylingRangeNext(range);
  var isTemplate = next !== 0;
  var cursor = isTemplate ? next : prev;

  while (cursor !== 0) {
    var itemKey = tData[cursor];
    var itemRange = tData[cursor + 1];
    bindings.unshift({
      key: itemKey,
      index: cursor,
      isTemplate: isTemplate,
      prevDuplicate: getTStylingRangePrevDuplicate(itemRange),
      nextDuplicate: getTStylingRangeNextDuplicate(itemRange),
      nextIndex: getTStylingRangeNext(itemRange),
      prevIndex: getTStylingRangePrev(itemRange)
    });
    if (cursor === prev) isTemplate = false;
    cursor = getTStylingRangePrev(itemRange);
  }

  bindings.push((isClassBased ? tNode.residualClasses : tNode.residualStyles) || null);
  return bindings;
}

function processTNodeChildren(tNode, buf) {
  while (tNode) {
    buf.push(tNode.template_);
    tNode = tNode.next;
  }
}

var TViewData = NG_DEV_MODE && createNamedArrayType('TViewData') || null;
var TVIEWDATA_EMPTY; // can't initialize here or it will not be tree shaken, because
// `LView` constructor could have side-effects.

/**
 * This function clones a blueprint and creates TData.
 *
 * Simple slice will keep the same type, and we need it to be TData
 */

function cloneToTViewData(list) {
  if (TVIEWDATA_EMPTY === undefined) TVIEWDATA_EMPTY = new TViewData();
  return TVIEWDATA_EMPTY.concat(list);
}

var LViewBlueprint = NG_DEV_MODE && createNamedArrayType('LViewBlueprint') || null;
var MatchesArray = NG_DEV_MODE && createNamedArrayType('MatchesArray') || null;
var TViewComponents = NG_DEV_MODE && createNamedArrayType('TViewComponents') || null;
var TNodeLocalNames = NG_DEV_MODE && createNamedArrayType('TNodeLocalNames') || null;
var TNodeInitialInputs = NG_DEV_MODE && createNamedArrayType('TNodeInitialInputs') || null;
var TNodeInitialData = NG_DEV_MODE && createNamedArrayType('TNodeInitialData') || null;
var LCleanup = NG_DEV_MODE && createNamedArrayType('LCleanup') || null;
var TCleanup = NG_DEV_MODE && createNamedArrayType('TCleanup') || null;

function attachLViewDebug(lView) {
  attachDebugObject(lView, new LViewDebug(lView));
}

function attachLContainerDebug(lContainer) {
  attachDebugObject(lContainer, new LContainerDebug(lContainer));
}

function toDebug(obj) {
  if (obj) {
    var debug = obj.debug;
    assertDefined(debug, 'Object does not have a debug representation.');
    return debug;
  } else {
    return obj;
  }
}
/**
 * Use this method to unwrap a native element in `LView` and convert it into HTML for easier
 * reading.
 *
 * @param value possibly wrapped native DOM node.
 * @param includeChildren If `true` then the serialized HTML form will include child elements
 * (same
 * as `outerHTML`). If `false` then the serialized HTML form will only contain the element
 * itself
 * (will not serialize child elements).
 */


function toHtml(value) {
  var includeChildren = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var node = unwrapRNode(value);

  if (node) {
    switch (node.nodeType) {
      case Node.TEXT_NODE:
        return node.textContent;

      case Node.COMMENT_NODE:
        return "<!--".concat(node.textContent, "-->");

      case Node.ELEMENT_NODE:
        var outerHTML = node.outerHTML;

        if (includeChildren) {
          return outerHTML;
        } else {
          var innerHTML = '>' + node.innerHTML + '<';
          return outerHTML.split(innerHTML)[0] + '>';
        }

    }
  }

  return null;
}

var LViewDebug = /*#__PURE__*/function () {
  function LViewDebug(_raw_lView) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, LViewDebug);

    this._raw_lView = _raw_lView;
  }
  /**
   * Flags associated with the `LView` unpacked into a more readable state.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(LViewDebug, [{
    key: "flags",
    get: function get() {
      var flags = this._raw_lView[FLAGS];
      return {
        __raw__flags__: flags,
        initPhaseState: flags & 3
        /* InitPhaseStateMask */
        ,
        creationMode: !!(flags & 4
        /* CreationMode */
        ),
        firstViewPass: !!(flags & 8
        /* FirstLViewPass */
        ),
        checkAlways: !!(flags & 16
        /* CheckAlways */
        ),
        dirty: !!(flags & 64
        /* Dirty */
        ),
        attached: !!(flags & 128
        /* Attached */
        ),
        destroyed: !!(flags & 256
        /* Destroyed */
        ),
        isRoot: !!(flags & 512
        /* IsRoot */
        ),
        indexWithinInitPhase: flags >> 11
        /* IndexWithinInitPhaseShift */

      };
    }
  }, {
    key: "parent",
    get: function get() {
      return toDebug(this._raw_lView[PARENT]);
    }
  }, {
    key: "hostHTML",
    get: function get() {
      return toHtml(this._raw_lView[HOST], true);
    }
  }, {
    key: "html",
    get: function get() {
      return (this.nodes || []).map(function (node) {
        return toHtml(node.native, true);
      }).join('');
    }
  }, {
    key: "context",
    get: function get() {
      return this._raw_lView[CONTEXT];
    }
    /**
     * The tree of nodes associated with the current `LView`. The nodes have been normalized into
     * a tree structure with relevant details pulled out for readability.
     */

  }, {
    key: "nodes",
    get: function get() {
      var lView = this._raw_lView;
      var tNode = lView[TVIEW].firstChild;
      return toDebugNodes(tNode, lView);
    }
  }, {
    key: "tView",
    get: function get() {
      return this._raw_lView[TVIEW];
    }
  }, {
    key: "cleanup",
    get: function get() {
      return this._raw_lView[CLEANUP];
    }
  }, {
    key: "injector",
    get: function get() {
      return this._raw_lView[INJECTOR$1];
    }
  }, {
    key: "rendererFactory",
    get: function get() {
      return this._raw_lView[RENDERER_FACTORY];
    }
  }, {
    key: "renderer",
    get: function get() {
      return this._raw_lView[RENDERER];
    }
  }, {
    key: "sanitizer",
    get: function get() {
      return this._raw_lView[SANITIZER];
    }
  }, {
    key: "childHead",
    get: function get() {
      return toDebug(this._raw_lView[CHILD_HEAD]);
    }
  }, {
    key: "next",
    get: function get() {
      return toDebug(this._raw_lView[NEXT]);
    }
  }, {
    key: "childTail",
    get: function get() {
      return toDebug(this._raw_lView[CHILD_TAIL]);
    }
  }, {
    key: "declarationView",
    get: function get() {
      return toDebug(this._raw_lView[DECLARATION_VIEW]);
    }
  }, {
    key: "queries",
    get: function get() {
      return this._raw_lView[QUERIES];
    }
  }, {
    key: "tHost",
    get: function get() {
      return this._raw_lView[T_HOST];
    }
  }, {
    key: "decls",
    get: function get() {
      return toLViewRange(this.tView, this._raw_lView, HEADER_OFFSET, this.tView.bindingStartIndex);
    }
  }, {
    key: "vars",
    get: function get() {
      var tView = this.tView;
      return toLViewRange(tView, this._raw_lView, tView.bindingStartIndex, tView.i18nStartIndex);
    }
  }, {
    key: "i18n",
    get: function get() {
      var tView = this.tView;
      return toLViewRange(tView, this._raw_lView, tView.i18nStartIndex, tView.expandoStartIndex);
    }
  }, {
    key: "expando",
    get: function get() {
      var tView = this.tView;
      return toLViewRange(this.tView, this._raw_lView, this.tView.expandoStartIndex, this._raw_lView.length);
    }
    /**
     * Normalized view of child views (and containers) attached at this location.
     */

  }, {
    key: "childViews",
    get: function get() {
      var childViews = [];
      var child = this.childHead;

      while (child) {
        childViews.push(child);
        child = child.next;
      }

      return childViews;
    }
  }]);

  return LViewDebug;
}();

function toLViewRange(tView, lView, start, end) {
  var content = [];

  for (var index = start; index < end; index++) {
    content.push({
      index: index,
      t: tView.data[index],
      l: lView[index]
    });
  }

  return {
    start: start,
    end: end,
    length: end - start,
    content: content
  };
}
/**
 * Turns a flat list of nodes into a tree by walking the associated `TNode` tree.
 *
 * @param tNode
 * @param lView
 */


function toDebugNodes(tNode, lView) {
  if (tNode) {
    var debugNodes = [];
    var tNodeCursor = tNode;

    while (tNodeCursor) {
      debugNodes.push(buildDebugNode(tNodeCursor, lView));
      tNodeCursor = tNodeCursor.next;
    }

    return debugNodes;
  } else {
    return [];
  }
}

function buildDebugNode(tNode, lView) {
  var rawValue = lView[tNode.index];
  var native = unwrapRNode(rawValue);
  var factories = [];
  var instances = [];
  var tView = lView[TVIEW];

  for (var i = tNode.directiveStart; i < tNode.directiveEnd; i++) {
    var def = tView.data[i];
    factories.push(def.type);
    instances.push(lView[i]);
  }

  return {
    html: toHtml(native),
    type: TNodeTypeAsString[tNode.type],
    native: native,
    children: toDebugNodes(tNode.child, lView),
    factories: factories,
    instances: instances,
    injector: buildNodeInjectorDebug(tNode, tView, lView)
  };
}

function buildNodeInjectorDebug(tNode, tView, lView) {
  var viewProviders = [];

  for (var i = tNode.providerIndexStart_; i < tNode.providerIndexEnd_; i++) {
    viewProviders.push(tView.data[i]);
  }

  var providers = [];

  for (var _i2 = tNode.providerIndexEnd_; _i2 < tNode.directiveEnd; _i2++) {
    providers.push(tView.data[_i2]);
  }

  var nodeInjectorDebug = {
    bloom: toBloom(lView, tNode.injectorIndex),
    cumulativeBloom: toBloom(tView.data, tNode.injectorIndex),
    providers: providers,
    viewProviders: viewProviders,
    parentInjectorIndex: lView[tNode.providerIndexStart_ - 1]
  };
  return nodeInjectorDebug;
}
/**
 * Convert a number at `idx` location in `array` into binary representation.
 *
 * @param array
 * @param idx
 */


function binary(array, idx) {
  var value = array[idx]; // If not a number we print 8 `?` to retain alignment but let user know that it was called on
  // wrong type.

  if (typeof value !== 'number') return '????????'; // We prefix 0s so that we have constant length number

  var text = '00000000' + value.toString(2);
  return text.substring(text.length - 8);
}
/**
 * Convert a bloom filter at location `idx` in `array` into binary representation.
 *
 * @param array
 * @param idx
 */


function toBloom(array, idx) {
  return "".concat(binary(array, idx + 7), "_").concat(binary(array, idx + 6), "_").concat(binary(array, idx + 5), "_").concat(binary(array, idx + 4), "_").concat(binary(array, idx + 3), "_").concat(binary(array, idx + 2), "_").concat(binary(array, idx + 1), "_").concat(binary(array, idx + 0));
}

var LContainerDebug = /*#__PURE__*/function () {
  function LContainerDebug(_raw_lContainer) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, LContainerDebug);

    this._raw_lContainer = _raw_lContainer;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(LContainerDebug, [{
    key: "hasTransplantedViews",
    get: function get() {
      return this._raw_lContainer[HAS_TRANSPLANTED_VIEWS];
    }
  }, {
    key: "views",
    get: function get() {
      return this._raw_lContainer.slice(CONTAINER_HEADER_OFFSET).map(toDebug);
    }
  }, {
    key: "parent",
    get: function get() {
      return toDebug(this._raw_lContainer[PARENT]);
    }
  }, {
    key: "movedViews",
    get: function get() {
      return this._raw_lContainer[MOVED_VIEWS];
    }
  }, {
    key: "host",
    get: function get() {
      return this._raw_lContainer[HOST];
    }
  }, {
    key: "native",
    get: function get() {
      return this._raw_lContainer[NATIVE];
    }
  }, {
    key: "next",
    get: function get() {
      return toDebug(this._raw_lContainer[NEXT]);
    }
  }]);

  return LContainerDebug;
}();
/**
 * Return an `LView` value if found.
 *
 * @param value `LView` if any
 */


function readLViewValue(value) {
  while (Array.isArray(value)) {
    // This check is not quite right, as it does not take into account `StylingContext`
    // This is why it is in debug, not in util.ts
    if (value.length >= HEADER_OFFSET - 1) return value;
    value = value[HOST];
  }

  return null;
}

var ɵ0$4 = function ɵ0$4() {
  return Promise.resolve(null);
};
/**
 * A permanent marker promise which signifies that the current CD tree is
 * clean.
 */


var _CLEAN_PROMISE = ɵ0$4();
/**
 * Process the `TView.expandoInstructions`. (Execute the `hostBindings`.)
 *
 * @param tView `TView` containing the `expandoInstructions`
 * @param lView `LView` associated with the `TView`
 */


function setHostBindingsByExecutingExpandoInstructions(tView, lView) {
  ngDevMode && assertSame(tView, lView[TVIEW], '`LView` is not associated with the `TView`!');

  try {
    var expandoInstructions = tView.expandoInstructions;

    if (expandoInstructions !== null) {
      var bindingRootIndex = tView.expandoStartIndex;
      var currentDirectiveIndex = -1;
      var currentElementIndex = -1; // TODO(misko): PERF It is possible to get here with `TView.expandoInstructions` containing no
      // functions to execute. This is wasteful as there is no work to be done, but we still need
      // to iterate over the instructions.
      // In example of this is in this test: `host_binding_spec.ts`
      // `fit('should not cause problems if detectChanges is called when a property updates', ...`
      // In the above test we get here with expando [0, 0, 1] which requires a lot of processing but
      // there is no function to execute.

      for (var i = 0; i < expandoInstructions.length; i++) {
        var instruction = expandoInstructions[i];

        if (typeof instruction === 'number') {
          if (instruction <= 0) {
            // Negative numbers mean that we are starting new EXPANDO block and need to update
            // the current element and directive index.
            // Important: In JS `-x` and `0-x` is not the same! If `x===0` then `-x` will produce
            // `-0` which requires non standard math arithmetic and it can prevent VM optimizations.
            // `0-0` will always produce `0` and will not cause a potential deoptimization in VM.
            // TODO(misko): PERF This should be refactored to use `~instruction` as that does not
            // suffer from `-0` and it is faster/more compact.
            currentElementIndex = 0 - instruction;
            setSelectedIndex(currentElementIndex); // Injector block and providers are taken into account.

            var providerCount = expandoInstructions[++i];
            bindingRootIndex += 9
            /* SIZE */
            + providerCount;
            currentDirectiveIndex = bindingRootIndex;
          } else {
            // This is either the injector size (so the binding root can skip over directives
            // and get to the first set of host bindings on this node) or the host var count
            // (to get to the next set of host bindings on this node).
            bindingRootIndex += instruction;
          }
        } else {
          // If it's not a number, it's a host binding function that needs to be executed.
          if (instruction !== null) {
            ngDevMode && assertLessThan(currentDirectiveIndex, 1048576
            /* CptViewProvidersCountShifter */
            , 'Reached the max number of host bindings');
            setBindingRootForHostBindings(bindingRootIndex, currentDirectiveIndex);
            var hostCtx = lView[currentDirectiveIndex];
            instruction(2
            /* Update */
            , hostCtx);
          } // TODO(misko): PERF Relying on incrementing the `currentDirectiveIndex` here is
          // sub-optimal. The implications are that if we have a lot of directives but none of them
          // have host bindings we nevertheless need to iterate over the expando instructions to
          // update the counter. It would be much better if we could encode the
          // `currentDirectiveIndex` into the `expandoInstruction` array so that we only need to
          // iterate over those directives which actually have `hostBindings`.


          currentDirectiveIndex++;
        }
      }
    }
  } finally {
    setSelectedIndex(-1);
  }
}
/** Refreshes all content queries declared by directives in a given view */


function refreshContentQueries(tView, lView) {
  var contentQueries = tView.contentQueries;

  if (contentQueries !== null) {
    for (var i = 0; i < contentQueries.length; i += 2) {
      var queryStartIdx = contentQueries[i];
      var directiveDefIdx = contentQueries[i + 1];

      if (directiveDefIdx !== -1) {
        var _directiveDef2 = tView.data[directiveDefIdx];
        ngDevMode && assertDefined(_directiveDef2.contentQueries, 'contentQueries function should be defined');
        setCurrentQueryIndex(queryStartIdx);

        _directiveDef2.contentQueries(2
        /* Update */
        , lView[directiveDefIdx], directiveDefIdx);
      }
    }
  }
}
/** Refreshes child components in the current view (update mode). */


function refreshChildComponents(hostLView, components) {
  for (var i = 0; i < components.length; i++) {
    refreshComponent(hostLView, components[i]);
  }
}
/** Renders child components in the current view (creation mode). */


function renderChildComponents(hostLView, components) {
  for (var i = 0; i < components.length; i++) {
    renderComponent(hostLView, components[i]);
  }
}
/**
 * Creates a native element from a tag name, using a renderer.
 * @param name the tag name
 * @param renderer A renderer to use
 * @returns the element created
 */


function elementCreate(name, renderer, namespace) {
  if (isProceduralRenderer(renderer)) {
    return renderer.createElement(name, namespace);
  } else {
    return namespace === null ? renderer.createElement(name) : renderer.createElementNS(namespace, name);
  }
}

function createLView(parentLView, tView, context, flags, host, tHostNode, rendererFactory, renderer, sanitizer, injector) {
  var lView = ngDevMode ? cloneToLViewFromTViewBlueprint(tView) : tView.blueprint.slice();
  lView[HOST] = host;
  lView[FLAGS] = flags | 4
  /* CreationMode */
  | 128
  /* Attached */
  | 8
  /* FirstLViewPass */
  ;
  resetPreOrderHookFlags(lView);
  ngDevMode && tView.declTNode && parentLView && assertTNodeForLView(tView.declTNode, parentLView);
  lView[PARENT] = lView[DECLARATION_VIEW] = parentLView;
  lView[CONTEXT] = context;
  lView[RENDERER_FACTORY] = rendererFactory || parentLView && parentLView[RENDERER_FACTORY];
  ngDevMode && assertDefined(lView[RENDERER_FACTORY], 'RendererFactory is required');
  lView[RENDERER] = renderer || parentLView && parentLView[RENDERER];
  ngDevMode && assertDefined(lView[RENDERER], 'Renderer is required');
  lView[SANITIZER] = sanitizer || parentLView && parentLView[SANITIZER] || null;
  lView[INJECTOR$1] = injector || parentLView && parentLView[INJECTOR$1] || null;
  lView[T_HOST] = tHostNode;
  ngDevMode && assertEqual(tView.type == 2
  /* Embedded */
  ? parentLView !== null : true, true, 'Embedded views must have parentLView');
  lView[DECLARATION_COMPONENT_VIEW] = tView.type == 2
  /* Embedded */
  ? parentLView[DECLARATION_COMPONENT_VIEW] : lView;
  ngDevMode && attachLViewDebug(lView);
  return lView;
}

function getOrCreateTNode(tView, index, type, name, attrs) {
  // Keep this function short, so that the VM will inline it.
  var adjustedIndex = index + HEADER_OFFSET;
  var tNode = tView.data[adjustedIndex] || createTNodeAtIndex(tView, adjustedIndex, type, name, attrs);
  setCurrentTNode(tNode, true);
  return tNode;
}

function createTNodeAtIndex(tView, adjustedIndex, type, name, attrs) {
  var currentTNode = getCurrentTNode();
  var isParent = isCurrentTNodeParent();
  var parent = isParent ? currentTNode : currentTNode && currentTNode.parent; // Parents cannot cross component boundaries because components will be used in multiple places.

  var tNode = tView.data[adjustedIndex] = createTNode(tView, parent, type, adjustedIndex, name, attrs); // Assign a pointer to the first child node of a given view. The first node is not always the one
  // at index 0, in case of i18n, index 0 can be the instruction `i18nStart` and the first node has
  // the index 1 or more, so we can't just check node index.

  if (tView.firstChild === null) {
    tView.firstChild = tNode;
  }

  if (currentTNode !== null) {
    if (isParent && currentTNode.child == null && tNode.parent !== null) {
      // We are in the same view, which means we are adding content node to the parent view.
      currentTNode.child = tNode;
    } else if (!isParent) {
      currentTNode.next = tNode;
    }
  }

  return tNode;
}
/**
 * When elements are created dynamically after a view blueprint is created (e.g. through
 * i18nApply() or ComponentFactory.create), we need to adjust the blueprint for future
 * template passes.
 *
 * @param tView `TView` associated with `LView`
 * @param view The `LView` containing the blueprint to adjust
 * @param numSlotsToAlloc The number of slots to alloc in the LView, should be >0
 */


function allocExpando(tView, lView, numSlotsToAlloc) {
  ngDevMode && assertGreaterThan(numSlotsToAlloc, 0, 'The number of slots to alloc should be greater than 0');

  if (numSlotsToAlloc > 0) {
    if (tView.firstCreatePass) {
      for (var i = 0; i < numSlotsToAlloc; i++) {
        tView.blueprint.push(null);
        tView.data.push(null);
        lView.push(null);
      } // We should only increment the expando start index if there aren't already directives
      // and injectors saved in the "expando" section


      if (!tView.expandoInstructions) {
        tView.expandoStartIndex += numSlotsToAlloc;
      } else {
        // Since we're adding the dynamic nodes into the expando section, we need to let the host
        // bindings know that they should skip x slots
        tView.expandoInstructions.push(numSlotsToAlloc);
      }
    }
  }
} //////////////////////////
//// Render
//////////////////////////

/**
 * Processes a view in the creation mode. This includes a number of steps in a specific order:
 * - creating view query functions (if any);
 * - executing a template function in the creation mode;
 * - updating static queries (if any);
 * - creating child components defined in a given view.
 */


function renderView(tView, lView, context) {
  ngDevMode && assertEqual(isCreationMode(lView), true, 'Should be run in creation mode');
  enterView(lView);

  try {
    var viewQuery = tView.viewQuery;

    if (viewQuery !== null) {
      executeViewQueryFn(1
      /* Create */
      , viewQuery, context);
    } // Execute a template associated with this view, if it exists. A template function might not be
    // defined for the root component views.


    var templateFn = tView.template;

    if (templateFn !== null) {
      executeTemplate(tView, lView, templateFn, 1
      /* Create */
      , context);
    } // This needs to be set before children are processed to support recursive components.
    // This must be set to false immediately after the first creation run because in an
    // ngFor loop, all the views will be created together before update mode runs and turns
    // off firstCreatePass. If we don't set it here, instances will perform directive
    // matching, etc again and again.


    if (tView.firstCreatePass) {
      tView.firstCreatePass = false;
    } // We resolve content queries specifically marked as `static` in creation mode. Dynamic
    // content queries are resolved during change detection (i.e. update mode), after embedded
    // views are refreshed (see block above).


    if (tView.staticContentQueries) {
      refreshContentQueries(tView, lView);
    } // We must materialize query results before child components are processed
    // in case a child component has projected a container. The LContainer needs
    // to exist so the embedded views are properly attached by the container.


    if (tView.staticViewQueries) {
      executeViewQueryFn(2
      /* Update */
      , tView.viewQuery, context);
    } // Render child component views.


    var components = tView.components;

    if (components !== null) {
      renderChildComponents(lView, components);
    }
  } catch (error) {
    // If we didn't manage to get past the first template pass due to
    // an error, mark the view as corrupted so we can try to recover.
    if (tView.firstCreatePass) {
      tView.incompleteFirstPass = true;
    }

    throw error;
  } finally {
    lView[FLAGS] &= ~4
    /* CreationMode */
    ;
    leaveView();
  }
}
/**
 * Processes a view in update mode. This includes a number of steps in a specific order:
 * - executing a template function in update mode;
 * - executing hooks;
 * - refreshing queries;
 * - setting host bindings;
 * - refreshing child (embedded and component) views.
 */


function refreshView(tView, lView, templateFn, context) {
  ngDevMode && assertEqual(isCreationMode(lView), false, 'Should be run in update mode');
  var flags = lView[FLAGS];
  if ((flags & 256
  /* Destroyed */
  ) === 256
  /* Destroyed */
  ) return;
  enterView(lView);
  var checkNoChangesMode = getCheckNoChangesMode();

  try {
    resetPreOrderHookFlags(lView);
    setBindingIndex(tView.bindingStartIndex);

    if (templateFn !== null) {
      executeTemplate(tView, lView, templateFn, 2
      /* Update */
      , context);
    }

    var hooksInitPhaseCompleted = (flags & 3
    /* InitPhaseStateMask */
    ) === 3
    /* InitPhaseCompleted */
    ; // execute pre-order hooks (OnInit, OnChanges, DoCheck)
    // PERF WARNING: do NOT extract this to a separate function without running benchmarks

    if (!checkNoChangesMode) {
      if (hooksInitPhaseCompleted) {
        var preOrderCheckHooks = tView.preOrderCheckHooks;

        if (preOrderCheckHooks !== null) {
          executeCheckHooks(lView, preOrderCheckHooks, null);
        }
      } else {
        var preOrderHooks = tView.preOrderHooks;

        if (preOrderHooks !== null) {
          executeInitAndCheckHooks(lView, preOrderHooks, 0
          /* OnInitHooksToBeRun */
          , null);
        }

        incrementInitPhaseFlags(lView, 0
        /* OnInitHooksToBeRun */
        );
      }
    } // First mark transplanted views that are declared in this lView as needing a refresh at their
    // insertion points. This is needed to avoid the situation where the template is defined in this
    // `LView` but its declaration appears after the insertion component.


    markTransplantedViewsForRefresh(lView);
    refreshEmbeddedViews(lView); // Content query results must be refreshed before content hooks are called.

    if (tView.contentQueries !== null) {
      refreshContentQueries(tView, lView);
    } // execute content hooks (AfterContentInit, AfterContentChecked)
    // PERF WARNING: do NOT extract this to a separate function without running benchmarks


    if (!checkNoChangesMode) {
      if (hooksInitPhaseCompleted) {
        var contentCheckHooks = tView.contentCheckHooks;

        if (contentCheckHooks !== null) {
          executeCheckHooks(lView, contentCheckHooks);
        }
      } else {
        var contentHooks = tView.contentHooks;

        if (contentHooks !== null) {
          executeInitAndCheckHooks(lView, contentHooks, 1
          /* AfterContentInitHooksToBeRun */
          );
        }

        incrementInitPhaseFlags(lView, 1
        /* AfterContentInitHooksToBeRun */
        );
      }
    }

    setHostBindingsByExecutingExpandoInstructions(tView, lView); // Refresh child component views.

    var components = tView.components;

    if (components !== null) {
      refreshChildComponents(lView, components);
    } // View queries must execute after refreshing child components because a template in this view
    // could be inserted in a child component. If the view query executes before child component
    // refresh, the template might not yet be inserted.


    var viewQuery = tView.viewQuery;

    if (viewQuery !== null) {
      executeViewQueryFn(2
      /* Update */
      , viewQuery, context);
    } // execute view hooks (AfterViewInit, AfterViewChecked)
    // PERF WARNING: do NOT extract this to a separate function without running benchmarks


    if (!checkNoChangesMode) {
      if (hooksInitPhaseCompleted) {
        var viewCheckHooks = tView.viewCheckHooks;

        if (viewCheckHooks !== null) {
          executeCheckHooks(lView, viewCheckHooks);
        }
      } else {
        var viewHooks = tView.viewHooks;

        if (viewHooks !== null) {
          executeInitAndCheckHooks(lView, viewHooks, 2
          /* AfterViewInitHooksToBeRun */
          );
        }

        incrementInitPhaseFlags(lView, 2
        /* AfterViewInitHooksToBeRun */
        );
      }
    }

    if (tView.firstUpdatePass === true) {
      // We need to make sure that we only flip the flag on successful `refreshView` only
      // Don't do this in `finally` block.
      // If we did this in `finally` block then an exception could block the execution of styling
      // instructions which in turn would be unable to insert themselves into the styling linked
      // list. The result of this would be that if the exception would not be throw on subsequent CD
      // the styling would be unable to process it data and reflect to the DOM.
      tView.firstUpdatePass = false;
    } // Do not reset the dirty state when running in check no changes mode. We don't want components
    // to behave differently depending on whether check no changes is enabled or not. For example:
    // Marking an OnPush component as dirty from within the `ngAfterViewInit` hook in order to
    // refresh a `NgClass` binding should work. If we would reset the dirty state in the check
    // no changes cycle, the component would be not be dirty for the next update pass. This would
    // be different in production mode where the component dirty state is not reset.


    if (!checkNoChangesMode) {
      lView[FLAGS] &= ~(64
      /* Dirty */
      | 8
      /* FirstLViewPass */
      );
    }

    if (lView[FLAGS] & 1024
    /* RefreshTransplantedView */
    ) {
        lView[FLAGS] &= ~1024
        /* RefreshTransplantedView */
        ;
        updateTransplantedViewCount(lView[PARENT], -1);
      }
  } finally {
    leaveView();
  }
}

function renderComponentOrTemplate(tView, lView, templateFn, context) {
  var rendererFactory = lView[RENDERER_FACTORY];
  var normalExecutionPath = !getCheckNoChangesMode();
  var creationModeIsActive = isCreationMode(lView);

  try {
    if (normalExecutionPath && !creationModeIsActive && rendererFactory.begin) {
      rendererFactory.begin();
    }

    if (creationModeIsActive) {
      renderView(tView, lView, context);
    }

    refreshView(tView, lView, templateFn, context);
  } finally {
    if (normalExecutionPath && !creationModeIsActive && rendererFactory.end) {
      rendererFactory.end();
    }
  }
}

function executeTemplate(tView, lView, templateFn, rf, context) {
  var prevSelectedIndex = getSelectedIndex();

  try {
    setSelectedIndex(-1);

    if (rf & 2
    /* Update */
    && lView.length > HEADER_OFFSET) {
      // When we're updating, inherently select 0 so we don't
      // have to generate that instruction for most update blocks.
      selectIndexInternal(tView, lView, 0, getCheckNoChangesMode());
    }

    templateFn(rf, context);
  } finally {
    setSelectedIndex(prevSelectedIndex);
  }
} //////////////////////////
//// Element
//////////////////////////


function executeContentQueries(tView, tNode, lView) {
  if (isContentQueryHost(tNode)) {
    var start = tNode.directiveStart;
    var end = tNode.directiveEnd;

    for (var directiveIndex = start; directiveIndex < end; directiveIndex++) {
      var def = tView.data[directiveIndex];

      if (def.contentQueries) {
        def.contentQueries(1
        /* Create */
        , lView[directiveIndex], directiveIndex);
      }
    }
  }
}
/**
 * Creates directive instances.
 */


function createDirectivesInstances(tView, lView, tNode) {
  if (!getBindingsEnabled()) return;
  instantiateAllDirectives(tView, lView, tNode, getNativeByTNode(tNode, lView));

  if ((tNode.flags & 128
  /* hasHostBindings */
  ) === 128
  /* hasHostBindings */
  ) {
      invokeDirectivesHostBindings(tView, lView, tNode);
    }
}
/**
 * Takes a list of local names and indices and pushes the resolved local variable values
 * to LView in the same order as they are loaded in the template with load().
 */


function saveResolvedLocalsInData(viewData, tNode) {
  var localRefExtractor = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : getNativeByTNode;
  var localNames = tNode.localNames;

  if (localNames !== null) {
    var localIndex = tNode.index + 1;

    for (var i = 0; i < localNames.length; i += 2) {
      var index = localNames[i + 1];
      var value = index === -1 ? localRefExtractor(tNode, viewData) : viewData[index];
      viewData[localIndex++] = value;
    }
  }
}
/**
 * Gets TView from a template function or creates a new TView
 * if it doesn't already exist.
 *
 * @param def ComponentDef
 * @returns TView
 */


function getOrCreateTComponentView(def) {
  var tView = def.tView; // Create a TView if there isn't one, or recreate it if the first create pass didn't
  // complete successfully since we can't know for sure whether it's in a usable shape.

  if (tView === null || tView.incompleteFirstPass) {
    // Declaration node here is null since this function is called when we dynamically create a
    // component and hence there is no declaration.
    var declTNode = null;
    return def.tView = createTView(1
    /* Component */
    , declTNode, def.template, def.decls, def.vars, def.directiveDefs, def.pipeDefs, def.viewQuery, def.schemas, def.consts);
  }

  return tView;
}
/**
 * Creates a TView instance
 *
 * @param type Type of `TView`.
 * @param declTNode Declaration location of this `TView`.
 * @param templateFn Template function
 * @param decls The number of nodes, local refs, and pipes in this template
 * @param directives Registry of directives for this view
 * @param pipes Registry of pipes for this view
 * @param viewQuery View queries for this view
 * @param schemas Schemas for this view
 * @param consts Constants for this view
 */


function createTView(type, declTNode, templateFn, decls, vars, directives, pipes, viewQuery, schemas, constsOrFactory) {
  ngDevMode && ngDevMode.tView++;
  var bindingStartIndex = HEADER_OFFSET + decls; // This length does not yet contain host bindings from child directives because at this point,
  // we don't know which directives are active on this template. As soon as a directive is matched
  // that has a host binding, we will update the blueprint with that def's hostVars count.

  var initialViewLength = bindingStartIndex + vars;
  var blueprint = createViewBlueprint(bindingStartIndex, initialViewLength);
  var consts = typeof constsOrFactory === 'function' ? constsOrFactory() : constsOrFactory;
  var tView = blueprint[TVIEW] = ngDevMode ? new TViewConstructor(type, blueprint, // blueprint: LView,
  templateFn, // template: ComponentTemplate<{}>|null,
  null, // queries: TQueries|null
  viewQuery, // viewQuery: ViewQueriesFunction<{}>|null,
  declTNode, // declTNode: TNode|null,
  cloneToTViewData(blueprint).fill(null, bindingStartIndex), // data: TData,
  bindingStartIndex, // bindingStartIndex: number,
  initialViewLength, // expandoStartIndex: number,
  null, // expandoInstructions: ExpandoInstructions|null,
  true, // firstCreatePass: boolean,
  true, // firstUpdatePass: boolean,
  false, // staticViewQueries: boolean,
  false, // staticContentQueries: boolean,
  null, // preOrderHooks: HookData|null,
  null, // preOrderCheckHooks: HookData|null,
  null, // contentHooks: HookData|null,
  null, // contentCheckHooks: HookData|null,
  null, // viewHooks: HookData|null,
  null, // viewCheckHooks: HookData|null,
  null, // destroyHooks: DestroyHookData|null,
  null, // cleanup: any[]|null,
  null, // contentQueries: number[]|null,
  null, // components: number[]|null,
  typeof directives === 'function' ? directives() : directives, // directiveRegistry: DirectiveDefList|null,
  typeof pipes === 'function' ? pipes() : pipes, // pipeRegistry: PipeDefList|null,
  null, // firstChild: TNode|null,
  schemas, // schemas: SchemaMetadata[]|null,
  consts, // consts: TConstants|null
  false, // incompleteFirstPass: boolean
  decls, // ngDevMode only: decls
  vars) : {
    type: type,
    blueprint: blueprint,
    template: templateFn,
    queries: null,
    viewQuery: viewQuery,
    declTNode: declTNode,
    data: blueprint.slice().fill(null, bindingStartIndex),
    bindingStartIndex: bindingStartIndex,
    expandoStartIndex: initialViewLength,
    expandoInstructions: null,
    firstCreatePass: true,
    firstUpdatePass: true,
    staticViewQueries: false,
    staticContentQueries: false,
    preOrderHooks: null,
    preOrderCheckHooks: null,
    contentHooks: null,
    contentCheckHooks: null,
    viewHooks: null,
    viewCheckHooks: null,
    destroyHooks: null,
    cleanup: null,
    contentQueries: null,
    components: null,
    directiveRegistry: typeof directives === 'function' ? directives() : directives,
    pipeRegistry: typeof pipes === 'function' ? pipes() : pipes,
    firstChild: null,
    schemas: schemas,
    consts: consts,
    incompleteFirstPass: false
  };

  if (ngDevMode) {
    // For performance reasons it is important that the tView retains the same shape during runtime.
    // (To make sure that all of the code is monomorphic.) For this reason we seal the object to
    // prevent class transitions.
    Object.seal(tView);
  }

  return tView;
}

function createViewBlueprint(bindingStartIndex, initialViewLength) {
  var blueprint = ngDevMode ? new LViewBlueprint() : [];

  for (var i = 0; i < initialViewLength; i++) {
    blueprint.push(i < bindingStartIndex ? null : NO_CHANGE);
  }

  return blueprint;
}

function createError(text, token) {
  return new Error("Renderer: ".concat(text, " [").concat(stringifyForError(token), "]"));
}

function assertHostNodeExists(rElement, elementOrSelector) {
  if (!rElement) {
    if (typeof elementOrSelector === 'string') {
      throw createError('Host node with selector not found:', elementOrSelector);
    } else {
      throw createError('Host node is required:', elementOrSelector);
    }
  }
}
/**
 * Locates the host native element, used for bootstrapping existing nodes into rendering pipeline.
 *
 * @param rendererFactory Factory function to create renderer instance.
 * @param elementOrSelector Render element or CSS selector to locate the element.
 * @param encapsulation View Encapsulation defined for component that requests host element.
 */


function locateHostElement(renderer, elementOrSelector, encapsulation) {
  if (isProceduralRenderer(renderer)) {
    // When using native Shadow DOM, do not clear host element to allow native slot projection
    var preserveContent = encapsulation === ViewEncapsulation$1.ShadowDom;
    return renderer.selectRootElement(elementOrSelector, preserveContent);
  }

  var rElement = typeof elementOrSelector === 'string' ? renderer.querySelector(elementOrSelector) : elementOrSelector;
  ngDevMode && assertHostNodeExists(rElement, elementOrSelector); // Always clear host element's content when Renderer3 is in use. For procedural renderer case we
  // make it depend on whether ShadowDom encapsulation is used (in which case the content should be
  // preserved to allow native slot projection). ShadowDom encapsulation requires procedural
  // renderer, and procedural renderer case is handled above.

  rElement.textContent = '';
  return rElement;
}
/**
 * Saves context for this cleanup function in LView.cleanupInstances.
 *
 * On the first template pass, saves in TView:
 * - Cleanup function
 * - Index of context we just saved in LView.cleanupInstances
 */


function storeCleanupWithContext(tView, lView, context, cleanupFn) {
  var lCleanup = getLCleanup(lView);
  lCleanup.push(context);

  if (tView.firstCreatePass) {
    getTViewCleanup(tView).push(cleanupFn, lCleanup.length - 1);
  }
}

function createTNode(tView, tParent, type, adjustedIndex, tagName, attrs) {
  ngDevMode && ngDevMode.tNode++;
  var injectorIndex = tParent ? tParent.injectorIndex : -1;
  var tNode = ngDevMode ? new TNodeDebug(tView, // tView_: TView
  type, // type: TNodeType
  adjustedIndex, // index: number
  injectorIndex, // injectorIndex: number
  -1, // directiveStart: number
  -1, // directiveEnd: number
  -1, // directiveStylingLast: number
  null, // propertyBindings: number[]|null
  0, // flags: TNodeFlags
  0, // providerIndexes: TNodeProviderIndexes
  tagName, // tagName: string|null
  attrs, // attrs: (string|AttributeMarker|(string|SelectorFlags)[])[]|null
  null, // mergedAttrs
  null, // localNames: (string|number)[]|null
  undefined, // initialInputs: (string[]|null)[]|null|undefined
  null, // inputs: PropertyAliases|null
  null, // outputs: PropertyAliases|null
  null, // tViews: ITView|ITView[]|null
  null, // next: ITNode|null
  null, // projectionNext: ITNode|null
  null, // child: ITNode|null
  tParent, // parent: TElementNode|TContainerNode|null
  null, // projection: number|(ITNode|RNode[])[]|null
  null, // styles: string|null
  null, // stylesWithoutHost: string|null
  undefined, // residualStyles: string|null
  null, // classes: string|null
  null, // classesWithoutHost: string|null
  undefined, // residualClasses: string|null
  0, // classBindings: TStylingRange;
  0) : {
    type: type,
    index: adjustedIndex,
    injectorIndex: injectorIndex,
    directiveStart: -1,
    directiveEnd: -1,
    directiveStylingLast: -1,
    propertyBindings: null,
    flags: 0,
    providerIndexes: 0,
    tagName: tagName,
    attrs: attrs,
    mergedAttrs: null,
    localNames: null,
    initialInputs: undefined,
    inputs: null,
    outputs: null,
    tViews: null,
    next: null,
    projectionNext: null,
    child: null,
    parent: tParent,
    projection: null,
    styles: null,
    stylesWithoutHost: null,
    residualStyles: undefined,
    classes: null,
    classesWithoutHost: null,
    residualClasses: undefined,
    classBindings: 0,
    styleBindings: 0
  };

  if (ngDevMode) {
    // For performance reasons it is important that the tNode retains the same shape during runtime.
    // (To make sure that all of the code is monomorphic.) For this reason we seal the object to
    // prevent class transitions.
    Object.seal(tNode);
  }

  return tNode;
}

function generatePropertyAliases(inputAliasMap, directiveDefIdx, propStore) {
  for (var publicName in inputAliasMap) {
    if (inputAliasMap.hasOwnProperty(publicName)) {
      propStore = propStore === null ? {} : propStore;
      var internalName = inputAliasMap[publicName];

      if (propStore.hasOwnProperty(publicName)) {
        propStore[publicName].push(directiveDefIdx, internalName);
      } else {
        propStore[publicName] = [directiveDefIdx, internalName];
      }
    }
  }

  return propStore;
}
/**
 * Initializes data structures required to work with directive outputs and outputs.
 * Initialization is done for all directives matched on a given TNode.
 */


function initializeInputAndOutputAliases(tView, tNode) {
  ngDevMode && assertFirstCreatePass(tView);
  var start = tNode.directiveStart;
  var end = tNode.directiveEnd;
  var defs = tView.data;
  var tNodeAttrs = tNode.attrs;
  var inputsFromAttrs = ngDevMode ? new TNodeInitialInputs() : [];
  var inputsStore = null;
  var outputsStore = null;

  for (var i = start; i < end; i++) {
    var _directiveDef3 = defs[i];
    var directiveInputs = _directiveDef3.inputs; // Do not use unbound attributes as inputs to structural directives, since structural
    // directive inputs can only be set using microsyntax (e.g. `<div *dir="exp">`).
    // TODO(FW-1930): microsyntax expressions may also contain unbound/static attributes, which
    // should be set for inline templates.

    var initialInputs = tNodeAttrs !== null && !isInlineTemplate(tNode) ? generateInitialInputs(directiveInputs, tNodeAttrs) : null;
    inputsFromAttrs.push(initialInputs);
    inputsStore = generatePropertyAliases(directiveInputs, i, inputsStore);
    outputsStore = generatePropertyAliases(_directiveDef3.outputs, i, outputsStore);
  }

  if (inputsStore !== null) {
    if (inputsStore.hasOwnProperty('class')) {
      tNode.flags |= 16
      /* hasClassInput */
      ;
    }

    if (inputsStore.hasOwnProperty('style')) {
      tNode.flags |= 32
      /* hasStyleInput */
      ;
    }
  }

  tNode.initialInputs = inputsFromAttrs;
  tNode.inputs = inputsStore;
  tNode.outputs = outputsStore;
}
/**
 * Mapping between attributes names that don't correspond to their element property names.
 *
 * Performance note: this function is written as a series of if checks (instead of, say, a property
 * object lookup) for performance reasons - the series of `if` checks seems to be the fastest way of
 * mapping property names. Do NOT change without benchmarking.
 *
 * Note: this mapping has to be kept in sync with the equally named mapping in the template
 * type-checking machinery of ngtsc.
 */


function mapPropName(name) {
  if (name === 'class') return 'className';
  if (name === 'for') return 'htmlFor';
  if (name === 'formaction') return 'formAction';
  if (name === 'innerHtml') return 'innerHTML';
  if (name === 'readonly') return 'readOnly';
  if (name === 'tabindex') return 'tabIndex';
  return name;
}

function elementPropertyInternal(tView, tNode, lView, propName, value, renderer, sanitizer, nativeOnly) {
  ngDevMode && assertNotSame(value, NO_CHANGE, 'Incoming value should never be NO_CHANGE.');
  var element = getNativeByTNode(tNode, lView);
  var inputData = tNode.inputs;
  var dataValue;

  if (!nativeOnly && inputData != null && (dataValue = inputData[propName])) {
    setInputsForProperty(tView, lView, dataValue, propName, value);
    if (isComponentHost(tNode)) markDirtyIfOnPush(lView, tNode.index);

    if (ngDevMode) {
      setNgReflectProperties(lView, element, tNode.type, dataValue, value);
    }
  } else if (tNode.type === 2
  /* Element */
  ) {
      propName = mapPropName(propName);

      if (ngDevMode) {
        validateAgainstEventProperties(propName);

        if (!validateProperty(tView, element, propName, tNode)) {
          // Return here since we only log warnings for unknown properties.
          logUnknownPropertyError(propName, tNode);
          return;
        }

        ngDevMode.rendererSetProperty++;
      } // It is assumed that the sanitizer is only added when the compiler determines that the
      // property is risky, so sanitization can be done without further checks.


      value = sanitizer != null ? sanitizer(value, tNode.tagName || '', propName) : value;

      if (isProceduralRenderer(renderer)) {
        renderer.setProperty(element, propName, value);
      } else if (!isAnimationProp(propName)) {
        element.setProperty ? element.setProperty(propName, value) : element[propName] = value;
      }
    } else if (tNode.type === 0
  /* Container */
  || tNode.type === 3
  /* ElementContainer */
  ) {
      // If the node is a container and the property didn't
      // match any of the inputs or schemas we should throw.
      if (ngDevMode && !matchingSchemas(tView, tNode.tagName)) {
        logUnknownPropertyError(propName, tNode);
      }
    }
}
/** If node is an OnPush component, marks its LView dirty. */


function markDirtyIfOnPush(lView, viewIndex) {
  ngDevMode && assertLView(lView);
  var childComponentLView = getComponentLViewByIndex(viewIndex, lView);

  if (!(childComponentLView[FLAGS] & 16
  /* CheckAlways */
  )) {
    childComponentLView[FLAGS] |= 64
    /* Dirty */
    ;
  }
}

function setNgReflectProperty(lView, element, type, attrName, value) {
  var renderer = lView[RENDERER];
  attrName = normalizeDebugBindingName(attrName);
  var debugValue = normalizeDebugBindingValue(value);

  if (type === 2
  /* Element */
  ) {
      if (value == null) {
        isProceduralRenderer(renderer) ? renderer.removeAttribute(element, attrName) : element.removeAttribute(attrName);
      } else {
        isProceduralRenderer(renderer) ? renderer.setAttribute(element, attrName, debugValue) : element.setAttribute(attrName, debugValue);
      }
    } else {
    var textContent = "bindings=".concat(JSON.stringify(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_5__["default"])({}, attrName, debugValue), null, 2));

    if (isProceduralRenderer(renderer)) {
      renderer.setValue(element, textContent);
    } else {
      element.textContent = textContent;
    }
  }
}

function setNgReflectProperties(lView, element, type, dataValue, value) {
  if (type === 2
  /* Element */
  || type === 0
  /* Container */
  ) {
      /**
       * dataValue is an array containing runtime input or output names for the directives:
       * i+0: directive instance index
       * i+1: privateName
       *
       * e.g. [0, 'change', 'change-minified']
       * we want to set the reflected property with the privateName: dataValue[i+1]
       */
      for (var i = 0; i < dataValue.length; i += 2) {
        setNgReflectProperty(lView, element, type, dataValue[i + 1], value);
      }
    }
}

function validateProperty(tView, element, propName, tNode) {
  // If `schemas` is set to `null`, that's an indication that this Component was compiled in AOT
  // mode where this check happens at compile time. In JIT mode, `schemas` is always present and
  // defined as an array (as an empty array in case `schemas` field is not defined) and we should
  // execute the check below.
  if (tView.schemas === null) return true; // The property is considered valid if the element matches the schema, it exists on the element
  // or it is synthetic, and we are in a browser context (web worker nodes should be skipped).

  if (matchingSchemas(tView, tNode.tagName) || propName in element || isAnimationProp(propName)) {
    return true;
  } // Note: `typeof Node` returns 'function' in most browsers, but on IE it is 'object' so we
  // need to account for both here, while being careful for `typeof null` also returning 'object'.


  return typeof Node === 'undefined' || Node === null || !(element instanceof Node);
}

function matchingSchemas(tView, tagName) {
  var schemas = tView.schemas;

  if (schemas !== null) {
    for (var i = 0; i < schemas.length; i++) {
      var schema = schemas[i];

      if (schema === NO_ERRORS_SCHEMA || schema === CUSTOM_ELEMENTS_SCHEMA && tagName && tagName.indexOf('-') > -1) {
        return true;
      }
    }
  }

  return false;
}
/**
 * Logs an error that a property is not supported on an element.
 * @param propName Name of the invalid property.
 * @param tNode Node on which we encountered the property.
 */


function logUnknownPropertyError(propName, tNode) {
  console.error("Can't bind to '".concat(propName, "' since it isn't a known property of '").concat(tNode.tagName, "'."));
}
/**
 * Instantiate a root component.
 */


function instantiateRootComponent(tView, lView, def) {
  var rootTNode = getCurrentTNode();

  if (tView.firstCreatePass) {
    if (def.providersResolver) def.providersResolver(def);
    generateExpandoInstructionBlock(tView, rootTNode, 1);
    baseResolveDirective(tView, lView, def);
  }

  var directive = getNodeInjectable(lView, tView, lView.length - 1, rootTNode);
  attachPatchData(directive, lView);
  var native = getNativeByTNode(rootTNode, lView);

  if (native) {
    attachPatchData(native, lView);
  }

  return directive;
}
/**
 * Resolve the matched directives on a node.
 */


function resolveDirectives(tView, lView, tNode, localRefs) {
  // Please make sure to have explicit type for `exportsMap`. Inferred type triggers bug in
  // tsickle.
  ngDevMode && assertFirstCreatePass(tView);
  var hasDirectives = false;

  if (getBindingsEnabled()) {
    var directiveDefs = findDirectiveDefMatches(tView, lView, tNode);
    var exportsMap = localRefs === null ? null : {
      '': -1
    };

    if (directiveDefs !== null) {
      var totalDirectiveHostVars = 0;
      hasDirectives = true;
      initTNodeFlags(tNode, tView.data.length, directiveDefs.length); // When the same token is provided by several directives on the same node, some rules apply in
      // the viewEngine:
      // - viewProviders have priority over providers
      // - the last directive in NgModule.declarations has priority over the previous one
      // So to match these rules, the order in which providers are added in the arrays is very
      // important.

      for (var i = 0; i < directiveDefs.length; i++) {
        var def = directiveDefs[i];
        if (def.providersResolver) def.providersResolver(def);
      }

      generateExpandoInstructionBlock(tView, tNode, directiveDefs.length);
      var preOrderHooksFound = false;
      var preOrderCheckHooksFound = false;

      for (var _i3 = 0; _i3 < directiveDefs.length; _i3++) {
        var _def2 = directiveDefs[_i3]; // Merge the attrs in the order of matches. This assumes that the first directive is the
        // component itself, so that the component has the least priority.

        tNode.mergedAttrs = mergeHostAttrs(tNode.mergedAttrs, _def2.hostAttrs);
        baseResolveDirective(tView, lView, _def2);
        saveNameToExportMap(tView.data.length - 1, _def2, exportsMap);
        if (_def2.contentQueries !== null) tNode.flags |= 8
        /* hasContentQuery */
        ;
        if (_def2.hostBindings !== null || _def2.hostAttrs !== null || _def2.hostVars !== 0) tNode.flags |= 128
        /* hasHostBindings */
        ;
        var lifeCycleHooks = _def2.type.prototype; // Only push a node index into the preOrderHooks array if this is the first
        // pre-order hook found on this node.

        if (!preOrderHooksFound && (lifeCycleHooks.ngOnChanges || lifeCycleHooks.ngOnInit || lifeCycleHooks.ngDoCheck)) {
          // We will push the actual hook function into this array later during dir instantiation.
          // We cannot do it now because we must ensure hooks are registered in the same
          // order that directives are created (i.e. injection order).
          (tView.preOrderHooks || (tView.preOrderHooks = [])).push(tNode.index - HEADER_OFFSET);
          preOrderHooksFound = true;
        }

        if (!preOrderCheckHooksFound && (lifeCycleHooks.ngOnChanges || lifeCycleHooks.ngDoCheck)) {
          (tView.preOrderCheckHooks || (tView.preOrderCheckHooks = [])).push(tNode.index - HEADER_OFFSET);
          preOrderCheckHooksFound = true;
        }

        addHostBindingsToExpandoInstructions(tView, _def2);
        totalDirectiveHostVars += _def2.hostVars;
      }

      initializeInputAndOutputAliases(tView, tNode);
      growHostVarsSpace(tView, lView, totalDirectiveHostVars);
    }

    if (exportsMap) cacheMatchingLocalNames(tNode, localRefs, exportsMap);
  } // Merge the template attrs last so that they have the highest priority.


  tNode.mergedAttrs = mergeHostAttrs(tNode.mergedAttrs, tNode.attrs);
  return hasDirectives;
}
/**
 * Add `hostBindings` to the `TView.expandoInstructions`.
 *
 * @param tView `TView` to which the `hostBindings` should be added.
 * @param def `ComponentDef`/`DirectiveDef`, which contains the `hostVars`/`hostBindings` to add.
 */


function addHostBindingsToExpandoInstructions(tView, def) {
  ngDevMode && assertFirstCreatePass(tView);
  var expando = tView.expandoInstructions; // TODO(misko): PERF we are adding `hostBindings` even if there is nothing to add! This is
  // suboptimal for performance. `def.hostBindings` may be null,
  // but we still need to push null to the array as a placeholder
  // to ensure the directive counter is incremented (so host
  // binding functions always line up with the corrective directive).
  // This is suboptimal for performance. See `currentDirectiveIndex`
  //  comment in `setHostBindingsByExecutingExpandoInstructions` for more
  // details.  expando.push(def.hostBindings);

  expando.push(def.hostBindings);
  var hostVars = def.hostVars;

  if (hostVars !== 0) {
    expando.push(def.hostVars);
  }
}
/**
 * Grow the `LView`, blueprint and `TView.data` to accommodate the `hostBindings`.
 *
 * To support locality we don't know ahead of time how many `hostVars` of the containing directives
 * we need to allocate. For this reason we allow growing these data structures as we discover more
 * directives to accommodate them.
 *
 * @param tView `TView` which needs to be grown.
 * @param lView `LView` which needs to be grown.
 * @param count Size by which we need to grow the data structures.
 */


function growHostVarsSpace(tView, lView, count) {
  ngDevMode && assertFirstCreatePass(tView);
  ngDevMode && assertSame(tView, lView[TVIEW], '`LView` must be associated with `TView`!');

  for (var i = 0; i < count; i++) {
    lView.push(NO_CHANGE);
    tView.blueprint.push(NO_CHANGE);
    tView.data.push(null);
  }
}
/**
 * Instantiate all the directives that were previously resolved on the current node.
 */


function instantiateAllDirectives(tView, lView, tNode, native) {
  var start = tNode.directiveStart;
  var end = tNode.directiveEnd;

  if (!tView.firstCreatePass) {
    getOrCreateNodeInjectorForNode(tNode, lView);
  }

  attachPatchData(native, lView);
  var initialInputs = tNode.initialInputs;

  for (var i = start; i < end; i++) {
    var def = tView.data[i];
    var isComponent = isComponentDef(def);

    if (isComponent) {
      ngDevMode && assertNodeOfPossibleTypes(tNode, [2
      /* Element */
      ]);
      addComponentLogic(lView, tNode, def);
    }

    var directive = getNodeInjectable(lView, tView, i, tNode);
    attachPatchData(directive, lView);

    if (initialInputs !== null) {
      setInputsFromAttrs(lView, i - start, directive, def, tNode, initialInputs);
    }

    if (isComponent) {
      var componentView = getComponentLViewByIndex(tNode.index, lView);
      componentView[CONTEXT] = directive;
    }
  }
}

function invokeDirectivesHostBindings(tView, lView, tNode) {
  var start = tNode.directiveStart;
  var end = tNode.directiveEnd;
  var expando = tView.expandoInstructions;
  var firstCreatePass = tView.firstCreatePass;
  var elementIndex = tNode.index - HEADER_OFFSET;
  var currentDirectiveIndex = getCurrentDirectiveIndex();

  try {
    setSelectedIndex(elementIndex);

    for (var dirIndex = start; dirIndex < end; dirIndex++) {
      var def = tView.data[dirIndex];
      var directive = lView[dirIndex];
      setCurrentDirectiveIndex(dirIndex);

      if (def.hostBindings !== null || def.hostVars !== 0 || def.hostAttrs !== null) {
        invokeHostBindingsInCreationMode(def, directive);
      } else if (firstCreatePass) {
        expando.push(null);
      }
    }
  } finally {
    setSelectedIndex(-1);
    setCurrentDirectiveIndex(currentDirectiveIndex);
  }
}
/**
 * Invoke the host bindings in creation mode.
 *
 * @param def `DirectiveDef` which may contain the `hostBindings` function.
 * @param directive Instance of directive.
 */


function invokeHostBindingsInCreationMode(def, directive) {
  if (def.hostBindings !== null) {
    def.hostBindings(1
    /* Create */
    , directive);
  }
}
/**
 * Generates a new block in TView.expandoInstructions for this node.
 *
 * Each expando block starts with the element index (turned negative so we can distinguish
 * it from the hostVar count) and the directive count. See more in VIEW_DATA.md.
 */


function generateExpandoInstructionBlock(tView, tNode, directiveCount) {
  ngDevMode && assertEqual(tView.firstCreatePass, true, 'Expando block should only be generated on first create pass.'); // Important: In JS `-x` and `0-x` is not the same! If `x===0` then `-x` will produce `-0` which
  // requires non standard math arithmetic and it can prevent VM optimizations.
  // `0-0` will always produce `0` and will not cause a potential deoptimization in VM.

  var elementIndex = HEADER_OFFSET - tNode.index;
  var providerStartIndex = tNode.providerIndexes & 1048575
  /* ProvidersStartIndexMask */
  ;
  var providerCount = tView.data.length - providerStartIndex;
  (tView.expandoInstructions || (tView.expandoInstructions = [])).push(elementIndex, providerCount, directiveCount);
}
/**
 * Matches the current node against all available selectors.
 * If a component is matched (at most one), it is returned in first position in the array.
 */


function findDirectiveDefMatches(tView, viewData, tNode) {
  ngDevMode && assertFirstCreatePass(tView);
  ngDevMode && assertNodeOfPossibleTypes(tNode, [2
  /* Element */
  , 3
  /* ElementContainer */
  , 0
  /* Container */
  ]);
  var registry = tView.directiveRegistry;
  var matches = null;

  if (registry) {
    for (var i = 0; i < registry.length; i++) {
      var def = registry[i];

      if (isNodeMatchingSelectorList(tNode, def.selectors,
      /* isProjectionMode */
      false)) {
        matches || (matches = ngDevMode ? new MatchesArray() : []);
        diPublicInInjector(getOrCreateNodeInjectorForNode(tNode, viewData), tView, def.type);

        if (isComponentDef(def)) {
          if (ngDevMode) {
            assertNodeOfPossibleTypes(tNode, [2
            /* Element */
            ], "\"".concat(tNode.tagName, "\" tags cannot be used as component hosts. ") + "Please use a different tag to activate the ".concat(stringify(def.type), " component."));
            if (tNode.flags & 2
            /* isComponentHost */
            ) throwMultipleComponentError(tNode);
          }

          markAsComponentHost(tView, tNode); // The component is always stored first with directives after.

          matches.unshift(def);
        } else {
          matches.push(def);
        }
      }
    }
  }

  return matches;
}
/**
 * Marks a given TNode as a component's host. This consists of:
 * - setting appropriate TNode flags;
 * - storing index of component's host element so it will be queued for view refresh during CD.
 */


function markAsComponentHost(tView, hostTNode) {
  ngDevMode && assertFirstCreatePass(tView);
  hostTNode.flags |= 2
  /* isComponentHost */
  ;
  (tView.components || (tView.components = ngDevMode ? new TViewComponents() : [])).push(hostTNode.index);
}
/** Caches local names and their matching directive indices for query and template lookups. */


function cacheMatchingLocalNames(tNode, localRefs, exportsMap) {
  if (localRefs) {
    var localNames = tNode.localNames = ngDevMode ? new TNodeLocalNames() : []; // Local names must be stored in tNode in the same order that localRefs are defined
    // in the template to ensure the data is loaded in the same slots as their refs
    // in the template (for template queries).

    for (var i = 0; i < localRefs.length; i += 2) {
      var index = exportsMap[localRefs[i + 1]];
      if (index == null) throw new Error("Export of name '".concat(localRefs[i + 1], "' not found!"));
      localNames.push(localRefs[i], index);
    }
  }
}
/**
 * Builds up an export map as directives are created, so local refs can be quickly mapped
 * to their directive instances.
 */


function saveNameToExportMap(index, def, exportsMap) {
  if (exportsMap) {
    if (def.exportAs) {
      for (var i = 0; i < def.exportAs.length; i++) {
        exportsMap[def.exportAs[i]] = index;
      }
    }

    if (isComponentDef(def)) exportsMap[''] = index;
  }
}
/**
 * Initializes the flags on the current node, setting all indices to the initial index,
 * the directive count to 0, and adding the isComponent flag.
 * @param index the initial index
 */


function initTNodeFlags(tNode, index, numberOfDirectives) {
  ngDevMode && assertNotEqual(numberOfDirectives, tNode.directiveEnd - tNode.directiveStart, 'Reached the max number of directives');
  tNode.flags |= 1
  /* isDirectiveHost */
  ; // When the first directive is created on a node, save the index

  tNode.directiveStart = index;
  tNode.directiveEnd = index + numberOfDirectives;
  tNode.providerIndexes = index;
}

function baseResolveDirective(tView, viewData, def) {
  tView.data.push(def);
  var directiveFactory = def.factory || (def.factory = getFactoryDef(def.type, true));
  var nodeInjectorFactory = new NodeInjectorFactory(directiveFactory, isComponentDef(def), null);
  tView.blueprint.push(nodeInjectorFactory);
  viewData.push(nodeInjectorFactory);
}

function addComponentLogic(lView, hostTNode, def) {
  var native = getNativeByTNode(hostTNode, lView);
  var tView = getOrCreateTComponentView(def); // Only component views should be added to the view tree directly. Embedded views are
  // accessed through their containers because they may be removed / re-added later.

  var rendererFactory = lView[RENDERER_FACTORY];
  var componentView = addToViewTree(lView, createLView(lView, tView, null, def.onPush ? 64
  /* Dirty */
  : 16
  /* CheckAlways */
  , native, hostTNode, rendererFactory, rendererFactory.createRenderer(native, def), null, null)); // Component view will always be created before any injected LContainers,
  // so this is a regular element, wrap it with the component view

  lView[hostTNode.index] = componentView;
}

function elementAttributeInternal(tNode, lView, name, value, sanitizer, namespace) {
  if (ngDevMode) {
    assertNotSame(value, NO_CHANGE, 'Incoming value should never be NO_CHANGE.');
    validateAgainstEventAttributes(name);
    assertNodeNotOfTypes(tNode, [0
    /* Container */
    , 3
    /* ElementContainer */
    ], "Attempted to set attribute `".concat(name, "` on a container node. ") + "Host bindings are not valid on ng-container or ng-template.");
  }

  var element = getNativeByTNode(tNode, lView);
  var renderer = lView[RENDERER];

  if (value == null) {
    ngDevMode && ngDevMode.rendererRemoveAttribute++;
    isProceduralRenderer(renderer) ? renderer.removeAttribute(element, name, namespace) : element.removeAttribute(name);
  } else {
    ngDevMode && ngDevMode.rendererSetAttribute++;
    var strValue = sanitizer == null ? renderStringify(value) : sanitizer(value, tNode.tagName || '', name);

    if (isProceduralRenderer(renderer)) {
      renderer.setAttribute(element, name, strValue, namespace);
    } else {
      namespace ? element.setAttributeNS(namespace, name, strValue) : element.setAttribute(name, strValue);
    }
  }
}
/**
 * Sets initial input properties on directive instances from attribute data
 *
 * @param lView Current LView that is being processed.
 * @param directiveIndex Index of the directive in directives array
 * @param instance Instance of the directive on which to set the initial inputs
 * @param def The directive def that contains the list of inputs
 * @param tNode The static data for this node
 */


function setInputsFromAttrs(lView, directiveIndex, instance, def, tNode, initialInputData) {
  var initialInputs = initialInputData[directiveIndex];

  if (initialInputs !== null) {
    var setInput = def.setInput;

    for (var i = 0; i < initialInputs.length;) {
      var publicName = initialInputs[i++];
      var privateName = initialInputs[i++];
      var value = initialInputs[i++];

      if (setInput !== null) {
        def.setInput(instance, value, publicName, privateName);
      } else {
        instance[privateName] = value;
      }

      if (ngDevMode) {
        var nativeElement = getNativeByTNode(tNode, lView);
        setNgReflectProperty(lView, nativeElement, tNode.type, privateName, value);
      }
    }
  }
}
/**
 * Generates initialInputData for a node and stores it in the template's static storage
 * so subsequent template invocations don't have to recalculate it.
 *
 * initialInputData is an array containing values that need to be set as input properties
 * for directives on this node, but only once on creation. We need this array to support
 * the case where you set an @Input property of a directive using attribute-like syntax.
 * e.g. if you have a `name` @Input, you can set it once like this:
 *
 * <my-component name="Bess"></my-component>
 *
 * @param inputs The list of inputs from the directive def
 * @param attrs The static attrs on this node
 */


function generateInitialInputs(inputs, attrs) {
  var inputsToStore = null;
  var i = 0;

  while (i < attrs.length) {
    var attrName = attrs[i];

    if (attrName === 0
    /* NamespaceURI */
    ) {
        // We do not allow inputs on namespaced attributes.
        i += 4;
        continue;
      } else if (attrName === 5
    /* ProjectAs */
    ) {
        // Skip over the `ngProjectAs` value.
        i += 2;
        continue;
      } // If we hit any other attribute markers, we're done anyway. None of those are valid inputs.


    if (typeof attrName === 'number') break;

    if (inputs.hasOwnProperty(attrName)) {
      if (inputsToStore === null) inputsToStore = [];
      inputsToStore.push(attrName, inputs[attrName], attrs[i + 1]);
    }

    i += 2;
  }

  return inputsToStore;
} //////////////////////////
//// ViewContainer & View
//////////////////////////
// Not sure why I need to do `any` here but TS complains later.


var LContainerArray = (typeof ngDevMode === 'undefined' || ngDevMode) && initNgDevMode() && createNamedArrayType('LContainer');
/**
 * Creates a LContainer, either from a container instruction, or for a ViewContainerRef.
 *
 * @param hostNative The host element for the LContainer
 * @param hostTNode The host TNode for the LContainer
 * @param currentView The parent view of the LContainer
 * @param native The native comment element
 * @param isForViewContainerRef Optional a flag indicating the ViewContainerRef case
 * @returns LContainer
 */

function createLContainer(hostNative, currentView, native, tNode) {
  ngDevMode && assertLView(currentView);
  ngDevMode && !isProceduralRenderer(currentView[RENDERER]) && assertDomNode(native); // https://jsperf.com/array-literal-vs-new-array-really

  var lContainer = new (ngDevMode ? LContainerArray : Array)(hostNative, // host native
  true, // Boolean `true` in this position signifies that this is an `LContainer`
  false, // has transplanted views
  currentView, // parent
  null, // next
  0, // transplanted views to refresh count
  tNode, // t_host
  native, // native,
  null, // view refs
  null);
  ngDevMode && assertEqual(lContainer.length, CONTAINER_HEADER_OFFSET, 'Should allocate correct number of slots for LContainer header.');
  ngDevMode && attachLContainerDebug(lContainer);
  return lContainer;
}
/**
 * Goes over embedded views (ones created through ViewContainerRef APIs) and refreshes
 * them by executing an associated template function.
 */


function refreshEmbeddedViews(lView) {
  for (var lContainer = getFirstLContainer(lView); lContainer !== null; lContainer = getNextLContainer(lContainer)) {
    for (var i = CONTAINER_HEADER_OFFSET; i < lContainer.length; i++) {
      var embeddedLView = lContainer[i];
      var embeddedTView = embeddedLView[TVIEW];
      ngDevMode && assertDefined(embeddedTView, 'TView must be allocated');

      if (viewAttachedToChangeDetector(embeddedLView)) {
        refreshView(embeddedTView, embeddedLView, embeddedTView.template, embeddedLView[CONTEXT]);
      }
    }
  }
}
/**
 * Mark transplanted views as needing to be refreshed at their insertion points.
 *
 * @param lView The `LView` that may have transplanted views.
 */


function markTransplantedViewsForRefresh(lView) {
  for (var lContainer = getFirstLContainer(lView); lContainer !== null; lContainer = getNextLContainer(lContainer)) {
    if (!lContainer[HAS_TRANSPLANTED_VIEWS]) continue;
    var movedViews = lContainer[MOVED_VIEWS];
    ngDevMode && assertDefined(movedViews, 'Transplanted View flags set but missing MOVED_VIEWS');

    for (var i = 0; i < movedViews.length; i++) {
      var movedLView = movedViews[i];
      var insertionLContainer = movedLView[PARENT];
      ngDevMode && assertLContainer(insertionLContainer); // We don't want to increment the counter if the moved LView was already marked for
      // refresh.

      if ((movedLView[FLAGS] & 1024
      /* RefreshTransplantedView */
      ) === 0) {
        updateTransplantedViewCount(insertionLContainer, 1);
      } // Note, it is possible that the `movedViews` is tracking views that are transplanted *and*
      // those that aren't (declaration component === insertion component). In the latter case,
      // it's fine to add the flag, as we will clear it immediately in
      // `refreshEmbeddedViews` for the view currently being refreshed.


      movedLView[FLAGS] |= 1024
      /* RefreshTransplantedView */
      ;
    }
  }
} /////////////

/**
 * Refreshes components by entering the component view and processing its bindings, queries, etc.
 *
 * @param componentHostIdx  Element index in LView[] (adjusted for HEADER_OFFSET)
 */


function refreshComponent(hostLView, componentHostIdx) {
  ngDevMode && assertEqual(isCreationMode(hostLView), false, 'Should be run in update mode');
  var componentView = getComponentLViewByIndex(componentHostIdx, hostLView); // Only attached components that are CheckAlways or OnPush and dirty should be refreshed

  if (viewAttachedToChangeDetector(componentView)) {
    var tView = componentView[TVIEW];

    if (componentView[FLAGS] & (16
    /* CheckAlways */
    | 64
    /* Dirty */
    )) {
      refreshView(tView, componentView, tView.template, componentView[CONTEXT]);
    } else if (componentView[TRANSPLANTED_VIEWS_TO_REFRESH] > 0) {
      // Only attached components that are CheckAlways or OnPush and dirty should be refreshed
      refreshContainsDirtyView(componentView);
    }
  }
}
/**
 * Refreshes all transplanted views marked with `LViewFlags.RefreshTransplantedView` that are
 * children or descendants of the given lView.
 *
 * @param lView The lView which contains descendant transplanted views that need to be refreshed.
 */


function refreshContainsDirtyView(lView) {
  for (var lContainer = getFirstLContainer(lView); lContainer !== null; lContainer = getNextLContainer(lContainer)) {
    for (var i = CONTAINER_HEADER_OFFSET; i < lContainer.length; i++) {
      var embeddedLView = lContainer[i];

      if (embeddedLView[FLAGS] & 1024
      /* RefreshTransplantedView */
      ) {
          var embeddedTView = embeddedLView[TVIEW];
          ngDevMode && assertDefined(embeddedTView, 'TView must be allocated');
          refreshView(embeddedTView, embeddedLView, embeddedTView.template, embeddedLView[CONTEXT]);
        } else if (embeddedLView[TRANSPLANTED_VIEWS_TO_REFRESH] > 0) {
        refreshContainsDirtyView(embeddedLView);
      }
    }
  }

  var tView = lView[TVIEW]; // Refresh child component views.

  var components = tView.components;

  if (components !== null) {
    for (var _i4 = 0; _i4 < components.length; _i4++) {
      var componentView = getComponentLViewByIndex(components[_i4], lView); // Only attached components that are CheckAlways or OnPush and dirty should be refreshed

      if (viewAttachedToChangeDetector(componentView) && componentView[TRANSPLANTED_VIEWS_TO_REFRESH] > 0) {
        refreshContainsDirtyView(componentView);
      }
    }
  }
}

function renderComponent(hostLView, componentHostIdx) {
  ngDevMode && assertEqual(isCreationMode(hostLView), true, 'Should be run in creation mode');
  var componentView = getComponentLViewByIndex(componentHostIdx, hostLView);
  var componentTView = componentView[TVIEW];
  syncViewWithBlueprint(componentTView, componentView);
  renderView(componentTView, componentView, componentView[CONTEXT]);
}
/**
 * Syncs an LView instance with its blueprint if they have gotten out of sync.
 *
 * Typically, blueprints and their view instances should always be in sync, so the loop here
 * will be skipped. However, consider this case of two components side-by-side:
 *
 * App template:
 * ```
 * <comp></comp>
 * <comp></comp>
 * ```
 *
 * The following will happen:
 * 1. App template begins processing.
 * 2. First <comp> is matched as a component and its LView is created.
 * 3. Second <comp> is matched as a component and its LView is created.
 * 4. App template completes processing, so it's time to check child templates.
 * 5. First <comp> template is checked. It has a directive, so its def is pushed to blueprint.
 * 6. Second <comp> template is checked. Its blueprint has been updated by the first
 * <comp> template, but its LView was created before this update, so it is out of sync.
 *
 * Note that embedded views inside ngFor loops will never be out of sync because these views
 * are processed as soon as they are created.
 *
 * @param tView The `TView` that contains the blueprint for syncing
 * @param lView The view to sync
 */


function syncViewWithBlueprint(tView, lView) {
  for (var i = lView.length; i < tView.blueprint.length; i++) {
    lView.push(tView.blueprint[i]);
  }
}
/**
 * Adds LView or LContainer to the end of the current view tree.
 *
 * This structure will be used to traverse through nested views to remove listeners
 * and call onDestroy callbacks.
 *
 * @param lView The view where LView or LContainer should be added
 * @param adjustedHostIndex Index of the view's host node in LView[], adjusted for header
 * @param lViewOrLContainer The LView or LContainer to add to the view tree
 * @returns The state passed in
 */


function addToViewTree(lView, lViewOrLContainer) {
  // TODO(benlesh/misko): This implementation is incorrect, because it always adds the LContainer
  // to the end of the queue, which means if the developer retrieves the LContainers from RNodes out
  // of order, the change detection will run out of order, as the act of retrieving the the
  // LContainer from the RNode is what adds it to the queue.
  if (lView[CHILD_HEAD]) {
    lView[CHILD_TAIL][NEXT] = lViewOrLContainer;
  } else {
    lView[CHILD_HEAD] = lViewOrLContainer;
  }

  lView[CHILD_TAIL] = lViewOrLContainer;
  return lViewOrLContainer;
} ///////////////////////////////
//// Change detection
///////////////////////////////

/**
 * Marks current view and all ancestors dirty.
 *
 * Returns the root view because it is found as a byproduct of marking the view tree
 * dirty, and can be used by methods that consume markViewDirty() to easily schedule
 * change detection. Otherwise, such methods would need to traverse up the view tree
 * an additional time to get the root view and schedule a tick on it.
 *
 * @param lView The starting LView to mark dirty
 * @returns the root LView
 */


function markViewDirty(lView) {
  while (lView) {
    lView[FLAGS] |= 64
    /* Dirty */
    ;
    var parent = getLViewParent(lView); // Stop traversing up as soon as you find a root view that wasn't attached to any container

    if (isRootView(lView) && !parent) {
      return lView;
    } // continue otherwise


    lView = parent;
  }

  return null;
}
/**
 * Used to schedule change detection on the whole application.
 *
 * Unlike `tick`, `scheduleTick` coalesces multiple calls into one change detection run.
 * It is usually called indirectly by calling `markDirty` when the view needs to be
 * re-rendered.
 *
 * Typically `scheduleTick` uses `requestAnimationFrame` to coalesce multiple
 * `scheduleTick` requests. The scheduling function can be overridden in
 * `renderComponent`'s `scheduler` option.
 */


function scheduleTick(rootContext, flags) {
  var nothingScheduled = rootContext.flags === 0
  /* Empty */
  ;
  rootContext.flags |= flags;

  if (nothingScheduled && rootContext.clean == _CLEAN_PROMISE) {
    var res;
    rootContext.clean = new Promise(function (r) {
      return res = r;
    });
    rootContext.scheduler(function () {
      if (rootContext.flags & 1
      /* DetectChanges */
      ) {
          rootContext.flags &= ~1
          /* DetectChanges */
          ;
          tickRootContext(rootContext);
        }

      if (rootContext.flags & 2
      /* FlushPlayers */
      ) {
          rootContext.flags &= ~2
          /* FlushPlayers */
          ;
          var playerHandler = rootContext.playerHandler;

          if (playerHandler) {
            playerHandler.flushPlayers();
          }
        }

      rootContext.clean = _CLEAN_PROMISE;
      res(null);
    });
  }
}

function tickRootContext(rootContext) {
  for (var i = 0; i < rootContext.components.length; i++) {
    var rootComponent = rootContext.components[i];
    var lView = readPatchedLView(rootComponent);
    var tView = lView[TVIEW];
    renderComponentOrTemplate(tView, lView, tView.template, rootComponent);
  }
}

function detectChangesInternal(tView, lView, context) {
  var rendererFactory = lView[RENDERER_FACTORY];
  if (rendererFactory.begin) rendererFactory.begin();

  try {
    refreshView(tView, lView, tView.template, context);
  } catch (error) {
    handleError(lView, error);
    throw error;
  } finally {
    if (rendererFactory.end) rendererFactory.end();
  }
}
/**
 * Synchronously perform change detection on a root view and its components.
 *
 * @param lView The view which the change detection should be performed on.
 */


function detectChangesInRootView(lView) {
  tickRootContext(lView[CONTEXT]);
}

function checkNoChangesInternal(tView, view, context) {
  setCheckNoChangesMode(true);

  try {
    detectChangesInternal(tView, view, context);
  } finally {
    setCheckNoChangesMode(false);
  }
}
/**
 * Checks the change detector on a root view and its components, and throws if any changes are
 * detected.
 *
 * This is used in development mode to verify that running change detection doesn't
 * introduce other changes.
 *
 * @param lView The view which the change detection should be checked on.
 */


function checkNoChangesInRootView(lView) {
  setCheckNoChangesMode(true);

  try {
    detectChangesInRootView(lView);
  } finally {
    setCheckNoChangesMode(false);
  }
}

function executeViewQueryFn(flags, viewQueryFn, component) {
  ngDevMode && assertDefined(viewQueryFn, 'View queries function to execute must be defined.');
  setCurrentQueryIndex(0);
  viewQueryFn(flags, component);
} ///////////////////////////////
//// Bindings & interpolations
///////////////////////////////

/**
 * Stores meta-data for a property binding to be used by TestBed's `DebugElement.properties`.
 *
 * In order to support TestBed's `DebugElement.properties` we need to save, for each binding:
 * - a bound property name;
 * - a static parts of interpolated strings;
 *
 * A given property metadata is saved at the binding's index in the `TView.data` (in other words, a
 * property binding metadata will be stored in `TView.data` at the same index as a bound value in
 * `LView`). Metadata are represented as `INTERPOLATION_DELIMITER`-delimited string with the
 * following format:
 * - `propertyName` for bound properties;
 * - `propertyName�prefix�interpolation_static_part1�..interpolation_static_partN�suffix` for
 * interpolated properties.
 *
 * @param tData `TData` where meta-data will be saved;
 * @param tNode `TNode` that is a target of the binding;
 * @param propertyName bound property name;
 * @param bindingIndex binding index in `LView`
 * @param interpolationParts static interpolation parts (for property interpolations)
 */


function storePropertyBindingMetadata(tData, tNode, propertyName, bindingIndex) {
  // Binding meta-data are stored only the first time a given property instruction is processed.
  // Since we don't have a concept of the "first update pass" we need to check for presence of the
  // binding meta-data to decide if one should be stored (or if was stored already).
  if (tData[bindingIndex] === null) {
    if (tNode.inputs == null || !tNode.inputs[propertyName]) {
      var propBindingIdxs = tNode.propertyBindings || (tNode.propertyBindings = []);
      propBindingIdxs.push(bindingIndex);
      var bindingMetadata = propertyName;

      for (var _len7 = arguments.length, interpolationParts = new Array(_len7 > 4 ? _len7 - 4 : 0), _key7 = 4; _key7 < _len7; _key7++) {
        interpolationParts[_key7 - 4] = arguments[_key7];
      }

      if (interpolationParts.length > 0) {
        bindingMetadata += INTERPOLATION_DELIMITER + interpolationParts.join(INTERPOLATION_DELIMITER);
      }

      tData[bindingIndex] = bindingMetadata;
    }
  }
}

var CLEAN_PROMISE = _CLEAN_PROMISE;

function getLCleanup(view) {
  // top level variables should not be exported for performance reasons (PERF_NOTES.md)
  return view[CLEANUP] || (view[CLEANUP] = ngDevMode ? new LCleanup() : []);
}

function getTViewCleanup(tView) {
  return tView.cleanup || (tView.cleanup = ngDevMode ? new TCleanup() : []);
}
/**
 * There are cases where the sub component's renderer needs to be included
 * instead of the current renderer (see the componentSyntheticHost* instructions).
 */


function loadComponentRenderer(currentDef, tNode, lView) {
  // TODO(FW-2043): the `currentDef` is null when host bindings are invoked while creating root
  // component (see packages/core/src/render3/component.ts). This is not consistent with the process
  // of creating inner components, when current directive index is available in the state. In order
  // to avoid relying on current def being `null` (thus special-casing root component creation), the
  // process of creating root component should be unified with the process of creating inner
  // components.
  if (currentDef === null || isComponentDef(currentDef)) {
    lView = unwrapLView(lView[tNode.index]);
  }

  return lView[RENDERER];
}
/** Handles an error thrown in an LView. */


function handleError(lView, error) {
  var injector = lView[INJECTOR$1];
  var errorHandler = injector ? injector.get(ErrorHandler, null) : null;
  errorHandler && errorHandler.handleError(error);
}
/**
 * Set the inputs of directives at the current node to corresponding value.
 *
 * @param tView The current TView
 * @param lView the `LView` which contains the directives.
 * @param inputs mapping between the public "input" name and privately-known,
 *        possibly minified, property names to write to.
 * @param value Value to set.
 */


function setInputsForProperty(tView, lView, inputs, publicName, value) {
  for (var i = 0; i < inputs.length;) {
    var index = inputs[i++];
    var privateName = inputs[i++];
    var instance = lView[index];
    ngDevMode && assertIndexInRange(lView, index);
    var def = tView.data[index];

    if (def.setInput !== null) {
      def.setInput(instance, value, publicName, privateName);
    } else {
      instance[privateName] = value;
    }
  }
}
/**
 * Updates a text binding at a given index in a given LView.
 */


function textBindingInternal(lView, index, value) {
  ngDevMode && assertNotSame(value, NO_CHANGE, 'value should not be NO_CHANGE');
  ngDevMode && assertIndexInRange(lView, index + HEADER_OFFSET);
  var element = getNativeByIndex(index, lView);
  ngDevMode && assertDefined(element, 'native element should exist');
  ngDevMode && ngDevMode.rendererSetText++;
  var renderer = lView[RENDERER];
  isProceduralRenderer(renderer) ? renderer.setValue(element, value) : element.textContent = value;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var unusedValueToPlacateAjd$1 = unusedValueExportToPlacateAjd$1 + unusedValueExportToPlacateAjd$4 + unusedValueExportToPlacateAjd$5 + unusedValueExportToPlacateAjd$2 + unusedValueExportToPlacateAjd;
/**
 * NOTE: for performance reasons, the possible actions are inlined within the function instead of
 * being passed as an argument.
 */

function applyToElementOrContainer(action, renderer, parent, lNodeToHandle, beforeNode) {
  // If this slot was allocated for a text node dynamically created by i18n, the text node itself
  // won't be created until i18nApply() in the update block, so this node should be skipped.
  // For more info, see "ICU expressions should work inside an ngTemplateOutlet inside an ngFor"
  // in `i18n_spec.ts`.
  if (lNodeToHandle != null) {
    var lContainer;
    var isComponent = false; // We are expecting an RNode, but in the case of a component or LContainer the `RNode` is
    // wrapped in an array which needs to be unwrapped. We need to know if it is a component and if
    // it has LContainer so that we can process all of those cases appropriately.

    if (isLContainer(lNodeToHandle)) {
      lContainer = lNodeToHandle;
    } else if (isLView(lNodeToHandle)) {
      isComponent = true;
      ngDevMode && assertDefined(lNodeToHandle[HOST], 'HOST must be defined for a component LView');
      lNodeToHandle = lNodeToHandle[HOST];
    }

    var rNode = unwrapRNode(lNodeToHandle);
    ngDevMode && !isProceduralRenderer(renderer) && assertDomNode(rNode);

    if (action === 0
    /* Create */
    && parent !== null) {
      if (beforeNode == null) {
        nativeAppendChild(renderer, parent, rNode);
      } else {
        nativeInsertBefore(renderer, parent, rNode, beforeNode || null);
      }
    } else if (action === 1
    /* Insert */
    && parent !== null) {
      nativeInsertBefore(renderer, parent, rNode, beforeNode || null);
    } else if (action === 2
    /* Detach */
    ) {
        nativeRemoveNode(renderer, rNode, isComponent);
      } else if (action === 3
    /* Destroy */
    ) {
        ngDevMode && ngDevMode.rendererDestroyNode++;
        renderer.destroyNode(rNode);
      }

    if (lContainer != null) {
      applyContainer(renderer, action, lContainer, parent, beforeNode);
    }
  }
}

function createTextNode(value, renderer) {
  ngDevMode && ngDevMode.rendererCreateTextNode++;
  ngDevMode && ngDevMode.rendererSetText++;
  return isProceduralRenderer(renderer) ? renderer.createText(value) : renderer.createTextNode(value);
}
/**
 * Removes all DOM elements associated with a view.
 *
 * Because some root nodes of the view may be containers, we sometimes need
 * to propagate deeply into the nested containers to remove all elements in the
 * views beneath it.
 *
 * @param tView The `TView' of the `LView` from which elements should be added or removed
 * @param lView The view from which elements should be added or removed
 */


function removeViewFromContainer(tView, lView) {
  var renderer = lView[RENDERER];
  applyView(tView, lView, renderer, 2
  /* Detach */
  , null, null);
  lView[HOST] = null;
  lView[T_HOST] = null;
}
/**
 * Adds all DOM elements associated with a view.
 *
 * Because some root nodes of the view may be containers, we sometimes need
 * to propagate deeply into the nested containers to add all elements in the
 * views beneath it.
 *
 * @param tView The `TView' of the `LView` from which elements should be added or removed
 * @param parentTNode The `TNode` where the `LView` should be attached to.
 * @param renderer Current renderer to use for DOM manipulations.
 * @param lView The view from which elements should be added or removed
 * @param parentNativeNode The parent `RElement` where it should be inserted into.
 * @param beforeNode The node before which elements should be added, if insert mode
 */


function addViewToContainer(tView, parentTNode, renderer, lView, parentNativeNode, beforeNode) {
  lView[HOST] = parentNativeNode;
  lView[T_HOST] = parentTNode;
  applyView(tView, lView, renderer, 1
  /* Insert */
  , parentNativeNode, beforeNode);
}
/**
 * Detach a `LView` from the DOM by detaching its nodes.
 *
 * @param tView The `TView' of the `LView` to be detached
 * @param lView the `LView` to be detached.
 */


function renderDetachView(tView, lView) {
  applyView(tView, lView, lView[RENDERER], 2
  /* Detach */
  , null, null);
}
/**
 * Traverses down and up the tree of views and containers to remove listeners and
 * call onDestroy callbacks.
 *
 * Notes:
 *  - Because it's used for onDestroy calls, it needs to be bottom-up.
 *  - Must process containers instead of their views to avoid splicing
 *  when views are destroyed and re-added.
 *  - Using a while loop because it's faster than recursion
 *  - Destroy only called on movement to sibling or movement to parent (laterally or up)
 *
 *  @param rootView The view to destroy
 */


function destroyViewTree(rootView) {
  // If the view has no children, we can clean it up and return early.
  var lViewOrLContainer = rootView[CHILD_HEAD];

  if (!lViewOrLContainer) {
    return cleanUpView(rootView[TVIEW], rootView);
  }

  while (lViewOrLContainer) {
    var next = null;

    if (isLView(lViewOrLContainer)) {
      // If LView, traverse down to child.
      next = lViewOrLContainer[CHILD_HEAD];
    } else {
      ngDevMode && assertLContainer(lViewOrLContainer); // If container, traverse down to its first LView.

      var firstView = lViewOrLContainer[CONTAINER_HEADER_OFFSET];
      if (firstView) next = firstView;
    }

    if (!next) {
      // Only clean up view when moving to the side or up, as destroy hooks
      // should be called in order from the bottom up.
      while (lViewOrLContainer && !lViewOrLContainer[NEXT] && lViewOrLContainer !== rootView) {
        if (isLView(lViewOrLContainer)) {
          cleanUpView(lViewOrLContainer[TVIEW], lViewOrLContainer);
        }

        lViewOrLContainer = lViewOrLContainer[PARENT];
      }

      if (lViewOrLContainer === null) lViewOrLContainer = rootView;

      if (isLView(lViewOrLContainer)) {
        cleanUpView(lViewOrLContainer[TVIEW], lViewOrLContainer);
      }

      next = lViewOrLContainer && lViewOrLContainer[NEXT];
    }

    lViewOrLContainer = next;
  }
}
/**
 * Inserts a view into a container.
 *
 * This adds the view to the container's array of active views in the correct
 * position. It also adds the view's elements to the DOM if the container isn't a
 * root node of another view (in that case, the view's elements will be added when
 * the container's parent view is added later).
 *
 * @param tView The `TView' of the `LView` to insert
 * @param lView The view to insert
 * @param lContainer The container into which the view should be inserted
 * @param index Which index in the container to insert the child view into
 */


function insertView(tView, lView, lContainer, index) {
  ngDevMode && assertLView(lView);
  ngDevMode && assertLContainer(lContainer);
  var indexInContainer = CONTAINER_HEADER_OFFSET + index;
  var containerLength = lContainer.length;

  if (index > 0) {
    // This is a new view, we need to add it to the children.
    lContainer[indexInContainer - 1][NEXT] = lView;
  }

  if (index < containerLength - CONTAINER_HEADER_OFFSET) {
    lView[NEXT] = lContainer[indexInContainer];
    addToArray(lContainer, CONTAINER_HEADER_OFFSET + index, lView);
  } else {
    lContainer.push(lView);
    lView[NEXT] = null;
  }

  lView[PARENT] = lContainer; // track views where declaration and insertion points are different

  var declarationLContainer = lView[DECLARATION_LCONTAINER];

  if (declarationLContainer !== null && lContainer !== declarationLContainer) {
    trackMovedView(declarationLContainer, lView);
  } // notify query that a new view has been added


  var lQueries = lView[QUERIES];

  if (lQueries !== null) {
    lQueries.insertView(tView);
  } // Sets the attached flag


  lView[FLAGS] |= 128
  /* Attached */
  ;
}
/**
 * Track views created from the declaration container (TemplateRef) and inserted into a
 * different LContainer.
 */


function trackMovedView(declarationContainer, lView) {
  ngDevMode && assertDefined(lView, 'LView required');
  ngDevMode && assertLContainer(declarationContainer);
  var movedViews = declarationContainer[MOVED_VIEWS];
  var insertedLContainer = lView[PARENT];
  ngDevMode && assertLContainer(insertedLContainer);
  var insertedComponentLView = insertedLContainer[PARENT][DECLARATION_COMPONENT_VIEW];
  ngDevMode && assertDefined(insertedComponentLView, 'Missing insertedComponentLView');
  var declaredComponentLView = lView[DECLARATION_COMPONENT_VIEW];
  ngDevMode && assertDefined(declaredComponentLView, 'Missing declaredComponentLView');

  if (declaredComponentLView !== insertedComponentLView) {
    // At this point the declaration-component is not same as insertion-component; this means that
    // this is a transplanted view. Mark the declared lView as having transplanted views so that
    // those views can participate in CD.
    declarationContainer[HAS_TRANSPLANTED_VIEWS] = true;
  }

  if (movedViews === null) {
    declarationContainer[MOVED_VIEWS] = [lView];
  } else {
    movedViews.push(lView);
  }
}

function detachMovedView(declarationContainer, lView) {
  ngDevMode && assertLContainer(declarationContainer);
  ngDevMode && assertDefined(declarationContainer[MOVED_VIEWS], 'A projected view should belong to a non-empty projected views collection');
  var movedViews = declarationContainer[MOVED_VIEWS];
  var declarationViewIndex = movedViews.indexOf(lView);
  var insertionLContainer = lView[PARENT];
  ngDevMode && assertLContainer(insertionLContainer); // If the view was marked for refresh but then detached before it was checked (where the flag
  // would be cleared and the counter decremented), we need to decrement the view counter here
  // instead.

  if (lView[FLAGS] & 1024
  /* RefreshTransplantedView */
  ) {
      lView[FLAGS] &= ~1024
      /* RefreshTransplantedView */
      ;
      updateTransplantedViewCount(insertionLContainer, -1);
    }

  movedViews.splice(declarationViewIndex, 1);
}
/**
 * Detaches a view from a container.
 *
 * This method removes the view from the container's array of active views. It also
 * removes the view's elements from the DOM.
 *
 * @param lContainer The container from which to detach a view
 * @param removeIndex The index of the view to detach
 * @returns Detached LView instance.
 */


function detachView(lContainer, removeIndex) {
  if (lContainer.length <= CONTAINER_HEADER_OFFSET) return;
  var indexInContainer = CONTAINER_HEADER_OFFSET + removeIndex;
  var viewToDetach = lContainer[indexInContainer];

  if (viewToDetach) {
    var declarationLContainer = viewToDetach[DECLARATION_LCONTAINER];

    if (declarationLContainer !== null && declarationLContainer !== lContainer) {
      detachMovedView(declarationLContainer, viewToDetach);
    }

    if (removeIndex > 0) {
      lContainer[indexInContainer - 1][NEXT] = viewToDetach[NEXT];
    }

    var removedLView = removeFromArray(lContainer, CONTAINER_HEADER_OFFSET + removeIndex);
    removeViewFromContainer(viewToDetach[TVIEW], viewToDetach); // notify query that a view has been removed

    var lQueries = removedLView[QUERIES];

    if (lQueries !== null) {
      lQueries.detachView(removedLView[TVIEW]);
    }

    viewToDetach[PARENT] = null;
    viewToDetach[NEXT] = null; // Unsets the attached flag

    viewToDetach[FLAGS] &= ~128
    /* Attached */
    ;
  }

  return viewToDetach;
}
/**
 * A standalone function which destroys an LView,
 * conducting clean up (e.g. removing listeners, calling onDestroys).
 *
 * @param tView The `TView' of the `LView` to be destroyed
 * @param lView The view to be destroyed.
 */


function destroyLView(tView, lView) {
  if (!(lView[FLAGS] & 256
  /* Destroyed */
  )) {
    var renderer = lView[RENDERER];

    if (isProceduralRenderer(renderer) && renderer.destroyNode) {
      applyView(tView, lView, renderer, 3
      /* Destroy */
      , null, null);
    }

    destroyViewTree(lView);
  }
}
/**
 * Calls onDestroys hooks for all directives and pipes in a given view and then removes all
 * listeners. Listeners are removed as the last step so events delivered in the onDestroys hooks
 * can be propagated to @Output listeners.
 *
 * @param tView `TView` for the `LView` to clean up.
 * @param lView The LView to clean up
 */


function cleanUpView(tView, lView) {
  if (!(lView[FLAGS] & 256
  /* Destroyed */
  )) {
    // Usually the Attached flag is removed when the view is detached from its parent, however
    // if it's a root view, the flag won't be unset hence why we're also removing on destroy.
    lView[FLAGS] &= ~128
    /* Attached */
    ; // Mark the LView as destroyed *before* executing the onDestroy hooks. An onDestroy hook
    // runs arbitrary user code, which could include its own `viewRef.destroy()` (or similar). If
    // We don't flag the view as destroyed before the hooks, this could lead to an infinite loop.
    // This also aligns with the ViewEngine behavior. It also means that the onDestroy hook is
    // really more of an "afterDestroy" hook if you think about it.

    lView[FLAGS] |= 256
    /* Destroyed */
    ;
    executeOnDestroys(tView, lView);
    removeListeners(tView, lView); // For component views only, the local renderer is destroyed at clean up time.

    if (lView[TVIEW].type === 1
    /* Component */
    && isProceduralRenderer(lView[RENDERER])) {
      ngDevMode && ngDevMode.rendererDestroy++;
      lView[RENDERER].destroy();
    }

    var declarationContainer = lView[DECLARATION_LCONTAINER]; // we are dealing with an embedded view that is still inserted into a container

    if (declarationContainer !== null && isLContainer(lView[PARENT])) {
      // and this is a projected view
      if (declarationContainer !== lView[PARENT]) {
        detachMovedView(declarationContainer, lView);
      } // For embedded views still attached to a container: remove query result from this view.


      var lQueries = lView[QUERIES];

      if (lQueries !== null) {
        lQueries.detachView(tView);
      }
    }
  }
}
/** Removes listeners and unsubscribes from output subscriptions */


function removeListeners(tView, lView) {
  var tCleanup = tView.cleanup;

  if (tCleanup !== null) {
    var lCleanup = lView[CLEANUP];

    for (var i = 0; i < tCleanup.length - 1; i += 2) {
      if (typeof tCleanup[i] === 'string') {
        // This is a native DOM listener
        var idxOrTargetGetter = tCleanup[i + 1];
        var target = typeof idxOrTargetGetter === 'function' ? idxOrTargetGetter(lView) : unwrapRNode(lView[idxOrTargetGetter]);
        var listener = lCleanup[tCleanup[i + 2]];
        var useCaptureOrSubIdx = tCleanup[i + 3];

        if (typeof useCaptureOrSubIdx === 'boolean') {
          // native DOM listener registered with Renderer3
          target.removeEventListener(tCleanup[i], listener, useCaptureOrSubIdx);
        } else {
          if (useCaptureOrSubIdx >= 0) {
            // unregister
            lCleanup[useCaptureOrSubIdx]();
          } else {
            // Subscription
            lCleanup[-useCaptureOrSubIdx].unsubscribe();
          }
        }

        i += 2;
      } else {
        // This is a cleanup function that is grouped with the index of its context
        var context = lCleanup[tCleanup[i + 1]];
        tCleanup[i].call(context);
      }
    }

    lView[CLEANUP] = null;
  }
}
/** Calls onDestroy hooks for this view */


function executeOnDestroys(tView, lView) {
  var destroyHooks;

  if (tView != null && (destroyHooks = tView.destroyHooks) != null) {
    for (var i = 0; i < destroyHooks.length; i += 2) {
      var context = lView[destroyHooks[i]]; // Only call the destroy hook if the context has been requested.

      if (!(context instanceof NodeInjectorFactory)) {
        var toCall = destroyHooks[i + 1];

        if (Array.isArray(toCall)) {
          for (var j = 0; j < toCall.length; j += 2) {
            toCall[j + 1].call(context[toCall[j]]);
          }
        } else {
          toCall.call(context);
        }
      }
    }
  }
}
/**
 * Returns a native element if a node can be inserted into the given parent.
 *
 * There are two reasons why we may not be able to insert a element immediately.
 * - Projection: When creating a child content element of a component, we have to skip the
 *   insertion because the content of a component will be projected.
 *   `<component><content>delayed due to projection</content></component>`
 * - Parent container is disconnected: This can happen when we are inserting a view into
 *   parent container, which itself is disconnected. For example the parent container is part
 *   of a View which has not be inserted or is made for projection but has not been inserted
 *   into destination.
 */


function getRenderParent(tView, tNode, currentView) {
  // Skip over element and ICU containers as those are represented by a comment node and
  // can't be used as a render parent.
  var parentTNode = tNode.parent;

  while (parentTNode != null && (parentTNode.type === 3
  /* ElementContainer */
  || parentTNode.type === 4
  /* IcuContainer */
  )) {
    tNode = parentTNode;
    parentTNode = tNode.parent;
  } // If the parent tNode is null, then we are inserting across views: either into an embedded view
  // or a component view.


  if (parentTNode === null) {
    // We are inserting a root element of the component view into the component host element and
    // it should always be eager.
    return currentView[HOST];
  } else {
    var isIcuCase = tNode && tNode.type === 4
    /* IcuContainer */
    ; // If the parent of this node is an ICU container, then it is represented by comment node and we
    // need to use it as an anchor. If it is projected then it's direct parent node is the renderer.

    if (isIcuCase && tNode.flags & 4
    /* isProjected */
    ) {
        return getNativeByTNode(tNode, currentView).parentNode;
      }

    ngDevMode && assertNodeType(parentTNode, 2
    /* Element */
    );

    if (parentTNode.flags & 2
    /* isComponentHost */
    ) {
        var tData = tView.data;
        var _tNode2 = tData[parentTNode.index];
        var encapsulation = tData[_tNode2.directiveStart].encapsulation; // We've got a parent which is an element in the current view. We just need to verify if the
        // parent element is not a component. Component's content nodes are not inserted immediately
        // because they will be projected, and so doing insert at this point would be wasteful.
        // Since the projection would then move it to its final destination. Note that we can't
        // make this assumption when using the Shadow DOM, because the native projection placeholders
        // (<content> or <slot>) have to be in place as elements are being inserted.

        if (encapsulation !== ViewEncapsulation$1.ShadowDom && encapsulation !== ViewEncapsulation$1.Native) {
          return null;
        }
      }

    return getNativeByTNode(parentTNode, currentView);
  }
}
/**
 * Inserts a native node before another native node for a given parent using {@link Renderer3}.
 * This is a utility function that can be used when native nodes were determined - it abstracts an
 * actual renderer being used.
 */


function nativeInsertBefore(renderer, parent, child, beforeNode) {
  ngDevMode && ngDevMode.rendererInsertBefore++;

  if (isProceduralRenderer(renderer)) {
    renderer.insertBefore(parent, child, beforeNode);
  } else {
    parent.insertBefore(child, beforeNode, true);
  }
}

function nativeAppendChild(renderer, parent, child) {
  ngDevMode && ngDevMode.rendererAppendChild++;
  ngDevMode && assertDefined(parent, 'parent node must be defined');

  if (isProceduralRenderer(renderer)) {
    renderer.appendChild(parent, child);
  } else {
    parent.appendChild(child);
  }
}

function nativeAppendOrInsertBefore(renderer, parent, child, beforeNode) {
  if (beforeNode !== null) {
    nativeInsertBefore(renderer, parent, child, beforeNode);
  } else {
    nativeAppendChild(renderer, parent, child);
  }
}
/** Removes a node from the DOM given its native parent. */


function nativeRemoveChild(renderer, parent, child, isHostElement) {
  if (isProceduralRenderer(renderer)) {
    renderer.removeChild(parent, child, isHostElement);
  } else {
    parent.removeChild(child);
  }
}
/**
 * Returns a native parent of a given native node.
 */


function nativeParentNode(renderer, node) {
  return isProceduralRenderer(renderer) ? renderer.parentNode(node) : node.parentNode;
}
/**
 * Returns a native sibling of a given native node.
 */


function nativeNextSibling(renderer, node) {
  return isProceduralRenderer(renderer) ? renderer.nextSibling(node) : node.nextSibling;
}
/**
 * Finds a native "anchor" node for cases where we can't append a native child directly
 * (`appendChild`) and need to use a reference (anchor) node for the `insertBefore` operation.
 * @param parentTNode
 * @param lView
 */


function getNativeAnchorNode(parentTNode, lView) {
  if (parentTNode.type === 3
  /* ElementContainer */
  || parentTNode.type === 4
  /* IcuContainer */
  ) {
      return getNativeByTNode(parentTNode, lView);
    }

  return null;
}
/**
 * Appends the `child` native node (or a collection of nodes) to the `parent`.
 *
 * The element insertion might be delayed {@link canInsertNativeNode}.
 *
 * @param tView The `TView' to be appended
 * @param lView The current LView
 * @param childEl The native child (or children) that should be appended
 * @param childTNode The TNode of the child element
 * @returns Whether or not the child was appended
 */


function appendChild(tView, lView, childEl, childTNode) {
  var renderParent = getRenderParent(tView, childTNode, lView);

  if (renderParent != null) {
    var renderer = lView[RENDERER];
    var parentTNode = childTNode.parent || lView[T_HOST];
    var anchorNode = getNativeAnchorNode(parentTNode, lView);

    if (Array.isArray(childEl)) {
      for (var i = 0; i < childEl.length; i++) {
        nativeAppendOrInsertBefore(renderer, renderParent, childEl[i], anchorNode);
      }
    } else {
      nativeAppendOrInsertBefore(renderer, renderParent, childEl, anchorNode);
    }
  }
}
/**
 * Returns the first native node for a given LView, starting from the provided TNode.
 *
 * Native nodes are returned in the order in which those appear in the native tree (DOM).
 */


function getFirstNativeNode(lView, tNode) {
  if (tNode !== null) {
    ngDevMode && assertNodeOfPossibleTypes(tNode, [2
    /* Element */
    , 0
    /* Container */
    , 3
    /* ElementContainer */
    , 4
    /* IcuContainer */
    , 1
    /* Projection */
    ]);
    var tNodeType = tNode.type;

    if (tNodeType === 2
    /* Element */
    ) {
        return getNativeByTNode(tNode, lView);
      } else if (tNodeType === 0
    /* Container */
    ) {
        return getBeforeNodeForView(-1, lView[tNode.index]);
      } else if (tNodeType === 3
    /* ElementContainer */
    || tNodeType === 4
    /* IcuContainer */
    ) {
        var elIcuContainerChild = tNode.child;

        if (elIcuContainerChild !== null) {
          return getFirstNativeNode(lView, elIcuContainerChild);
        } else {
          var rNodeOrLContainer = lView[tNode.index];

          if (isLContainer(rNodeOrLContainer)) {
            return getBeforeNodeForView(-1, rNodeOrLContainer);
          } else {
            return unwrapRNode(rNodeOrLContainer);
          }
        }
      } else {
      var componentView = lView[DECLARATION_COMPONENT_VIEW];
      var componentHost = componentView[T_HOST];
      var parentView = getLViewParent(componentView);
      var firstProjectedTNode = componentHost.projection[tNode.projection];

      if (firstProjectedTNode != null) {
        return getFirstNativeNode(parentView, firstProjectedTNode);
      } else {
        return getFirstNativeNode(lView, tNode.next);
      }
    }
  }

  return null;
}

function getBeforeNodeForView(viewIndexInContainer, lContainer) {
  var nextViewIndex = CONTAINER_HEADER_OFFSET + viewIndexInContainer + 1;

  if (nextViewIndex < lContainer.length) {
    var lView = lContainer[nextViewIndex];
    var firstTNodeOfView = lView[TVIEW].firstChild;

    if (firstTNodeOfView !== null) {
      return getFirstNativeNode(lView, firstTNodeOfView);
    }
  }

  return lContainer[NATIVE];
}
/**
 * Removes a native node itself using a given renderer. To remove the node we are looking up its
 * parent from the native tree as not all platforms / browsers support the equivalent of
 * node.remove().
 *
 * @param renderer A renderer to be used
 * @param rNode The native node that should be removed
 * @param isHostElement A flag indicating if a node to be removed is a host of a component.
 */


function nativeRemoveNode(renderer, rNode, isHostElement) {
  var nativeParent = nativeParentNode(renderer, rNode);

  if (nativeParent) {
    nativeRemoveChild(renderer, nativeParent, rNode, isHostElement);
  }
}
/**
 * Performs the operation of `action` on the node. Typically this involves inserting or removing
 * nodes on the LView or projection boundary.
 */


function applyNodes(renderer, action, tNode, lView, renderParent, beforeNode, isProjection) {
  while (tNode != null) {
    ngDevMode && assertTNodeForLView(tNode, lView);
    ngDevMode && assertNodeOfPossibleTypes(tNode, [0
    /* Container */
    , 2
    /* Element */
    , 3
    /* ElementContainer */
    , 1
    /* Projection */
    , 4
    /* IcuContainer */
    ]);
    var rawSlotValue = lView[tNode.index];
    var tNodeType = tNode.type;

    if (isProjection) {
      if (action === 0
      /* Create */
      ) {
          rawSlotValue && attachPatchData(unwrapRNode(rawSlotValue), lView);
          tNode.flags |= 4
          /* isProjected */
          ;
        }
    }

    if ((tNode.flags & 64
    /* isDetached */
    ) !== 64
    /* isDetached */
    ) {
        if (tNodeType === 3
        /* ElementContainer */
        || tNodeType === 4
        /* IcuContainer */
        ) {
            applyNodes(renderer, action, tNode.child, lView, renderParent, beforeNode, false);
            applyToElementOrContainer(action, renderer, renderParent, rawSlotValue, beforeNode);
          } else if (tNodeType === 1
        /* Projection */
        ) {
            applyProjectionRecursive(renderer, action, lView, tNode, renderParent, beforeNode);
          } else {
          ngDevMode && assertNodeOfPossibleTypes(tNode, [2
          /* Element */
          , 0
          /* Container */
          ]);
          applyToElementOrContainer(action, renderer, renderParent, rawSlotValue, beforeNode);
        }
      }

    tNode = isProjection ? tNode.projectionNext : tNode.next;
  }
}

function applyView(tView, lView, renderer, action, renderParent, beforeNode) {
  applyNodes(renderer, action, tView.firstChild, lView, renderParent, beforeNode, false);
}
/**
 * `applyProjection` performs operation on the projection.
 *
 * Inserting a projection requires us to locate the projected nodes from the parent component. The
 * complication is that those nodes themselves could be re-projected from their parent component.
 *
 * @param tView The `TView` of `LView` which needs to be inserted, detached, destroyed
 * @param lView The `LView` which needs to be inserted, detached, destroyed.
 * @param tProjectionNode node to project
 */


function applyProjection(tView, lView, tProjectionNode) {
  var renderer = lView[RENDERER];
  var renderParent = getRenderParent(tView, tProjectionNode, lView);
  var parentTNode = tProjectionNode.parent || lView[T_HOST];
  var beforeNode = getNativeAnchorNode(parentTNode, lView);
  applyProjectionRecursive(renderer, 0
  /* Create */
  , lView, tProjectionNode, renderParent, beforeNode);
}
/**
 * `applyProjectionRecursive` performs operation on the projection specified by `action` (insert,
 * detach, destroy)
 *
 * Inserting a projection requires us to locate the projected nodes from the parent component. The
 * complication is that those nodes themselves could be re-projected from their parent component.
 *
 * @param renderer Render to use
 * @param action action to perform (insert, detach, destroy)
 * @param lView The LView which needs to be inserted, detached, destroyed.
 * @param tProjectionNode node to project
 * @param renderParent parent DOM element for insertion/removal.
 * @param beforeNode Before which node the insertions should happen.
 */


function applyProjectionRecursive(renderer, action, lView, tProjectionNode, renderParent, beforeNode) {
  var componentLView = lView[DECLARATION_COMPONENT_VIEW];
  var componentNode = componentLView[T_HOST];
  ngDevMode && assertEqual(typeof tProjectionNode.projection, 'number', 'expecting projection index');
  var nodeToProjectOrRNodes = componentNode.projection[tProjectionNode.projection];

  if (Array.isArray(nodeToProjectOrRNodes)) {
    // This should not exist, it is a bit of a hack. When we bootstrap a top level node and we
    // need to support passing projectable nodes, so we cheat and put them in the TNode
    // of the Host TView. (Yes we put instance info at the T Level). We can get away with it
    // because we know that that TView is not shared and therefore it will not be a problem.
    // This should be refactored and cleaned up.
    for (var i = 0; i < nodeToProjectOrRNodes.length; i++) {
      var rNode = nodeToProjectOrRNodes[i];
      applyToElementOrContainer(action, renderer, renderParent, rNode, beforeNode);
    }
  } else {
    var nodeToProject = nodeToProjectOrRNodes;
    var projectedComponentLView = componentLView[PARENT];
    applyNodes(renderer, action, nodeToProject, projectedComponentLView, renderParent, beforeNode, true);
  }
}
/**
 * `applyContainer` performs an operation on the container and its views as specified by
 * `action` (insert, detach, destroy)
 *
 * Inserting a Container is complicated by the fact that the container may have Views which
 * themselves have containers or projections.
 *
 * @param renderer Renderer to use
 * @param action action to perform (insert, detach, destroy)
 * @param lContainer The LContainer which needs to be inserted, detached, destroyed.
 * @param renderParent parent DOM element for insertion/removal.
 * @param beforeNode Before which node the insertions should happen.
 */


function applyContainer(renderer, action, lContainer, renderParent, beforeNode) {
  ngDevMode && assertLContainer(lContainer);
  var anchor = lContainer[NATIVE]; // LContainer has its own before node.

  var native = unwrapRNode(lContainer); // An LContainer can be created dynamically on any node by injecting ViewContainerRef.
  // Asking for a ViewContainerRef on an element will result in a creation of a separate anchor node
  // (comment in the DOM) that will be different from the LContainer's host node. In this particular
  // case we need to execute action on 2 nodes:
  // - container's host node (this is done in the executeActionOnElementOrContainer)
  // - container's host node (this is done here)

  if (anchor !== native) {
    // This is very strange to me (Misko). I would expect that the native is same as anchor. I don't
    // see a reason why they should be different, but they are.
    //
    // If they are we need to process the second anchor as well.
    applyToElementOrContainer(action, renderer, renderParent, anchor, beforeNode);
  }

  for (var i = CONTAINER_HEADER_OFFSET; i < lContainer.length; i++) {
    var lView = lContainer[i];
    applyView(lView[TVIEW], lView, renderer, action, renderParent, anchor);
  }
}
/**
 * Writes class/style to element.
 *
 * @param renderer Renderer to use.
 * @param isClassBased `true` if it should be written to `class` (`false` to write to `style`)
 * @param rNode The Node to write to.
 * @param prop Property to write to. This would be the class/style name.
 * @param value Value to write. If `null`/`undefined`/`false` this is considered a remove (set/add
 *        otherwise).
 */


function applyStyling(renderer, isClassBased, rNode, prop, value) {
  var isProcedural = isProceduralRenderer(renderer);

  if (isClassBased) {
    // We actually want JS true/false here because any truthy value should add the class
    if (!value) {
      ngDevMode && ngDevMode.rendererRemoveClass++;

      if (isProcedural) {
        renderer.removeClass(rNode, prop);
      } else {
        rNode.classList.remove(prop);
      }
    } else {
      ngDevMode && ngDevMode.rendererAddClass++;

      if (isProcedural) {
        renderer.addClass(rNode, prop);
      } else {
        ngDevMode && assertDefined(rNode.classList, 'HTMLElement expected');
        rNode.classList.add(prop);
      }
    }
  } else {
    // TODO(misko): Can't import RendererStyleFlags2.DashCase as it causes imports to be resolved in
    // different order which causes failures. Using direct constant as workaround for now.
    var flags = prop.indexOf('-') == -1 ? undefined : 2
    /* RendererStyleFlags2.DashCase */
    ;

    if (value == null
    /** || value === undefined */
    ) {
        ngDevMode && ngDevMode.rendererRemoveStyle++;

        if (isProcedural) {
          renderer.removeStyle(rNode, prop, flags);
        } else {
          rNode.style.removeProperty(prop);
        }
      } else {
      ngDevMode && ngDevMode.rendererSetStyle++;

      if (isProcedural) {
        renderer.setStyle(rNode, prop, value, flags);
      } else {
        ngDevMode && assertDefined(rNode.style, 'HTMLElement expected');
        rNode.style.setProperty(prop, value);
      }
    }
  }
}
/**
 * Write `cssText` to `RElement`.
 *
 * This function does direct write without any reconciliation. Used for writing initial values, so
 * that static styling values do not pull in the style parser.
 *
 * @param renderer Renderer to use
 * @param element The element which needs to be updated.
 * @param newValue The new class list to write.
 */


function writeDirectStyle(renderer, element, newValue) {
  ngDevMode && assertString(newValue, '\'newValue\' should be a string');

  if (isProceduralRenderer(renderer)) {
    renderer.setAttribute(element, 'style', newValue);
  } else {
    element.style.cssText = newValue;
  }

  ngDevMode && ngDevMode.rendererSetStyle++;
}
/**
 * Write `className` to `RElement`.
 *
 * This function does direct write without any reconciliation. Used for writing initial values, so
 * that static styling values do not pull in the style parser.
 *
 * @param renderer Renderer to use
 * @param element The element which needs to be updated.
 * @param newValue The new class list to write.
 */


function writeDirectClass(renderer, element, newValue) {
  ngDevMode && assertString(newValue, '\'newValue\' should be a string');

  if (isProceduralRenderer(renderer)) {
    if (newValue === '') {
      // There are tests in `google3` which expect `element.getAttribute('class')` to be `null`.
      renderer.removeAttribute(element, 'class');
    } else {
      renderer.setAttribute(element, 'class', newValue);
    }
  } else {
    element.className = newValue;
  }

  ngDevMode && ngDevMode.rendererSetClassName++;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ViewRef = /*#__PURE__*/function () {
  function ViewRef(
  /**
   * This represents `LView` associated with the component when ViewRef is a ChangeDetectorRef.
   *
   * When ViewRef is created for a dynamic component, this also represents the `LView` for the
   * component.
   *
   * For a "regular" ViewRef created for an embedded view, this is the `LView` for the embedded
   * view.
   *
   * @internal
   */
  _lView,
  /**
   * This represents the `LView` associated with the point where `ChangeDetectorRef` was
   * requested.
   *
   * This may be different from `_lView` if the `_cdRefInjectingView` is an embedded view.
   */
  _cdRefInjectingView) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ViewRef);

    this._lView = _lView;
    this._cdRefInjectingView = _cdRefInjectingView;
    this._appRef = null;
    this._viewContainerRef = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ViewRef, [{
    key: "destroy",
    value: function destroy() {
      if (this._appRef) {
        this._appRef.detachView(this);
      } else if (this._viewContainerRef) {
        var index = this._viewContainerRef.indexOf(this);

        if (index > -1) {
          this._viewContainerRef.detach(index);
        }

        this._viewContainerRef = null;
      }

      destroyLView(this._lView[TVIEW], this._lView);
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      storeCleanupWithContext(this._lView[TVIEW], this._lView, null, callback);
    }
    /**
     * Marks a view and all of its ancestors dirty.
     *
     * It also triggers change detection by calling `scheduleTick` internally, which coalesces
     * multiple `markForCheck` calls to into one change detection run.
     *
     * This can be used to ensure an {@link ChangeDetectionStrategy#OnPush OnPush} component is
     * checked when it needs to be re-rendered but the two normal triggers haven't marked it
     * dirty (i.e. inputs haven't changed and events haven't fired in the view).
     *
     * <!-- TODO: Add a link to a chapter on OnPush components -->
     *
     * @usageNotes
     * ### Example
     *
     * ```typescript
     * @Component({
     *   selector: 'my-app',
     *   template: `Number of ticks: {{numberOfTicks}}`
     *   changeDetection: ChangeDetectionStrategy.OnPush,
     * })
     * class AppComponent {
     *   numberOfTicks = 0;
     *
     *   constructor(private ref: ChangeDetectorRef) {
     *     setInterval(() => {
     *       this.numberOfTicks++;
     *       // the following is required, otherwise the view will not be updated
     *       this.ref.markForCheck();
     *     }, 1000);
     *   }
     * }
     * ```
     */

  }, {
    key: "markForCheck",
    value: function markForCheck() {
      markViewDirty(this._cdRefInjectingView || this._lView);
    }
    /**
     * Detaches the view from the change detection tree.
     *
     * Detached views will not be checked during change detection runs until they are
     * re-attached, even if they are dirty. `detach` can be used in combination with
     * {@link ChangeDetectorRef#detectChanges detectChanges} to implement local change
     * detection checks.
     *
     * <!-- TODO: Add a link to a chapter on detach/reattach/local digest -->
     * <!-- TODO: Add a live demo once ref.detectChanges is merged into master -->
     *
     * @usageNotes
     * ### Example
     *
     * The following example defines a component with a large list of readonly data.
     * Imagine the data changes constantly, many times per second. For performance reasons,
     * we want to check and update the list every five seconds. We can do that by detaching
     * the component's change detector and doing a local check every five seconds.
     *
     * ```typescript
     * class DataProvider {
     *   // in a real application the returned data will be different every time
     *   get data() {
     *     return [1,2,3,4,5];
     *   }
     * }
     *
     * @Component({
     *   selector: 'giant-list',
     *   template: `
     *     <li *ngFor="let d of dataProvider.data">Data {{d}}</li>
     *   `,
     * })
     * class GiantList {
     *   constructor(private ref: ChangeDetectorRef, private dataProvider: DataProvider) {
     *     ref.detach();
     *     setInterval(() => {
     *       this.ref.detectChanges();
     *     }, 5000);
     *   }
     * }
     *
     * @Component({
     *   selector: 'app',
     *   providers: [DataProvider],
     *   template: `
     *     <giant-list><giant-list>
     *   `,
     * })
     * class App {
     * }
     * ```
     */

  }, {
    key: "detach",
    value: function detach() {
      this._lView[FLAGS] &= ~128
      /* Attached */
      ;
    }
    /**
     * Re-attaches a view to the change detection tree.
     *
     * This can be used to re-attach views that were previously detached from the tree
     * using {@link ChangeDetectorRef#detach detach}. Views are attached to the tree by default.
     *
     * <!-- TODO: Add a link to a chapter on detach/reattach/local digest -->
     *
     * @usageNotes
     * ### Example
     *
     * The following example creates a component displaying `live` data. The component will detach
     * its change detector from the main change detector tree when the component's live property
     * is set to false.
     *
     * ```typescript
     * class DataProvider {
     *   data = 1;
     *
     *   constructor() {
     *     setInterval(() => {
     *       this.data = this.data * 2;
     *     }, 500);
     *   }
     * }
     *
     * @Component({
     *   selector: 'live-data',
     *   inputs: ['live'],
     *   template: 'Data: {{dataProvider.data}}'
     * })
     * class LiveData {
     *   constructor(private ref: ChangeDetectorRef, private dataProvider: DataProvider) {}
     *
     *   set live(value) {
     *     if (value) {
     *       this.ref.reattach();
     *     } else {
     *       this.ref.detach();
     *     }
     *   }
     * }
     *
     * @Component({
     *   selector: 'my-app',
     *   providers: [DataProvider],
     *   template: `
     *     Live Update: <input type="checkbox" [(ngModel)]="live">
     *     <live-data [live]="live"><live-data>
     *   `,
     * })
     * class AppComponent {
     *   live = true;
     * }
     * ```
     */

  }, {
    key: "reattach",
    value: function reattach() {
      this._lView[FLAGS] |= 128
      /* Attached */
      ;
    }
    /**
     * Checks the view and its children.
     *
     * This can also be used in combination with {@link ChangeDetectorRef#detach detach} to implement
     * local change detection checks.
     *
     * <!-- TODO: Add a link to a chapter on detach/reattach/local digest -->
     * <!-- TODO: Add a live demo once ref.detectChanges is merged into master -->
     *
     * @usageNotes
     * ### Example
     *
     * The following example defines a component with a large list of readonly data.
     * Imagine, the data changes constantly, many times per second. For performance reasons,
     * we want to check and update the list every five seconds.
     *
     * We can do that by detaching the component's change detector and doing a local change detection
     * check every five seconds.
     *
     * See {@link ChangeDetectorRef#detach detach} for more information.
     */

  }, {
    key: "detectChanges",
    value: function detectChanges() {
      detectChangesInternal(this._lView[TVIEW], this._lView, this.context);
    }
    /**
     * Checks the change detector and its children, and throws if any changes are detected.
     *
     * This is used in development mode to verify that running change detection doesn't
     * introduce other changes.
     */

  }, {
    key: "checkNoChanges",
    value: function checkNoChanges() {
      checkNoChangesInternal(this._lView[TVIEW], this._lView, this.context);
    }
  }, {
    key: "attachToViewContainerRef",
    value: function attachToViewContainerRef(vcRef) {
      if (this._appRef) {
        throw new Error('This view is already attached directly to the ApplicationRef!');
      }

      this._viewContainerRef = vcRef;
    }
  }, {
    key: "detachFromAppRef",
    value: function detachFromAppRef() {
      this._appRef = null;
      renderDetachView(this._lView[TVIEW], this._lView);
    }
  }, {
    key: "attachToAppRef",
    value: function attachToAppRef(appRef) {
      if (this._viewContainerRef) {
        throw new Error('This view is already attached to a ViewContainer!');
      }

      this._appRef = appRef;
    }
  }, {
    key: "rootNodes",
    get: function get() {
      var lView = this._lView;
      var tView = lView[TVIEW];
      return collectNativeNodes(tView, lView, tView.firstChild, []);
    }
  }, {
    key: "context",
    get: function get() {
      return this._lView[CONTEXT];
    }
  }, {
    key: "destroyed",
    get: function get() {
      return (this._lView[FLAGS] & 256
      /* Destroyed */
      ) === 256
      /* Destroyed */
      ;
    }
  }]);

  return ViewRef;
}();
/** @internal */


var RootViewRef = /*#__PURE__*/function (_ViewRef) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(RootViewRef, _ViewRef);

  var _super6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(RootViewRef);

  function RootViewRef(_view) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, RootViewRef);

    _this = _super6.call(this, _view);
    _this._view = _view;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(RootViewRef, [{
    key: "detectChanges",
    value: function detectChanges() {
      detectChangesInRootView(this._view);
    }
  }, {
    key: "checkNoChanges",
    value: function checkNoChanges() {
      checkNoChangesInRootView(this._view);
    }
  }, {
    key: "context",
    get: function get() {
      return null;
    }
  }]);

  return RootViewRef;
}(ViewRef);

function collectNativeNodes(tView, lView, tNode, result) {
  var isProjection = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;

  while (tNode !== null) {
    ngDevMode && assertNodeOfPossibleTypes(tNode, [2
    /* Element */
    , 0
    /* Container */
    , 1
    /* Projection */
    , 3
    /* ElementContainer */
    , 4
    /* IcuContainer */
    ]);
    var lNode = lView[tNode.index];

    if (lNode !== null) {
      result.push(unwrapRNode(lNode));
    } // A given lNode can represent either a native node or a LContainer (when it is a host of a
    // ViewContainerRef). When we find a LContainer we need to descend into it to collect root nodes
    // from the views in this container.


    if (isLContainer(lNode)) {
      for (var i = CONTAINER_HEADER_OFFSET; i < lNode.length; i++) {
        var lViewInAContainer = lNode[i];
        var lViewFirstChildTNode = lViewInAContainer[TVIEW].firstChild;

        if (lViewFirstChildTNode !== null) {
          collectNativeNodes(lViewInAContainer[TVIEW], lViewInAContainer, lViewFirstChildTNode, result);
        }
      }
    }

    var tNodeType = tNode.type;

    if (tNodeType === 3
    /* ElementContainer */
    || tNodeType === 4
    /* IcuContainer */
    ) {
        collectNativeNodes(tView, lView, tNode.child, result);
      } else if (tNodeType === 1
    /* Projection */
    ) {
        var componentView = lView[DECLARATION_COMPONENT_VIEW];
        var componentHost = componentView[T_HOST];
        var slotIdx = tNode.projection;
        ngDevMode && assertDefined(componentHost.projection, 'Components with projection nodes (<ng-content>) must have projection slots defined.');
        var nodesInSlot = componentHost.projection[slotIdx];

        if (Array.isArray(nodesInSlot)) {
          result.push.apply(result, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(nodesInSlot));
        } else {
          var parentView = getLViewParent(componentView);
          ngDevMode && assertDefined(parentView, 'Component views should always have a parent view (component\'s host view)');
          collectNativeNodes(parentView[TVIEW], parentView, nodesInSlot, result, true);
        }
      }

    tNode = isProjection ? tNode.projectionNext : tNode.next;
  }

  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Creates an ElementRef from the most recent node.
 *
 * @returns The ElementRef instance to use
 */


function injectElementRef(ElementRefToken) {
  return createElementRef(ElementRefToken, getCurrentTNode(), getLView());
}

var R3ElementRef;
/**
 * Creates an ElementRef given a node.
 *
 * @param ElementRefToken The ElementRef type
 * @param tNode The node for which you'd like an ElementRef
 * @param view The view to which the node belongs
 * @returns The ElementRef instance to use
 */

function createElementRef(ElementRefToken, tNode, view) {
  if (!R3ElementRef) {
    R3ElementRef = /*#__PURE__*/function (_ElementRefToken) {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ElementRef, _ElementRefToken);

      var _super7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ElementRef);

      function ElementRef() {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ElementRef);

        return _super7.apply(this, arguments);
      }

      return ElementRef;
    }(ElementRefToken);
  }

  return new R3ElementRef(getNativeByTNode(tNode, view));
}

var R3TemplateRef;
/**
 * Creates a TemplateRef given a node.
 *
 * @returns The TemplateRef instance to use
 */

function injectTemplateRef(TemplateRefToken, ElementRefToken) {
  return createTemplateRef(TemplateRefToken, ElementRefToken, getCurrentTNode(), getLView());
}
/**
 * Creates a TemplateRef and stores it on the injector.
 *
 * @param TemplateRefToken The TemplateRef type
 * @param ElementRefToken The ElementRef type
 * @param hostTNode The node on which a TemplateRef is requested
 * @param hostView The view to which the node belongs
 * @returns The TemplateRef instance or null if we can't create a TemplateRef on a given node type
 */


function createTemplateRef(TemplateRefToken, ElementRefToken, hostTNode, hostView) {
  if (!R3TemplateRef) {
    R3TemplateRef = /*#__PURE__*/function (_TemplateRefToken) {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateRef, _TemplateRefToken);

      var _super8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(TemplateRef);

      function TemplateRef(_declarationView, _declarationTContainer, elementRef) {
        var _this2;

        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TemplateRef);

        _this2 = _super8.call(this);
        _this2._declarationView = _declarationView;
        _this2._declarationTContainer = _declarationTContainer;
        _this2.elementRef = elementRef;
        return _this2;
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TemplateRef, [{
        key: "createEmbeddedView",
        value: function createEmbeddedView(context) {
          var embeddedTView = this._declarationTContainer.tViews;
          var embeddedLView = createLView(this._declarationView, embeddedTView, context, 16
          /* CheckAlways */
          , null, embeddedTView.declTNode, null, null, null, null);
          var declarationLContainer = this._declarationView[this._declarationTContainer.index];
          ngDevMode && assertLContainer(declarationLContainer);
          embeddedLView[DECLARATION_LCONTAINER] = declarationLContainer;
          var declarationViewLQueries = this._declarationView[QUERIES];

          if (declarationViewLQueries !== null) {
            embeddedLView[QUERIES] = declarationViewLQueries.createEmbeddedView(embeddedTView);
          }

          renderView(embeddedTView, embeddedLView, context);
          return new ViewRef(embeddedLView);
        }
      }]);

      return TemplateRef;
    }(TemplateRefToken);
  }

  if (hostTNode.type === 0
  /* Container */
  ) {
      ngDevMode && assertDefined(hostTNode.tViews, 'TView must be allocated');
      return new R3TemplateRef(hostView, hostTNode, createElementRef(ElementRefToken, hostTNode, hostView));
    } else {
    return null;
  }
}

var R3ViewContainerRef;
/**
 * Creates a ViewContainerRef and stores it on the injector. Or, if the ViewContainerRef
 * already exists, retrieves the existing ViewContainerRef.
 *
 * @returns The ViewContainerRef instance to use
 */

function injectViewContainerRef(ViewContainerRefToken, ElementRefToken) {
  var previousTNode = getCurrentTNode();
  return createContainerRef(ViewContainerRefToken, ElementRefToken, previousTNode, getLView());
}
/**
 * Creates a ViewContainerRef and stores it on the injector.
 *
 * @param ViewContainerRefToken The ViewContainerRef type
 * @param ElementRefToken The ElementRef type
 * @param hostTNode The node that is requesting a ViewContainerRef
 * @param hostView The view to which the node belongs
 * @returns The ViewContainerRef instance to use
 */


function createContainerRef(ViewContainerRefToken, ElementRefToken, hostTNode, hostView) {
  if (!R3ViewContainerRef) {
    R3ViewContainerRef = /*#__PURE__*/function (_ViewContainerRefToke) {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ViewContainerRef, _ViewContainerRefToke);

      var _super9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ViewContainerRef);

      function ViewContainerRef(_lContainer, _hostTNode, _hostView) {
        var _this3;

        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ViewContainerRef);

        _this3 = _super9.call(this);
        _this3._lContainer = _lContainer;
        _this3._hostTNode = _hostTNode;
        _this3._hostView = _hostView;
        return _this3;
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ViewContainerRef, [{
        key: "clear",
        value: function clear() {
          while (this.length > 0) {
            this.remove(this.length - 1);
          }
        }
      }, {
        key: "get",
        value: function get(index) {
          return this._lContainer[VIEW_REFS] !== null && this._lContainer[VIEW_REFS][index] || null;
        }
      }, {
        key: "createEmbeddedView",
        value: function createEmbeddedView(templateRef, context, index) {
          var viewRef = templateRef.createEmbeddedView(context || {});
          this.insert(viewRef, index);
          return viewRef;
        }
      }, {
        key: "createComponent",
        value: function createComponent(componentFactory, index, injector, projectableNodes, ngModuleRef) {
          var contextInjector = injector || this.parentInjector;

          if (!ngModuleRef && componentFactory.ngModule == null && contextInjector) {
            // DO NOT REFACTOR. The code here used to have a `value || undefined` expression
            // which seems to cause internal google apps to fail. This is documented in the
            // following internal bug issue: go/b/142967802
            var result = contextInjector.get(NgModuleRef, null);

            if (result) {
              ngModuleRef = result;
            }
          }

          var componentRef = componentFactory.create(contextInjector, projectableNodes, undefined, ngModuleRef);
          this.insert(componentRef.hostView, index);
          return componentRef;
        }
      }, {
        key: "insert",
        value: function insert(viewRef, index) {
          var lView = viewRef._lView;
          var tView = lView[TVIEW];

          if (viewRef.destroyed) {
            throw new Error('Cannot insert a destroyed View in a ViewContainer!');
          }

          this.allocateContainerIfNeeded();

          if (viewAttachedToContainer(lView)) {
            // If view is already attached, detach it first so we clean up references appropriately.
            var prevIdx = this.indexOf(viewRef); // A view might be attached either to this or a different container. The `prevIdx` for
            // those cases will be:
            // equal to -1 for views attached to this ViewContainerRef
            // >= 0 for views attached to a different ViewContainerRef

            if (prevIdx !== -1) {
              this.detach(prevIdx);
            } else {
              var prevLContainer = lView[PARENT];
              ngDevMode && assertEqual(isLContainer(prevLContainer), true, 'An attached view should have its PARENT point to a container.'); // We need to re-create a R3ViewContainerRef instance since those are not stored on
              // LView (nor anywhere else).

              var prevVCRef = new R3ViewContainerRef(prevLContainer, prevLContainer[T_HOST], prevLContainer[PARENT]);
              prevVCRef.detach(prevVCRef.indexOf(viewRef));
            }
          } // Logical operation of adding `LView` to `LContainer`


          var adjustedIdx = this._adjustIndex(index);

          var lContainer = this._lContainer;
          insertView(tView, lView, lContainer, adjustedIdx); // Physical operation of adding the DOM nodes.

          var beforeNode = getBeforeNodeForView(adjustedIdx, lContainer);
          var renderer = lView[RENDERER];
          var renderParent = nativeParentNode(renderer, lContainer[NATIVE]);

          if (renderParent !== null) {
            addViewToContainer(tView, lContainer[T_HOST], renderer, lView, renderParent, beforeNode);
          }

          viewRef.attachToViewContainerRef(this);
          addToArray(lContainer[VIEW_REFS], adjustedIdx, viewRef);
          return viewRef;
        }
      }, {
        key: "move",
        value: function move(viewRef, newIndex) {
          if (viewRef.destroyed) {
            throw new Error('Cannot move a destroyed View in a ViewContainer!');
          }

          return this.insert(viewRef, newIndex);
        }
      }, {
        key: "indexOf",
        value: function indexOf(viewRef) {
          var viewRefsArr = this._lContainer[VIEW_REFS];
          return viewRefsArr !== null ? viewRefsArr.indexOf(viewRef) : -1;
        }
      }, {
        key: "remove",
        value: function remove(index) {
          this.allocateContainerIfNeeded();

          var adjustedIdx = this._adjustIndex(index, -1);

          var detachedView = detachView(this._lContainer, adjustedIdx);

          if (detachedView) {
            // Before destroying the view, remove it from the container's array of `ViewRef`s.
            // This ensures the view container length is updated before calling
            // `destroyLView`, which could recursively call view container methods that
            // rely on an accurate container length.
            // (e.g. a method on this view container being called by a child directive's OnDestroy
            // lifecycle hook)
            removeFromArray(this._lContainer[VIEW_REFS], adjustedIdx);
            destroyLView(detachedView[TVIEW], detachedView);
          }
        }
      }, {
        key: "detach",
        value: function detach(index) {
          this.allocateContainerIfNeeded();

          var adjustedIdx = this._adjustIndex(index, -1);

          var view = detachView(this._lContainer, adjustedIdx);
          var wasDetached = view && removeFromArray(this._lContainer[VIEW_REFS], adjustedIdx) != null;
          return wasDetached ? new ViewRef(view) : null;
        }
      }, {
        key: "_adjustIndex",
        value: function _adjustIndex(index) {
          var shift = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

          if (index == null) {
            return this.length + shift;
          }

          if (ngDevMode) {
            assertGreaterThan(index, -1, "ViewRef index must be positive, got ".concat(index)); // +1 because it's legal to insert at the end.

            assertLessThan(index, this.length + 1 + shift, 'index');
          }

          return index;
        }
      }, {
        key: "allocateContainerIfNeeded",
        value: function allocateContainerIfNeeded() {
          if (this._lContainer[VIEW_REFS] === null) {
            this._lContainer[VIEW_REFS] = [];
          }
        }
      }, {
        key: "element",
        get: function get() {
          return createElementRef(ElementRefToken, this._hostTNode, this._hostView);
        }
      }, {
        key: "injector",
        get: function get() {
          return new NodeInjector(this._hostTNode, this._hostView);
        }
        /** @deprecated No replacement */

      }, {
        key: "parentInjector",
        get: function get() {
          var parentLocation = getParentInjectorLocation(this._hostTNode, this._hostView);

          if (hasParentInjector(parentLocation)) {
            var parentView = getParentInjectorView(parentLocation, this._hostView);
            var injectorIndex = getParentInjectorIndex(parentLocation);
            ngDevMode && assertNodeInjector(parentView, injectorIndex);
            var parentTNode = parentView[TVIEW].data[injectorIndex + 8
            /* TNODE */
            ];
            return new NodeInjector(parentTNode, parentView);
          } else {
            return new NodeInjector(null, this._hostView);
          }
        }
      }, {
        key: "length",
        get: function get() {
          return this._lContainer.length - CONTAINER_HEADER_OFFSET;
        }
      }]);

      return ViewContainerRef;
    }(ViewContainerRefToken);
  }

  ngDevMode && assertNodeOfPossibleTypes(hostTNode, [0
  /* Container */
  , 2
  /* Element */
  , 3
  /* ElementContainer */
  ]);
  var lContainer;
  var slotValue = hostView[hostTNode.index];

  if (isLContainer(slotValue)) {
    // If the host is a container, we don't need to create a new LContainer
    lContainer = slotValue;
  } else {
    var commentNode; // If the host is an element container, the native host element is guaranteed to be a
    // comment and we can reuse that comment as anchor element for the new LContainer.
    // The comment node in question is already part of the DOM structure so we don't need to append
    // it again.

    if (hostTNode.type === 3
    /* ElementContainer */
    ) {
        commentNode = unwrapRNode(slotValue);
      } else {
      ngDevMode && ngDevMode.rendererCreateComment++;
      commentNode = hostView[RENDERER].createComment(ngDevMode ? 'container' : ''); // A `ViewContainerRef` can be injected by the root (topmost / bootstrapped) component. In
      // this case we can't use TView / TNode data structures to insert container's marker node
      // (both a parent of a comment node and the comment node itself are not part of any view). In
      // this specific case we use low-level DOM manipulation to insert container's marker (comment)
      // node.

      if (isRootView(hostView)) {
        var renderer = hostView[RENDERER];
        var hostNative = getNativeByTNode(hostTNode, hostView);
        var parentOfHostNative = nativeParentNode(renderer, hostNative);
        nativeInsertBefore(renderer, parentOfHostNative, commentNode, nativeNextSibling(renderer, hostNative));
      } else {
        appendChild(hostView[TVIEW], hostView, commentNode, hostTNode);
      }
    }

    hostView[hostTNode.index] = lContainer = createLContainer(slotValue, hostView, commentNode, hostTNode);
    addToViewTree(hostView, lContainer);
  }

  return new R3ViewContainerRef(lContainer, hostTNode, hostView);
}
/** Returns a ChangeDetectorRef (a.k.a. a ViewRef) */


function injectChangeDetectorRef() {
  var isPipe = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  return createViewRef(getCurrentTNode(), getLView(), isPipe);
}
/**
 * Creates a ViewRef and stores it on the injector as ChangeDetectorRef (public alias).
 *
 * @param tNode The node that is requesting a ChangeDetectorRef
 * @param lView The view to which the node belongs
 * @param isPipe Whether the view is being injected into a pipe.
 * @returns The ChangeDetectorRef to use
 */


function createViewRef(tNode, lView, isPipe) {
  // `isComponentView` will be true for Component and Directives (but not for Pipes).
  // See https://github.com/angular/angular/pull/33072 for proper fix
  var isComponentView = !isPipe && isComponentHost(tNode);

  if (isComponentView) {
    // The LView represents the location where the component is declared.
    // Instead we want the LView for the component View and so we need to look it up.
    var componentView = getComponentLViewByIndex(tNode.index, lView); // look down

    return new ViewRef(componentView, componentView);
  } else if (tNode.type === 2
  /* Element */
  || tNode.type === 0
  /* Container */
  || tNode.type === 3
  /* ElementContainer */
  || tNode.type === 4
  /* IcuContainer */
  ) {
      // The LView represents the location where the injection is requested from.
      // We need to locate the containing LView (in case where the `lView` is an embedded view)
      var hostComponentView = lView[DECLARATION_COMPONENT_VIEW]; // look up

      return new ViewRef(hostComponentView, lView);
    }

  return null;
}
/** Returns a Renderer2 (or throws when application was bootstrapped with Renderer3) */


function getOrCreateRenderer2(view) {
  var renderer = view[RENDERER];

  if (isProceduralRenderer(renderer)) {
    return renderer;
  } else {
    throw new Error('Cannot inject Renderer2 when the application uses Renderer3!');
  }
}
/** Injects a Renderer2 for the current component. */


function injectRenderer2() {
  // We need the Renderer to be based on the component that it's being injected into, however since
  // DI happens before we've entered its view, `getLView` will return the parent view instead.
  var lView = getLView();
  var tNode = getCurrentTNode();
  var nodeAtIndex = getComponentLViewByIndex(tNode.index, lView);
  return getOrCreateRenderer2(isLView(nodeAtIndex) ? nodeAtIndex : lView);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Base class that provides change detection functionality.
 * A change-detection tree collects all views that are to be checked for changes.
 * Use the methods to add and remove views from the tree, initiate change-detection,
 * and explicitly mark views as _dirty_, meaning that they have changed and need to be re-rendered.
 *
 * @see [Using change detection hooks](guide/lifecycle-hooks#using-change-detection-hooks)
 * @see [Defining custom change detection](guide/lifecycle-hooks#defining-custom-change-detection)
 *
 * @usageNotes
 *
 * The following examples demonstrate how to modify default change-detection behavior
 * to perform explicit detection when needed.
 *
 * ### Use `markForCheck()` with `CheckOnce` strategy
 *
 * The following example sets the `OnPush` change-detection strategy for a component
 * (`CheckOnce`, rather than the default `CheckAlways`), then forces a second check
 * after an interval. See [live demo](http://plnkr.co/edit/GC512b?p=preview).
 *
 * <code-example path="core/ts/change_detect/change-detection.ts"
 * region="mark-for-check"></code-example>
 *
 * ### Detach change detector to limit how often check occurs
 *
 * The following example defines a component with a large list of read-only data
 * that is expected to change constantly, many times per second.
 * To improve performance, we want to check and update the list
 * less often than the changes actually occur. To do that, we detach
 * the component's change detector and perform an explicit local check every five seconds.
 *
 * <code-example path="core/ts/change_detect/change-detection.ts" region="detach"></code-example>
 *
 *
 * ### Reattaching a detached component
 *
 * The following example creates a component displaying live data.
 * The component detaches its change detector from the main change detector tree
 * when the `live` property is set to false, and reattaches it when the property
 * becomes true.
 *
 * <code-example path="core/ts/change_detect/change-detection.ts" region="reattach"></code-example>
 *
 * @publicApi
 */


var ChangeDetectorRef = function ChangeDetectorRef() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ChangeDetectorRef);
};
/**
 * @internal
 * @nocollapse
 */


ChangeDetectorRef.__NG_ELEMENT_ID__ = function () {
  return SWITCH_CHANGE_DETECTOR_REF_FACTORY();
};

var SWITCH_CHANGE_DETECTOR_REF_FACTORY__POST_R3__ = injectChangeDetectorRef;

var SWITCH_CHANGE_DETECTOR_REF_FACTORY__PRE_R3__ = function SWITCH_CHANGE_DETECTOR_REF_FACTORY__PRE_R3__() {};

var ɵ0$5 = SWITCH_CHANGE_DETECTOR_REF_FACTORY__POST_R3__;
var SWITCH_CHANGE_DETECTOR_REF_FACTORY = SWITCH_CHANGE_DETECTOR_REF_FACTORY__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * Represents a type that a Component or other object is instances of.
 *
 * An example of a `Type` is `MyCustomComponent` class, which in JavaScript is represented by
 * the `MyCustomComponent` constructor function.
 *
 * @publicApi
 */

var Type = Function;

function isType(v) {
  return typeof v === 'function';
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/*
 * #########################
 * Attention: These Regular expressions have to hold even if the code is minified!
 * ##########################
 */

/**
 * Regular expression that detects pass-through constructors for ES5 output. This Regex
 * intends to capture the common delegation pattern emitted by TypeScript and Babel. Also
 * it intends to capture the pattern where existing constructors have been downleveled from
 * ES2015 to ES5 using TypeScript w/ downlevel iteration. e.g.
 *
 * ```
 *   function MyClass() {
 *     var _this = _super.apply(this, arguments) || this;
 * ```
 *
 * ```
 *   function MyClass() {
 *     var _this = _super.apply(this, __spread(arguments)) || this;
 * ```
 *
 * More details can be found in: https://github.com/angular/angular/issues/38453.
 */


var ES5_DELEGATE_CTOR = /^function\s+\S+\(\)\s*{[\s\S]+\.apply\(this,\s*(arguments|[^()]+\(arguments\))\)/;
/** Regular expression that detects ES2015 classes which extend from other classes. */

var ES2015_INHERITED_CLASS = /^class\s+[A-Za-z\d$_]*\s*extends\s+[^{]+{/;
/**
 * Regular expression that detects ES2015 classes which extend from other classes and
 * have an explicit constructor defined.
 */

var ES2015_INHERITED_CLASS_WITH_CTOR = /^class\s+[A-Za-z\d$_]*\s*extends\s+[^{]+{[\s\S]*constructor\s*\(/;
/**
 * Regular expression that detects ES2015 classes which extend from other classes
 * and inherit a constructor.
 */

var ES2015_INHERITED_CLASS_WITH_DELEGATE_CTOR = /^class\s+[A-Za-z\d$_]*\s*extends\s+[^{]+{[\s\S]*constructor\s*\(\)\s*{\s*super\(\.\.\.arguments\)/;
/**
 * Determine whether a stringified type is a class which delegates its constructor
 * to its parent.
 *
 * This is not trivial since compiled code can actually contain a constructor function
 * even if the original source code did not. For instance, when the child class contains
 * an initialized instance property.
 */

function isDelegateCtor(typeStr) {
  return ES5_DELEGATE_CTOR.test(typeStr) || ES2015_INHERITED_CLASS_WITH_DELEGATE_CTOR.test(typeStr) || ES2015_INHERITED_CLASS.test(typeStr) && !ES2015_INHERITED_CLASS_WITH_CTOR.test(typeStr);
}

var ReflectionCapabilities = /*#__PURE__*/function () {
  function ReflectionCapabilities(reflect) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ReflectionCapabilities);

    this._reflect = reflect || _global['Reflect'];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ReflectionCapabilities, [{
    key: "isReflectionEnabled",
    value: function isReflectionEnabled() {
      return true;
    }
  }, {
    key: "factory",
    value: function factory(t) {
      return function () {
        for (var _len8 = arguments.length, args = new Array(_len8), _key8 = 0; _key8 < _len8; _key8++) {
          args[_key8] = arguments[_key8];
        }

        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(t, args);
      };
    }
    /** @internal */

  }, {
    key: "_zipTypesAndAnnotations",
    value: function _zipTypesAndAnnotations(paramTypes, paramAnnotations) {
      var result;

      if (typeof paramTypes === 'undefined') {
        result = newArray(paramAnnotations.length);
      } else {
        result = newArray(paramTypes.length);
      }

      for (var i = 0; i < result.length; i++) {
        // TS outputs Object for parameters without types, while Traceur omits
        // the annotations. For now we preserve the Traceur behavior to aid
        // migration, but this can be revisited.
        if (typeof paramTypes === 'undefined') {
          result[i] = [];
        } else if (paramTypes[i] && paramTypes[i] != Object) {
          result[i] = [paramTypes[i]];
        } else {
          result[i] = [];
        }

        if (paramAnnotations && paramAnnotations[i] != null) {
          result[i] = result[i].concat(paramAnnotations[i]);
        }
      }

      return result;
    }
  }, {
    key: "_ownParameters",
    value: function _ownParameters(type, parentCtor) {
      var typeStr = type.toString(); // If we have no decorators, we only have function.length as metadata.
      // In that case, to detect whether a child class declared an own constructor or not,
      // we need to look inside of that constructor to check whether it is
      // just calling the parent.
      // This also helps to work around for https://github.com/Microsoft/TypeScript/issues/12439
      // that sets 'design:paramtypes' to []
      // if a class inherits from another class but has no ctor declared itself.

      if (isDelegateCtor(typeStr)) {
        return null;
      } // Prefer the direct API.


      if (type.parameters && type.parameters !== parentCtor.parameters) {
        return type.parameters;
      } // API of tsickle for lowering decorators to properties on the class.


      var tsickleCtorParams = type.ctorParameters;

      if (tsickleCtorParams && tsickleCtorParams !== parentCtor.ctorParameters) {
        // Newer tsickle uses a function closure
        // Retain the non-function case for compatibility with older tsickle
        var ctorParameters = typeof tsickleCtorParams === 'function' ? tsickleCtorParams() : tsickleCtorParams;

        var _paramTypes = ctorParameters.map(function (ctorParam) {
          return ctorParam && ctorParam.type;
        });

        var _paramAnnotations = ctorParameters.map(function (ctorParam) {
          return ctorParam && convertTsickleDecoratorIntoMetadata(ctorParam.decorators);
        });

        return this._zipTypesAndAnnotations(_paramTypes, _paramAnnotations);
      } // API for metadata created by invoking the decorators.


      var paramAnnotations = type.hasOwnProperty(PARAMETERS) && type[PARAMETERS];

      var paramTypes = this._reflect && this._reflect.getOwnMetadata && this._reflect.getOwnMetadata('design:paramtypes', type);

      if (paramTypes || paramAnnotations) {
        return this._zipTypesAndAnnotations(paramTypes, paramAnnotations);
      } // If a class has no decorators, at least create metadata
      // based on function.length.
      // Note: We know that this is a real constructor as we checked
      // the content of the constructor above.


      return newArray(type.length);
    }
  }, {
    key: "parameters",
    value: function parameters(type) {
      // Note: only report metadata if we have at least one class decorator
      // to stay in sync with the static reflector.
      if (!isType(type)) {
        return [];
      }

      var parentCtor = getParentCtor(type);

      var parameters = this._ownParameters(type, parentCtor);

      if (!parameters && parentCtor !== Object) {
        parameters = this.parameters(parentCtor);
      }

      return parameters || [];
    }
  }, {
    key: "_ownAnnotations",
    value: function _ownAnnotations(typeOrFunc, parentCtor) {
      // Prefer the direct API.
      if (typeOrFunc.annotations && typeOrFunc.annotations !== parentCtor.annotations) {
        var annotations = typeOrFunc.annotations;

        if (typeof annotations === 'function' && annotations.annotations) {
          annotations = annotations.annotations;
        }

        return annotations;
      } // API of tsickle for lowering decorators to properties on the class.


      if (typeOrFunc.decorators && typeOrFunc.decorators !== parentCtor.decorators) {
        return convertTsickleDecoratorIntoMetadata(typeOrFunc.decorators);
      } // API for metadata created by invoking the decorators.


      if (typeOrFunc.hasOwnProperty(ANNOTATIONS)) {
        return typeOrFunc[ANNOTATIONS];
      }

      return null;
    }
  }, {
    key: "annotations",
    value: function annotations(typeOrFunc) {
      if (!isType(typeOrFunc)) {
        return [];
      }

      var parentCtor = getParentCtor(typeOrFunc);
      var ownAnnotations = this._ownAnnotations(typeOrFunc, parentCtor) || [];
      var parentAnnotations = parentCtor !== Object ? this.annotations(parentCtor) : [];
      return parentAnnotations.concat(ownAnnotations);
    }
  }, {
    key: "_ownPropMetadata",
    value: function _ownPropMetadata(typeOrFunc, parentCtor) {
      // Prefer the direct API.
      if (typeOrFunc.propMetadata && typeOrFunc.propMetadata !== parentCtor.propMetadata) {
        var propMetadata = typeOrFunc.propMetadata;

        if (typeof propMetadata === 'function' && propMetadata.propMetadata) {
          propMetadata = propMetadata.propMetadata;
        }

        return propMetadata;
      } // API of tsickle for lowering decorators to properties on the class.


      if (typeOrFunc.propDecorators && typeOrFunc.propDecorators !== parentCtor.propDecorators) {
        var propDecorators = typeOrFunc.propDecorators;
        var _propMetadata = {};
        Object.keys(propDecorators).forEach(function (prop) {
          _propMetadata[prop] = convertTsickleDecoratorIntoMetadata(propDecorators[prop]);
        });
        return _propMetadata;
      } // API for metadata created by invoking the decorators.


      if (typeOrFunc.hasOwnProperty(PROP_METADATA)) {
        return typeOrFunc[PROP_METADATA];
      }

      return null;
    }
  }, {
    key: "propMetadata",
    value: function propMetadata(typeOrFunc) {
      if (!isType(typeOrFunc)) {
        return {};
      }

      var parentCtor = getParentCtor(typeOrFunc);
      var propMetadata = {};

      if (parentCtor !== Object) {
        var parentPropMetadata = this.propMetadata(parentCtor);
        Object.keys(parentPropMetadata).forEach(function (propName) {
          propMetadata[propName] = parentPropMetadata[propName];
        });
      }

      var ownPropMetadata = this._ownPropMetadata(typeOrFunc, parentCtor);

      if (ownPropMetadata) {
        Object.keys(ownPropMetadata).forEach(function (propName) {
          var decorators = [];

          if (propMetadata.hasOwnProperty(propName)) {
            decorators.push.apply(decorators, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(propMetadata[propName]));
          }

          decorators.push.apply(decorators, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(ownPropMetadata[propName]));
          propMetadata[propName] = decorators;
        });
      }

      return propMetadata;
    }
  }, {
    key: "ownPropMetadata",
    value: function ownPropMetadata(typeOrFunc) {
      if (!isType(typeOrFunc)) {
        return {};
      }

      return this._ownPropMetadata(typeOrFunc, getParentCtor(typeOrFunc)) || {};
    }
  }, {
    key: "hasLifecycleHook",
    value: function hasLifecycleHook(type, lcProperty) {
      return type instanceof Type && lcProperty in type.prototype;
    }
  }, {
    key: "guards",
    value: function guards(type) {
      return {};
    }
  }, {
    key: "getter",
    value: function getter(name) {
      return new Function('o', 'return o.' + name + ';');
    }
  }, {
    key: "setter",
    value: function setter(name) {
      return new Function('o', 'v', 'return o.' + name + ' = v;');
    }
  }, {
    key: "method",
    value: function method(name) {
      var functionBody = "if (!o.".concat(name, ") throw new Error('\"").concat(name, "\" is undefined');\n        return o.").concat(name, ".apply(o, args);");
      return new Function('o', 'args', functionBody);
    } // There is not a concept of import uri in Js, but this is useful in developing Dart applications.

  }, {
    key: "importUri",
    value: function importUri(type) {
      // StaticSymbol
      if (typeof type === 'object' && type['filePath']) {
        return type['filePath'];
      } // Runtime type


      return "./".concat(stringify(type));
    }
  }, {
    key: "resourceUri",
    value: function resourceUri(type) {
      return "./".concat(stringify(type));
    }
  }, {
    key: "resolveIdentifier",
    value: function resolveIdentifier(name, moduleUrl, members, runtime) {
      return runtime;
    }
  }, {
    key: "resolveEnum",
    value: function resolveEnum(enumIdentifier, name) {
      return enumIdentifier[name];
    }
  }]);

  return ReflectionCapabilities;
}();

function convertTsickleDecoratorIntoMetadata(decoratorInvocations) {
  if (!decoratorInvocations) {
    return [];
  }

  return decoratorInvocations.map(function (decoratorInvocation) {
    var decoratorType = decoratorInvocation.type;
    var annotationCls = decoratorType.annotationCls;
    var annotationArgs = decoratorInvocation.args ? decoratorInvocation.args : [];
    return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(annotationCls, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(annotationArgs));
  });
}

function getParentCtor(ctor) {
  var parentProto = ctor.prototype ? Object.getPrototypeOf(ctor.prototype) : null;
  var parentCtor = parentProto ? parentProto.constructor : null; // Note: We always use `Object` as the null value
  // to simplify checking later on.

  return parentCtor || Object;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _reflect = null;

function getReflect() {
  return _reflect = _reflect || new ReflectionCapabilities();
}

function reflectDependencies(type) {
  return convertDependencies(getReflect().parameters(type));
}

function convertDependencies(deps) {
  var compiler = getCompilerFacade();
  return deps.map(function (dep) {
    return reflectDependency(compiler, dep);
  });
}

function reflectDependency(compiler, dep) {
  var meta = {
    token: null,
    host: false,
    optional: false,
    resolved: compiler.R3ResolvedDependencyType.Token,
    self: false,
    skipSelf: false
  };

  function setTokenAndResolvedType(token) {
    meta.resolved = compiler.R3ResolvedDependencyType.Token;
    meta.token = token;
  }

  if (Array.isArray(dep) && dep.length > 0) {
    for (var j = 0; j < dep.length; j++) {
      var param = dep[j];

      if (param === undefined) {
        // param may be undefined if type of dep is not set by ngtsc
        continue;
      }

      var proto = Object.getPrototypeOf(param);

      if (param instanceof Optional || proto.ngMetadataName === 'Optional') {
        meta.optional = true;
      } else if (param instanceof SkipSelf || proto.ngMetadataName === 'SkipSelf') {
        meta.skipSelf = true;
      } else if (param instanceof Self || proto.ngMetadataName === 'Self') {
        meta.self = true;
      } else if (param instanceof Host || proto.ngMetadataName === 'Host') {
        meta.host = true;
      } else if (param instanceof Inject) {
        meta.token = param.token;
      } else if (param instanceof Attribute) {
        if (param.attributeName === undefined) {
          throw new Error("Attribute name must be defined.");
        }

        meta.token = param.attributeName;
        meta.resolved = compiler.R3ResolvedDependencyType.Attribute;
      } else if (param === ChangeDetectorRef) {
        meta.token = param;
        meta.resolved = compiler.R3ResolvedDependencyType.ChangeDetectorRef;
      } else {
        setTokenAndResolvedType(param);
      }
    }
  } else if (dep === undefined || Array.isArray(dep) && dep.length === 0) {
    meta.token = undefined;
    meta.resolved = R3ResolvedDependencyType.Invalid;
  } else {
    setTokenAndResolvedType(dep);
  }

  return meta;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Compile an Angular injectable according to its `Injectable` metadata, and patch the resulting
 * injectable def (`ɵprov`) onto the injectable type.
 */


function compileInjectable(type, srcMeta) {
  var ngInjectableDef = null;
  var ngFactoryDef = null; // if NG_PROV_DEF is already defined on this class then don't overwrite it

  if (!type.hasOwnProperty(NG_PROV_DEF)) {
    Object.defineProperty(type, NG_PROV_DEF, {
      get: function get() {
        if (ngInjectableDef === null) {
          ngInjectableDef = getCompilerFacade().compileInjectable(angularCoreDiEnv, "ng:///".concat(type.name, "/\u0275prov.js"), getInjectableMetadata(type, srcMeta));
        }

        return ngInjectableDef;
      }
    }); // On IE10 properties defined via `defineProperty` won't be inherited by child classes,
    // which will break inheriting the injectable definition from a grandparent through an
    // undecorated parent class. We work around it by defining a method which should be used
    // as a fallback. This should only be a problem in JIT mode, because in AOT TypeScript
    // seems to have a workaround for static properties. When inheriting from an undecorated
    // parent is no longer supported (v11 or later), this can safely be removed.

    if (!type.hasOwnProperty(NG_PROV_DEF_FALLBACK)) {
      type[NG_PROV_DEF_FALLBACK] = function () {
        return type[NG_PROV_DEF];
      };
    }
  } // if NG_FACTORY_DEF is already defined on this class then don't overwrite it


  if (!type.hasOwnProperty(NG_FACTORY_DEF)) {
    Object.defineProperty(type, NG_FACTORY_DEF, {
      get: function get() {
        if (ngFactoryDef === null) {
          var metadata = getInjectableMetadata(type, srcMeta);
          var compiler = getCompilerFacade();
          ngFactoryDef = compiler.compileFactory(angularCoreDiEnv, "ng:///".concat(type.name, "/\u0275fac.js"), {
            name: metadata.name,
            type: metadata.type,
            typeArgumentCount: metadata.typeArgumentCount,
            deps: reflectDependencies(type),
            injectFn: 'inject',
            target: compiler.R3FactoryTarget.Injectable
          });
        }

        return ngFactoryDef;
      },
      // Leave this configurable so that the factories from directives or pipes can take precedence.
      configurable: true
    });
  }
}

var ɵ0$6 = getClosureSafeProperty;
var USE_VALUE$1 = getClosureSafeProperty({
  provide: String,
  useValue: ɵ0$6
});

function isUseClassProvider(meta) {
  return meta.useClass !== undefined;
}

function isUseValueProvider(meta) {
  return USE_VALUE$1 in meta;
}

function isUseFactoryProvider(meta) {
  return meta.useFactory !== undefined;
}

function isUseExistingProvider(meta) {
  return meta.useExisting !== undefined;
}

function getInjectableMetadata(type, srcMeta) {
  // Allow the compilation of a class with a `@Injectable()` decorator without parameters
  var meta = srcMeta || {
    providedIn: null
  };
  var compilerMeta = {
    name: type.name,
    type: type,
    typeArgumentCount: 0,
    providedIn: meta.providedIn,
    userDeps: undefined
  };

  if ((isUseClassProvider(meta) || isUseFactoryProvider(meta)) && meta.deps !== undefined) {
    compilerMeta.userDeps = convertDependencies(meta.deps);
  }

  if (isUseClassProvider(meta)) {
    // The user explicitly specified useClass, and may or may not have provided deps.
    compilerMeta.useClass = resolveForwardRef(meta.useClass);
  } else if (isUseValueProvider(meta)) {
    // The user explicitly specified useValue.
    compilerMeta.useValue = resolveForwardRef(meta.useValue);
  } else if (isUseFactoryProvider(meta)) {
    // The user explicitly specified useFactory.
    compilerMeta.useFactory = meta.useFactory;
  } else if (isUseExistingProvider(meta)) {
    // The user explicitly specified useExisting.
    compilerMeta.useExisting = resolveForwardRef(meta.useExisting);
  }

  return compilerMeta;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$7 = getClosureSafeProperty;
var USE_VALUE$2 = getClosureSafeProperty({
  provide: String,
  useValue: ɵ0$7
});
var EMPTY_ARRAY$1 = [];

function convertInjectableProviderToFactory(type, provider) {
  if (!provider) {
    var reflectionCapabilities = new ReflectionCapabilities();
    var deps = reflectionCapabilities.parameters(type); // TODO - convert to flags.

    return function () {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(type, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(injectArgs(deps)));
    };
  }

  if (USE_VALUE$2 in provider) {
    var valueProvider = provider;
    return function () {
      return valueProvider.useValue;
    };
  } else if (provider.useExisting) {
    var existingProvider = provider;
    return function () {
      return ɵɵinject(resolveForwardRef(existingProvider.useExisting));
    };
  } else if (provider.useFactory) {
    var factoryProvider = provider;
    return function () {
      return factoryProvider.useFactory.apply(factoryProvider, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(injectArgs(factoryProvider.deps || EMPTY_ARRAY$1)));
    };
  } else if (provider.useClass) {
    var classProvider = provider;
    var _deps = provider.deps;

    if (!_deps) {
      var _reflectionCapabilities = new ReflectionCapabilities();

      _deps = _reflectionCapabilities.parameters(type);
    }

    return function () {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(resolveForwardRef(classProvider.useClass), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(injectArgs(_deps)));
    };
  } else {
    var _deps2 = provider.deps;

    if (!_deps2) {
      var _reflectionCapabilities2 = new ReflectionCapabilities();

      _deps2 = _reflectionCapabilities2.parameters(type);
    }

    return function () {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(type, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(injectArgs(_deps2)));
    };
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$8 = function ɵ0$8(type, meta) {
  return SWITCH_COMPILE_INJECTABLE(type, meta);
};
/**
 * Injectable decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */


var Injectable = makeDecorator('Injectable', undefined, undefined, undefined, ɵ0$8);
/**
 * Supports @Injectable() in JIT mode for Render2.
 */

function render2CompileInjectable(injectableType, options) {
  if (options && options.providedIn !== undefined && !getInjectableDef(injectableType)) {
    injectableType.ɵprov = ɵɵdefineInjectable({
      token: injectableType,
      providedIn: options.providedIn,
      factory: convertInjectableProviderToFactory(injectableType, options)
    });
  }
}

var SWITCH_COMPILE_INJECTABLE__POST_R3__ = compileInjectable;
var SWITCH_COMPILE_INJECTABLE__PRE_R3__ = render2CompileInjectable;
var SWITCH_COMPILE_INJECTABLE = SWITCH_COMPILE_INJECTABLE__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An internal token whose presence in an injector indicates that the injector should treat itself
 * as a root scoped injector when processing requests for unknown tokens which may indicate
 * they are provided in the root scope.
 */

var INJECTOR_SCOPE = new InjectionToken('Set Injector scope.');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Marker which indicates that a value has not yet been created from the factory function.
 */

var NOT_YET = {};
/**
 * Marker which indicates that the factory function for a token is in the process of being called.
 *
 * If the injector is asked to inject a token with its value set to CIRCULAR, that indicates
 * injection of a dependency has recursively attempted to inject the original token, and there is
 * a circular dependency among the providers.
 */

var CIRCULAR = {};
var EMPTY_ARRAY$2 = [];
/**
 * A lazily initialized NullInjector.
 */

var NULL_INJECTOR = undefined;

function getNullInjector() {
  if (NULL_INJECTOR === undefined) {
    NULL_INJECTOR = new NullInjector();
  }

  return NULL_INJECTOR;
}
/**
 * Create a new `Injector` which is configured using a `defType` of `InjectorType<any>`s.
 *
 * @publicApi
 */


function createInjector(defType) {
  var parent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var additionalProviders = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var name = arguments.length > 3 ? arguments[3] : undefined;
  var injector = createInjectorWithoutInjectorInstances(defType, parent, additionalProviders, name);

  injector._resolveInjectorDefTypes();

  return injector;
}
/**
 * Creates a new injector without eagerly resolving its injector types. Can be used in places
 * where resolving the injector types immediately can lead to an infinite loop. The injector types
 * should be resolved at a later point by calling `_resolveInjectorDefTypes`.
 */


function createInjectorWithoutInjectorInstances(defType) {
  var parent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var additionalProviders = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var name = arguments.length > 3 ? arguments[3] : undefined;
  return new R3Injector(defType, additionalProviders, parent || getNullInjector(), name);
}

var R3Injector = /*#__PURE__*/function () {
  function R3Injector(def, additionalProviders, parent) {
    var _this4 = this;

    var source = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, R3Injector);

    this.parent = parent;
    /**
     * Map of tokens to records which contain the instances of those tokens.
     * - `null` value implies that we don't have the record. Used by tree-shakable injectors
     * to prevent further searches.
     */

    this.records = new Map();
    /**
     * The transitive set of `InjectorType`s which define this injector.
     */

    this.injectorDefTypes = new Set();
    /**
     * Set of values instantiated by this injector which contain `ngOnDestroy` lifecycle hooks.
     */

    this.onDestroy = new Set();
    this._destroyed = false;
    var dedupStack = []; // Start off by creating Records for every provider declared in every InjectorType
    // included transitively in additional providers then do the same for `def`. This order is
    // important because `def` may include providers that override ones in additionalProviders.

    additionalProviders && deepForEach(additionalProviders, function (provider) {
      return _this4.processProvider(provider, def, additionalProviders);
    });
    deepForEach([def], function (injectorDef) {
      return _this4.processInjectorType(injectorDef, [], dedupStack);
    }); // Make sure the INJECTOR token provides this injector.

    this.records.set(INJECTOR, makeRecord(undefined, this)); // Detect whether this injector has the APP_ROOT_SCOPE token and thus should provide
    // any injectable scoped to APP_ROOT_SCOPE.

    var record = this.records.get(INJECTOR_SCOPE);
    this.scope = record != null ? record.value : null; // Source name, used for debugging

    this.source = source || (typeof def === 'object' ? null : stringify(def));
  }
  /**
   * Flag indicating that this injector was previously destroyed.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(R3Injector, [{
    key: "destroy",

    /**
     * Destroy the injector and release references to every instance or provider associated with it.
     *
     * Also calls the `OnDestroy` lifecycle hooks of every instance that was created for which a
     * hook was found.
     */
    value: function destroy() {
      this.assertNotDestroyed(); // Set destroyed = true first, in case lifecycle hooks re-enter destroy().

      this._destroyed = true;

      try {
        // Call all the lifecycle hooks.
        this.onDestroy.forEach(function (service) {
          return service.ngOnDestroy();
        });
      } finally {
        // Release all references.
        this.records.clear();
        this.onDestroy.clear();
        this.injectorDefTypes.clear();
      }
    }
  }, {
    key: "get",
    value: function get(token) {
      var notFoundValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : THROW_IF_NOT_FOUND;
      var flags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : InjectFlags.Default;
      this.assertNotDestroyed(); // Set the injection context.

      var previousInjector = setCurrentInjector(this);

      try {
        // Check for the SkipSelf flag.
        if (!(flags & InjectFlags.SkipSelf)) {
          // SkipSelf isn't set, check if the record belongs to this injector.
          var record = this.records.get(token);

          if (record === undefined) {
            // No record, but maybe the token is scoped to this injector. Look for an injectable
            // def with a scope matching this injector.
            var def = couldBeInjectableType(token) && getInjectableDef(token);

            if (def && this.injectableDefInScope(def)) {
              // Found an injectable def and it's scoped to this injector. Pretend as if it was here
              // all along.
              record = makeRecord(injectableDefOrInjectorDefFactory(token), NOT_YET);
            } else {
              record = null;
            }

            this.records.set(token, record);
          } // If a record was found, get the instance for it and return it.


          if (record != null
          /* NOT null || undefined */
          ) {
              return this.hydrate(token, record);
            }
        } // Select the next injector based on the Self flag - if self is set, the next injector is
        // the NullInjector, otherwise it's the parent.


        var nextInjector = !(flags & InjectFlags.Self) ? this.parent : getNullInjector(); // Set the notFoundValue based on the Optional flag - if optional is set and notFoundValue
        // is undefined, the value is null, otherwise it's the notFoundValue.

        notFoundValue = flags & InjectFlags.Optional && notFoundValue === THROW_IF_NOT_FOUND ? null : notFoundValue;
        return nextInjector.get(token, notFoundValue);
      } catch (e) {
        if (e.name === 'NullInjectorError') {
          var path = e[NG_TEMP_TOKEN_PATH] = e[NG_TEMP_TOKEN_PATH] || [];
          path.unshift(stringify(token));

          if (previousInjector) {
            // We still have a parent injector, keep throwing
            throw e;
          } else {
            // Format & throw the final error message when we don't have any previous injector
            return catchInjectorError(e, token, 'R3InjectorError', this.source);
          }
        } else {
          throw e;
        }
      } finally {
        // Lastly, clean up the state by restoring the previous injector.
        setCurrentInjector(previousInjector);
      }
    }
    /** @internal */

  }, {
    key: "_resolveInjectorDefTypes",
    value: function _resolveInjectorDefTypes() {
      var _this5 = this;

      this.injectorDefTypes.forEach(function (defType) {
        return _this5.get(defType);
      });
    }
  }, {
    key: "toString",
    value: function toString() {
      var tokens = [],
          records = this.records;
      records.forEach(function (v, token) {
        return tokens.push(stringify(token));
      });
      return "R3Injector[".concat(tokens.join(', '), "]");
    }
  }, {
    key: "assertNotDestroyed",
    value: function assertNotDestroyed() {
      if (this._destroyed) {
        throw new Error('Injector has already been destroyed.');
      }
    }
    /**
     * Add an `InjectorType` or `InjectorTypeWithProviders` and all of its transitive providers
     * to this injector.
     *
     * If an `InjectorTypeWithProviders` that declares providers besides the type is specified,
     * the function will return "true" to indicate that the providers of the type definition need
     * to be processed. This allows us to process providers of injector types after all imports of
     * an injector definition are processed. (following View Engine semantics: see FW-1349)
     */

  }, {
    key: "processInjectorType",
    value: function processInjectorType(defOrWrappedDef, parents, dedupStack) {
      var _this6 = this;

      defOrWrappedDef = resolveForwardRef(defOrWrappedDef);
      if (!defOrWrappedDef) return false; // Either the defOrWrappedDef is an InjectorType (with injector def) or an
      // InjectorDefTypeWithProviders (aka ModuleWithProviders). Detecting either is a megamorphic
      // read, so care is taken to only do the read once.
      // First attempt to read the injector def (`ɵinj`).

      var def = getInjectorDef(defOrWrappedDef); // If that's not present, then attempt to read ngModule from the InjectorDefTypeWithProviders.

      var ngModule = def == null && defOrWrappedDef.ngModule || undefined; // Determine the InjectorType. In the case where `defOrWrappedDef` is an `InjectorType`,
      // then this is easy. In the case of an InjectorDefTypeWithProviders, then the definition type
      // is the `ngModule`.

      var defType = ngModule === undefined ? defOrWrappedDef : ngModule; // Check for circular dependencies.

      if (ngDevMode && parents.indexOf(defType) !== -1) {
        var defName = stringify(defType);
        throw new Error("Circular dependency in DI detected for type ".concat(defName, ". Dependency path: ").concat(parents.map(function (defType) {
          return stringify(defType);
        }).join(' > '), " > ").concat(defName, "."));
      } // Check for multiple imports of the same module


      var isDuplicate = dedupStack.indexOf(defType) !== -1; // Finally, if defOrWrappedType was an `InjectorDefTypeWithProviders`, then the actual
      // `InjectorDef` is on its `ngModule`.

      if (ngModule !== undefined) {
        def = getInjectorDef(ngModule);
      } // If no definition was found, it might be from exports. Remove it.


      if (def == null) {
        return false;
      } // Add providers in the same way that @NgModule resolution did:
      // First, include providers from any imports.


      if (def.imports != null && !isDuplicate) {
        // Before processing defType's imports, add it to the set of parents. This way, if it ends
        // up deeply importing itself, this can be detected.
        ngDevMode && parents.push(defType); // Add it to the set of dedups. This way we can detect multiple imports of the same module

        dedupStack.push(defType);
        var importTypesWithProviders;

        try {
          deepForEach(def.imports, function (imported) {
            if (_this6.processInjectorType(imported, parents, dedupStack)) {
              if (importTypesWithProviders === undefined) importTypesWithProviders = []; // If the processed import is an injector type with providers, we store it in the
              // list of import types with providers, so that we can process those afterwards.

              importTypesWithProviders.push(imported);
            }
          });
        } finally {
          // Remove it from the parents set when finished.
          ngDevMode && parents.pop();
        } // Imports which are declared with providers (TypeWithProviders) need to be processed
        // after all imported modules are processed. This is similar to how View Engine
        // processes/merges module imports in the metadata resolver. See: FW-1349.


        if (importTypesWithProviders !== undefined) {
          var _loop = function _loop(i) {
            var _importTypesWithProvi = importTypesWithProviders[i],
                ngModule = _importTypesWithProvi.ngModule,
                providers = _importTypesWithProvi.providers;
            deepForEach(providers, function (provider) {
              return _this6.processProvider(provider, ngModule, providers || EMPTY_ARRAY$2);
            });
          };

          for (var i = 0; i < importTypesWithProviders.length; i++) {
            _loop(i);
          }
        }
      } // Track the InjectorType and add a provider for it. It's important that this is done after the
      // def's imports.


      this.injectorDefTypes.add(defType);
      this.records.set(defType, makeRecord(def.factory, NOT_YET)); // Next, include providers listed on the definition itself.

      var defProviders = def.providers;

      if (defProviders != null && !isDuplicate) {
        var injectorType = defOrWrappedDef;
        deepForEach(defProviders, function (provider) {
          return _this6.processProvider(provider, injectorType, defProviders);
        });
      }

      return ngModule !== undefined && defOrWrappedDef.providers !== undefined;
    }
    /**
     * Process a `SingleProvider` and add it.
     */

  }, {
    key: "processProvider",
    value: function processProvider(provider, ngModuleType, providers) {
      // Determine the token from the provider. Either it's its own token, or has a {provide: ...}
      // property.
      provider = resolveForwardRef(provider);
      var token = isTypeProvider(provider) ? provider : resolveForwardRef(provider && provider.provide); // Construct a `Record` for the provider.

      var record = providerToRecord(provider, ngModuleType, providers);

      if (!isTypeProvider(provider) && provider.multi === true) {
        // If the provider indicates that it's a multi-provider, process it specially.
        // First check whether it's been defined already.
        var multiRecord = this.records.get(token);

        if (multiRecord) {
          // It has. Throw a nice error if
          if (ngDevMode && multiRecord.multi === undefined) {
            throwMixedMultiProviderError();
          }
        } else {
          multiRecord = makeRecord(undefined, NOT_YET, true);

          multiRecord.factory = function () {
            return injectArgs(multiRecord.multi);
          };

          this.records.set(token, multiRecord);
        }

        token = provider;
        multiRecord.multi.push(provider);
      } else {
        var existing = this.records.get(token);

        if (ngDevMode && existing && existing.multi !== undefined) {
          throwMixedMultiProviderError();
        }
      }

      this.records.set(token, record);
    }
  }, {
    key: "hydrate",
    value: function hydrate(token, record) {
      if (ngDevMode && record.value === CIRCULAR) {
        throwCyclicDependencyError(stringify(token));
      } else if (record.value === NOT_YET) {
        record.value = CIRCULAR;
        record.value = record.factory();
      }

      if (typeof record.value === 'object' && record.value && hasOnDestroy(record.value)) {
        this.onDestroy.add(record.value);
      }

      return record.value;
    }
  }, {
    key: "injectableDefInScope",
    value: function injectableDefInScope(def) {
      if (!def.providedIn) {
        return false;
      } else if (typeof def.providedIn === 'string') {
        return def.providedIn === 'any' || def.providedIn === this.scope;
      } else {
        return this.injectorDefTypes.has(def.providedIn);
      }
    }
  }, {
    key: "destroyed",
    get: function get() {
      return this._destroyed;
    }
  }]);

  return R3Injector;
}();

function injectableDefOrInjectorDefFactory(token) {
  // Most tokens will have an injectable def directly on them, which specifies a factory directly.
  var injectableDef = getInjectableDef(token);
  var factory = injectableDef !== null ? injectableDef.factory : getFactoryDef(token);

  if (factory !== null) {
    return factory;
  } // If the token is an NgModule, it's also injectable but the factory is on its injector def
  // (`ɵinj`)


  var injectorDef = getInjectorDef(token);

  if (injectorDef !== null) {
    return injectorDef.factory;
  } // InjectionTokens should have an injectable def (ɵprov) and thus should be handled above.
  // If it's missing that, it's an error.


  if (token instanceof InjectionToken) {
    throw new Error("Token ".concat(stringify(token), " is missing a \u0275prov definition."));
  } // Undecorated types can sometimes be created if they have no constructor arguments.


  if (token instanceof Function) {
    return getUndecoratedInjectableFactory(token);
  } // There was no way to resolve a factory for this token.


  throw new Error('unreachable');
}

function getUndecoratedInjectableFactory(token) {
  // If the token has parameters then it has dependencies that we cannot resolve implicitly.
  var paramLength = token.length;

  if (paramLength > 0) {
    var args = newArray(paramLength, '?');
    throw new Error("Can't resolve all parameters for ".concat(stringify(token), ": (").concat(args.join(', '), ")."));
  } // The constructor function appears to have no parameters.
  // This might be because it inherits from a super-class. In which case, use an injectable
  // def from an ancestor if there is one.
  // Otherwise this really is a simple class with no dependencies, so return a factory that
  // just instantiates the zero-arg constructor.


  var inheritedInjectableDef = getInheritedInjectableDef(token);

  if (inheritedInjectableDef !== null) {
    return function () {
      return inheritedInjectableDef.factory(token);
    };
  } else {
    return function () {
      return new token();
    };
  }
}

function providerToRecord(provider, ngModuleType, providers) {
  if (isValueProvider(provider)) {
    return makeRecord(undefined, provider.useValue);
  } else {
    var factory = providerToFactory(provider, ngModuleType, providers);
    return makeRecord(factory, NOT_YET);
  }
}
/**
 * Converts a `SingleProvider` into a factory function.
 *
 * @param provider provider to convert to factory
 */


function providerToFactory(provider, ngModuleType, providers) {
  var factory = undefined;

  if (isTypeProvider(provider)) {
    var unwrappedProvider = resolveForwardRef(provider);
    return getFactoryDef(unwrappedProvider) || injectableDefOrInjectorDefFactory(unwrappedProvider);
  } else {
    if (isValueProvider(provider)) {
      factory = function factory() {
        return resolveForwardRef(provider.useValue);
      };
    } else if (isFactoryProvider(provider)) {
      factory = function factory() {
        return provider.useFactory.apply(provider, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(injectArgs(provider.deps || [])));
      };
    } else if (isExistingProvider(provider)) {
      factory = function factory() {
        return ɵɵinject(resolveForwardRef(provider.useExisting));
      };
    } else {
      var classRef = resolveForwardRef(provider && (provider.useClass || provider.provide));

      if (ngDevMode && !classRef) {
        throwInvalidProviderError(ngModuleType, providers, provider);
      }

      if (hasDeps(provider)) {
        factory = function factory() {
          return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(classRef, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(injectArgs(provider.deps)));
        };
      } else {
        return getFactoryDef(classRef) || injectableDefOrInjectorDefFactory(classRef);
      }
    }
  }

  return factory;
}

function makeRecord(factory, value) {
  var multi = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  return {
    factory: factory,
    value: value,
    multi: multi ? [] : undefined
  };
}

function isValueProvider(value) {
  return value !== null && typeof value == 'object' && USE_VALUE in value;
}

function isExistingProvider(value) {
  return !!(value && value.useExisting);
}

function isFactoryProvider(value) {
  return !!(value && value.useFactory);
}

function isTypeProvider(value) {
  return typeof value === 'function';
}

function isClassProvider(value) {
  return !!value.useClass;
}

function hasDeps(value) {
  return !!value.deps;
}

function hasOnDestroy(value) {
  return value !== null && typeof value === 'object' && typeof value.ngOnDestroy === 'function';
}

function couldBeInjectableType(value) {
  return typeof value === 'function' || typeof value === 'object' && value instanceof InjectionToken;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function INJECTOR_IMPL__PRE_R3__(providers, parent, name) {
  return new StaticInjector(providers, parent, name);
}

function INJECTOR_IMPL__POST_R3__(providers, parent, name) {
  return createInjector({
    name: name
  }, parent, providers, name);
}

var INJECTOR_IMPL = INJECTOR_IMPL__POST_R3__;
/**
 * Concrete injectors implement this interface. Injectors are configured
 * with [providers](guide/glossary#provider) that associate
 * dependencies of various types with [injection tokens](guide/glossary#di-token).
 *
 * @see ["DI Providers"](guide/dependency-injection-providers).
 * @see `StaticProvider`
 *
 * @usageNotes
 *
 *  The following example creates a service injector instance.
 *
 * {@example core/di/ts/provider_spec.ts region='ConstructorProvider'}
 *
 * ### Usage example
 *
 * {@example core/di/ts/injector_spec.ts region='Injector'}
 *
 * `Injector` returns itself when given `Injector` as a token:
 *
 * {@example core/di/ts/injector_spec.ts region='injectInjector'}
 *
 * @publicApi
 */

var Injector = /*#__PURE__*/function () {
  function Injector() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Injector);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(Injector, null, [{
    key: "create",
    value: function create(options, parent) {
      if (Array.isArray(options)) {
        return INJECTOR_IMPL(options, parent, '');
      } else {
        return INJECTOR_IMPL(options.providers, options.parent, options.name || '');
      }
    }
  }]);

  return Injector;
}();

Injector.THROW_IF_NOT_FOUND = THROW_IF_NOT_FOUND;
Injector.NULL = new NullInjector();
/** @nocollapse */

Injector.ɵprov = ɵɵdefineInjectable({
  token: Injector,
  providedIn: 'any',
  factory: function factory() {
    return ɵɵinject(INJECTOR);
  }
});
/**
 * @internal
 * @nocollapse
 */

Injector.__NG_ELEMENT_ID__ = -1;

var IDENT = function IDENT(value) {
  return value;
};

var ɵ0$9 = IDENT;
var EMPTY = [];
var CIRCULAR$1 = IDENT;

var MULTI_PROVIDER_FN = function MULTI_PROVIDER_FN() {
  return Array.prototype.slice.call(arguments);
};

var ɵ1$1 = MULTI_PROVIDER_FN;
var NO_NEW_LINE$1 = 'ɵ';

var StaticInjector = /*#__PURE__*/function () {
  function StaticInjector(providers) {
    var parent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Injector.NULL;
    var source = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, StaticInjector);

    this.parent = parent;
    this.source = source;
    var records = this._records = new Map();
    records.set(Injector, {
      token: Injector,
      fn: IDENT,
      deps: EMPTY,
      value: this,
      useNew: false
    });
    records.set(INJECTOR, {
      token: INJECTOR,
      fn: IDENT,
      deps: EMPTY,
      value: this,
      useNew: false
    });
    this.scope = recursivelyProcessProviders(records, providers);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(StaticInjector, [{
    key: "get",
    value: function get(token, notFoundValue) {
      var flags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : InjectFlags.Default;
      var records = this._records;
      var record = records.get(token);

      if (record === undefined) {
        // This means we have never seen this record, see if it is tree shakable provider.
        var injectableDef = getInjectableDef(token);

        if (injectableDef) {
          var providedIn = injectableDef && injectableDef.providedIn;

          if (providedIn === 'any' || providedIn != null && providedIn === this.scope) {
            records.set(token, record = resolveProvider({
              provide: token,
              useFactory: injectableDef.factory,
              deps: EMPTY
            }));
          }
        }

        if (record === undefined) {
          // Set record to null to make sure that we don't go through expensive lookup above again.
          records.set(token, null);
        }
      }

      var lastInjector = setCurrentInjector(this);

      try {
        return tryResolveToken(token, record, records, this.parent, notFoundValue, flags);
      } catch (e) {
        return catchInjectorError(e, token, 'StaticInjectorError', this.source);
      } finally {
        setCurrentInjector(lastInjector);
      }
    }
  }, {
    key: "toString",
    value: function toString() {
      var tokens = [],
          records = this._records;
      records.forEach(function (v, token) {
        return tokens.push(stringify(token));
      });
      return "StaticInjector[".concat(tokens.join(', '), "]");
    }
  }]);

  return StaticInjector;
}();

function resolveProvider(provider) {
  var deps = computeDeps(provider);
  var fn = IDENT;
  var value = EMPTY;
  var useNew = false;
  var provide = resolveForwardRef(provider.provide);

  if (USE_VALUE in provider) {
    // We need to use USE_VALUE in provider since provider.useValue could be defined as undefined.
    value = provider.useValue;
  } else if (provider.useFactory) {
    fn = provider.useFactory;
  } else if (provider.useExisting) {// Just use IDENT
  } else if (provider.useClass) {
    useNew = true;
    fn = resolveForwardRef(provider.useClass);
  } else if (typeof provide == 'function') {
    useNew = true;
    fn = provide;
  } else {
    throw staticError('StaticProvider does not have [useValue|useFactory|useExisting|useClass] or [provide] is not newable', provider);
  }

  return {
    deps: deps,
    fn: fn,
    useNew: useNew,
    value: value
  };
}

function multiProviderMixError(token) {
  return staticError('Cannot mix multi providers and regular providers', token);
}

function recursivelyProcessProviders(records, provider) {
  var scope = null;

  if (provider) {
    provider = resolveForwardRef(provider);

    if (Array.isArray(provider)) {
      // if we have an array recurse into the array
      for (var i = 0; i < provider.length; i++) {
        scope = recursivelyProcessProviders(records, provider[i]) || scope;
      }
    } else if (typeof provider === 'function') {
      // Functions were supported in ReflectiveInjector, but are not here. For safety give useful
      // error messages
      throw staticError('Function/Class not supported', provider);
    } else if (provider && typeof provider === 'object' && provider.provide) {
      // At this point we have what looks like a provider: {provide: ?, ....}
      var token = resolveForwardRef(provider.provide);
      var resolvedProvider = resolveProvider(provider);

      if (provider.multi === true) {
        // This is a multi provider.
        var multiProvider = records.get(token);

        if (multiProvider) {
          if (multiProvider.fn !== MULTI_PROVIDER_FN) {
            throw multiProviderMixError(token);
          }
        } else {
          // Create a placeholder factory which will look up the constituents of the multi provider.
          records.set(token, multiProvider = {
            token: provider.provide,
            deps: [],
            useNew: false,
            fn: MULTI_PROVIDER_FN,
            value: EMPTY
          });
        } // Treat the provider as the token.


        token = provider;
        multiProvider.deps.push({
          token: token,
          options: 6
          /* Default */

        });
      }

      var record = records.get(token);

      if (record && record.fn == MULTI_PROVIDER_FN) {
        throw multiProviderMixError(token);
      }

      if (token === INJECTOR_SCOPE) {
        scope = resolvedProvider.value;
      }

      records.set(token, resolvedProvider);
    } else {
      throw staticError('Unexpected provider', provider);
    }
  }

  return scope;
}

function tryResolveToken(token, record, records, parent, notFoundValue, flags) {
  try {
    return resolveToken(token, record, records, parent, notFoundValue, flags);
  } catch (e) {
    // ensure that 'e' is of type Error.
    if (!(e instanceof Error)) {
      e = new Error(e);
    }

    var path = e[NG_TEMP_TOKEN_PATH] = e[NG_TEMP_TOKEN_PATH] || [];
    path.unshift(token);

    if (record && record.value == CIRCULAR$1) {
      // Reset the Circular flag.
      record.value = EMPTY;
    }

    throw e;
  }
}

function resolveToken(token, record, records, parent, notFoundValue, flags) {
  var value;

  if (record && !(flags & InjectFlags.SkipSelf)) {
    // If we don't have a record, this implies that we don't own the provider hence don't know how
    // to resolve it.
    value = record.value;

    if (value == CIRCULAR$1) {
      throw Error(NO_NEW_LINE$1 + 'Circular dependency');
    } else if (value === EMPTY) {
      record.value = CIRCULAR$1;
      var obj = undefined;
      var useNew = record.useNew;
      var fn = record.fn;
      var depRecords = record.deps;
      var deps = EMPTY;

      if (depRecords.length) {
        deps = [];

        for (var i = 0; i < depRecords.length; i++) {
          var depRecord = depRecords[i];
          var options = depRecord.options;
          var childRecord = options & 2
          /* CheckSelf */
          ? records.get(depRecord.token) : undefined;
          deps.push(tryResolveToken( // Current Token to resolve
          depRecord.token, // A record which describes how to resolve the token.
          // If undefined, this means we don't have such a record
          childRecord, // Other records we know about.
          records, // If we don't know how to resolve dependency and we should not check parent for it,
          // than pass in Null injector.
          !childRecord && !(options & 4
          /* CheckParent */
          ) ? Injector.NULL : parent, options & 1
          /* Optional */
          ? null : Injector.THROW_IF_NOT_FOUND, InjectFlags.Default));
        }
      }

      record.value = value = useNew ? Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(fn, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(deps)) : fn.apply(obj, deps);
    }
  } else if (!(flags & InjectFlags.Self)) {
    value = parent.get(token, notFoundValue, InjectFlags.Default);
  } else if (!(flags & InjectFlags.Optional)) {
    value = Injector.NULL.get(token, notFoundValue);
  } else {
    value = Injector.NULL.get(token, typeof notFoundValue !== 'undefined' ? notFoundValue : null);
  }

  return value;
}

function computeDeps(provider) {
  var deps = EMPTY;
  var providerDeps = provider.deps;

  if (providerDeps && providerDeps.length) {
    deps = [];

    for (var i = 0; i < providerDeps.length; i++) {
      var options = 6
      /* Default */
      ;
      var token = resolveForwardRef(providerDeps[i]);

      if (Array.isArray(token)) {
        for (var j = 0, annotations = token; j < annotations.length; j++) {
          var annotation = annotations[j];

          if (annotation instanceof Optional || annotation == Optional) {
            options = options | 1
            /* Optional */
            ;
          } else if (annotation instanceof SkipSelf || annotation == SkipSelf) {
            options = options & ~2
            /* CheckSelf */
            ;
          } else if (annotation instanceof Self || annotation == Self) {
            options = options & ~4
            /* CheckParent */
            ;
          } else if (annotation instanceof Inject) {
            token = annotation.token;
          } else {
            token = resolveForwardRef(annotation);
          }
        }
      }

      deps.push({
        token: token,
        options: options
      });
    }
  } else if (provider.useExisting) {
    var _token = resolveForwardRef(provider.useExisting);

    deps = [{
      token: _token,
      options: 6
      /* Default */

    }];
  } else if (!providerDeps && !(USE_VALUE in provider)) {
    // useValue & useExisting are the only ones which are exempt from deps all others need it.
    throw staticError('\'deps\' required', provider);
  }

  return deps;
}

function staticError(text, obj) {
  return new Error(formatError(text, obj, 'StaticInjectorError'));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function findFirstClosedCycle(keys) {
  var res = [];

  for (var i = 0; i < keys.length; ++i) {
    if (res.indexOf(keys[i]) > -1) {
      res.push(keys[i]);
      return res;
    }

    res.push(keys[i]);
  }

  return res;
}

function constructResolvingPath(keys) {
  if (keys.length > 1) {
    var reversed = findFirstClosedCycle(keys.slice().reverse());
    var tokenStrs = reversed.map(function (k) {
      return stringify(k.token);
    });
    return ' (' + tokenStrs.join(' -> ') + ')';
  }

  return '';
}

function injectionError(injector, key, constructResolvingMessage, originalError) {
  var keys = [key];
  var errMsg = constructResolvingMessage(keys);
  var error = originalError ? wrappedError(errMsg, originalError) : Error(errMsg);
  error.addKey = addKey;
  error.keys = keys;
  error.injectors = [injector];
  error.constructResolvingMessage = constructResolvingMessage;
  error[ERROR_ORIGINAL_ERROR] = originalError;
  return error;
}

function addKey(injector, key) {
  this.injectors.push(injector);
  this.keys.push(key); // Note: This updated message won't be reflected in the `.stack` property

  this.message = this.constructResolvingMessage(this.keys);
}
/**
 * Thrown when trying to retrieve a dependency by key from {@link Injector}, but the
 * {@link Injector} does not have a {@link Provider} for the given key.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * class A {
 *   constructor(b:B) {}
 * }
 *
 * expect(() => Injector.resolveAndCreate([A])).toThrowError();
 * ```
 */


function noProviderError(injector, key) {
  return injectionError(injector, key, function (keys) {
    var first = stringify(keys[0].token);
    return "No provider for ".concat(first, "!").concat(constructResolvingPath(keys));
  });
}
/**
 * Thrown when dependencies form a cycle.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * var injector = Injector.resolveAndCreate([
 *   {provide: "one", useFactory: (two) => "two", deps: [[new Inject("two")]]},
 *   {provide: "two", useFactory: (one) => "one", deps: [[new Inject("one")]]}
 * ]);
 *
 * expect(() => injector.get("one")).toThrowError();
 * ```
 *
 * Retrieving `A` or `B` throws a `CyclicDependencyError` as the graph above cannot be constructed.
 */


function cyclicDependencyError(injector, key) {
  return injectionError(injector, key, function (keys) {
    return "Cannot instantiate cyclic dependency!".concat(constructResolvingPath(keys));
  });
}
/**
 * Thrown when a constructing type returns with an Error.
 *
 * The `InstantiationError` class contains the original error plus the dependency graph which caused
 * this object to be instantiated.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * class A {
 *   constructor() {
 *     throw new Error('message');
 *   }
 * }
 *
 * var injector = Injector.resolveAndCreate([A]);

 * try {
 *   injector.get(A);
 * } catch (e) {
 *   expect(e instanceof InstantiationError).toBe(true);
 *   expect(e.originalException.message).toEqual("message");
 *   expect(e.originalStack).toBeDefined();
 * }
 * ```
 */


function instantiationError(injector, originalException, originalStack, key) {
  return injectionError(injector, key, function (keys) {
    var first = stringify(keys[0].token);
    return "".concat(originalException.message, ": Error during instantiation of ").concat(first, "!").concat(constructResolvingPath(keys), ".");
  }, originalException);
}
/**
 * Thrown when an object other then {@link Provider} (or `Type`) is passed to {@link Injector}
 * creation.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * expect(() => Injector.resolveAndCreate(["not a type"])).toThrowError();
 * ```
 */


function invalidProviderError(provider) {
  return Error("Invalid provider - only instances of Provider and Type are allowed, got: ".concat(provider));
}
/**
 * Thrown when the class has no annotation information.
 *
 * Lack of annotation information prevents the {@link Injector} from determining which dependencies
 * need to be injected into the constructor.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * class A {
 *   constructor(b) {}
 * }
 *
 * expect(() => Injector.resolveAndCreate([A])).toThrowError();
 * ```
 *
 * This error is also thrown when the class not marked with {@link Injectable} has parameter types.
 *
 * ```typescript
 * class B {}
 *
 * class A {
 *   constructor(b:B) {} // no information about the parameter types of A is available at runtime.
 * }
 *
 * expect(() => Injector.resolveAndCreate([A,B])).toThrowError();
 * ```
 *
 */


function noAnnotationError(typeOrFunc, params) {
  var signature = [];

  for (var i = 0, ii = params.length; i < ii; i++) {
    var parameter = params[i];

    if (!parameter || parameter.length == 0) {
      signature.push('?');
    } else {
      signature.push(parameter.map(stringify).join(' '));
    }
  }

  return Error('Cannot resolve all parameters for \'' + stringify(typeOrFunc) + '\'(' + signature.join(', ') + '). ' + 'Make sure that all the parameters are decorated with Inject or have valid type annotations and that \'' + stringify(typeOrFunc) + '\' is decorated with Injectable.');
}
/**
 * Thrown when getting an object by index.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * class A {}
 *
 * var injector = Injector.resolveAndCreate([A]);
 *
 * expect(() => injector.getAt(100)).toThrowError();
 * ```
 *
 */


function outOfBoundsError(index) {
  return Error("Index ".concat(index, " is out-of-bounds."));
} // TODO: add a working example after alpha38 is released

/**
 * Thrown when a multi provider and a regular provider are bound to the same token.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * expect(() => Injector.resolveAndCreate([
 *   { provide: "Strings", useValue: "string1", multi: true},
 *   { provide: "Strings", useValue: "string2", multi: false}
 * ])).toThrowError();
 * ```
 */


function mixingMultiProvidersWithRegularProvidersError(provider1, provider2) {
  return Error("Cannot mix multi providers and regular providers, got: ".concat(provider1, " ").concat(provider2));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A unique object used for retrieving items from the {@link ReflectiveInjector}.
 *
 * Keys have:
 * - a system-wide unique `id`.
 * - a `token`.
 *
 * `Key` is used internally by {@link ReflectiveInjector} because its system-wide unique `id` allows
 * the
 * injector to store created objects in a more efficient way.
 *
 * `Key` should not be created directly. {@link ReflectiveInjector} creates keys automatically when
 * resolving
 * providers.
 *
 * @deprecated No replacement
 * @publicApi
 */


var ReflectiveKey = /*#__PURE__*/function () {
  /**
   * Private
   */
  function ReflectiveKey(token, id) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ReflectiveKey);

    this.token = token;
    this.id = id;

    if (!token) {
      throw new Error('Token must be defined!');
    }

    this.displayName = stringify(this.token);
  }
  /**
   * Retrieves a `Key` for a token.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ReflectiveKey, null, [{
    key: "get",
    value: function get(token) {
      return _globalKeyRegistry.get(resolveForwardRef(token));
    }
    /**
     * @returns the number of keys registered in the system.
     */

  }, {
    key: "numberOfKeys",
    get: function get() {
      return _globalKeyRegistry.numberOfKeys;
    }
  }]);

  return ReflectiveKey;
}();

var KeyRegistry = /*#__PURE__*/function () {
  function KeyRegistry() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, KeyRegistry);

    this._allKeys = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(KeyRegistry, [{
    key: "get",
    value: function get(token) {
      if (token instanceof ReflectiveKey) return token;

      if (this._allKeys.has(token)) {
        return this._allKeys.get(token);
      }

      var newKey = new ReflectiveKey(token, ReflectiveKey.numberOfKeys);

      this._allKeys.set(token, newKey);

      return newKey;
    }
  }, {
    key: "numberOfKeys",
    get: function get() {
      return this._allKeys.size;
    }
  }]);

  return KeyRegistry;
}();

var _globalKeyRegistry = new KeyRegistry();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Provides access to reflection data about symbols. Used internally by Angular
 * to power dependency injection and compilation.
 */


var Reflector = /*#__PURE__*/function () {
  function Reflector(reflectionCapabilities) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Reflector);

    this.reflectionCapabilities = reflectionCapabilities;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(Reflector, [{
    key: "updateCapabilities",
    value: function updateCapabilities(caps) {
      this.reflectionCapabilities = caps;
    }
  }, {
    key: "factory",
    value: function factory(type) {
      return this.reflectionCapabilities.factory(type);
    }
  }, {
    key: "parameters",
    value: function parameters(typeOrFunc) {
      return this.reflectionCapabilities.parameters(typeOrFunc);
    }
  }, {
    key: "annotations",
    value: function annotations(typeOrFunc) {
      return this.reflectionCapabilities.annotations(typeOrFunc);
    }
  }, {
    key: "propMetadata",
    value: function propMetadata(typeOrFunc) {
      return this.reflectionCapabilities.propMetadata(typeOrFunc);
    }
  }, {
    key: "hasLifecycleHook",
    value: function hasLifecycleHook(type, lcProperty) {
      return this.reflectionCapabilities.hasLifecycleHook(type, lcProperty);
    }
  }, {
    key: "getter",
    value: function getter(name) {
      return this.reflectionCapabilities.getter(name);
    }
  }, {
    key: "setter",
    value: function setter(name) {
      return this.reflectionCapabilities.setter(name);
    }
  }, {
    key: "method",
    value: function method(name) {
      return this.reflectionCapabilities.method(name);
    }
  }, {
    key: "importUri",
    value: function importUri(type) {
      return this.reflectionCapabilities.importUri(type);
    }
  }, {
    key: "resourceUri",
    value: function resourceUri(type) {
      return this.reflectionCapabilities.resourceUri(type);
    }
  }, {
    key: "resolveIdentifier",
    value: function resolveIdentifier(name, moduleUrl, members, runtime) {
      return this.reflectionCapabilities.resolveIdentifier(name, moduleUrl, members, runtime);
    }
  }, {
    key: "resolveEnum",
    value: function resolveEnum(identifier, name) {
      return this.reflectionCapabilities.resolveEnum(identifier, name);
    }
  }]);

  return Reflector;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The {@link Reflector} used internally in Angular to access metadata
 * about symbols.
 */


var reflector = new Reflector(new ReflectionCapabilities());
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * `Dependency` is used by the framework to extend DI.
 * This is internal to Angular and should not be used directly.
 */

var ReflectiveDependency = /*#__PURE__*/function () {
  function ReflectiveDependency(key, optional, visibility) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ReflectiveDependency);

    this.key = key;
    this.optional = optional;
    this.visibility = visibility;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ReflectiveDependency, null, [{
    key: "fromKey",
    value: function fromKey(key) {
      return new ReflectiveDependency(key, false, null);
    }
  }]);

  return ReflectiveDependency;
}();

var _EMPTY_LIST = [];

var ResolvedReflectiveProvider_ = function ResolvedReflectiveProvider_(key, resolvedFactories, multiProvider) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ResolvedReflectiveProvider_);

  this.key = key;
  this.resolvedFactories = resolvedFactories;
  this.multiProvider = multiProvider;
  this.resolvedFactory = this.resolvedFactories[0];
};
/**
 * An internal resolved representation of a factory function created by resolving `Provider`.
 * @publicApi
 */


var ResolvedReflectiveFactory = function ResolvedReflectiveFactory(
/**
 * Factory function which can return an instance of an object represented by a key.
 */
factory,
/**
 * Arguments (dependencies) to the `factory` function.
 */
dependencies) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ResolvedReflectiveFactory);

  this.factory = factory;
  this.dependencies = dependencies;
};
/**
 * Resolve a single provider.
 */


function resolveReflectiveFactory(provider) {
  var factoryFn;
  var resolvedDeps;

  if (provider.useClass) {
    var useClass = resolveForwardRef(provider.useClass);
    factoryFn = reflector.factory(useClass);
    resolvedDeps = _dependenciesFor(useClass);
  } else if (provider.useExisting) {
    factoryFn = function factoryFn(aliasInstance) {
      return aliasInstance;
    };

    resolvedDeps = [ReflectiveDependency.fromKey(ReflectiveKey.get(provider.useExisting))];
  } else if (provider.useFactory) {
    factoryFn = provider.useFactory;
    resolvedDeps = constructDependencies(provider.useFactory, provider.deps);
  } else {
    factoryFn = function factoryFn() {
      return provider.useValue;
    };

    resolvedDeps = _EMPTY_LIST;
  }

  return new ResolvedReflectiveFactory(factoryFn, resolvedDeps);
}
/**
 * Converts the `Provider` into `ResolvedProvider`.
 *
 * `Injector` internally only uses `ResolvedProvider`, `Provider` contains convenience provider
 * syntax.
 */


function resolveReflectiveProvider(provider) {
  return new ResolvedReflectiveProvider_(ReflectiveKey.get(provider.provide), [resolveReflectiveFactory(provider)], provider.multi || false);
}
/**
 * Resolve a list of Providers.
 */


function resolveReflectiveProviders(providers) {
  var normalized = _normalizeProviders(providers, []);

  var resolved = normalized.map(resolveReflectiveProvider);
  var resolvedProviderMap = mergeResolvedReflectiveProviders(resolved, new Map());
  return Array.from(resolvedProviderMap.values());
}
/**
 * Merges a list of ResolvedProviders into a list where each key is contained exactly once and
 * multi providers have been merged.
 */


function mergeResolvedReflectiveProviders(providers, normalizedProvidersMap) {
  for (var i = 0; i < providers.length; i++) {
    var provider = providers[i];
    var existing = normalizedProvidersMap.get(provider.key.id);

    if (existing) {
      if (provider.multiProvider !== existing.multiProvider) {
        throw mixingMultiProvidersWithRegularProvidersError(existing, provider);
      }

      if (provider.multiProvider) {
        for (var j = 0; j < provider.resolvedFactories.length; j++) {
          existing.resolvedFactories.push(provider.resolvedFactories[j]);
        }
      } else {
        normalizedProvidersMap.set(provider.key.id, provider);
      }
    } else {
      var resolvedProvider = void 0;

      if (provider.multiProvider) {
        resolvedProvider = new ResolvedReflectiveProvider_(provider.key, provider.resolvedFactories.slice(), provider.multiProvider);
      } else {
        resolvedProvider = provider;
      }

      normalizedProvidersMap.set(provider.key.id, resolvedProvider);
    }
  }

  return normalizedProvidersMap;
}

function _normalizeProviders(providers, res) {
  providers.forEach(function (b) {
    if (b instanceof Type) {
      res.push({
        provide: b,
        useClass: b
      });
    } else if (b && typeof b == 'object' && b.provide !== undefined) {
      res.push(b);
    } else if (Array.isArray(b)) {
      _normalizeProviders(b, res);
    } else {
      throw invalidProviderError(b);
    }
  });
  return res;
}

function constructDependencies(typeOrFunc, dependencies) {
  if (!dependencies) {
    return _dependenciesFor(typeOrFunc);
  } else {
    var params = dependencies.map(function (t) {
      return [t];
    });
    return dependencies.map(function (t) {
      return _extractToken(typeOrFunc, t, params);
    });
  }
}

function _dependenciesFor(typeOrFunc) {
  var params = reflector.parameters(typeOrFunc);
  if (!params) return [];

  if (params.some(function (p) {
    return p == null;
  })) {
    throw noAnnotationError(typeOrFunc, params);
  }

  return params.map(function (p) {
    return _extractToken(typeOrFunc, p, params);
  });
}

function _extractToken(typeOrFunc, metadata, params) {
  var token = null;
  var optional = false;

  if (!Array.isArray(metadata)) {
    if (metadata instanceof Inject) {
      return _createDependency(metadata.token, optional, null);
    } else {
      return _createDependency(metadata, optional, null);
    }
  }

  var visibility = null;

  for (var i = 0; i < metadata.length; ++i) {
    var paramMetadata = metadata[i];

    if (paramMetadata instanceof Type) {
      token = paramMetadata;
    } else if (paramMetadata instanceof Inject) {
      token = paramMetadata.token;
    } else if (paramMetadata instanceof Optional) {
      optional = true;
    } else if (paramMetadata instanceof Self || paramMetadata instanceof SkipSelf) {
      visibility = paramMetadata;
    } else if (paramMetadata instanceof InjectionToken) {
      token = paramMetadata;
    }
  }

  token = resolveForwardRef(token);

  if (token != null) {
    return _createDependency(token, optional, visibility);
  } else {
    throw noAnnotationError(typeOrFunc, params);
  }
}

function _createDependency(token, optional, visibility) {
  return new ReflectiveDependency(ReflectiveKey.get(token), optional, visibility);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Threshold for the dynamic version


var UNDEFINED = {};
/**
 * A ReflectiveDependency injection container used for instantiating objects and resolving
 * dependencies.
 *
 * An `Injector` is a replacement for a `new` operator, which can automatically resolve the
 * constructor dependencies.
 *
 * In typical use, application code asks for the dependencies in the constructor and they are
 * resolved by the `Injector`.
 *
 * @usageNotes
 * ### Example
 *
 * The following example creates an `Injector` configured to create `Engine` and `Car`.
 *
 * ```typescript
 * @Injectable()
 * class Engine {
 * }
 *
 * @Injectable()
 * class Car {
 *   constructor(public engine:Engine) {}
 * }
 *
 * var injector = ReflectiveInjector.resolveAndCreate([Car, Engine]);
 * var car = injector.get(Car);
 * expect(car instanceof Car).toBe(true);
 * expect(car.engine instanceof Engine).toBe(true);
 * ```
 *
 * Notice, we don't use the `new` operator because we explicitly want to have the `Injector`
 * resolve all of the object's dependencies automatically.
 *
 * @deprecated from v5 - slow and brings in a lot of code, Use `Injector.create` instead.
 * @publicApi
 */

var ReflectiveInjector = /*#__PURE__*/function () {
  function ReflectiveInjector() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ReflectiveInjector);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ReflectiveInjector, null, [{
    key: "resolve",

    /**
     * Turns an array of provider definitions into an array of resolved providers.
     *
     * A resolution is a process of flattening multiple nested arrays and converting individual
     * providers into an array of `ResolvedReflectiveProvider`s.
     *
     * @usageNotes
     * ### Example
     *
     * ```typescript
     * @Injectable()
     * class Engine {
     * }
     *
     * @Injectable()
     * class Car {
     *   constructor(public engine:Engine) {}
     * }
     *
     * var providers = ReflectiveInjector.resolve([Car, [[Engine]]]);
     *
     * expect(providers.length).toEqual(2);
     *
     * expect(providers[0] instanceof ResolvedReflectiveProvider).toBe(true);
     * expect(providers[0].key.displayName).toBe("Car");
     * expect(providers[0].dependencies.length).toEqual(1);
     * expect(providers[0].factory).toBeDefined();
     *
     * expect(providers[1].key.displayName).toBe("Engine");
     * });
     * ```
     *
     */
    value: function resolve(providers) {
      return resolveReflectiveProviders(providers);
    }
    /**
     * Resolves an array of providers and creates an injector from those providers.
     *
     * The passed-in providers can be an array of `Type`, `Provider`,
     * or a recursive array of more providers.
     *
     * @usageNotes
     * ### Example
     *
     * ```typescript
     * @Injectable()
     * class Engine {
     * }
     *
     * @Injectable()
     * class Car {
     *   constructor(public engine:Engine) {}
     * }
     *
     * var injector = ReflectiveInjector.resolveAndCreate([Car, Engine]);
     * expect(injector.get(Car) instanceof Car).toBe(true);
     * ```
     */

  }, {
    key: "resolveAndCreate",
    value: function resolveAndCreate(providers, parent) {
      var ResolvedReflectiveProviders = ReflectiveInjector.resolve(providers);
      return ReflectiveInjector.fromResolvedProviders(ResolvedReflectiveProviders, parent);
    }
    /**
     * Creates an injector from previously resolved providers.
     *
     * This API is the recommended way to construct injectors in performance-sensitive parts.
     *
     * @usageNotes
     * ### Example
     *
     * ```typescript
     * @Injectable()
     * class Engine {
     * }
     *
     * @Injectable()
     * class Car {
     *   constructor(public engine:Engine) {}
     * }
     *
     * var providers = ReflectiveInjector.resolve([Car, Engine]);
     * var injector = ReflectiveInjector.fromResolvedProviders(providers);
     * expect(injector.get(Car) instanceof Car).toBe(true);
     * ```
     */

  }, {
    key: "fromResolvedProviders",
    value: function fromResolvedProviders(providers, parent) {
      return new ReflectiveInjector_(providers, parent);
    }
  }]);

  return ReflectiveInjector;
}();

var ReflectiveInjector_ = /*#__PURE__*/function () {
  /**
   * Private
   */
  function ReflectiveInjector_(_providers, _parent) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ReflectiveInjector_);

    /** @internal */
    this._constructionCounter = 0;
    this._providers = _providers;
    this.parent = _parent || null;
    var len = _providers.length;
    this.keyIds = [];
    this.objs = [];

    for (var i = 0; i < len; i++) {
      this.keyIds[i] = _providers[i].key.id;
      this.objs[i] = UNDEFINED;
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ReflectiveInjector_, [{
    key: "get",
    value: function get(token) {
      var notFoundValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : THROW_IF_NOT_FOUND;
      return this._getByKey(ReflectiveKey.get(token), null, notFoundValue);
    }
  }, {
    key: "resolveAndCreateChild",
    value: function resolveAndCreateChild(providers) {
      var ResolvedReflectiveProviders = ReflectiveInjector.resolve(providers);
      return this.createChildFromResolved(ResolvedReflectiveProviders);
    }
  }, {
    key: "createChildFromResolved",
    value: function createChildFromResolved(providers) {
      var inj = new ReflectiveInjector_(providers);
      inj.parent = this;
      return inj;
    }
  }, {
    key: "resolveAndInstantiate",
    value: function resolveAndInstantiate(provider) {
      return this.instantiateResolved(ReflectiveInjector.resolve([provider])[0]);
    }
  }, {
    key: "instantiateResolved",
    value: function instantiateResolved(provider) {
      return this._instantiateProvider(provider);
    }
  }, {
    key: "getProviderAtIndex",
    value: function getProviderAtIndex(index) {
      if (index < 0 || index >= this._providers.length) {
        throw outOfBoundsError(index);
      }

      return this._providers[index];
    }
    /** @internal */

  }, {
    key: "_new",
    value: function _new(provider) {
      if (this._constructionCounter++ > this._getMaxNumberOfObjects()) {
        throw cyclicDependencyError(this, provider.key);
      }

      return this._instantiateProvider(provider);
    }
  }, {
    key: "_getMaxNumberOfObjects",
    value: function _getMaxNumberOfObjects() {
      return this.objs.length;
    }
  }, {
    key: "_instantiateProvider",
    value: function _instantiateProvider(provider) {
      if (provider.multiProvider) {
        var res = [];

        for (var i = 0; i < provider.resolvedFactories.length; ++i) {
          res[i] = this._instantiate(provider, provider.resolvedFactories[i]);
        }

        return res;
      } else {
        return this._instantiate(provider, provider.resolvedFactories[0]);
      }
    }
  }, {
    key: "_instantiate",
    value: function _instantiate(provider, ResolvedReflectiveFactory) {
      var _this7 = this;

      var factory = ResolvedReflectiveFactory.factory;
      var deps;

      try {
        deps = ResolvedReflectiveFactory.dependencies.map(function (dep) {
          return _this7._getByReflectiveDependency(dep);
        });
      } catch (e) {
        if (e.addKey) {
          e.addKey(this, provider.key);
        }

        throw e;
      }

      var obj;

      try {
        obj = factory.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(deps));
      } catch (e) {
        throw instantiationError(this, e, e.stack, provider.key);
      }

      return obj;
    }
  }, {
    key: "_getByReflectiveDependency",
    value: function _getByReflectiveDependency(dep) {
      return this._getByKey(dep.key, dep.visibility, dep.optional ? null : THROW_IF_NOT_FOUND);
    }
  }, {
    key: "_getByKey",
    value: function _getByKey(key, visibility, notFoundValue) {
      if (key === ReflectiveInjector_.INJECTOR_KEY) {
        return this;
      }

      if (visibility instanceof Self) {
        return this._getByKeySelf(key, notFoundValue);
      } else {
        return this._getByKeyDefault(key, notFoundValue, visibility);
      }
    }
  }, {
    key: "_getObjByKeyId",
    value: function _getObjByKeyId(keyId) {
      for (var i = 0; i < this.keyIds.length; i++) {
        if (this.keyIds[i] === keyId) {
          if (this.objs[i] === UNDEFINED) {
            this.objs[i] = this._new(this._providers[i]);
          }

          return this.objs[i];
        }
      }

      return UNDEFINED;
    }
    /** @internal */

  }, {
    key: "_throwOrNull",
    value: function _throwOrNull(key, notFoundValue) {
      if (notFoundValue !== THROW_IF_NOT_FOUND) {
        return notFoundValue;
      } else {
        throw noProviderError(this, key);
      }
    }
    /** @internal */

  }, {
    key: "_getByKeySelf",
    value: function _getByKeySelf(key, notFoundValue) {
      var obj = this._getObjByKeyId(key.id);

      return obj !== UNDEFINED ? obj : this._throwOrNull(key, notFoundValue);
    }
    /** @internal */

  }, {
    key: "_getByKeyDefault",
    value: function _getByKeyDefault(key, notFoundValue, visibility) {
      var inj;

      if (visibility instanceof SkipSelf) {
        inj = this.parent;
      } else {
        inj = this;
      }

      while (inj instanceof ReflectiveInjector_) {
        var inj_ = inj;

        var obj = inj_._getObjByKeyId(key.id);

        if (obj !== UNDEFINED) return obj;
        inj = inj_.parent;
      }

      if (inj !== null) {
        return inj.get(key.token, notFoundValue);
      } else {
        return this._throwOrNull(key, notFoundValue);
      }
    }
  }, {
    key: "toString",
    value: function toString() {
      return this.displayName;
    }
  }, {
    key: "displayName",
    get: function get() {
      var providers = _mapProviders(this, function (b) {
        return ' "' + b.key.displayName + '" ';
      }).join(', ');

      return "ReflectiveInjector(providers: [".concat(providers, "])");
    }
  }]);

  return ReflectiveInjector_;
}();

ReflectiveInjector_.INJECTOR_KEY = ReflectiveKey.get(Injector);

function _mapProviders(injector, fn) {
  var res = [];

  for (var i = 0; i < injector._providers.length; ++i) {
    res[i] = fn(injector.getProviderAtIndex(i));
  }

  return res;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A DI token that you can use to create a virtual [provider](guide/glossary#provider)
 * that will populate the `entryComponents` field of components and NgModules
 * based on its `useValue` property value.
 * All components that are referenced in the `useValue` value (either directly
 * or in a nested array or map) are added to the `entryComponents` property.
 *
 * @usageNotes
 *
 * The following example shows how the router can populate the `entryComponents`
 * field of an NgModule based on a router configuration that refers
 * to components.
 *
 * ```typescript
 * // helper function inside the router
 * function provideRoutes(routes) {
 *   return [
 *     {provide: ROUTES, useValue: routes},
 *     {provide: ANALYZE_FOR_ENTRY_COMPONENTS, useValue: routes, multi: true}
 *   ];
 * }
 *
 * // user code
 * let routes = [
 *   {path: '/root', component: RootComp},
 *   {path: '/teams', component: TeamsComp}
 * ];
 *
 * @NgModule({
 *   providers: [provideRoutes(routes)]
 * })
 * class ModuleWithRoutes {}
 * ```
 *
 * @publicApi
 * @deprecated Since 9.0.0. With Ivy, this property is no longer necessary.
 */


var ANALYZE_FOR_ENTRY_COMPONENTS = new InjectionToken('AnalyzeForEntryComponents');
/**
 * Base class for query metadata.
 *
 * @see `ContentChildren`.
 * @see `ContentChild`.
 * @see `ViewChildren`.
 * @see `ViewChild`.
 *
 * @publicApi
 */

var Query = function Query() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Query);
};

var ɵ0$a = function ɵ0$a(selector) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return Object.assign({
    selector: selector,
    first: false,
    isViewQuery: false,
    descendants: false
  }, data);
};
/**
 * ContentChildren decorator and metadata.
 *
 *
 * @Annotation
 * @publicApi
 */


var ContentChildren = makePropDecorator('ContentChildren', ɵ0$a, Query);

var ɵ1$2 = function ɵ1$2(selector) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return Object.assign({
    selector: selector,
    first: true,
    isViewQuery: false,
    descendants: true
  }, data);
};
/**
 * ContentChild decorator and metadata.
 *
 *
 * @Annotation
 *
 * @publicApi
 */


var ContentChild = makePropDecorator('ContentChild', ɵ1$2, Query);

var ɵ2 = function ɵ2(selector) {
  var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return Object.assign({
    selector: selector,
    first: false,
    isViewQuery: true,
    descendants: true
  }, data);
};
/**
 * ViewChildren decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */


var ViewChildren = makePropDecorator('ViewChildren', ɵ2, Query);

var ɵ3 = function ɵ3(selector, data) {
  return Object.assign({
    selector: selector,
    first: true,
    isViewQuery: true,
    descendants: true
  }, data);
};
/**
 * ViewChild decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */


var ViewChild = makePropDecorator('ViewChild', ɵ3, Query);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Used to resolve resource URLs on `@Component` when used with JIT compilation.
 *
 * Example:
 * ```
 * @Component({
 *   selector: 'my-comp',
 *   templateUrl: 'my-comp.html', // This requires asynchronous resolution
 * })
 * class MyComponent{
 * }
 *
 * // Calling `renderComponent` will fail because `renderComponent` is a synchronous process
 * // and `MyComponent`'s `@Component.templateUrl` needs to be resolved asynchronously.
 *
 * // Calling `resolveComponentResources()` will resolve `@Component.templateUrl` into
 * // `@Component.template`, which allows `renderComponent` to proceed in a synchronous manner.
 *
 * // Use browser's `fetch()` function as the default resource resolution strategy.
 * resolveComponentResources(fetch).then(() => {
 *   // After resolution all URLs have been converted into `template` strings.
 *   renderComponent(MyComponent);
 * });
 *
 * ```
 *
 * NOTE: In AOT the resolution happens during compilation, and so there should be no need
 * to call this method outside JIT mode.
 *
 * @param resourceResolver a function which is responsible for returning a `Promise` to the
 * contents of the resolved URL. Browser's `fetch()` method is a good default implementation.
 */

function resolveComponentResources(resourceResolver) {
  // Store all promises which are fetching the resources.
  var componentResolved = []; // Cache so that we don't fetch the same resource more than once.

  var urlMap = new Map();

  function cachedResourceResolve(url) {
    var promise = urlMap.get(url);

    if (!promise) {
      var resp = resourceResolver(url);
      urlMap.set(url, promise = resp.then(unwrapResponse));
    }

    return promise;
  }

  componentResourceResolutionQueue.forEach(function (component, type) {
    var promises = [];

    if (component.templateUrl) {
      promises.push(cachedResourceResolve(component.templateUrl).then(function (template) {
        component.template = template;
      }));
    }

    var styleUrls = component.styleUrls;
    var styles = component.styles || (component.styles = []);
    var styleOffset = component.styles.length;
    styleUrls && styleUrls.forEach(function (styleUrl, index) {
      styles.push(''); // pre-allocate array.

      promises.push(cachedResourceResolve(styleUrl).then(function (style) {
        styles[styleOffset + index] = style;
        styleUrls.splice(styleUrls.indexOf(styleUrl), 1);

        if (styleUrls.length == 0) {
          component.styleUrls = undefined;
        }
      }));
    });
    var fullyResolved = Promise.all(promises).then(function () {
      return componentDefResolved(type);
    });
    componentResolved.push(fullyResolved);
  });
  clearResolutionOfComponentResourcesQueue();
  return Promise.all(componentResolved).then(function () {
    return undefined;
  });
}

var componentResourceResolutionQueue = new Map(); // Track when existing ɵcmp for a Type is waiting on resources.

var componentDefPendingResolution = new Set();

function maybeQueueResolutionOfComponentResources(type, metadata) {
  if (componentNeedsResolution(metadata)) {
    componentResourceResolutionQueue.set(type, metadata);
    componentDefPendingResolution.add(type);
  }
}

function isComponentDefPendingResolution(type) {
  return componentDefPendingResolution.has(type);
}

function componentNeedsResolution(component) {
  return !!(component.templateUrl && !component.hasOwnProperty('template') || component.styleUrls && component.styleUrls.length);
}

function clearResolutionOfComponentResourcesQueue() {
  var old = componentResourceResolutionQueue;
  componentResourceResolutionQueue = new Map();
  return old;
}

function restoreComponentResolutionQueue(queue) {
  componentDefPendingResolution.clear();
  queue.forEach(function (_, type) {
    return componentDefPendingResolution.add(type);
  });
  componentResourceResolutionQueue = queue;
}

function isComponentResourceResolutionQueueEmpty() {
  return componentResourceResolutionQueue.size === 0;
}

function unwrapResponse(response) {
  return typeof response == 'string' ? response : response.text();
}

function componentDefResolved(type) {
  componentDefPendingResolution.delete(type);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Compute the static styling (class/style) from `TAttributes`.
 *
 * This function should be called during `firstCreatePass` only.
 *
 * @param tNode The `TNode` into which the styling information should be loaded.
 * @param attrs `TAttributes` containing the styling information.
 * @param writeToHost Where should the resulting static styles be written?
 *   - `false` Write to `TNode.stylesWithoutHost` / `TNode.classesWithoutHost`
 *   - `true` Write to `TNode.styles` / `TNode.classes`
 */


function computeStaticStyling(tNode, attrs, writeToHost) {
  ngDevMode && assertFirstCreatePass(getTView(), 'Expecting to be called in first template pass only');
  var styles = writeToHost ? tNode.styles : null;
  var classes = writeToHost ? tNode.classes : null;
  var mode = 0;

  if (attrs !== null) {
    for (var i = 0; i < attrs.length; i++) {
      var value = attrs[i];

      if (typeof value === 'number') {
        mode = value;
      } else if (mode == 1
      /* Classes */
      ) {
          classes = concatStringsWithSpace(classes, value);
        } else if (mode == 2
      /* Styles */
      ) {
          var style = value;
          var styleValue = attrs[++i];
          styles = concatStringsWithSpace(styles, style + ': ' + styleValue + ';');
        }
    }
  }

  writeToHost ? tNode.styles = styles : tNode.stylesWithoutHost = styles;
  writeToHost ? tNode.classes = classes : tNode.classesWithoutHost = classes;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Synchronously perform change detection on a component (and possibly its sub-components).
 *
 * This function triggers change detection in a synchronous way on a component.
 *
 * @param component The component which the change detection should be performed on.
 */


function detectChanges(component) {
  var view = getComponentViewByInstance(component);
  detectChangesInternal(view[TVIEW], view, component);
}
/**
 * Marks the component as dirty (needing change detection). Marking a component dirty will
 * schedule a change detection on it at some point in the future.
 *
 * Marking an already dirty component as dirty won't do anything. Only one outstanding change
 * detection can be scheduled per component tree.
 *
 * @param component Component to mark as dirty.
 */


function markDirty(component) {
  ngDevMode && assertDefined(component, 'component');
  var rootView = markViewDirty(getComponentViewByInstance(component));
  ngDevMode && assertDefined(rootView[CONTEXT], 'rootContext should be defined');
  scheduleTick(rootView[CONTEXT], 1
  /* DetectChanges */
  );
}
/**
 * Used to perform change detection on the whole application.
 *
 * This is equivalent to `detectChanges`, but invoked on root component. Additionally, `tick`
 * executes lifecycle hooks and conditionally checks components based on their
 * `ChangeDetectionStrategy` and dirtiness.
 *
 * The preferred way to trigger change detection is to call `markDirty`. `markDirty` internally
 * schedules `tick` using a scheduler in order to coalesce multiple `markDirty` calls into a
 * single change detection run. By default, the scheduler is `requestAnimationFrame`, but can
 * be changed when calling `renderComponent` and providing the `scheduler` option.
 */


function tick(component) {
  var rootView = getRootView(component);
  var rootContext = rootView[CONTEXT];
  tickRootContext(rootContext);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Retrieves the component instance associated with a given DOM element.
 *
 * @usageNotes
 * Given the following DOM structure:
 * ```html
 * <my-app>
 *   <div>
 *     <child-comp></child-comp>
 *   </div>
 * </my-app>
 * ```
 * Calling `getComponent` on `<child-comp>` will return the instance of `ChildComponent`
 * associated with this DOM element.
 *
 * Calling the function on `<my-app>` will return the `MyApp` instance.
 *
 *
 * @param element DOM element from which the component should be retrieved.
 * @returns Component instance associated with the element or `null` if there
 *    is no component associated with it.
 *
 * @publicApi
 * @globalApi ng
 */


function getComponent(element) {
  assertDomElement(element);
  var context = loadLContext(element, false);
  if (context === null) return null;

  if (context.component === undefined) {
    context.component = getComponentAtNodeIndex(context.nodeIndex, context.lView);
  }

  return context.component;
}
/**
 * If inside an embedded view (e.g. `*ngIf` or `*ngFor`), retrieves the context of the embedded
 * view that the element is part of. Otherwise retrieves the instance of the component whose view
 * owns the element (in this case, the result is the same as calling `getOwningComponent`).
 *
 * @param element Element for which to get the surrounding component instance.
 * @returns Instance of the component that is around the element or null if the element isn't
 *    inside any component.
 *
 * @publicApi
 * @globalApi ng
 */


function getContext(element) {
  assertDomElement(element);
  var context = loadLContext(element, false);
  return context === null ? null : context.lView[CONTEXT];
}
/**
 * Retrieves the component instance whose view contains the DOM element.
 *
 * For example, if `<child-comp>` is used in the template of `<app-comp>`
 * (i.e. a `ViewChild` of `<app-comp>`), calling `getOwningComponent` on `<child-comp>`
 * would return `<app-comp>`.
 *
 * @param elementOrDir DOM element, component or directive instance
 *    for which to retrieve the root components.
 * @returns Component instance whose view owns the DOM element or null if the element is not
 *    part of a component view.
 *
 * @publicApi
 * @globalApi ng
 */


function getOwningComponent(elementOrDir) {
  var context = loadLContext(elementOrDir, false);
  if (context === null) return null;
  var lView = context.lView;
  var parent;
  ngDevMode && assertLView(lView);

  while (lView[TVIEW].type === 2
  /* Embedded */
  && (parent = getLViewParent(lView))) {
    lView = parent;
  }

  return lView[FLAGS] & 512
  /* IsRoot */
  ? null : lView[CONTEXT];
}
/**
 * Retrieves all root components associated with a DOM element, directive or component instance.
 * Root components are those which have been bootstrapped by Angular.
 *
 * @param elementOrDir DOM element, component or directive instance
 *    for which to retrieve the root components.
 * @returns Root components associated with the target object.
 *
 * @publicApi
 * @globalApi ng
 */


function getRootComponents(elementOrDir) {
  return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(getRootContext(elementOrDir).components);
}
/**
 * Retrieves an `Injector` associated with an element, component or directive instance.
 *
 * @param elementOrDir DOM element, component or directive instance for which to
 *    retrieve the injector.
 * @returns Injector associated with the element, component or directive instance.
 *
 * @publicApi
 * @globalApi ng
 */


function getInjector(elementOrDir) {
  var context = loadLContext(elementOrDir, false);
  if (context === null) return Injector.NULL;
  var tNode = context.lView[TVIEW].data[context.nodeIndex];
  return new NodeInjector(tNode, context.lView);
}
/**
 * Retrieve a set of injection tokens at a given DOM node.
 *
 * @param element Element for which the injection tokens should be retrieved.
 */


function getInjectionTokens(element) {
  var context = loadLContext(element, false);
  if (context === null) return [];
  var lView = context.lView;
  var tView = lView[TVIEW];
  var tNode = tView.data[context.nodeIndex];
  var providerTokens = [];
  var startIndex = tNode.providerIndexes & 1048575
  /* ProvidersStartIndexMask */
  ;
  var endIndex = tNode.directiveEnd;

  for (var i = startIndex; i < endIndex; i++) {
    var value = tView.data[i];

    if (isDirectiveDefHack(value)) {
      // The fact that we sometimes store Type and sometimes DirectiveDef in this location is a
      // design flaw.  We should always store same type so that we can be monomorphic. The issue
      // is that for Components/Directives we store the def instead the type. The correct behavior
      // is that we should always be storing injectable type in this location.
      value = value.type;
    }

    providerTokens.push(value);
  }

  return providerTokens;
}
/**
 * Retrieves directive instances associated with a given DOM element. Does not include
 * component instances.
 *
 * @usageNotes
 * Given the following DOM structure:
 * ```
 * <my-app>
 *   <button my-button></button>
 *   <my-comp></my-comp>
 * </my-app>
 * ```
 * Calling `getDirectives` on `<button>` will return an array with an instance of the `MyButton`
 * directive that is associated with the DOM element.
 *
 * Calling `getDirectives` on `<my-comp>` will return an empty array.
 *
 * @param element DOM element for which to get the directives.
 * @returns Array of directives associated with the element.
 *
 * @publicApi
 * @globalApi ng
 */


function getDirectives(element) {
  var context = loadLContext(element);

  if (context.directives === undefined) {
    context.directives = getDirectivesAtNodeIndex(context.nodeIndex, context.lView, false);
  } // The `directives` in this case are a named array called `LComponentView`. Clone the
  // result so we don't expose an internal data structure in the user's console.


  return context.directives === null ? [] : Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(context.directives);
}

function loadLContext(target) {
  var throwOnNotFound = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  var context = getLContext(target);

  if (!context && throwOnNotFound) {
    throw new Error(ngDevMode ? "Unable to find context associated with ".concat(stringifyForError(target)) : 'Invalid ng target');
  }

  return context;
}
/**
 * Retrieve map of local references.
 *
 * The references are retrieved as a map of local reference name to element or directive instance.
 *
 * @param target DOM element, component or directive instance for which to retrieve
 *    the local references.
 */


function getLocalRefs(target) {
  var context = loadLContext(target, false);
  if (context === null) return {};

  if (context.localRefs === undefined) {
    context.localRefs = discoverLocalRefs(context.lView, context.nodeIndex);
  }

  return context.localRefs || {};
}
/**
 * Retrieves the host element of a component or directive instance.
 * The host element is the DOM element that matched the selector of the directive.
 *
 * @param componentOrDirective Component or directive instance for which the host
 *     element should be retrieved.
 * @returns Host element of the target.
 *
 * @publicApi
 * @globalApi ng
 */


function getHostElement(componentOrDirective) {
  return getLContext(componentOrDirective).native;
}
/**
 * Retrieves the rendered text for a given component.
 *
 * This function retrieves the host element of a component and
 * and then returns the `textContent` for that element. This implies
 * that the text returned will include re-projected content of
 * the component as well.
 *
 * @param component The component to return the content text for.
 */


function getRenderedText(component) {
  var hostElement = getHostElement(component);
  return hostElement.textContent || '';
}

function loadLContextFromNode(node) {
  if (!(node instanceof Node)) throw new Error('Expecting instance of DOM Element');
  return loadLContext(node);
}
/**
 * Retrieves a list of event listeners associated with a DOM element. The list does include host
 * listeners, but it does not include event listeners defined outside of the Angular context
 * (e.g. through `addEventListener`).
 *
 * @usageNotes
 * Given the following DOM structure:
 * ```
 * <my-app>
 *   <div (click)="doSomething()"></div>
 * </my-app>
 *
 * ```
 * Calling `getListeners` on `<div>` will return an object that looks as follows:
 * ```
 * {
 *   name: 'click',
 *   element: <div>,
 *   callback: () => doSomething(),
 *   useCapture: false
 * }
 * ```
 *
 * @param element Element for which the DOM listeners should be retrieved.
 * @returns Array of event listeners on the DOM element.
 *
 * @publicApi
 * @globalApi ng
 */


function getListeners(element) {
  assertDomElement(element);
  var lContext = loadLContext(element, false);
  if (lContext === null) return [];
  var lView = lContext.lView;
  var tView = lView[TVIEW];
  var lCleanup = lView[CLEANUP];
  var tCleanup = tView.cleanup;
  var listeners = [];

  if (tCleanup && lCleanup) {
    for (var i = 0; i < tCleanup.length;) {
      var firstParam = tCleanup[i++];
      var secondParam = tCleanup[i++];

      if (typeof firstParam === 'string') {
        var name = firstParam;
        var listenerElement = unwrapRNode(lView[secondParam]);
        var callback = lCleanup[tCleanup[i++]];
        var useCaptureOrIndx = tCleanup[i++]; // if useCaptureOrIndx is boolean then report it as is.
        // if useCaptureOrIndx is positive number then it in unsubscribe method
        // if useCaptureOrIndx is negative number then it is a Subscription

        var type = typeof useCaptureOrIndx === 'boolean' || useCaptureOrIndx >= 0 ? 'dom' : 'output';
        var useCapture = typeof useCaptureOrIndx === 'boolean' ? useCaptureOrIndx : false;

        if (element == listenerElement) {
          listeners.push({
            element: element,
            name: name,
            callback: callback,
            useCapture: useCapture,
            type: type
          });
        }
      }
    }
  }

  listeners.sort(sortListeners);
  return listeners;
}

function sortListeners(a, b) {
  if (a.name == b.name) return 0;
  return a.name < b.name ? -1 : 1;
}
/**
 * This function should not exist because it is megamorphic and only mostly correct.
 *
 * See call site for more info.
 */


function isDirectiveDefHack(obj) {
  return obj.type !== undefined && obj.template !== undefined && obj.declaredInputs !== undefined;
}
/**
 * Returns the attached `DebugNode` instance for an element in the DOM.
 *
 * @param element DOM element which is owned by an existing component's view.
 */


function getDebugNode(element) {
  var debugNode = null;
  var lContext = loadLContextFromNode(element);
  var lView = lContext.lView;
  var nodeIndex = lContext.nodeIndex;

  if (nodeIndex !== -1) {
    var valueInLView = lView[nodeIndex]; // this means that value in the lView is a component with its own
    // data. In this situation the TNode is not accessed at the same spot.

    var tNode = isLView(valueInLView) ? valueInLView[T_HOST] : getTNode(lView[TVIEW], nodeIndex - HEADER_OFFSET);
    ngDevMode && assertEqual(tNode.index, nodeIndex, 'Expecting that TNode at index is same as index');
    debugNode = buildDebugNode(tNode, lView);
  }

  return debugNode;
}
/**
 * Retrieve the component `LView` from component/element.
 *
 * NOTE: `LView` is a private and should not be leaked outside.
 *       Don't export this method to `ng.*` on window.
 *
 * @param target DOM element or component instance for which to retrieve the LView.
 */


function getComponentLView(target) {
  var lContext = loadLContext(target);
  var nodeIndx = lContext.nodeIndex;
  var lView = lContext.lView;
  var componentLView = lView[nodeIndx];
  ngDevMode && assertLView(componentLView);
  return componentLView;
}
/** Asserts that a value is a DOM Element. */


function assertDomElement(value) {
  if (typeof Element !== 'undefined' && !(value instanceof Element)) {
    throw new Error('Expecting instance of DOM Element');
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Marks a component for check (in case of OnPush components) and synchronously
 * performs change detection on the application this component belongs to.
 *
 * @param component Component to {@link ChangeDetectorRef#markForCheck mark for check}.
 *
 * @publicApi
 * @globalApi ng
 */


function applyChanges(component) {
  markDirty(component);
  getRootComponents(component).forEach(function (rootComponent) {
    return detectChanges(rootComponent);
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This file introduces series of globally accessible debug tools
 * to allow for the Angular debugging story to function.
 *
 * To see this in action run the following command:
 *
 *   bazel run --config=ivy
 *   //packages/core/test/bundling/todo:devserver
 *
 *  Then load `localhost:5432` and start using the console tools.
 */

/**
 * This value reflects the property on the window where the dev
 * tools are patched (window.ng).
 * */


var GLOBAL_PUBLISH_EXPANDO_KEY = 'ng';
var _published = false;
/**
 * Publishes a collection of default debug tools onto`window.ng`.
 *
 * These functions are available globally when Angular is in development
 * mode and are automatically stripped away from prod mode is on.
 */

function publishDefaultGlobalUtils() {
  if (!_published) {
    _published = true;
    publishGlobalUtil('getComponent', getComponent);
    publishGlobalUtil('getContext', getContext);
    publishGlobalUtil('getListeners', getListeners);
    publishGlobalUtil('getOwningComponent', getOwningComponent);
    publishGlobalUtil('getHostElement', getHostElement);
    publishGlobalUtil('getInjector', getInjector);
    publishGlobalUtil('getRootComponents', getRootComponents);
    publishGlobalUtil('getDirectives', getDirectives);
    publishGlobalUtil('applyChanges', applyChanges);
  }
}
/**
 * Publishes the given function to `window.ng` so that it can be
 * used from the browser console when an application is not in production.
 */


function publishGlobalUtil(name, fn) {
  if (typeof COMPILED === 'undefined' || !COMPILED) {
    // Note: we can't export `ng` when using closure enhanced optimization as:
    // - closure declares globals itself for minified names, which sometimes clobber our `ng` global
    // - we can't declare a closure extern as the namespace `ng` is already used within Google
    //   for typings for AngularJS (via `goog.provide('ng....')`).
    var w = _global;
    ngDevMode && assertDefined(fn, 'function not defined');

    if (w) {
      var container = w[GLOBAL_PUBLISH_EXPANDO_KEY];

      if (!container) {
        container = w[GLOBAL_PUBLISH_EXPANDO_KEY] = {};
      }

      container[name] = fn;
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$b = function ɵ0$b(token, notFoundValue) {
  throw new Error('NullInjector: Not found: ' + stringifyForError(token));
}; // TODO: A hack to not pull in the NullInjector from @angular/core.


var NULL_INJECTOR$1 = {
  get: ɵ0$b
};
/**
 * Bootstraps a Component into an existing host element and returns an instance
 * of the component.
 *
 * Use this function to bootstrap a component into the DOM tree. Each invocation
 * of this function will create a separate tree of components, injectors and
 * change detection cycles and lifetimes. To dynamically insert a new component
 * into an existing tree such that it shares the same injection, change detection
 * and object lifetime, use {@link ViewContainer#createComponent}.
 *
 * @param componentType Component to bootstrap
 * @param options Optional parameters which control bootstrapping
 */

function renderComponent$1(componentType
/* Type as workaround for: Microsoft/TypeScript/issues/4881 */
) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  ngDevMode && publishDefaultGlobalUtils();
  ngDevMode && assertComponentType(componentType);
  var rendererFactory = opts.rendererFactory || domRendererFactory3;
  var sanitizer = opts.sanitizer || null;
  var componentDef = getComponentDef(componentType);
  if (componentDef.type != componentType) componentDef.type = componentType; // The first index of the first selector is the tag name.

  var componentTag = componentDef.selectors[0][0];
  var hostRenderer = rendererFactory.createRenderer(null, null);
  var hostRNode = locateHostElement(hostRenderer, opts.host || componentTag, componentDef.encapsulation);
  var rootFlags = componentDef.onPush ? 64
  /* Dirty */
  | 512
  /* IsRoot */
  : 16
  /* CheckAlways */
  | 512
  /* IsRoot */
  ;
  var rootContext = createRootContext(opts.scheduler, opts.playerHandler);
  var renderer = rendererFactory.createRenderer(hostRNode, componentDef);
  var rootTView = createTView(0
  /* Root */
  , null, null, 1, 0, null, null, null, null, null);
  var rootView = createLView(null, rootTView, rootContext, rootFlags, null, null, rendererFactory, renderer, null, opts.injector || null);
  enterView(rootView);
  var component;

  try {
    if (rendererFactory.begin) rendererFactory.begin();
    var componentView = createRootComponentView(hostRNode, componentDef, rootView, rendererFactory, renderer, sanitizer);
    component = createRootComponent(componentView, componentDef, rootView, rootContext, opts.hostFeatures || null); // create mode pass

    renderView(rootTView, rootView, null); // update mode pass

    refreshView(rootTView, rootView, null, null);
  } finally {
    leaveView();
    if (rendererFactory.end) rendererFactory.end();
  }

  return component;
}
/**
 * Creates the root component view and the root component node.
 *
 * @param rNode Render host element.
 * @param def ComponentDef
 * @param rootView The parent view where the host node is stored
 * @param hostRenderer The current renderer
 * @param sanitizer The sanitizer, if provided
 *
 * @returns Component view created
 */


function createRootComponentView(rNode, def, rootView, rendererFactory, hostRenderer, sanitizer) {
  var tView = rootView[TVIEW];
  ngDevMode && assertIndexInRange(rootView, 0 + HEADER_OFFSET);
  rootView[0 + HEADER_OFFSET] = rNode;
  var tNode = getOrCreateTNode(tView, 0, 2
  /* Element */
  , null, null);
  var mergedAttrs = tNode.mergedAttrs = def.hostAttrs;

  if (mergedAttrs !== null) {
    computeStaticStyling(tNode, mergedAttrs, true);

    if (rNode !== null) {
      setUpAttributes(hostRenderer, rNode, mergedAttrs);

      if (tNode.classes !== null) {
        writeDirectClass(hostRenderer, rNode, tNode.classes);
      }

      if (tNode.styles !== null) {
        writeDirectStyle(hostRenderer, rNode, tNode.styles);
      }
    }
  }

  var viewRenderer = rendererFactory.createRenderer(rNode, def);
  var componentView = createLView(rootView, getOrCreateTComponentView(def), null, def.onPush ? 64
  /* Dirty */
  : 16
  /* CheckAlways */
  , rootView[HEADER_OFFSET], tNode, rendererFactory, viewRenderer, sanitizer || null, null);

  if (tView.firstCreatePass) {
    diPublicInInjector(getOrCreateNodeInjectorForNode(tNode, rootView), tView, def.type);
    markAsComponentHost(tView, tNode);
    initTNodeFlags(tNode, rootView.length, 1);
  }

  addToViewTree(rootView, componentView); // Store component view at node index, with node as the HOST

  return rootView[HEADER_OFFSET] = componentView;
}
/**
 * Creates a root component and sets it up with features and host bindings. Shared by
 * renderComponent() and ViewContainerRef.createComponent().
 */


function createRootComponent(componentView, componentDef, rootLView, rootContext, hostFeatures) {
  var tView = rootLView[TVIEW]; // Create directive instance with factory() and store at next index in viewData

  var component = instantiateRootComponent(tView, rootLView, componentDef);
  rootContext.components.push(component);
  componentView[CONTEXT] = component;
  hostFeatures && hostFeatures.forEach(function (feature) {
    return feature(component, componentDef);
  }); // We want to generate an empty QueryList for root content queries for backwards
  // compatibility with ViewEngine.

  if (componentDef.contentQueries) {
    componentDef.contentQueries(1
    /* Create */
    , component, rootLView.length - 1);
  }

  var rootTNode = getCurrentTNode();
  ngDevMode && assertDefined(rootTNode, 'tNode should have been already created');

  if (tView.firstCreatePass && (componentDef.hostBindings !== null || componentDef.hostAttrs !== null)) {
    var elementIndex = rootTNode.index - HEADER_OFFSET;
    setSelectedIndex(elementIndex);
    var rootTView = rootLView[TVIEW];
    addHostBindingsToExpandoInstructions(rootTView, componentDef);
    growHostVarsSpace(rootTView, rootLView, componentDef.hostVars);
    invokeHostBindingsInCreationMode(componentDef, component);
  }

  return component;
}

function createRootContext(scheduler, playerHandler) {
  return {
    components: [],
    scheduler: scheduler || defaultScheduler,
    clean: CLEAN_PROMISE,
    playerHandler: playerHandler || null,
    flags: 0
    /* Empty */

  };
}
/**
 * Used to enable lifecycle hooks on the root component.
 *
 * Include this feature when calling `renderComponent` if the root component
 * you are rendering has lifecycle hooks defined. Otherwise, the hooks won't
 * be called properly.
 *
 * Example:
 *
 * ```
 * renderComponent(AppComponent, {hostFeatures: [LifecycleHooksFeature]});
 * ```
 */


function LifecycleHooksFeature(component, def) {
  var rootTView = readPatchedLView(component)[TVIEW];
  var dirIndex = rootTView.data.length - 1; // TODO(misko): replace `as TNode` with createTNode call. (needs refactoring to lose dep on
  // LNode).

  registerPostOrderHooks(rootTView, {
    directiveStart: dirIndex,
    directiveEnd: dirIndex + 1
  });
}
/**
 * Wait on component until it is rendered.
 *
 * This function returns a `Promise` which is resolved when the component's
 * change detection is executed. This is determined by finding the scheduler
 * associated with the `component`'s render tree and waiting until the scheduler
 * flushes. If nothing is scheduled, the function returns a resolved promise.
 *
 * Example:
 * ```
 * await whenRendered(myComponent);
 * ```
 *
 * @param component Component to wait upon
 * @returns Promise which resolves when the component is rendered.
 */


function whenRendered(component) {
  return getRootContext(component).clean;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function getSuperType(type) {
  return Object.getPrototypeOf(type.prototype).constructor;
}
/**
 * Merges the definition from a super class to a sub class.
 * @param definition The definition that is a SubClass of another directive of component
 *
 * @codeGenApi
 */


function ɵɵInheritDefinitionFeature(definition) {
  var superType = getSuperType(definition.type);
  var shouldInheritFields = true;
  var inheritanceChain = [definition];

  while (superType) {
    var superDef = undefined;

    if (isComponentDef(definition)) {
      // Don't use getComponentDef/getDirectiveDef. This logic relies on inheritance.
      superDef = superType.ɵcmp || superType.ɵdir;
    } else {
      if (superType.ɵcmp) {
        throw new Error('Directives cannot inherit Components');
      } // Don't use getComponentDef/getDirectiveDef. This logic relies on inheritance.


      superDef = superType.ɵdir;
    }

    if (superDef) {
      if (shouldInheritFields) {
        inheritanceChain.push(superDef); // Some fields in the definition may be empty, if there were no values to put in them that
        // would've justified object creation. Unwrap them if necessary.

        var writeableDef = definition;
        writeableDef.inputs = maybeUnwrapEmpty(definition.inputs);
        writeableDef.declaredInputs = maybeUnwrapEmpty(definition.declaredInputs);
        writeableDef.outputs = maybeUnwrapEmpty(definition.outputs); // Merge hostBindings

        var superHostBindings = superDef.hostBindings;
        superHostBindings && inheritHostBindings(definition, superHostBindings); // Merge queries

        var superViewQuery = superDef.viewQuery;
        var superContentQueries = superDef.contentQueries;
        superViewQuery && inheritViewQuery(definition, superViewQuery);
        superContentQueries && inheritContentQueries(definition, superContentQueries); // Merge inputs and outputs

        fillProperties(definition.inputs, superDef.inputs);
        fillProperties(definition.declaredInputs, superDef.declaredInputs);
        fillProperties(definition.outputs, superDef.outputs); // Merge animations metadata.
        // If `superDef` is a Component, the `data` field is present (defaults to an empty object).

        if (isComponentDef(superDef) && superDef.data.animation) {
          // If super def is a Component, the `definition` is also a Component, since Directives can
          // not inherit Components (we throw an error above and cannot reach this code).
          var defData = definition.data;
          defData.animation = (defData.animation || []).concat(superDef.data.animation);
        }
      } // Run parent features


      var features = superDef.features;

      if (features) {
        for (var i = 0; i < features.length; i++) {
          var feature = features[i];

          if (feature && feature.ngInherit) {
            feature(definition);
          } // If `InheritDefinitionFeature` is a part of the current `superDef`, it means that this
          // def already has all the necessary information inherited from its super class(es), so we
          // can stop merging fields from super classes. However we need to iterate through the
          // prototype chain to look for classes that might contain other "features" (like
          // NgOnChanges), which we should invoke for the original `definition`. We set the
          // `shouldInheritFields` flag to indicate that, essentially skipping fields inheritance
          // logic and only invoking functions from the "features" list.


          if (feature === ɵɵInheritDefinitionFeature) {
            shouldInheritFields = false;
          }
        }
      }
    }

    superType = Object.getPrototypeOf(superType);
  }

  mergeHostAttrsAcrossInheritance(inheritanceChain);
}
/**
 * Merge the `hostAttrs` and `hostVars` from the inherited parent to the base class.
 *
 * @param inheritanceChain A list of `WritableDefs` starting at the top most type and listing
 * sub-types in order. For each type take the `hostAttrs` and `hostVars` and merge it with the child
 * type.
 */


function mergeHostAttrsAcrossInheritance(inheritanceChain) {
  var hostVars = 0;
  var hostAttrs = null; // We process the inheritance order from the base to the leaves here.

  for (var i = inheritanceChain.length - 1; i >= 0; i--) {
    var def = inheritanceChain[i]; // For each `hostVars`, we need to add the superclass amount.

    def.hostVars = hostVars += def.hostVars; // for each `hostAttrs` we need to merge it with superclass.

    def.hostAttrs = mergeHostAttrs(def.hostAttrs, hostAttrs = mergeHostAttrs(hostAttrs, def.hostAttrs));
  }
}

function maybeUnwrapEmpty(value) {
  if (value === EMPTY_OBJ) {
    return {};
  } else if (value === EMPTY_ARRAY) {
    return [];
  } else {
    return value;
  }
}

function inheritViewQuery(definition, superViewQuery) {
  var prevViewQuery = definition.viewQuery;

  if (prevViewQuery) {
    definition.viewQuery = function (rf, ctx) {
      superViewQuery(rf, ctx);
      prevViewQuery(rf, ctx);
    };
  } else {
    definition.viewQuery = superViewQuery;
  }
}

function inheritContentQueries(definition, superContentQueries) {
  var prevContentQueries = definition.contentQueries;

  if (prevContentQueries) {
    definition.contentQueries = function (rf, ctx, directiveIndex) {
      superContentQueries(rf, ctx, directiveIndex);
      prevContentQueries(rf, ctx, directiveIndex);
    };
  } else {
    definition.contentQueries = superContentQueries;
  }
}

function inheritHostBindings(definition, superHostBindings) {
  var prevHostBindings = definition.hostBindings;

  if (prevHostBindings) {
    definition.hostBindings = function (rf, ctx) {
      superHostBindings(rf, ctx);
      prevHostBindings(rf, ctx);
    };
  } else {
    definition.hostBindings = superHostBindings;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Fields which exist on either directive or component definitions, and need to be copied from
 * parent to child classes by the `ɵɵCopyDefinitionFeature`.
 */


var COPY_DIRECTIVE_FIELDS = [// The child class should use the providers of its parent.
'providersResolver'];
/**
 * Fields which exist only on component definitions, and need to be copied from parent to child
 * classes by the `ɵɵCopyDefinitionFeature`.
 *
 * The type here allows any field of `ComponentDef` which is not also a property of `DirectiveDef`,
 * since those should go in `COPY_DIRECTIVE_FIELDS` above.
 */

var COPY_COMPONENT_FIELDS = [// The child class should use the template function of its parent, including all template
// semantics.
'template', 'decls', 'consts', 'vars', 'onPush', 'ngContentSelectors', // The child class should use the CSS styles of its parent, including all styling semantics.
'styles', 'encapsulation', // The child class should be checked by the runtime in the same way as its parent.
'schemas'];
/**
 * Copies the fields not handled by the `ɵɵInheritDefinitionFeature` from the supertype of a
 * definition.
 *
 * This exists primarily to support ngcc migration of an existing View Engine pattern, where an
 * entire decorator is inherited from a parent to a child class. When ngcc detects this case, it
 * generates a skeleton definition on the child class, and applies this feature.
 *
 * The `ɵɵCopyDefinitionFeature` then copies any needed fields from the parent class' definition,
 * including things like the component template function.
 *
 * @param definition The definition of a child class which inherits from a parent class with its
 * own definition.
 *
 * @codeGenApi
 */

function ɵɵCopyDefinitionFeature(definition) {
  var superType = getSuperType(definition.type);
  var superDef = undefined;

  if (isComponentDef(definition)) {
    // Don't use getComponentDef/getDirectiveDef. This logic relies on inheritance.
    superDef = superType.ɵcmp;
  } else {
    // Don't use getComponentDef/getDirectiveDef. This logic relies on inheritance.
    superDef = superType.ɵdir;
  } // Needed because `definition` fields are readonly.


  var defAny = definition; // Copy over any fields that apply to either directives or components.

  var _iterator2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__["default"])(COPY_DIRECTIVE_FIELDS),
      _step2;

  try {
    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
      var _field = _step2.value;
      defAny[_field] = superDef[_field];
    }
  } catch (err) {
    _iterator2.e(err);
  } finally {
    _iterator2.f();
  }

  if (isComponentDef(superDef)) {
    // Copy over any component-specific fields.
    var _iterator3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__["default"])(COPY_COMPONENT_FIELDS),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var field = _step3.value;
        defAny[field] = superDef[field];
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _symbolIterator = null;

function getSymbolIterator() {
  if (!_symbolIterator) {
    var _Symbol = _global['Symbol'];

    if (_Symbol && _Symbol.iterator) {
      _symbolIterator = _Symbol.iterator;
    } else {
      // es6-shim specific logic
      var keys = Object.getOwnPropertyNames(Map.prototype);

      for (var i = 0; i < keys.length; ++i) {
        var key = keys[i];

        if (key !== 'entries' && key !== 'size' && Map.prototype[key] === Map.prototype['entries']) {
          _symbolIterator = key;
        }
      }
    }
  }

  return _symbolIterator;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function devModeEqual(a, b) {
  var isListLikeIterableA = isListLikeIterable(a);
  var isListLikeIterableB = isListLikeIterable(b);

  if (isListLikeIterableA && isListLikeIterableB) {
    return areIterablesEqual(a, b, devModeEqual);
  } else {
    var isAObject = a && (typeof a === 'object' || typeof a === 'function');
    var isBObject = b && (typeof b === 'object' || typeof b === 'function');

    if (!isListLikeIterableA && isAObject && !isListLikeIterableB && isBObject) {
      return true;
    } else {
      return Object.is(a, b);
    }
  }
}
/**
 * Indicates that the result of a {@link Pipe} transformation has changed even though the
 * reference has not changed.
 *
 * Wrapped values are unwrapped automatically during the change detection, and the unwrapped value
 * is stored.
 *
 * Example:
 *
 * ```
 * if (this._latestValue === this._latestReturnedValue) {
 *    return this._latestReturnedValue;
 *  } else {
 *    this._latestReturnedValue = this._latestValue;
 *    return WrappedValue.wrap(this._latestValue); // this will force update
 *  }
 * ```
 *
 * @publicApi
 * @deprecated from v10 stop using. (No replacement, deemed unnecessary.)
 */


var WrappedValue = /*#__PURE__*/function () {
  function WrappedValue(value) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, WrappedValue);

    this.wrapped = value;
  }
  /** Creates a wrapped value. */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(WrappedValue, null, [{
    key: "wrap",
    value: function wrap(value) {
      return new WrappedValue(value);
    }
    /**
     * Returns the underlying value of a wrapped value.
     * Returns the given `value` when it is not wrapped.
     **/

  }, {
    key: "unwrap",
    value: function unwrap(value) {
      return WrappedValue.isWrapped(value) ? value.wrapped : value;
    }
    /** Returns true if `value` is a wrapped value. */

  }, {
    key: "isWrapped",
    value: function isWrapped(value) {
      return value instanceof WrappedValue;
    }
  }]);

  return WrappedValue;
}();

function isListLikeIterable(obj) {
  if (!isJsObject(obj)) return false;
  return Array.isArray(obj) || !(obj instanceof Map) && // JS Map are iterables but return entries as [k, v]
  getSymbolIterator() in obj; // JS Iterable have a Symbol.iterator prop
}

function areIterablesEqual(a, b, comparator) {
  var iterator1 = a[getSymbolIterator()]();
  var iterator2 = b[getSymbolIterator()]();

  while (true) {
    var item1 = iterator1.next();
    var item2 = iterator2.next();
    if (item1.done && item2.done) return true;
    if (item1.done || item2.done) return false;
    if (!comparator(item1.value, item2.value)) return false;
  }
}

function iterateListLike(obj, fn) {
  if (Array.isArray(obj)) {
    for (var i = 0; i < obj.length; i++) {
      fn(obj[i]);
    }
  } else {
    var iterator = obj[getSymbolIterator()]();
    var item;

    while (!(item = iterator.next()).done) {
      fn(item.value);
    }
  }
}

function isJsObject(o) {
  return o !== null && (typeof o === 'function' || typeof o === 'object');
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// TODO(misko): consider inlining

/** Updates binding and returns the value. */


function updateBinding(lView, bindingIndex, value) {
  return lView[bindingIndex] = value;
}
/** Gets the current binding value. */


function getBinding(lView, bindingIndex) {
  ngDevMode && assertIndexInRange(lView, bindingIndex);
  ngDevMode && assertNotSame(lView[bindingIndex], NO_CHANGE, 'Stored value should never be NO_CHANGE.');
  return lView[bindingIndex];
}
/**
 * Updates binding if changed, then returns whether it was updated.
 *
 * This function also checks the `CheckNoChangesMode` and throws if changes are made.
 * Some changes (Objects/iterables) during `CheckNoChangesMode` are exempt to comply with VE
 * behavior.
 *
 * @param lView current `LView`
 * @param bindingIndex The binding in the `LView` to check
 * @param value New value to check against `lView[bindingIndex]`
 * @returns `true` if the bindings has changed. (Throws if binding has changed during
 *          `CheckNoChangesMode`)
 */


function bindingUpdated(lView, bindingIndex, value) {
  ngDevMode && assertNotSame(value, NO_CHANGE, 'Incoming value should never be NO_CHANGE.');
  ngDevMode && assertLessThan(bindingIndex, lView.length, "Slot should have been initialized to NO_CHANGE");
  var oldValue = lView[bindingIndex];

  if (Object.is(oldValue, value)) {
    return false;
  } else {
    if (ngDevMode && getCheckNoChangesMode()) {
      // View engine didn't report undefined values as changed on the first checkNoChanges pass
      // (before the change detection was run).
      var oldValueToCompare = oldValue !== NO_CHANGE ? oldValue : undefined;

      if (!devModeEqual(oldValueToCompare, value)) {
        var details = getExpressionChangedErrorDetails(lView, bindingIndex, oldValueToCompare, value);
        throwErrorIfNoChangesMode(oldValue === NO_CHANGE, details.oldValue, details.newValue, details.propName);
      } // There was a change, but the `devModeEqual` decided that the change is exempt from an error.
      // For this reason we exit as if no change. The early exit is needed to prevent the changed
      // value to be written into `LView` (If we would write the new value that we would not see it
      // as change on next CD.)


      return false;
    }

    lView[bindingIndex] = value;
    return true;
  }
}
/** Updates 2 bindings if changed, then returns whether either was updated. */


function bindingUpdated2(lView, bindingIndex, exp1, exp2) {
  var different = bindingUpdated(lView, bindingIndex, exp1);
  return bindingUpdated(lView, bindingIndex + 1, exp2) || different;
}
/** Updates 3 bindings if changed, then returns whether any was updated. */


function bindingUpdated3(lView, bindingIndex, exp1, exp2, exp3) {
  var different = bindingUpdated2(lView, bindingIndex, exp1, exp2);
  return bindingUpdated(lView, bindingIndex + 2, exp3) || different;
}
/** Updates 4 bindings if changed, then returns whether any was updated. */


function bindingUpdated4(lView, bindingIndex, exp1, exp2, exp3, exp4) {
  var different = bindingUpdated2(lView, bindingIndex, exp1, exp2);
  return bindingUpdated2(lView, bindingIndex + 2, exp3, exp4) || different;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Updates the value of or removes a bound attribute on an Element.
 *
 * Used in the case of `[attr.title]="value"`
 *
 * @param name name The name of the attribute.
 * @param value value The attribute is removed when value is `null` or `undefined`.
 *                  Otherwise the attribute value is set to the stringified value.
 * @param sanitizer An optional function used to sanitize the value.
 * @param namespace Optional namespace to use when setting the attribute.
 *
 * @codeGenApi
 */


function ɵɵattribute(name, value, sanitizer, namespace) {
  var lView = getLView();
  var bindingIndex = nextBindingIndex();

  if (bindingUpdated(lView, bindingIndex, value)) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, name, value, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, 'attr.' + name, bindingIndex);
  }

  return ɵɵattribute;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Create interpolation bindings with a variable number of expressions.
 *
 * If there are 1 to 8 expressions `interpolation1()` to `interpolation8()` should be used instead.
 * Those are faster because there is no need to create an array of expressions and iterate over it.
 *
 * `values`:
 * - has static text at even indexes,
 * - has evaluated expressions at odd indexes.
 *
 * Returns the concatenated string when any of the arguments changes, `NO_CHANGE` otherwise.
 */


function interpolationV(lView, values) {
  ngDevMode && assertLessThan(2, values.length, 'should have at least 3 values');
  ngDevMode && assertEqual(values.length % 2, 1, 'should have an odd number of values');
  var isBindingUpdated = false;
  var bindingIndex = getBindingIndex();

  for (var i = 1; i < values.length; i += 2) {
    // Check if bindings (odd indexes) have changed
    isBindingUpdated = bindingUpdated(lView, bindingIndex++, values[i]) || isBindingUpdated;
  }

  setBindingIndex(bindingIndex);

  if (!isBindingUpdated) {
    return NO_CHANGE;
  } // Build the updated content


  var content = values[0];

  for (var _i5 = 1; _i5 < values.length; _i5 += 2) {
    content += renderStringify(values[_i5]) + values[_i5 + 1];
  }

  return content;
}
/**
 * Creates an interpolation binding with 1 expression.
 *
 * @param prefix static value used for concatenation only.
 * @param v0 value checked for change.
 * @param suffix static value used for concatenation only.
 */


function interpolation1(lView, prefix, v0, suffix) {
  var different = bindingUpdated(lView, nextBindingIndex(), v0);
  return different ? prefix + renderStringify(v0) + suffix : NO_CHANGE;
}
/**
 * Creates an interpolation binding with 2 expressions.
 */


function interpolation2(lView, prefix, v0, i0, v1, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated2(lView, bindingIndex, v0, v1);
  incrementBindingIndex(2);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + suffix : NO_CHANGE;
}
/**
 * Creates an interpolation binding with 3 expressions.
 */


function interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated3(lView, bindingIndex, v0, v1, v2);
  incrementBindingIndex(3);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + i1 + renderStringify(v2) + suffix : NO_CHANGE;
}
/**
 * Create an interpolation binding with 4 expressions.
 */


function interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated4(lView, bindingIndex, v0, v1, v2, v3);
  incrementBindingIndex(4);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + i1 + renderStringify(v2) + i2 + renderStringify(v3) + suffix : NO_CHANGE;
}
/**
 * Creates an interpolation binding with 5 expressions.
 */


function interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated4(lView, bindingIndex, v0, v1, v2, v3);
  different = bindingUpdated(lView, bindingIndex + 4, v4) || different;
  incrementBindingIndex(5);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + i1 + renderStringify(v2) + i2 + renderStringify(v3) + i3 + renderStringify(v4) + suffix : NO_CHANGE;
}
/**
 * Creates an interpolation binding with 6 expressions.
 */


function interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated4(lView, bindingIndex, v0, v1, v2, v3);
  different = bindingUpdated2(lView, bindingIndex + 4, v4, v5) || different;
  incrementBindingIndex(6);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + i1 + renderStringify(v2) + i2 + renderStringify(v3) + i3 + renderStringify(v4) + i4 + renderStringify(v5) + suffix : NO_CHANGE;
}
/**
 * Creates an interpolation binding with 7 expressions.
 */


function interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated4(lView, bindingIndex, v0, v1, v2, v3);
  different = bindingUpdated3(lView, bindingIndex + 4, v4, v5, v6) || different;
  incrementBindingIndex(7);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + i1 + renderStringify(v2) + i2 + renderStringify(v3) + i3 + renderStringify(v4) + i4 + renderStringify(v5) + i5 + renderStringify(v6) + suffix : NO_CHANGE;
}
/**
 * Creates an interpolation binding with 8 expressions.
 */


function interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix) {
  var bindingIndex = getBindingIndex();
  var different = bindingUpdated4(lView, bindingIndex, v0, v1, v2, v3);
  different = bindingUpdated4(lView, bindingIndex + 4, v4, v5, v6, v7) || different;
  incrementBindingIndex(8);
  return different ? prefix + renderStringify(v0) + i0 + renderStringify(v1) + i1 + renderStringify(v2) + i2 + renderStringify(v3) + i3 + renderStringify(v4) + i4 + renderStringify(v5) + i5 + renderStringify(v6) + i6 + renderStringify(v7) + suffix : NO_CHANGE;
}
/**
 *
 * Update an interpolated attribute on an element with single bound value surrounded by text.
 *
 * Used when the value passed to a property has 1 interpolated value in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate1('title', 'prefix', v0, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate1(attrName, prefix, v0, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation1(lView, prefix, v0, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 1, prefix, suffix);
  }

  return ɵɵattributeInterpolate1;
}
/**
 *
 * Update an interpolated attribute on an element with 2 bound values surrounded by text.
 *
 * Used when the value passed to a property has 2 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate2('title', 'prefix', v0, '-', v1, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate2(attrName, prefix, v0, i0, v1, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation2(lView, prefix, v0, i0, v1, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 2, prefix, i0, suffix);
  }

  return ɵɵattributeInterpolate2;
}
/**
 *
 * Update an interpolated attribute on an element with 3 bound values surrounded by text.
 *
 * Used when the value passed to a property has 3 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}-{{v2}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate3(
 * 'title', 'prefix', v0, '-', v1, '-', v2, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate3(attrName, prefix, v0, i0, v1, i1, v2, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 3, prefix, i0, i1, suffix);
  }

  return ɵɵattributeInterpolate3;
}
/**
 *
 * Update an interpolated attribute on an element with 4 bound values surrounded by text.
 *
 * Used when the value passed to a property has 4 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate4(
 * 'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate4(attrName, prefix, v0, i0, v1, i1, v2, i2, v3, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 4, prefix, i0, i1, i2, suffix);
  }

  return ɵɵattributeInterpolate4;
}
/**
 *
 * Update an interpolated attribute on an element with 5 bound values surrounded by text.
 *
 * Used when the value passed to a property has 5 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate5(
 * 'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate5(attrName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 5, prefix, i0, i1, i2, i3, suffix);
  }

  return ɵɵattributeInterpolate5;
}
/**
 *
 * Update an interpolated attribute on an element with 6 bound values surrounded by text.
 *
 * Used when the value passed to a property has 6 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate6(
 *    'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate6(attrName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 6, prefix, i0, i1, i2, i3, i4, suffix);
  }

  return ɵɵattributeInterpolate6;
}
/**
 *
 * Update an interpolated attribute on an element with 7 bound values surrounded by text.
 *
 * Used when the value passed to a property has 7 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate7(
 *    'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate7(attrName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 7, prefix, i0, i1, i2, i3, i4, i5, suffix);
  }

  return ɵɵattributeInterpolate7;
}
/**
 *
 * Update an interpolated attribute on an element with 8 bound values surrounded by text.
 *
 * Used when the value passed to a property has 8 interpolated values in it:
 *
 * ```html
 * <div attr.title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolate8(
 *  'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, 'suffix');
 * ```
 *
 * @param attrName The name of the attribute to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param i6 Static value used for concatenation only.
 * @param v7 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolate8(attrName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix, sanitizer, namespace) {
  var lView = getLView();
  var interpolatedValue = interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolatedValue, sanitizer, namespace);
    ngDevMode && storePropertyBindingMetadata(getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - 8, prefix, i0, i1, i2, i3, i4, i5, i6, suffix);
  }

  return ɵɵattributeInterpolate8;
}
/**
 * Update an interpolated attribute on an element with 9 or more bound values surrounded by text.
 *
 * Used when the number of interpolated values exceeds 8.
 *
 * ```html
 * <div
 *  title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}-{{v8}}-{{v9}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵattributeInterpolateV(
 *  'title', ['prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, '-', v9,
 *  'suffix']);
 * ```
 *
 * @param attrName The name of the attribute to update.
 * @param values The collection of values and the strings in-between those values, beginning with
 * a string prefix and ending with a string suffix.
 * (e.g. `['prefix', value0, '-', value1, '-', value2, ..., value99, 'suffix']`)
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵattributeInterpolateV(attrName, values, sanitizer, namespace) {
  var lView = getLView();
  var interpolated = interpolationV(lView, values);

  if (interpolated !== NO_CHANGE) {
    var tNode = getSelectedTNode();
    elementAttributeInternal(tNode, lView, attrName, interpolated, sanitizer, namespace);

    if (ngDevMode) {
      var interpolationInBetween = [values[0]]; // prefix

      for (var i = 2; i < values.length; i += 2) {
        interpolationInBetween.push(values[i]);
      }

      storePropertyBindingMetadata.apply(void 0, [getTView().data, tNode, 'attr.' + attrName, getBindingIndex() - interpolationInBetween.length + 1].concat(interpolationInBetween));
    }
  }

  return ɵɵattributeInterpolateV;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function templateFirstCreatePass(index, tView, lView, templateFn, decls, vars, tagName, attrsIndex, localRefsIndex) {
  ngDevMode && assertFirstCreatePass(tView);
  ngDevMode && ngDevMode.firstCreatePass++;
  var tViewConsts = tView.consts; // TODO(pk): refactor getOrCreateTNode to have the "create" only version

  var tNode = getOrCreateTNode(tView, index, 0
  /* Container */
  , tagName || null, getConstant(tViewConsts, attrsIndex));
  resolveDirectives(tView, lView, tNode, getConstant(tViewConsts, localRefsIndex));
  registerPostOrderHooks(tView, tNode);
  var embeddedTView = tNode.tViews = createTView(2
  /* Embedded */
  , tNode, templateFn, decls, vars, tView.directiveRegistry, tView.pipeRegistry, null, tView.schemas, tViewConsts);

  if (tView.queries !== null) {
    tView.queries.template(tView, tNode);
    embeddedTView.queries = tView.queries.embeddedTView(tNode);
  }

  return tNode;
}
/**
 * Creates an LContainer for an ng-template (dynamically-inserted view), e.g.
 *
 * <ng-template #foo>
 *    <div></div>
 * </ng-template>
 *
 * @param index The index of the container in the data array
 * @param templateFn Inline template
 * @param decls The number of nodes, local refs, and pipes for this template
 * @param vars The number of bindings for this template
 * @param tagName The name of the container element, if applicable
 * @param attrsIndex Index of template attributes in the `consts` array.
 * @param localRefs Index of the local references in the `consts` array.
 * @param localRefExtractor A function which extracts local-refs values from the template.
 *        Defaults to the current element associated with the local-ref.
 *
 * @codeGenApi
 */


function ɵɵtemplate(index, templateFn, decls, vars, tagName, attrsIndex, localRefsIndex, localRefExtractor) {
  var lView = getLView();
  var tView = getTView();
  var adjustedIndex = index + HEADER_OFFSET;
  var tNode = tView.firstCreatePass ? templateFirstCreatePass(index, tView, lView, templateFn, decls, vars, tagName, attrsIndex, localRefsIndex) : tView.data[adjustedIndex];
  setCurrentTNode(tNode, false);
  var comment = lView[RENDERER].createComment(ngDevMode ? 'container' : '');
  appendChild(tView, lView, comment, tNode);
  attachPatchData(comment, lView);
  addToViewTree(lView, lView[adjustedIndex] = createLContainer(comment, lView, comment, tNode));

  if (isDirectiveHost(tNode)) {
    createDirectivesInstances(tView, lView, tNode);
  }

  if (localRefsIndex != null) {
    saveResolvedLocalsInData(lView, tNode, localRefExtractor);
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/** Store a value in the `data` at a given `index`. */


function store(tView, lView, index, value) {
  // We don't store any static data for local variables, so the first time
  // we see the template, we should store as null to avoid a sparse array
  var adjustedIndex = index + HEADER_OFFSET;

  if (adjustedIndex >= tView.data.length) {
    tView.data[adjustedIndex] = null;
    tView.blueprint[adjustedIndex] = null;
  }

  lView[adjustedIndex] = value;
}
/**
 * Retrieves a local reference from the current contextViewData.
 *
 * If the reference to retrieve is in a parent view, this instruction is used in conjunction
 * with a nextContext() call, which walks up the tree and updates the contextViewData instance.
 *
 * @param index The index of the local ref in contextViewData.
 *
 * @codeGenApi
 */


function ɵɵreference(index) {
  var contextLView = getContextLView();
  return load(contextLView, index);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function ɵɵdirectiveInject(token) {
  var flags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : InjectFlags.Default;
  var lView = getLView(); // Fall back to inject() if view hasn't been created. This situation can happen in tests
  // if inject utilities are used before bootstrapping.

  if (lView === null) {
    // Verify that we will not get into infinite loop.
    ngDevMode && assertInjectImplementationNot(ɵɵdirectiveInject);
    return ɵɵinject(token, flags);
  }

  var tNode = getCurrentTNode();
  return getOrCreateInjectable(tNode, lView, resolveForwardRef(token), flags);
}
/**
 * Facade for the attribute injection from DI.
 *
 * @codeGenApi
 */


function ɵɵinjectAttribute(attrNameToInject) {
  return injectAttributeImpl(getCurrentTNode(), attrNameToInject);
}
/**
 * Throws an error indicating that a factory function could not be generated by the compiler for a
 * particular class.
 *
 * This instruction allows the actual error message to be optimized away when ngDevMode is turned
 * off, saving bytes of generated code while still providing a good experience in dev mode.
 *
 * The name of the class is not mentioned here, but will be in the generated factory function name
 * and thus in the stack trace.
 *
 * @codeGenApi
 */


function ɵɵinvalidFactory() {
  var msg = ngDevMode ? "This constructor was not compatible with Dependency Injection." : 'invalid';
  throw new Error(msg);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Update a property on a selected element.
 *
 * Operates on the element selected by index via the {@link select} instruction.
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled
 *
 * @param propName Name of property. Because it is going to DOM, this is not subject to
 *        renaming as part of minification.
 * @param value New value to write.
 * @param sanitizer An optional function used to sanitize the value.
 * @returns This function returns itself so that it may be chained
 * (e.g. `property('name', ctx.name)('title', ctx.title)`)
 *
 * @codeGenApi
 */


function ɵɵproperty(propName, value, sanitizer) {
  var lView = getLView();
  var bindingIndex = nextBindingIndex();

  if (bindingUpdated(lView, bindingIndex, value)) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, value, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, bindingIndex);
  }

  return ɵɵproperty;
}
/**
 * Given `<div style="..." my-dir>` and `MyDir` with `@Input('style')` we need to write to
 * directive input.
 */


function setDirectiveInputsWhichShadowsStyling(tView, tNode, lView, value, isClassBased) {
  var inputs = tNode.inputs;
  var property = isClassBased ? 'class' : 'style'; // We support both 'class' and `className` hence the fallback.

  setInputsForProperty(tView, lView, inputs[property], property, value);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function elementStartFirstCreatePass(index, tView, lView, native, name, attrsIndex, localRefsIndex) {
  ngDevMode && assertFirstCreatePass(tView);
  ngDevMode && ngDevMode.firstCreatePass++;
  var tViewConsts = tView.consts;
  var attrs = getConstant(tViewConsts, attrsIndex);
  var tNode = getOrCreateTNode(tView, index, 2
  /* Element */
  , name, attrs);
  var hasDirectives = resolveDirectives(tView, lView, tNode, getConstant(tViewConsts, localRefsIndex));
  ngDevMode && logUnknownElementError(tView, native, tNode, hasDirectives);

  if (tNode.attrs !== null) {
    computeStaticStyling(tNode, tNode.attrs, false);
  }

  if (tNode.mergedAttrs !== null) {
    computeStaticStyling(tNode, tNode.mergedAttrs, true);
  }

  if (tView.queries !== null) {
    tView.queries.elementStart(tView, tNode);
  }

  return tNode;
}
/**
 * Create DOM element. The instruction must later be followed by `elementEnd()` call.
 *
 * @param index Index of the element in the LView array
 * @param name Name of the DOM Node
 * @param attrsIndex Index of the element's attributes in the `consts` array.
 * @param localRefsIndex Index of the element's local references in the `consts` array.
 *
 * Attributes and localRefs are passed as an array of strings where elements with an even index
 * hold an attribute name and elements with an odd index hold an attribute value, ex.:
 * ['id', 'warning5', 'class', 'alert']
 *
 * @codeGenApi
 */


function ɵɵelementStart(index, name, attrsIndex, localRefsIndex) {
  var lView = getLView();
  var tView = getTView();
  var adjustedIndex = HEADER_OFFSET + index;
  ngDevMode && assertEqual(getBindingIndex(), tView.bindingStartIndex, 'elements should be created before any bindings');
  ngDevMode && ngDevMode.rendererCreateElement++;
  ngDevMode && assertIndexInRange(lView, adjustedIndex);
  var renderer = lView[RENDERER];
  var native = lView[adjustedIndex] = elementCreate(name, renderer, getNamespace());
  var tNode = tView.firstCreatePass ? elementStartFirstCreatePass(index, tView, lView, native, name, attrsIndex, localRefsIndex) : tView.data[adjustedIndex];
  setCurrentTNode(tNode, true);
  var mergedAttrs = tNode.mergedAttrs;

  if (mergedAttrs !== null) {
    setUpAttributes(renderer, native, mergedAttrs);
  }

  var classes = tNode.classes;

  if (classes !== null) {
    writeDirectClass(renderer, native, classes);
  }

  var styles = tNode.styles;

  if (styles !== null) {
    writeDirectStyle(renderer, native, styles);
  }

  appendChild(tView, lView, native, tNode); // any immediate children of a component or template container must be pre-emptively
  // monkey-patched with the component view data so that the element can be inspected
  // later on using any element discovery utility methods (see `element_discovery.ts`)

  if (getElementDepthCount() === 0) {
    attachPatchData(native, lView);
  }

  increaseElementDepthCount();

  if (isDirectiveHost(tNode)) {
    createDirectivesInstances(tView, lView, tNode);
    executeContentQueries(tView, tNode, lView);
  }

  if (localRefsIndex !== null) {
    saveResolvedLocalsInData(lView, tNode);
  }
}
/**
 * Mark the end of the element.
 *
 * @codeGenApi
 */


function ɵɵelementEnd() {
  var currentTNode = getCurrentTNode();
  ngDevMode && assertDefined(currentTNode, 'No parent node to close.');

  if (isCurrentTNodeParent()) {
    setCurrentTNodeAsNotParent();
  } else {
    ngDevMode && assertHasParent(getCurrentTNode());
    currentTNode = currentTNode.parent;
    setCurrentTNode(currentTNode, false);
  }

  var tNode = currentTNode;
  ngDevMode && assertNodeType(tNode, 2
  /* Element */
  );
  decreaseElementDepthCount();
  var tView = getTView();

  if (tView.firstCreatePass) {
    registerPostOrderHooks(tView, currentTNode);

    if (isContentQueryHost(currentTNode)) {
      tView.queries.elementEnd(currentTNode);
    }
  }

  if (tNode.classesWithoutHost != null && hasClassInput(tNode)) {
    setDirectiveInputsWhichShadowsStyling(tView, tNode, getLView(), tNode.classesWithoutHost, true);
  }

  if (tNode.stylesWithoutHost != null && hasStyleInput(tNode)) {
    setDirectiveInputsWhichShadowsStyling(tView, tNode, getLView(), tNode.stylesWithoutHost, false);
  }
}
/**
 * Creates an empty element using {@link elementStart} and {@link elementEnd}
 *
 * @param index Index of the element in the data array
 * @param name Name of the DOM Node
 * @param attrsIndex Index of the element's attributes in the `consts` array.
 * @param localRefsIndex Index of the element's local references in the `consts` array.
 *
 * @codeGenApi
 */


function ɵɵelement(index, name, attrsIndex, localRefsIndex) {
  ɵɵelementStart(index, name, attrsIndex, localRefsIndex);
  ɵɵelementEnd();
}

function logUnknownElementError(tView, element, tNode, hasDirectives) {
  var schemas = tView.schemas; // If `schemas` is set to `null`, that's an indication that this Component was compiled in AOT
  // mode where this check happens at compile time. In JIT mode, `schemas` is always present and
  // defined as an array (as an empty array in case `schemas` field is not defined) and we should
  // execute the check below.

  if (schemas === null) return;
  var tagName = tNode.tagName; // If the element matches any directive, it's considered as valid.

  if (!hasDirectives && tagName !== null) {
    // The element is unknown if it's an instance of HTMLUnknownElement or it isn't registered
    // as a custom element. Note that unknown elements with a dash in their name won't be instances
    // of HTMLUnknownElement in browsers that support web components.
    var isUnknown = // Note that we can't check for `typeof HTMLUnknownElement === 'function'`,
    // because while most browsers return 'function', IE returns 'object'.
    typeof HTMLUnknownElement !== 'undefined' && HTMLUnknownElement && element instanceof HTMLUnknownElement || typeof customElements !== 'undefined' && tagName.indexOf('-') > -1 && !customElements.get(tagName);

    if (isUnknown && !matchingSchemas(tView, tagName)) {
      var message = "'".concat(tagName, "' is not a known element:\n");
      message += "1. If '".concat(tagName, "' is an Angular component, then verify that it is part of this module.\n");

      if (tagName && tagName.indexOf('-') > -1) {
        message += "2. If '".concat(tagName, "' is a Web Component then add 'CUSTOM_ELEMENTS_SCHEMA' to the '@NgModule.schemas' of this component to suppress this message.");
      } else {
        message += "2. To allow any element add 'NO_ERRORS_SCHEMA' to the '@NgModule.schemas' of this component.";
      }

      console.error(message);
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function elementContainerStartFirstCreatePass(index, tView, lView, attrsIndex, localRefsIndex) {
  ngDevMode && ngDevMode.firstCreatePass++;
  var tViewConsts = tView.consts;
  var attrs = getConstant(tViewConsts, attrsIndex);
  var tNode = getOrCreateTNode(tView, index, 3
  /* ElementContainer */
  , 'ng-container', attrs); // While ng-container doesn't necessarily support styling, we use the style context to identify
  // and execute directives on the ng-container.

  if (attrs !== null) {
    computeStaticStyling(tNode, attrs, true);
  }

  var localRefs = getConstant(tViewConsts, localRefsIndex);
  resolveDirectives(tView, lView, tNode, localRefs);

  if (tView.queries !== null) {
    tView.queries.elementStart(tView, tNode);
  }

  return tNode;
}
/**
 * Creates a logical container for other nodes (<ng-container>) backed by a comment node in the DOM.
 * The instruction must later be followed by `elementContainerEnd()` call.
 *
 * @param index Index of the element in the LView array
 * @param attrsIndex Index of the container attributes in the `consts` array.
 * @param localRefsIndex Index of the container's local references in the `consts` array.
 *
 * Even if this instruction accepts a set of attributes no actual attribute values are propagated to
 * the DOM (as a comment node can't have attributes). Attributes are here only for directive
 * matching purposes and setting initial inputs of directives.
 *
 * @codeGenApi
 */


function ɵɵelementContainerStart(index, attrsIndex, localRefsIndex) {
  var lView = getLView();
  var tView = getTView();
  var adjustedIndex = index + HEADER_OFFSET;
  ngDevMode && assertIndexInRange(lView, adjustedIndex);
  ngDevMode && assertEqual(getBindingIndex(), tView.bindingStartIndex, 'element containers should be created before any bindings');
  var tNode = tView.firstCreatePass ? elementContainerStartFirstCreatePass(index, tView, lView, attrsIndex, localRefsIndex) : tView.data[adjustedIndex];
  setCurrentTNode(tNode, true);
  ngDevMode && ngDevMode.rendererCreateComment++;
  var native = lView[adjustedIndex] = lView[RENDERER].createComment(ngDevMode ? 'ng-container' : '');
  appendChild(tView, lView, native, tNode);
  attachPatchData(native, lView);

  if (isDirectiveHost(tNode)) {
    createDirectivesInstances(tView, lView, tNode);
    executeContentQueries(tView, tNode, lView);
  }

  if (localRefsIndex != null) {
    saveResolvedLocalsInData(lView, tNode);
  }
}
/**
 * Mark the end of the <ng-container>.
 *
 * @codeGenApi
 */


function ɵɵelementContainerEnd() {
  var currentTNode = getCurrentTNode();
  var tView = getTView();

  if (isCurrentTNodeParent()) {
    setCurrentTNodeAsNotParent();
  } else {
    ngDevMode && assertHasParent(currentTNode);
    currentTNode = currentTNode.parent;
    setCurrentTNode(currentTNode, false);
  }

  ngDevMode && assertNodeType(currentTNode, 3
  /* ElementContainer */
  );

  if (tView.firstCreatePass) {
    registerPostOrderHooks(tView, currentTNode);

    if (isContentQueryHost(currentTNode)) {
      tView.queries.elementEnd(currentTNode);
    }
  }
}
/**
 * Creates an empty logical container using {@link elementContainerStart}
 * and {@link elementContainerEnd}
 *
 * @param index Index of the element in the LView array
 * @param attrsIndex Index of the container attributes in the `consts` array.
 * @param localRefsIndex Index of the container's local references in the `consts` array.
 *
 * @codeGenApi
 */


function ɵɵelementContainer(index, attrsIndex, localRefsIndex) {
  ɵɵelementContainerStart(index, attrsIndex, localRefsIndex);
  ɵɵelementContainerEnd();
}
/**
 * Returns the current OpaqueViewState instance.
 *
 * Used in conjunction with the restoreView() instruction to save a snapshot
 * of the current view and restore it when listeners are invoked. This allows
 * walking the declaration view tree in listeners to get vars from parent views.
 *
 * @codeGenApi
 */


function ɵɵgetCurrentView() {
  return getLView();
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Determine if the argument is shaped like a Promise
 */


function isPromise(obj) {
  // allow any Promise/A+ compliant thenable.
  // It's up to the caller to ensure that obj.then conforms to the spec
  return !!obj && typeof obj.then === 'function';
}
/**
 * Determine if the argument is an Observable
 */


function isObservable(obj) {
  // TODO: use isObservable once we update pass rxjs 6.1
  // https://github.com/ReactiveX/rxjs/blob/master/CHANGELOG.md#610-2018-05-03
  return !!obj && typeof obj.subscribe === 'function';
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Adds an event listener to the current node.
 *
 * If an output exists on one of the node's directives, it also subscribes to the output
 * and saves the subscription for later cleanup.
 *
 * @param eventName Name of the event
 * @param listenerFn The function to be called when event emits
 * @param useCapture Whether or not to use capture in event listener
 * @param eventTargetResolver Function that returns global target information in case this listener
 * should be attached to a global object like window, document or body
 *
 * @codeGenApi
 */


function ɵɵlistener(eventName, listenerFn) {
  var useCapture = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  var eventTargetResolver = arguments.length > 3 ? arguments[3] : undefined;
  var lView = getLView();
  var tView = getTView();
  var tNode = getCurrentTNode();
  listenerInternal(tView, lView, lView[RENDERER], tNode, eventName, listenerFn, useCapture, eventTargetResolver);
  return ɵɵlistener;
}
/**
 * Registers a synthetic host listener (e.g. `(@foo.start)`) on a component or directive.
 *
 * This instruction is for compatibility purposes and is designed to ensure that a
 * synthetic host listener (e.g. `@HostListener('@foo.start')`) properly gets rendered
 * in the component's renderer. Normally all host listeners are evaluated with the
 * parent component's renderer, but, in the case of animation @triggers, they need
 * to be evaluated with the sub component's renderer (because that's where the
 * animation triggers are defined).
 *
 * Do not use this instruction as a replacement for `listener`. This instruction
 * only exists to ensure compatibility with the ViewEngine's host binding behavior.
 *
 * @param eventName Name of the event
 * @param listenerFn The function to be called when event emits
 * @param useCapture Whether or not to use capture in event listener
 * @param eventTargetResolver Function that returns global target information in case this listener
 * should be attached to a global object like window, document or body
 *
 * @codeGenApi
 */


function ɵɵsyntheticHostListener(eventName, listenerFn) {
  var useCapture = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  var eventTargetResolver = arguments.length > 3 ? arguments[3] : undefined;
  var tNode = getCurrentTNode();
  var lView = getLView();
  var tView = getTView();
  var currentDef = getCurrentDirectiveDef(tView.data);
  var renderer = loadComponentRenderer(currentDef, tNode, lView);
  listenerInternal(tView, lView, renderer, tNode, eventName, listenerFn, useCapture, eventTargetResolver);
  return ɵɵsyntheticHostListener;
}
/**
 * A utility function that checks if a given element has already an event handler registered for an
 * event with a specified name. The TView.cleanup data structure is used to find out which events
 * are registered for a given element.
 */


function findExistingListener(tView, lView, eventName, tNodeIdx) {
  var tCleanup = tView.cleanup;

  if (tCleanup != null) {
    for (var i = 0; i < tCleanup.length - 1; i += 2) {
      var cleanupEventName = tCleanup[i];

      if (cleanupEventName === eventName && tCleanup[i + 1] === tNodeIdx) {
        // We have found a matching event name on the same node but it might not have been
        // registered yet, so we must explicitly verify entries in the LView cleanup data
        // structures.
        var lCleanup = lView[CLEANUP];
        var listenerIdxInLCleanup = tCleanup[i + 2];
        return lCleanup.length > listenerIdxInLCleanup ? lCleanup[listenerIdxInLCleanup] : null;
      } // TView.cleanup can have a mix of 4-elements entries (for event handler cleanups) or
      // 2-element entries (for directive and queries destroy hooks). As such we can encounter
      // blocks of 4 or 2 items in the tView.cleanup and this is why we iterate over 2 elements
      // first and jump another 2 elements if we detect listeners cleanup (4 elements). Also check
      // documentation of TView.cleanup for more details of this data structure layout.


      if (typeof cleanupEventName === 'string') {
        i += 2;
      }
    }
  }

  return null;
}

function listenerInternal(tView, lView, renderer, tNode, eventName, listenerFn) {
  var useCapture = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;
  var eventTargetResolver = arguments.length > 7 ? arguments[7] : undefined;
  var isTNodeDirectiveHost = isDirectiveHost(tNode);
  var firstCreatePass = tView.firstCreatePass;
  var tCleanup = firstCreatePass && (tView.cleanup || (tView.cleanup = [])); // When the ɵɵlistener instruction was generated and is executed we know that there is either a
  // native listener or a directive output on this element. As such we we know that we will have to
  // register a listener and store its cleanup function on LView.

  var lCleanup = getLCleanup(lView);
  ngDevMode && assertNodeOfPossibleTypes(tNode, [2
  /* Element */
  , 0
  /* Container */
  , 3
  /* ElementContainer */
  ]);
  var processOutputs = true; // add native event listener - applicable to elements only

  if (tNode.type === 2
  /* Element */
  ) {
      var native = getNativeByTNode(tNode, lView);
      var resolved = eventTargetResolver ? eventTargetResolver(native) : EMPTY_OBJ;
      var target = resolved.target || native;
      var lCleanupIndex = lCleanup.length;
      var idxOrTargetGetter = eventTargetResolver ? function (_lView) {
        return eventTargetResolver(unwrapRNode(_lView[tNode.index])).target;
      } : tNode.index; // In order to match current behavior, native DOM event listeners must be added for all
      // events (including outputs).

      if (isProceduralRenderer(renderer)) {
        // There might be cases where multiple directives on the same element try to register an event
        // handler function for the same event. In this situation we want to avoid registration of
        // several native listeners as each registration would be intercepted by NgZone and
        // trigger change detection. This would mean that a single user action would result in several
        // change detections being invoked. To avoid this situation we want to have only one call to
        // native handler registration (for the same element and same type of event).
        //
        // In order to have just one native event handler in presence of multiple handler functions,
        // we just register a first handler function as a native event listener and then chain
        // (coalesce) other handler functions on top of the first native handler function.
        var existingListener = null; // Please note that the coalescing described here doesn't happen for events specifying an
        // alternative target (ex. (document:click)) - this is to keep backward compatibility with the
        // view engine.
        // Also, we don't have to search for existing listeners is there are no directives
        // matching on a given node as we can't register multiple event handlers for the same event in
        // a template (this would mean having duplicate attributes).

        if (!eventTargetResolver && isTNodeDirectiveHost) {
          existingListener = findExistingListener(tView, lView, eventName, tNode.index);
        }

        if (existingListener !== null) {
          // Attach a new listener to coalesced listeners list, maintaining the order in which
          // listeners are registered. For performance reasons, we keep a reference to the last
          // listener in that list (in `__ngLastListenerFn__` field), so we can avoid going through
          // the entire set each time we need to add a new listener.
          var lastListenerFn = existingListener.__ngLastListenerFn__ || existingListener;
          lastListenerFn.__ngNextListenerFn__ = listenerFn;
          existingListener.__ngLastListenerFn__ = listenerFn;
          processOutputs = false;
        } else {
          // The first argument of `listen` function in Procedural Renderer is:
          // - either a target name (as a string) in case of global target (window, document, body)
          // - or element reference (in all other cases)
          listenerFn = wrapListener(tNode, lView, listenerFn, false
          /** preventDefault */
          );
          var cleanupFn = renderer.listen(resolved.name || target, eventName, listenerFn);
          ngDevMode && ngDevMode.rendererAddEventListener++;
          lCleanup.push(listenerFn, cleanupFn);
          tCleanup && tCleanup.push(eventName, idxOrTargetGetter, lCleanupIndex, lCleanupIndex + 1);
        }
      } else {
        listenerFn = wrapListener(tNode, lView, listenerFn, true
        /** preventDefault */
        );
        target.addEventListener(eventName, listenerFn, useCapture);
        ngDevMode && ngDevMode.rendererAddEventListener++;
        lCleanup.push(listenerFn);
        tCleanup && tCleanup.push(eventName, idxOrTargetGetter, lCleanupIndex, useCapture);
      }
    } // subscribe to directive outputs


  var outputs = tNode.outputs;
  var props;

  if (processOutputs && outputs !== null && (props = outputs[eventName])) {
    var propsLength = props.length;

    if (propsLength) {
      for (var i = 0; i < propsLength; i += 2) {
        var index = props[i];
        ngDevMode && assertIndexInRange(lView, index);
        var minifiedName = props[i + 1];
        var directiveInstance = lView[index];
        var output = directiveInstance[minifiedName];

        if (ngDevMode && !isObservable(output)) {
          throw new Error("@Output ".concat(minifiedName, " not initialized in '").concat(directiveInstance.constructor.name, "'."));
        }

        var subscription = output.subscribe(listenerFn);
        var idx = lCleanup.length;
        lCleanup.push(listenerFn, subscription);
        tCleanup && tCleanup.push(eventName, tNode.index, idx, -(idx + 1));
      }
    }
  }
}

function executeListenerWithErrorHandling(lView, listenerFn, e) {
  try {
    // Only explicitly returning false from a listener should preventDefault
    return listenerFn(e) !== false;
  } catch (error) {
    handleError(lView, error);
    return false;
  }
}
/**
 * Wraps an event listener with a function that marks ancestors dirty and prevents default behavior,
 * if applicable.
 *
 * @param tNode The TNode associated with this listener
 * @param lView The LView that contains this listener
 * @param listenerFn The listener function to call
 * @param wrapWithPreventDefault Whether or not to prevent default behavior
 * (the procedural renderer does this already, so in those cases, we should skip)
 */


function wrapListener(tNode, lView, listenerFn, wrapWithPreventDefault) {
  // Note: we are performing most of the work in the listener function itself
  // to optimize listener registration.
  return function wrapListenerIn_markDirtyAndPreventDefault(e) {
    // Ivy uses `Function` as a special token that allows us to unwrap the function
    // so that it can be invoked programmatically by `DebugNode.triggerEventHandler`.
    if (e === Function) {
      return listenerFn;
    } // In order to be backwards compatible with View Engine, events on component host nodes
    // must also mark the component view itself dirty (i.e. the view that it owns).


    var startView = tNode.flags & 2
    /* isComponentHost */
    ? getComponentLViewByIndex(tNode.index, lView) : lView; // See interfaces/view.ts for more on LViewFlags.ManualOnPush

    if ((lView[FLAGS] & 32
    /* ManualOnPush */
    ) === 0) {
      markViewDirty(startView);
    }

    var result = executeListenerWithErrorHandling(lView, listenerFn, e); // A just-invoked listener function might have coalesced listeners so we need to check for
    // their presence and invoke as needed.

    var nextListenerFn = wrapListenerIn_markDirtyAndPreventDefault.__ngNextListenerFn__;

    while (nextListenerFn) {
      // We should prevent default if any of the listeners explicitly return false
      result = executeListenerWithErrorHandling(lView, nextListenerFn, e) && result;
      nextListenerFn = nextListenerFn.__ngNextListenerFn__;
    }

    if (wrapWithPreventDefault && result === false) {
      e.preventDefault(); // Necessary for legacy browsers that don't support preventDefault (e.g. IE)

      e.returnValue = false;
    }

    return result;
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Retrieves a context at the level specified and saves it as the global, contextViewData.
 * Will get the next level up if level is not specified.
 *
 * This is used to save contexts of parent views so they can be bound in embedded views, or
 * in conjunction with reference() to bind a ref from a parent view.
 *
 * @param level The relative level of the view from which to grab context compared to contextVewData
 * @returns context
 *
 * @codeGenApi
 */


function ɵɵnextContext() {
  var level = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
  return nextContextImpl(level);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Checks a given node against matching projection slots and returns the
 * determined slot index. Returns "null" if no slot matched the given node.
 *
 * This function takes into account the parsed ngProjectAs selector from the
 * node's attributes. If present, it will check whether the ngProjectAs selector
 * matches any of the projection slot selectors.
 */


function matchingProjectionSlotIndex(tNode, projectionSlots) {
  var wildcardNgContentIndex = null;
  var ngProjectAsAttrVal = getProjectAsAttrValue(tNode);

  for (var i = 0; i < projectionSlots.length; i++) {
    var slotValue = projectionSlots[i]; // The last wildcard projection slot should match all nodes which aren't matching
    // any selector. This is necessary to be backwards compatible with view engine.

    if (slotValue === '*') {
      wildcardNgContentIndex = i;
      continue;
    } // If we ran into an `ngProjectAs` attribute, we should match its parsed selector
    // to the list of selectors, otherwise we fall back to matching against the node.


    if (ngProjectAsAttrVal === null ? isNodeMatchingSelectorList(tNode, slotValue,
    /* isProjectionMode */
    true) : isSelectorInSelectorList(ngProjectAsAttrVal, slotValue)) {
      return i; // first matching selector "captures" a given node
    }
  }

  return wildcardNgContentIndex;
}
/**
 * Instruction to distribute projectable nodes among <ng-content> occurrences in a given template.
 * It takes all the selectors from the entire component's template and decides where
 * each projected node belongs (it re-distributes nodes among "buckets" where each "bucket" is
 * backed by a selector).
 *
 * This function requires CSS selectors to be provided in 2 forms: parsed (by a compiler) and text,
 * un-parsed form.
 *
 * The parsed form is needed for efficient matching of a node against a given CSS selector.
 * The un-parsed, textual form is needed for support of the ngProjectAs attribute.
 *
 * Having a CSS selector in 2 different formats is not ideal, but alternatives have even more
 * drawbacks:
 * - having only a textual form would require runtime parsing of CSS selectors;
 * - we can't have only a parsed as we can't re-construct textual form from it (as entered by a
 * template author).
 *
 * @param projectionSlots? A collection of projection slots. A projection slot can be based
 *        on a parsed CSS selectors or set to the wildcard selector ("*") in order to match
 *        all nodes which do not match any selector. If not specified, a single wildcard
 *        selector projection slot will be defined.
 *
 * @codeGenApi
 */


function ɵɵprojectionDef(projectionSlots) {
  var componentNode = getLView()[DECLARATION_COMPONENT_VIEW][T_HOST];

  if (!componentNode.projection) {
    // If no explicit projection slots are defined, fall back to a single
    // projection slot with the wildcard selector.
    var numProjectionSlots = projectionSlots ? projectionSlots.length : 1;
    var projectionHeads = componentNode.projection = newArray(numProjectionSlots, null);
    var tails = projectionHeads.slice();
    var componentChild = componentNode.child;

    while (componentChild !== null) {
      var slotIndex = projectionSlots ? matchingProjectionSlotIndex(componentChild, projectionSlots) : 0;

      if (slotIndex !== null) {
        if (tails[slotIndex]) {
          tails[slotIndex].projectionNext = componentChild;
        } else {
          projectionHeads[slotIndex] = componentChild;
        }

        tails[slotIndex] = componentChild;
      }

      componentChild = componentChild.next;
    }
  }
}

var delayProjection = false;

function setDelayProjection(value) {
  delayProjection = value;
}
/**
 * Inserts previously re-distributed projected nodes. This instruction must be preceded by a call
 * to the projectionDef instruction.
 *
 * @param nodeIndex
 * @param selectorIndex:
 *        - 0 when the selector is `*` (or unspecified as this is the default value),
 *        - 1 based index of the selector from the {@link projectionDef}
 *
 * @codeGenApi
 */


function ɵɵprojection(nodeIndex) {
  var selectorIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var attrs = arguments.length > 2 ? arguments[2] : undefined;
  var lView = getLView();
  var tView = getTView();
  var tProjectionNode = getOrCreateTNode(tView, nodeIndex, 1
  /* Projection */
  , null, attrs || null); // We can't use viewData[HOST_NODE] because projection nodes can be nested in embedded views.

  if (tProjectionNode.projection === null) tProjectionNode.projection = selectorIndex; // `<ng-content>` has no content

  setCurrentTNodeAsNotParent(); // We might need to delay the projection of nodes if they are in the middle of an i18n block

  if (!delayProjection) {
    // re-distribution of projectable nodes is stored on a component's view level
    applyProjection(tView, lView, tProjectionNode);
  }
}
/**
 *
 * Update an interpolated property on an element with a lone bound value
 *
 * Used when the value passed to a property has 1 interpolated value in it, an no additional text
 * surrounds that interpolated value:
 *
 * ```html
 * <div title="{{v0}}"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate('title', v0);
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate(propName, v0, sanitizer) {
  ɵɵpropertyInterpolate1(propName, '', v0, '', sanitizer);
  return ɵɵpropertyInterpolate;
}
/**
 *
 * Update an interpolated property on an element with single bound value surrounded by text.
 *
 * Used when the value passed to a property has 1 interpolated value in it:
 *
 * ```html
 * <div title="prefix{{v0}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate1('title', 'prefix', v0, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate1(propName, prefix, v0, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation1(lView, prefix, v0, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 1, prefix, suffix);
  }

  return ɵɵpropertyInterpolate1;
}
/**
 *
 * Update an interpolated property on an element with 2 bound values surrounded by text.
 *
 * Used when the value passed to a property has 2 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate2('title', 'prefix', v0, '-', v1, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate2(propName, prefix, v0, i0, v1, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation2(lView, prefix, v0, i0, v1, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 2, prefix, i0, suffix);
  }

  return ɵɵpropertyInterpolate2;
}
/**
 *
 * Update an interpolated property on an element with 3 bound values surrounded by text.
 *
 * Used when the value passed to a property has 3 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}-{{v2}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate3(
 * 'title', 'prefix', v0, '-', v1, '-', v2, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate3(propName, prefix, v0, i0, v1, i1, v2, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 3, prefix, i0, i1, suffix);
  }

  return ɵɵpropertyInterpolate3;
}
/**
 *
 * Update an interpolated property on an element with 4 bound values surrounded by text.
 *
 * Used when the value passed to a property has 4 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate4(
 * 'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate4(propName, prefix, v0, i0, v1, i1, v2, i2, v3, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 4, prefix, i0, i1, i2, suffix);
  }

  return ɵɵpropertyInterpolate4;
}
/**
 *
 * Update an interpolated property on an element with 5 bound values surrounded by text.
 *
 * Used when the value passed to a property has 5 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate5(
 * 'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate5(propName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 5, prefix, i0, i1, i2, i3, suffix);
  }

  return ɵɵpropertyInterpolate5;
}
/**
 *
 * Update an interpolated property on an element with 6 bound values surrounded by text.
 *
 * Used when the value passed to a property has 6 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate6(
 *    'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate6(propName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 6, prefix, i0, i1, i2, i3, i4, suffix);
  }

  return ɵɵpropertyInterpolate6;
}
/**
 *
 * Update an interpolated property on an element with 7 bound values surrounded by text.
 *
 * Used when the value passed to a property has 7 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate7(
 *    'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate7(propName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 7, prefix, i0, i1, i2, i3, i4, i5, suffix);
  }

  return ɵɵpropertyInterpolate7;
}
/**
 *
 * Update an interpolated property on an element with 8 bound values surrounded by text.
 *
 * Used when the value passed to a property has 8 interpolated values in it:
 *
 * ```html
 * <div title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolate8(
 *  'title', 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, 'suffix');
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param i6 Static value used for concatenation only.
 * @param v7 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolate8(propName, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, getBindingIndex() - 8, prefix, i0, i1, i2, i3, i4, i5, i6, suffix);
  }

  return ɵɵpropertyInterpolate8;
}
/**
 * Update an interpolated property on an element with 9 or more bound values surrounded by text.
 *
 * Used when the number of interpolated values exceeds 8.
 *
 * ```html
 * <div
 *  title="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}-{{v8}}-{{v9}}suffix"></div>
 * ```
 *
 * Its compiled representation is::
 *
 * ```ts
 * ɵɵpropertyInterpolateV(
 *  'title', ['prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, '-', v9,
 *  'suffix']);
 * ```
 *
 * If the property name also exists as an input property on one of the element's directives,
 * the component property will be set instead of the element property. This check must
 * be conducted at runtime so child components that add new `@Inputs` don't have to be re-compiled.
 *
 * @param propName The name of the property to update.
 * @param values The collection of values and the strings inbetween those values, beginning with a
 * string prefix and ending with a string suffix.
 * (e.g. `['prefix', value0, '-', value1, '-', value2, ..., value99, 'suffix']`)
 * @param sanitizer An optional sanitizer function
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵpropertyInterpolateV(propName, values, sanitizer) {
  var lView = getLView();
  var interpolatedValue = interpolationV(lView, values);

  if (interpolatedValue !== NO_CHANGE) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, interpolatedValue, lView[RENDERER], sanitizer, false);

    if (ngDevMode) {
      var interpolationInBetween = [values[0]]; // prefix

      for (var i = 2; i < values.length; i += 2) {
        interpolationInBetween.push(values[i]);
      }

      storePropertyBindingMetadata.apply(void 0, [tView.data, tNode, propName, getBindingIndex() - interpolationInBetween.length + 1].concat(interpolationInBetween));
    }
  }

  return ɵɵpropertyInterpolateV;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This file contains reuseable "empty" symbols that can be used as default return values
 * in different parts of the rendering code. Because the same symbols are returned, this
 * allows for identity checks against these values to be consistently used by the framework
 * code.
 */


var EMPTY_OBJ$1 = {};
var EMPTY_ARRAY$3 = []; // freezing the values prevents any code from accidentally inserting new values in

if ((typeof ngDevMode === 'undefined' || ngDevMode) && initNgDevMode()) {
  // These property accesses can be ignored because ngDevMode will be set to false
  // when optimizing code and the whole if statement will be dropped.
  // tslint:disable-next-line:no-toplevel-property-access
  Object.freeze(EMPTY_OBJ$1); // tslint:disable-next-line:no-toplevel-property-access

  Object.freeze(EMPTY_ARRAY$3);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * NOTE: The word `styling` is used interchangeably as style or class styling.
 *
 * This file contains code to link styling instructions together so that they can be replayed in
 * priority order. The file exists because Ivy styling instruction execution order does not match
 * that of the priority order. The purpose of this code is to create a linked list so that the
 * instructions can be traversed in priority order when computing the styles.
 *
 * Assume we are dealing with the following code:
 * ```
 * @Component({
 *   template: `
 *     <my-cmp [style]=" {color: '#001'} "
 *             [style.color]=" #002 "
 *             dir-style-color-1
 *             dir-style-color-2> `
 * })
 * class ExampleComponent {
 *   static ngComp = ... {
 *     ...
 *     // Compiler ensures that `ɵɵstyleProp` is after `ɵɵstyleMap`
 *     ɵɵstyleMap({color: '#001'});
 *     ɵɵstyleProp('color', '#002');
 *     ...
 *   }
 * }
 *
 * @Directive({
 *   selector: `[dir-style-color-1]',
 * })
 * class Style1Directive {
 *   @HostBinding('style') style = {color: '#005'};
 *   @HostBinding('style.color') color = '#006';
 *
 *   static ngDir = ... {
 *     ...
 *     // Compiler ensures that `ɵɵstyleProp` is after `ɵɵstyleMap`
 *     ɵɵstyleMap({color: '#005'});
 *     ɵɵstyleProp('color', '#006');
 *     ...
 *   }
 * }
 *
 * @Directive({
 *   selector: `[dir-style-color-2]',
 * })
 * class Style2Directive {
 *   @HostBinding('style') style = {color: '#007'};
 *   @HostBinding('style.color') color = '#008';
 *
 *   static ngDir = ... {
 *     ...
 *     // Compiler ensures that `ɵɵstyleProp` is after `ɵɵstyleMap`
 *     ɵɵstyleMap({color: '#007'});
 *     ɵɵstyleProp('color', '#008');
 *     ...
 *   }
 * }
 *
 * @Directive({
 *   selector: `my-cmp',
 * })
 * class MyComponent {
 *   @HostBinding('style') style = {color: '#003'};
 *   @HostBinding('style.color') color = '#004';
 *
 *   static ngComp = ... {
 *     ...
 *     // Compiler ensures that `ɵɵstyleProp` is after `ɵɵstyleMap`
 *     ɵɵstyleMap({color: '#003'});
 *     ɵɵstyleProp('color', '#004');
 *     ...
 *   }
 * }
 * ```
 *
 * The Order of instruction execution is:
 *
 * NOTE: the comment binding location is for illustrative purposes only.
 *
 * ```
 * // Template: (ExampleComponent)
 *     ɵɵstyleMap({color: '#001'});   // Binding index: 10
 *     ɵɵstyleProp('color', '#002');  // Binding index: 12
 * // MyComponent
 *     ɵɵstyleMap({color: '#003'});   // Binding index: 20
 *     ɵɵstyleProp('color', '#004');  // Binding index: 22
 * // Style1Directive
 *     ɵɵstyleMap({color: '#005'});   // Binding index: 24
 *     ɵɵstyleProp('color', '#006');  // Binding index: 26
 * // Style2Directive
 *     ɵɵstyleMap({color: '#007'});   // Binding index: 28
 *     ɵɵstyleProp('color', '#008');  // Binding index: 30
 * ```
 *
 * The correct priority order of concatenation is:
 *
 * ```
 * // MyComponent
 *     ɵɵstyleMap({color: '#003'});   // Binding index: 20
 *     ɵɵstyleProp('color', '#004');  // Binding index: 22
 * // Style1Directive
 *     ɵɵstyleMap({color: '#005'});   // Binding index: 24
 *     ɵɵstyleProp('color', '#006');  // Binding index: 26
 * // Style2Directive
 *     ɵɵstyleMap({color: '#007'});   // Binding index: 28
 *     ɵɵstyleProp('color', '#008');  // Binding index: 30
 * // Template: (ExampleComponent)
 *     ɵɵstyleMap({color: '#001'});   // Binding index: 10
 *     ɵɵstyleProp('color', '#002');  // Binding index: 12
 * ```
 *
 * What color should be rendered?
 *
 * Once the items are correctly sorted in the list, the answer is simply the last item in the
 * concatenation list which is `#002`.
 *
 * To do so we keep a linked list of all of the bindings which pertain to this element.
 * Notice that the bindings are inserted in the order of execution, but the `TView.data` allows
 * us to traverse them in the order of priority.
 *
 * |Idx|`TView.data`|`LView`          | Notes
 * |---|------------|-----------------|--------------
 * |...|            |                 |
 * |10 |`null`      |`{color: '#001'}`| `ɵɵstyleMap('color', {color: '#001'})`
 * |11 |`30 | 12`   | ...             |
 * |12 |`color`     |`'#002'`         | `ɵɵstyleProp('color', '#002')`
 * |13 |`10 | 0`    | ...             |
 * |...|            |                 |
 * |20 |`null`      |`{color: '#003'}`| `ɵɵstyleMap('color', {color: '#003'})`
 * |21 |`0 | 22`    | ...             |
 * |22 |`color`     |`'#004'`         | `ɵɵstyleProp('color', '#004')`
 * |23 |`20 | 24`   | ...             |
 * |24 |`null`      |`{color: '#005'}`| `ɵɵstyleMap('color', {color: '#005'})`
 * |25 |`22 | 26`   | ...             |
 * |26 |`color`     |`'#006'`         | `ɵɵstyleProp('color', '#006')`
 * |27 |`24 | 28`   | ...             |
 * |28 |`null`      |`{color: '#007'}`| `ɵɵstyleMap('color', {color: '#007'})`
 * |29 |`26 | 30`   | ...             |
 * |30 |`color`     |`'#008'`         | `ɵɵstyleProp('color', '#008')`
 * |31 |`28 | 10`   | ...             |
 *
 * The above data structure allows us to re-concatenate the styling no matter which data binding
 * changes.
 *
 * NOTE: in addition to keeping track of next/previous index the `TView.data` also stores prev/next
 * duplicate bit. The duplicate bit if true says there either is a binding with the same name or
 * there is a map (which may contain the name). This information is useful in knowing if other
 * styles with higher priority need to be searched for overwrites.
 *
 * NOTE: See `should support example in 'tnode_linked_list.ts' documentation` in
 * `tnode_linked_list_spec.ts` for working example.
 */


var __unused_const_as_closure_does_not_like_standalone_comment_blocks__;
/**
 * Insert new `tStyleValue` at `TData` and link existing style bindings such that we maintain linked
 * list of styles and compute the duplicate flag.
 *
 * Note: this function is executed during `firstUpdatePass` only to populate the `TView.data`.
 *
 * The function works by keeping track of `tStylingRange` which contains two pointers pointing to
 * the head/tail of the template portion of the styles.
 *  - if `isHost === false` (we are template) then insertion is at tail of `TStylingRange`
 *  - if `isHost === true` (we are host binding) then insertion is at head of `TStylingRange`
 *
 * @param tData The `TData` to insert into.
 * @param tNode `TNode` associated with the styling element.
 * @param tStylingKey See `TStylingKey`.
 * @param index location of where `tStyleValue` should be stored (and linked into list.)
 * @param isHostBinding `true` if the insertion is for a `hostBinding`. (insertion is in front of
 *               template.)
 * @param isClassBinding True if the associated `tStylingKey` as a `class` styling.
 *                       `tNode.classBindings` should be used (or `tNode.styleBindings` otherwise.)
 */


function insertTStylingBinding(tData, tNode, tStylingKeyWithStatic, index, isHostBinding, isClassBinding) {
  ngDevMode && assertFirstUpdatePass(getTView());
  var tBindings = isClassBinding ? tNode.classBindings : tNode.styleBindings;
  var tmplHead = getTStylingRangePrev(tBindings);
  var tmplTail = getTStylingRangeNext(tBindings);
  tData[index] = tStylingKeyWithStatic;
  var isKeyDuplicateOfStatic = false;
  var tStylingKey;

  if (Array.isArray(tStylingKeyWithStatic)) {
    // We are case when the `TStylingKey` contains static fields as well.
    var staticKeyValueArray = tStylingKeyWithStatic;
    tStylingKey = staticKeyValueArray[1]; // unwrap.
    // We need to check if our key is present in the static so that we can mark it as duplicate.

    if (tStylingKey === null || keyValueArrayIndexOf(staticKeyValueArray, tStylingKey) > 0) {
      // tStylingKey is present in the statics, need to mark it as duplicate.
      isKeyDuplicateOfStatic = true;
    }
  } else {
    tStylingKey = tStylingKeyWithStatic;
  }

  if (isHostBinding) {
    // We are inserting host bindings
    // If we don't have template bindings then `tail` is 0.
    var hasTemplateBindings = tmplTail !== 0; // This is important to know because that means that the `head` can't point to the first
    // template bindings (there are none.) Instead the head points to the tail of the template.

    if (hasTemplateBindings) {
      // template head's "prev" will point to last host binding or to 0 if no host bindings yet
      var previousNode = getTStylingRangePrev(tData[tmplHead + 1]);
      tData[index + 1] = toTStylingRange(previousNode, tmplHead); // if a host binding has already been registered, we need to update the next of that host
      // binding to point to this one

      if (previousNode !== 0) {
        // We need to update the template-tail value to point to us.
        tData[previousNode + 1] = setTStylingRangeNext(tData[previousNode + 1], index);
      } // The "previous" of the template binding head should point to this host binding


      tData[tmplHead + 1] = setTStylingRangePrev(tData[tmplHead + 1], index);
    } else {
      tData[index + 1] = toTStylingRange(tmplHead, 0); // if a host binding has already been registered, we need to update the next of that host
      // binding to point to this one

      if (tmplHead !== 0) {
        // We need to update the template-tail value to point to us.
        tData[tmplHead + 1] = setTStylingRangeNext(tData[tmplHead + 1], index);
      } // if we don't have template, the head points to template-tail, and needs to be advanced.


      tmplHead = index;
    }
  } else {
    // We are inserting in template section.
    // We need to set this binding's "previous" to the current template tail
    tData[index + 1] = toTStylingRange(tmplTail, 0);
    ngDevMode && assertEqual(tmplHead !== 0 && tmplTail === 0, false, 'Adding template bindings after hostBindings is not allowed.');

    if (tmplHead === 0) {
      tmplHead = index;
    } else {
      // We need to update the previous value "next" to point to this binding
      tData[tmplTail + 1] = setTStylingRangeNext(tData[tmplTail + 1], index);
    }

    tmplTail = index;
  } // Now we need to update / compute the duplicates.
  // Starting with our location search towards head (least priority)


  if (isKeyDuplicateOfStatic) {
    tData[index + 1] = setTStylingRangePrevDuplicate(tData[index + 1]);
  }

  markDuplicates(tData, tStylingKey, index, true, isClassBinding);
  markDuplicates(tData, tStylingKey, index, false, isClassBinding);
  markDuplicateOfResidualStyling(tNode, tStylingKey, tData, index, isClassBinding);
  tBindings = toTStylingRange(tmplHead, tmplTail);

  if (isClassBinding) {
    tNode.classBindings = tBindings;
  } else {
    tNode.styleBindings = tBindings;
  }
}
/**
 * Look into the residual styling to see if the current `tStylingKey` is duplicate of residual.
 *
 * @param tNode `TNode` where the residual is stored.
 * @param tStylingKey `TStylingKey` to store.
 * @param tData `TData` associated with the current `LView`.
 * @param index location of where `tStyleValue` should be stored (and linked into list.)
 * @param isClassBinding True if the associated `tStylingKey` as a `class` styling.
 *                       `tNode.classBindings` should be used (or `tNode.styleBindings` otherwise.)
 */


function markDuplicateOfResidualStyling(tNode, tStylingKey, tData, index, isClassBinding) {
  var residual = isClassBinding ? tNode.residualClasses : tNode.residualStyles;

  if (residual != null
  /* or undefined */
  && typeof tStylingKey == 'string' && keyValueArrayIndexOf(residual, tStylingKey) >= 0) {
    // We have duplicate in the residual so mark ourselves as duplicate.
    tData[index + 1] = setTStylingRangeNextDuplicate(tData[index + 1]);
  }
}
/**
 * Marks `TStyleValue`s as duplicates if another style binding in the list has the same
 * `TStyleValue`.
 *
 * NOTE: this function is intended to be called twice once with `isPrevDir` set to `true` and once
 * with it set to `false` to search both the previous as well as next items in the list.
 *
 * No duplicate case
 * ```
 *   [style.color]
 *   [style.width.px] <<- index
 *   [style.height.px]
 * ```
 *
 * In the above case adding `[style.width.px]` to the existing `[style.color]` produces no
 * duplicates because `width` is not found in any other part of the linked list.
 *
 * Duplicate case
 * ```
 *   [style.color]
 *   [style.width.em]
 *   [style.width.px] <<- index
 * ```
 * In the above case adding `[style.width.px]` will produce a duplicate with `[style.width.em]`
 * because `width` is found in the chain.
 *
 * Map case 1
 * ```
 *   [style.width.px]
 *   [style.color]
 *   [style]  <<- index
 * ```
 * In the above case adding `[style]` will produce a duplicate with any other bindings because
 * `[style]` is a Map and as such is fully dynamic and could produce `color` or `width`.
 *
 * Map case 2
 * ```
 *   [style]
 *   [style.width.px]
 *   [style.color]  <<- index
 * ```
 * In the above case adding `[style.color]` will produce a duplicate because there is already a
 * `[style]` binding which is a Map and as such is fully dynamic and could produce `color` or
 * `width`.
 *
 * NOTE: Once `[style]` (Map) is added into the system all things are mapped as duplicates.
 * NOTE: We use `style` as example, but same logic is applied to `class`es as well.
 *
 * @param tData `TData` where the linked list is stored.
 * @param tStylingKey `TStylingKeyPrimitive` which contains the value to compare to other keys in
 *        the linked list.
 * @param index Starting location in the linked list to search from
 * @param isPrevDir Direction.
 *        - `true` for previous (lower priority);
 *        - `false` for next (higher priority).
 */


function markDuplicates(tData, tStylingKey, index, isPrevDir, isClassBinding) {
  var tStylingAtIndex = tData[index + 1];
  var isMap = tStylingKey === null;
  var cursor = isPrevDir ? getTStylingRangePrev(tStylingAtIndex) : getTStylingRangeNext(tStylingAtIndex);
  var foundDuplicate = false; // We keep iterating as long as we have a cursor
  // AND either:
  // - we found what we are looking for, OR
  // - we are a map in which case we have to continue searching even after we find what we were
  //   looking for since we are a wild card and everything needs to be flipped to duplicate.

  while (cursor !== 0 && (foundDuplicate === false || isMap)) {
    ngDevMode && assertIndexInRange(tData, cursor);
    var tStylingValueAtCursor = tData[cursor];
    var tStyleRangeAtCursor = tData[cursor + 1];

    if (isStylingMatch(tStylingValueAtCursor, tStylingKey)) {
      foundDuplicate = true;
      tData[cursor + 1] = isPrevDir ? setTStylingRangeNextDuplicate(tStyleRangeAtCursor) : setTStylingRangePrevDuplicate(tStyleRangeAtCursor);
    }

    cursor = isPrevDir ? getTStylingRangePrev(tStyleRangeAtCursor) : getTStylingRangeNext(tStyleRangeAtCursor);
  }

  if (foundDuplicate) {
    // if we found a duplicate, than mark ourselves.
    tData[index + 1] = isPrevDir ? setTStylingRangePrevDuplicate(tStylingAtIndex) : setTStylingRangeNextDuplicate(tStylingAtIndex);
  }
}
/**
 * Determines if two `TStylingKey`s are a match.
 *
 * When computing whether a binding contains a duplicate, we need to compare if the instruction
 * `TStylingKey` has a match.
 *
 * Here are examples of `TStylingKey`s which match given `tStylingKeyCursor` is:
 * - `color`
 *    - `color`    // Match another color
 *    - `null`     // That means that `tStylingKey` is a `classMap`/`styleMap` instruction
 *    - `['', 'color', 'other', true]` // wrapped `color` so match
 *    - `['', null, 'other', true]`       // wrapped `null` so match
 *    - `['', 'width', 'color', 'value']` // wrapped static value contains a match on `'color'`
 * - `null`       // `tStylingKeyCursor` always match as it is `classMap`/`styleMap` instruction
 *
 * @param tStylingKeyCursor
 * @param tStylingKey
 */


function isStylingMatch(tStylingKeyCursor, tStylingKey) {
  ngDevMode && assertNotEqual(Array.isArray(tStylingKey), true, 'Expected that \'tStylingKey\' has been unwrapped');

  if (tStylingKeyCursor === null || // If the cursor is `null` it means that we have map at that
  // location so we must assume that we have a match.
  tStylingKey == null || // If `tStylingKey` is `null` then it is a map therefor assume that it
  // contains a match.
  (Array.isArray(tStylingKeyCursor) ? tStylingKeyCursor[1] : tStylingKeyCursor) === tStylingKey // If the keys match explicitly than we are a match.
  ) {
      return true;
    } else if (Array.isArray(tStylingKeyCursor) && typeof tStylingKey === 'string') {
    // if we did not find a match, but `tStylingKeyCursor` is `KeyValueArray` that means cursor has
    // statics and we need to check those as well.
    return keyValueArrayIndexOf(tStylingKeyCursor, tStylingKey) >= 0; // see if we are matching the key
  }

  return false;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Global state of the parser. (This makes parser non-reentrant, but that is not an issue)


var parserState = {
  textEnd: 0,
  key: 0,
  keyEnd: 0,
  value: 0,
  valueEnd: 0
};
/**
 * Retrieves the last parsed `key` of style.
 * @param text the text to substring the key from.
 */

function getLastParsedKey(text) {
  return text.substring(parserState.key, parserState.keyEnd);
}
/**
 * Retrieves the last parsed `value` of style.
 * @param text the text to substring the key from.
 */


function getLastParsedValue(text) {
  return text.substring(parserState.value, parserState.valueEnd);
}
/**
 * Initializes `className` string for parsing and parses the first token.
 *
 * This function is intended to be used in this format:
 * ```
 * for (let i = parseClassName(text); i >= 0; i = parseClassNameNext(text, i)) {
 *   const key = getLastParsedKey();
 *   ...
 * }
 * ```
 * @param text `className` to parse
 * @returns index where the next invocation of `parseClassNameNext` should resume.
 */


function parseClassName(text) {
  resetParserState(text);
  return parseClassNameNext(text, consumeWhitespace(text, 0, parserState.textEnd));
}
/**
 * Parses next `className` token.
 *
 * This function is intended to be used in this format:
 * ```
 * for (let i = parseClassName(text); i >= 0; i = parseClassNameNext(text, i)) {
 *   const key = getLastParsedKey();
 *   ...
 * }
 * ```
 *
 * @param text `className` to parse
 * @param index where the parsing should resume.
 * @returns index where the next invocation of `parseClassNameNext` should resume.
 */


function parseClassNameNext(text, index) {
  var end = parserState.textEnd;

  if (end === index) {
    return -1;
  }

  index = parserState.keyEnd = consumeClassToken(text, parserState.key = index, end);
  return consumeWhitespace(text, index, end);
}
/**
 * Initializes `cssText` string for parsing and parses the first key/values.
 *
 * This function is intended to be used in this format:
 * ```
 * for (let i = parseStyle(text); i >= 0; i = parseStyleNext(text, i))) {
 *   const key = getLastParsedKey();
 *   const value = getLastParsedValue();
 *   ...
 * }
 * ```
 * @param text `cssText` to parse
 * @returns index where the next invocation of `parseStyleNext` should resume.
 */


function parseStyle(text) {
  resetParserState(text);
  return parseStyleNext(text, consumeWhitespace(text, 0, parserState.textEnd));
}
/**
 * Parses the next `cssText` key/values.
 *
 * This function is intended to be used in this format:
 * ```
 * for (let i = parseStyle(text); i >= 0; i = parseStyleNext(text, i))) {
 *   const key = getLastParsedKey();
 *   const value = getLastParsedValue();
 *   ...
 * }
 *
 * @param text `cssText` to parse
 * @param index where the parsing should resume.
 * @returns index where the next invocation of `parseStyleNext` should resume.
 */


function parseStyleNext(text, startIndex) {
  var end = parserState.textEnd;
  var index = parserState.key = consumeWhitespace(text, startIndex, end);

  if (end === index) {
    // we reached an end so just quit
    return -1;
  }

  index = parserState.keyEnd = consumeStyleKey(text, index, end);
  index = consumeSeparator(text, index, end, 58
  /* COLON */
  );
  index = parserState.value = consumeWhitespace(text, index, end);
  index = parserState.valueEnd = consumeStyleValue(text, index, end);
  return consumeSeparator(text, index, end, 59
  /* SEMI_COLON */
  );
}
/**
 * Reset the global state of the styling parser.
 * @param text The styling text to parse.
 */


function resetParserState(text) {
  parserState.key = 0;
  parserState.keyEnd = 0;
  parserState.value = 0;
  parserState.valueEnd = 0;
  parserState.textEnd = text.length;
}
/**
 * Returns index of next non-whitespace character.
 *
 * @param text Text to scan
 * @param startIndex Starting index of character where the scan should start.
 * @param endIndex Ending index of character where the scan should end.
 * @returns Index of next non-whitespace character (May be the same as `start` if no whitespace at
 *          that location.)
 */


function consumeWhitespace(text, startIndex, endIndex) {
  while (startIndex < endIndex && text.charCodeAt(startIndex) <= 32
  /* SPACE */
  ) {
    startIndex++;
  }

  return startIndex;
}
/**
 * Returns index of last char in class token.
 *
 * @param text Text to scan
 * @param startIndex Starting index of character where the scan should start.
 * @param endIndex Ending index of character where the scan should end.
 * @returns Index after last char in class token.
 */


function consumeClassToken(text, startIndex, endIndex) {
  while (startIndex < endIndex && text.charCodeAt(startIndex) > 32
  /* SPACE */
  ) {
    startIndex++;
  }

  return startIndex;
}
/**
 * Consumes all of the characters belonging to style key and token.
 *
 * @param text Text to scan
 * @param startIndex Starting index of character where the scan should start.
 * @param endIndex Ending index of character where the scan should end.
 * @returns Index after last style key character.
 */


function consumeStyleKey(text, startIndex, endIndex) {
  var ch;

  while (startIndex < endIndex && ((ch = text.charCodeAt(startIndex)) === 45
  /* DASH */
  || ch === 95
  /* UNDERSCORE */
  || (ch & -33
  /* UPPER_CASE */
  ) >= 65
  /* A */
  && (ch & -33
  /* UPPER_CASE */
  ) <= 90
  /* Z */
  || ch >= 48
  /* ZERO */
  && ch <= 57
  /* NINE */
  )) {
    startIndex++;
  }

  return startIndex;
}
/**
 * Consumes all whitespace and the separator `:` after the style key.
 *
 * @param text Text to scan
 * @param startIndex Starting index of character where the scan should start.
 * @param endIndex Ending index of character where the scan should end.
 * @returns Index after separator and surrounding whitespace.
 */


function consumeSeparator(text, startIndex, endIndex, separator) {
  startIndex = consumeWhitespace(text, startIndex, endIndex);

  if (startIndex < endIndex) {
    if (ngDevMode && text.charCodeAt(startIndex) !== separator) {
      malformedStyleError(text, String.fromCharCode(separator), startIndex);
    }

    startIndex++;
  }

  return startIndex;
}
/**
 * Consumes style value honoring `url()` and `""` text.
 *
 * @param text Text to scan
 * @param startIndex Starting index of character where the scan should start.
 * @param endIndex Ending index of character where the scan should end.
 * @returns Index after last style value character.
 */


function consumeStyleValue(text, startIndex, endIndex) {
  var ch1 = -1; // 1st previous character

  var ch2 = -1; // 2nd previous character

  var ch3 = -1; // 3rd previous character

  var i = startIndex;
  var lastChIndex = i;

  while (i < endIndex) {
    var ch = text.charCodeAt(i++);

    if (ch === 59
    /* SEMI_COLON */
    ) {
        return lastChIndex;
      } else if (ch === 34
    /* DOUBLE_QUOTE */
    || ch === 39
    /* SINGLE_QUOTE */
    ) {
        lastChIndex = i = consumeQuotedText(text, ch, i, endIndex);
      } else if (startIndex === i - 4 && // We have seen only 4 characters so far "URL(" (Ignore "foo_URL()")
    ch3 === 85
    /* U */
    && ch2 === 82
    /* R */
    && ch1 === 76
    /* L */
    && ch === 40
    /* OPEN_PAREN */
    ) {
        lastChIndex = i = consumeQuotedText(text, 41
        /* CLOSE_PAREN */
        , i, endIndex);
      } else if (ch > 32
    /* SPACE */
    ) {
        // if we have a non-whitespace character then capture its location
        lastChIndex = i;
      }

    ch3 = ch2;
    ch2 = ch1;
    ch1 = ch & -33
    /* UPPER_CASE */
    ;
  }

  return lastChIndex;
}
/**
 * Consumes all of the quoted characters.
 *
 * @param text Text to scan
 * @param quoteCharCode CharCode of either `"` or `'` quote or `)` for `url(...)`.
 * @param startIndex Starting index of character where the scan should start.
 * @param endIndex Ending index of character where the scan should end.
 * @returns Index after quoted characters.
 */


function consumeQuotedText(text, quoteCharCode, startIndex, endIndex) {
  var ch1 = -1; // 1st previous character

  var index = startIndex;

  while (index < endIndex) {
    var ch = text.charCodeAt(index++);

    if (ch == quoteCharCode && ch1 !== 92
    /* BACK_SLASH */
    ) {
        return index;
      }

    if (ch == 92
    /* BACK_SLASH */
    && ch1 === 92
    /* BACK_SLASH */
    ) {
        // two back slashes cancel each other out. For example `"\\"` should properly end the
        // quotation. (It should not assume that the last `"` is escaped.)
        ch1 = 0;
      } else {
      ch1 = ch;
    }
  }

  throw ngDevMode ? malformedStyleError(text, String.fromCharCode(quoteCharCode), endIndex) : new Error();
}

function malformedStyleError(text, expecting, index) {
  ngDevMode && assertEqual(typeof text === 'string', true, 'String expected here');
  throw throwError("Malformed style at location ".concat(index, " in string '") + text.substring(0, index) + '[>>' + text.substring(index, index + 1) + '<<]' + text.substr(index + 1) + "'. Expecting '".concat(expecting, "'."));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Update a style binding on an element with the provided value.
 *
 * If the style value is falsy then it will be removed from the element
 * (or assigned a different value depending if there are any styles placed
 * on the element with `styleMap` or any static styles that are
 * present from when the element was created with `styling`).
 *
 * Note that the styling element is updated as part of `stylingApply`.
 *
 * @param prop A valid CSS property.
 * @param value New value to write (`null` or an empty string to remove).
 * @param suffix Optional suffix. Used with scalar values to add unit such as `px`.
 *
 * Note that this will apply the provided style value to the host element if this function is called
 * within a host binding function.
 *
 * @codeGenApi
 */


function ɵɵstyleProp(prop, value, suffix) {
  checkStylingProperty(prop, value, suffix, false);
  return ɵɵstyleProp;
}
/**
 * Update a class binding on an element with the provided value.
 *
 * This instruction is meant to handle the `[class.foo]="exp"` case and,
 * therefore, the class binding itself must already be allocated using
 * `styling` within the creation block.
 *
 * @param prop A valid CSS class (only one).
 * @param value A true/false value which will turn the class on or off.
 *
 * Note that this will apply the provided class value to the host element if this function
 * is called within a host binding function.
 *
 * @codeGenApi
 */


function ɵɵclassProp(className, value) {
  checkStylingProperty(className, value, null, true);
  return ɵɵclassProp;
}
/**
 * Update style bindings using an object literal on an element.
 *
 * This instruction is meant to apply styling via the `[style]="exp"` template bindings.
 * When styles are applied to the element they will then be updated with respect to
 * any styles/classes set via `styleProp`. If any styles are set to falsy
 * then they will be removed from the element.
 *
 * Note that the styling instruction will not be applied until `stylingApply` is called.
 *
 * @param styles A key/value style map of the styles that will be applied to the given element.
 *        Any missing styles (that have already been applied to the element beforehand) will be
 *        removed (unset) from the element's styling.
 *
 * Note that this will apply the provided styleMap value to the host element if this function
 * is called within a host binding.
 *
 * @codeGenApi
 */


function ɵɵstyleMap(styles) {
  checkStylingMap(styleKeyValueArraySet, styleStringParser, styles, false);
}
/**
 * Parse text as style and add values to KeyValueArray.
 *
 * This code is pulled out to a separate function so that it can be tree shaken away if it is not
 * needed. It is only referenced from `ɵɵstyleMap`.
 *
 * @param keyValueArray KeyValueArray to add parsed values to.
 * @param text text to parse.
 */


function styleStringParser(keyValueArray, text) {
  for (var i = parseStyle(text); i >= 0; i = parseStyleNext(text, i)) {
    styleKeyValueArraySet(keyValueArray, getLastParsedKey(text), getLastParsedValue(text));
  }
}
/**
 * Update class bindings using an object literal or class-string on an element.
 *
 * This instruction is meant to apply styling via the `[class]="exp"` template bindings.
 * When classes are applied to the element they will then be updated with
 * respect to any styles/classes set via `classProp`. If any
 * classes are set to falsy then they will be removed from the element.
 *
 * Note that the styling instruction will not be applied until `stylingApply` is called.
 * Note that this will the provided classMap value to the host element if this function is called
 * within a host binding.
 *
 * @param classes A key/value map or string of CSS classes that will be added to the
 *        given element. Any missing classes (that have already been applied to the element
 *        beforehand) will be removed (unset) from the element's list of CSS classes.
 *
 * @codeGenApi
 */


function ɵɵclassMap(classes) {
  checkStylingMap(keyValueArraySet, classStringParser, classes, true);
}
/**
 * Parse text as class and add values to KeyValueArray.
 *
 * This code is pulled out to a separate function so that it can be tree shaken away if it is not
 * needed. It is only referenced from `ɵɵclassMap`.
 *
 * @param keyValueArray KeyValueArray to add parsed values to.
 * @param text text to parse.
 */


function classStringParser(keyValueArray, text) {
  for (var i = parseClassName(text); i >= 0; i = parseClassNameNext(text, i)) {
    keyValueArraySet(keyValueArray, getLastParsedKey(text), true);
  }
}
/**
 * Common code between `ɵɵclassProp` and `ɵɵstyleProp`.
 *
 * @param prop property name.
 * @param value binding value.
 * @param suffix suffix for the property (e.g. `em` or `px`)
 * @param isClassBased `true` if `class` change (`false` if `style`)
 */


function checkStylingProperty(prop, value, suffix, isClassBased) {
  var lView = getLView();
  var tView = getTView(); // Styling instructions use 2 slots per binding.
  // 1. one for the value / TStylingKey
  // 2. one for the intermittent-value / TStylingRange

  var bindingIndex = incrementBindingIndex(2);

  if (tView.firstUpdatePass) {
    stylingFirstUpdatePass(tView, prop, bindingIndex, isClassBased);
  }

  if (value !== NO_CHANGE && bindingUpdated(lView, bindingIndex, value)) {
    var tNode = tView.data[getSelectedIndex() + HEADER_OFFSET];
    updateStyling(tView, tNode, lView, lView[RENDERER], prop, lView[bindingIndex + 1] = normalizeSuffix(value, suffix), isClassBased, bindingIndex);
  }
}
/**
 * Common code between `ɵɵclassMap` and `ɵɵstyleMap`.
 *
 * @param keyValueArraySet (See `keyValueArraySet` in "util/array_utils") Gets passed in as a
 *        function so that `style` can be processed. This is done for tree shaking purposes.
 * @param stringParser Parser used to parse `value` if `string`. (Passed in as `style` and `class`
 *        have different parsers.)
 * @param value bound value from application
 * @param isClassBased `true` if `class` change (`false` if `style`)
 */


function checkStylingMap(keyValueArraySet, stringParser, value, isClassBased) {
  var tView = getTView();
  var bindingIndex = incrementBindingIndex(2);

  if (tView.firstUpdatePass) {
    stylingFirstUpdatePass(tView, null, bindingIndex, isClassBased);
  }

  var lView = getLView();

  if (value !== NO_CHANGE && bindingUpdated(lView, bindingIndex, value)) {
    // `getSelectedIndex()` should be here (rather than in instruction) so that it is guarded by the
    // if so as not to read unnecessarily.
    var tNode = tView.data[getSelectedIndex() + HEADER_OFFSET];

    if (hasStylingInputShadow(tNode, isClassBased) && !isInHostBindings(tView, bindingIndex)) {
      if (ngDevMode) {
        // verify that if we are shadowing then `TData` is appropriately marked so that we skip
        // processing this binding in styling resolution.
        var tStylingKey = tView.data[bindingIndex];
        assertEqual(Array.isArray(tStylingKey) ? tStylingKey[1] : tStylingKey, false, 'Styling linked list shadow input should be marked as \'false\'');
      } // VE does not concatenate the static portion like we are doing here.
      // Instead VE just ignores the static completely if dynamic binding is present.
      // Because of locality we have already set the static portion because we don't know if there
      // is a dynamic portion until later. If we would ignore the static portion it would look like
      // the binding has removed it. This would confuse `[ngStyle]`/`[ngClass]` to do the wrong
      // thing as it would think that the static portion was removed. For this reason we
      // concatenate it so that `[ngStyle]`/`[ngClass]`  can continue to work on changed.


      var staticPrefix = isClassBased ? tNode.classesWithoutHost : tNode.stylesWithoutHost;
      ngDevMode && isClassBased === false && staticPrefix !== null && assertEqual(staticPrefix.endsWith(';'), true, 'Expecting static portion to end with \';\'');

      if (staticPrefix !== null) {
        // We want to make sure that falsy values of `value` become empty strings.
        value = concatStringsWithSpace(staticPrefix, value ? value : '');
      } // Given `<div [style] my-dir>` such that `my-dir` has `@Input('style')`.
      // This takes over the `[style]` binding. (Same for `[class]`)


      setDirectiveInputsWhichShadowsStyling(tView, tNode, lView, value, isClassBased);
    } else {
      updateStylingMap(tView, tNode, lView, lView[RENDERER], lView[bindingIndex + 1], lView[bindingIndex + 1] = toStylingKeyValueArray(keyValueArraySet, stringParser, value), isClassBased, bindingIndex);
    }
  }
}
/**
 * Determines when the binding is in `hostBindings` section
 *
 * @param tView Current `TView`
 * @param bindingIndex index of binding which we would like if it is in `hostBindings`
 */


function isInHostBindings(tView, bindingIndex) {
  // All host bindings are placed after the expando section.
  return bindingIndex >= tView.expandoStartIndex;
}
/**
 * Collects the necessary information to insert the binding into a linked list of style bindings
 * using `insertTStylingBinding`.
 *
 * @param tView `TView` where the binding linked list will be stored.
 * @param tStylingKey Property/key of the binding.
 * @param bindingIndex Index of binding associated with the `prop`
 * @param isClassBased `true` if `class` change (`false` if `style`)
 */


function stylingFirstUpdatePass(tView, tStylingKey, bindingIndex, isClassBased) {
  ngDevMode && assertFirstUpdatePass(tView);
  var tData = tView.data;

  if (tData[bindingIndex + 1] === null) {
    // The above check is necessary because we don't clear first update pass until first successful
    // (no exception) template execution. This prevents the styling instruction from double adding
    // itself to the list.
    // `getSelectedIndex()` should be here (rather than in instruction) so that it is guarded by the
    // if so as not to read unnecessarily.
    var tNode = tData[getSelectedIndex() + HEADER_OFFSET];
    var isHostBindings = isInHostBindings(tView, bindingIndex);

    if (hasStylingInputShadow(tNode, isClassBased) && tStylingKey === null && !isHostBindings) {
      // `tStylingKey === null` implies that we are either `[style]` or `[class]` binding.
      // If there is a directive which uses `@Input('style')` or `@Input('class')` than
      // we need to neutralize this binding since that directive is shadowing it.
      // We turn this into a noop by setting the key to `false`
      tStylingKey = false;
    }

    tStylingKey = wrapInStaticStylingKey(tData, tNode, tStylingKey, isClassBased);
    insertTStylingBinding(tData, tNode, tStylingKey, bindingIndex, isHostBindings, isClassBased);
  }
}
/**
 * Adds static styling information to the binding if applicable.
 *
 * The linked list of styles not only stores the list and keys, but also stores static styling
 * information on some of the keys. This function determines if the key should contain the styling
 * information and computes it.
 *
 * See `TStylingStatic` for more details.
 *
 * @param tData `TData` where the linked list is stored.
 * @param tNode `TNode` for which the styling is being computed.
 * @param stylingKey `TStylingKeyPrimitive` which may need to be wrapped into `TStylingKey`
 * @param isClassBased `true` if `class` (`false` if `style`)
 */


function wrapInStaticStylingKey(tData, tNode, stylingKey, isClassBased) {
  var hostDirectiveDef = getCurrentDirectiveDef(tData);
  var residual = isClassBased ? tNode.residualClasses : tNode.residualStyles;

  if (hostDirectiveDef === null) {
    // We are in template node.
    // If template node already had styling instruction then it has already collected the static
    // styling and there is no need to collect them again. We know that we are the first styling
    // instruction because the `TNode.*Bindings` points to 0 (nothing has been inserted yet).
    var isFirstStylingInstructionInTemplate = (isClassBased ? tNode.classBindings : tNode.styleBindings) === 0;

    if (isFirstStylingInstructionInTemplate) {
      // It would be nice to be able to get the statics from `mergeAttrs`, however, at this point
      // they are already merged and it would not be possible to figure which property belongs where
      // in the priority.
      stylingKey = collectStylingFromDirectives(null, tData, tNode, stylingKey, isClassBased);
      stylingKey = collectStylingFromTAttrs(stylingKey, tNode.attrs, isClassBased); // We know that if we have styling binding in template we can't have residual.

      residual = null;
    }
  } else {
    // We are in host binding node and there was no binding instruction in template node.
    // This means that we need to compute the residual.
    var directiveStylingLast = tNode.directiveStylingLast;
    var isFirstStylingInstructionInHostBinding = directiveStylingLast === -1 || tData[directiveStylingLast] !== hostDirectiveDef;

    if (isFirstStylingInstructionInHostBinding) {
      stylingKey = collectStylingFromDirectives(hostDirectiveDef, tData, tNode, stylingKey, isClassBased);

      if (residual === null) {
        // - If `null` than either:
        //    - Template styling instruction already ran and it has consumed the static
        //      styling into its `TStylingKey` and so there is no need to update residual. Instead
        //      we need to update the `TStylingKey` associated with the first template node
        //      instruction. OR
        //    - Some other styling instruction ran and determined that there are no residuals
        var templateStylingKey = getTemplateHeadTStylingKey(tData, tNode, isClassBased);

        if (templateStylingKey !== undefined && Array.isArray(templateStylingKey)) {
          // Only recompute if `templateStylingKey` had static values. (If no static value found
          // then there is nothing to do since this operation can only produce less static keys, not
          // more.)
          templateStylingKey = collectStylingFromDirectives(null, tData, tNode, templateStylingKey[1]
          /* unwrap previous statics */
          , isClassBased);
          templateStylingKey = collectStylingFromTAttrs(templateStylingKey, tNode.attrs, isClassBased);
          setTemplateHeadTStylingKey(tData, tNode, isClassBased, templateStylingKey);
        }
      } else {
        // We only need to recompute residual if it is not `null`.
        // - If existing residual (implies there was no template styling). This means that some of
        //   the statics may have moved from the residual to the `stylingKey` and so we have to
        //   recompute.
        // - If `undefined` this is the first time we are running.
        residual = collectResidual(tData, tNode, isClassBased);
      }
    }
  }

  if (residual !== undefined) {
    isClassBased ? tNode.residualClasses = residual : tNode.residualStyles = residual;
  }

  return stylingKey;
}
/**
 * Retrieve the `TStylingKey` for the template styling instruction.
 *
 * This is needed since `hostBinding` styling instructions are inserted after the template
 * instruction. While the template instruction needs to update the residual in `TNode` the
 * `hostBinding` instructions need to update the `TStylingKey` of the template instruction because
 * the template instruction is downstream from the `hostBindings` instructions.
 *
 * @param tData `TData` where the linked list is stored.
 * @param tNode `TNode` for which the styling is being computed.
 * @param isClassBased `true` if `class` (`false` if `style`)
 * @return `TStylingKey` if found or `undefined` if not found.
 */


function getTemplateHeadTStylingKey(tData, tNode, isClassBased) {
  var bindings = isClassBased ? tNode.classBindings : tNode.styleBindings;

  if (getTStylingRangeNext(bindings) === 0) {
    // There does not seem to be a styling instruction in the `template`.
    return undefined;
  }

  return tData[getTStylingRangePrev(bindings)];
}
/**
 * Update the `TStylingKey` of the first template instruction in `TNode`.
 *
 * Logically `hostBindings` styling instructions are of lower priority than that of the template.
 * However, they execute after the template styling instructions. This means that they get inserted
 * in front of the template styling instructions.
 *
 * If we have a template styling instruction and a new `hostBindings` styling instruction is
 * executed it means that it may need to steal static fields from the template instruction. This
 * method allows us to update the first template instruction `TStylingKey` with a new value.
 *
 * Assume:
 * ```
 * <div my-dir style="color: red" [style.color]="tmplExp"></div>
 *
 * @Directive({
 *   host: {
 *     'style': 'width: 100px',
 *     '[style.color]': 'dirExp',
 *   }
 * })
 * class MyDir {}
 * ```
 *
 * when `[style.color]="tmplExp"` executes it creates this data structure.
 * ```
 *  ['', 'color', 'color', 'red', 'width', '100px'],
 * ```
 *
 * The reason for this is that the template instruction does not know if there are styling
 * instructions and must assume that there are none and must collect all of the static styling.
 * (both
 * `color' and 'width`)
 *
 * When `'[style.color]': 'dirExp',` executes we need to insert a new data into the linked list.
 * ```
 *  ['', 'color', 'width', '100px'],  // newly inserted
 *  ['', 'color', 'color', 'red', 'width', '100px'], // this is wrong
 * ```
 *
 * Notice that the template statics is now wrong as it incorrectly contains `width` so we need to
 * update it like so:
 * ```
 *  ['', 'color', 'width', '100px'],
 *  ['', 'color', 'color', 'red'],    // UPDATE
 * ```
 *
 * @param tData `TData` where the linked list is stored.
 * @param tNode `TNode` for which the styling is being computed.
 * @param isClassBased `true` if `class` (`false` if `style`)
 * @param tStylingKey New `TStylingKey` which is replacing the old one.
 */


function setTemplateHeadTStylingKey(tData, tNode, isClassBased, tStylingKey) {
  var bindings = isClassBased ? tNode.classBindings : tNode.styleBindings;
  ngDevMode && assertNotEqual(getTStylingRangeNext(bindings), 0, 'Expecting to have at least one template styling binding.');
  tData[getTStylingRangePrev(bindings)] = tStylingKey;
}
/**
 * Collect all static values after the current `TNode.directiveStylingLast` index.
 *
 * Collect the remaining styling information which has not yet been collected by an existing
 * styling instruction.
 *
 * @param tData `TData` where the `DirectiveDefs` are stored.
 * @param tNode `TNode` which contains the directive range.
 * @param isClassBased `true` if `class` (`false` if `style`)
 */


function collectResidual(tData, tNode, isClassBased) {
  var residual = undefined;
  var directiveEnd = tNode.directiveEnd;
  ngDevMode && assertNotEqual(tNode.directiveStylingLast, -1, 'By the time this function gets called at least one hostBindings-node styling instruction must have executed.'); // We add `1 + tNode.directiveStart` because we need to skip the current directive (as we are
  // collecting things after the last `hostBindings` directive which had a styling instruction.)

  for (var i = 1 + tNode.directiveStylingLast; i < directiveEnd; i++) {
    var attrs = tData[i].hostAttrs;
    residual = collectStylingFromTAttrs(residual, attrs, isClassBased);
  }

  return collectStylingFromTAttrs(residual, tNode.attrs, isClassBased);
}
/**
 * Collect the static styling information with lower priority than `hostDirectiveDef`.
 *
 * (This is opposite of residual styling.)
 *
 * @param hostDirectiveDef `DirectiveDef` for which we want to collect lower priority static
 *        styling. (Or `null` if template styling)
 * @param tData `TData` where the linked list is stored.
 * @param tNode `TNode` for which the styling is being computed.
 * @param stylingKey Existing `TStylingKey` to update or wrap.
 * @param isClassBased `true` if `class` (`false` if `style`)
 */


function collectStylingFromDirectives(hostDirectiveDef, tData, tNode, stylingKey, isClassBased) {
  // We need to loop because there can be directives which have `hostAttrs` but don't have
  // `hostBindings` so this loop catches up to the current directive..
  var currentDirective = null;
  var directiveEnd = tNode.directiveEnd;
  var directiveStylingLast = tNode.directiveStylingLast;

  if (directiveStylingLast === -1) {
    directiveStylingLast = tNode.directiveStart;
  } else {
    directiveStylingLast++;
  }

  while (directiveStylingLast < directiveEnd) {
    currentDirective = tData[directiveStylingLast];
    ngDevMode && assertDefined(currentDirective, 'expected to be defined');
    stylingKey = collectStylingFromTAttrs(stylingKey, currentDirective.hostAttrs, isClassBased);
    if (currentDirective === hostDirectiveDef) break;
    directiveStylingLast++;
  }

  if (hostDirectiveDef !== null) {
    // we only advance the styling cursor if we are collecting data from host bindings.
    // Template executes before host bindings and so if we would update the index,
    // host bindings would not get their statics.
    tNode.directiveStylingLast = directiveStylingLast;
  }

  return stylingKey;
}
/**
 * Convert `TAttrs` into `TStylingStatic`.
 *
 * @param stylingKey existing `TStylingKey` to update or wrap.
 * @param attrs `TAttributes` to process.
 * @param isClassBased `true` if `class` (`false` if `style`)
 */


function collectStylingFromTAttrs(stylingKey, attrs, isClassBased) {
  var desiredMarker = isClassBased ? 1
  /* Classes */
  : 2
  /* Styles */
  ;
  var currentMarker = -1
  /* ImplicitAttributes */
  ;

  if (attrs !== null) {
    for (var i = 0; i < attrs.length; i++) {
      var item = attrs[i];

      if (typeof item === 'number') {
        currentMarker = item;
      } else {
        if (currentMarker === desiredMarker) {
          if (!Array.isArray(stylingKey)) {
            stylingKey = stylingKey === undefined ? [] : ['', stylingKey];
          }

          keyValueArraySet(stylingKey, item, isClassBased ? true : attrs[++i]);
        }
      }
    }
  }

  return stylingKey === undefined ? null : stylingKey;
}
/**
 * Convert user input to `KeyValueArray`.
 *
 * This function takes user input which could be `string`, Object literal, or iterable and converts
 * it into a consistent representation. The output of this is `KeyValueArray` (which is an array
 * where
 * even indexes contain keys and odd indexes contain values for those keys).
 *
 * The advantage of converting to `KeyValueArray` is that we can perform diff in an input
 * independent
 * way.
 * (ie we can compare `foo bar` to `['bar', 'baz'] and determine a set of changes which need to be
 * applied)
 *
 * The fact that `KeyValueArray` is sorted is very important because it allows us to compute the
 * difference in linear fashion without the need to allocate any additional data.
 *
 * For example if we kept this as a `Map` we would have to iterate over previous `Map` to determine
 * which values need to be deleted, over the new `Map` to determine additions, and we would have to
 * keep additional `Map` to keep track of duplicates or items which have not yet been visited.
 *
 * @param keyValueArraySet (See `keyValueArraySet` in "util/array_utils") Gets passed in as a
 *        function so that `style` can be processed. This is done
 *        for tree shaking purposes.
 * @param stringParser The parser is passed in so that it will be tree shakable. See
 *        `styleStringParser` and `classStringParser`
 * @param value The value to parse/convert to `KeyValueArray`
 */


function toStylingKeyValueArray(keyValueArraySet, stringParser, value) {
  if (value == null
  /*|| value === undefined */
  || value === '') return EMPTY_ARRAY$3;
  var styleKeyValueArray = [];
  var unwrappedValue = unwrapSafeValue(value);

  if (Array.isArray(unwrappedValue)) {
    for (var i = 0; i < unwrappedValue.length; i++) {
      keyValueArraySet(styleKeyValueArray, unwrappedValue[i], true);
    }
  } else if (typeof unwrappedValue === 'object') {
    for (var key in unwrappedValue) {
      if (unwrappedValue.hasOwnProperty(key)) {
        keyValueArraySet(styleKeyValueArray, key, unwrappedValue[key]);
      }
    }
  } else if (typeof unwrappedValue === 'string') {
    stringParser(styleKeyValueArray, unwrappedValue);
  } else {
    ngDevMode && throwError('Unsupported styling type ' + typeof unwrappedValue + ': ' + unwrappedValue);
  }

  return styleKeyValueArray;
}
/**
 * Set a `value` for a `key`.
 *
 * See: `keyValueArraySet` for details
 *
 * @param keyValueArray KeyValueArray to add to.
 * @param key Style key to add.
 * @param value The value to set.
 */


function styleKeyValueArraySet(keyValueArray, key, value) {
  keyValueArraySet(keyValueArray, key, unwrapSafeValue(value));
}
/**
 * Update map based styling.
 *
 * Map based styling could be anything which contains more than one binding. For example `string`,
 * or object literal. Dealing with all of these types would complicate the logic so
 * instead this function expects that the complex input is first converted into normalized
 * `KeyValueArray`. The advantage of normalization is that we get the values sorted, which makes it
 * very cheap to compute deltas between the previous and current value.
 *
 * @param tView Associated `TView.data` contains the linked list of binding priorities.
 * @param tNode `TNode` where the binding is located.
 * @param lView `LView` contains the values associated with other styling binding at this `TNode`.
 * @param renderer Renderer to use if any updates.
 * @param oldKeyValueArray Previous value represented as `KeyValueArray`
 * @param newKeyValueArray Current value represented as `KeyValueArray`
 * @param isClassBased `true` if `class` (`false` if `style`)
 * @param bindingIndex Binding index of the binding.
 */


function updateStylingMap(tView, tNode, lView, renderer, oldKeyValueArray, newKeyValueArray, isClassBased, bindingIndex) {
  if (oldKeyValueArray === NO_CHANGE) {
    // On first execution the oldKeyValueArray is NO_CHANGE => treat it as empty KeyValueArray.
    oldKeyValueArray = EMPTY_ARRAY$3;
  }

  var oldIndex = 0;
  var newIndex = 0;
  var oldKey = 0 < oldKeyValueArray.length ? oldKeyValueArray[0] : null;
  var newKey = 0 < newKeyValueArray.length ? newKeyValueArray[0] : null;

  while (oldKey !== null || newKey !== null) {
    ngDevMode && assertLessThan(oldIndex, 999, 'Are we stuck in infinite loop?');
    ngDevMode && assertLessThan(newIndex, 999, 'Are we stuck in infinite loop?');
    var oldValue = oldIndex < oldKeyValueArray.length ? oldKeyValueArray[oldIndex + 1] : undefined;
    var newValue = newIndex < newKeyValueArray.length ? newKeyValueArray[newIndex + 1] : undefined;
    var setKey = null;
    var setValue = undefined;

    if (oldKey === newKey) {
      // UPDATE: Keys are equal => new value is overwriting old value.
      oldIndex += 2;
      newIndex += 2;

      if (oldValue !== newValue) {
        setKey = newKey;
        setValue = newValue;
      }
    } else if (newKey === null || oldKey !== null && oldKey < newKey) {
      // DELETE: oldKey key is missing or we did not find the oldKey in the newValue
      // (because the keyValueArray is sorted and `newKey` is found later alphabetically).
      // `"background" < "color"` so we need to delete `"background"` because it is not found in the
      // new array.
      oldIndex += 2;
      setKey = oldKey;
    } else {
      // CREATE: newKey's is earlier alphabetically than oldKey's (or no oldKey) => we have new key.
      // `"color" > "background"` so we need to add `color` because it is in new array but not in
      // old array.
      ngDevMode && assertDefined(newKey, 'Expecting to have a valid key');
      newIndex += 2;
      setKey = newKey;
      setValue = newValue;
    }

    if (setKey !== null) {
      updateStyling(tView, tNode, lView, renderer, setKey, setValue, isClassBased, bindingIndex);
    }

    oldKey = oldIndex < oldKeyValueArray.length ? oldKeyValueArray[oldIndex] : null;
    newKey = newIndex < newKeyValueArray.length ? newKeyValueArray[newIndex] : null;
  }
}
/**
 * Update a simple (property name) styling.
 *
 * This function takes `prop` and updates the DOM to that value. The function takes the binding
 * value as well as binding priority into consideration to determine which value should be written
 * to DOM. (For example it may be determined that there is a higher priority overwrite which blocks
 * the DOM write, or if the value goes to `undefined` a lower priority overwrite may be consulted.)
 *
 * @param tView Associated `TView.data` contains the linked list of binding priorities.
 * @param tNode `TNode` where the binding is located.
 * @param lView `LView` contains the values associated with other styling binding at this `TNode`.
 * @param renderer Renderer to use if any updates.
 * @param prop Either style property name or a class name.
 * @param value Either style value for `prop` or `true`/`false` if `prop` is class.
 * @param isClassBased `true` if `class` (`false` if `style`)
 * @param bindingIndex Binding index of the binding.
 */


function updateStyling(tView, tNode, lView, renderer, prop, value, isClassBased, bindingIndex) {
  if (tNode.type !== 2
  /* Element */
  ) {
      // It is possible to have styling on non-elements (such as ng-container).
      // This is rare, but it does happen. In such a case, just ignore the binding.
      return;
    }

  var tData = tView.data;
  var tRange = tData[bindingIndex + 1];
  var higherPriorityValue = getTStylingRangeNextDuplicate(tRange) ? findStylingValue(tData, tNode, lView, prop, getTStylingRangeNext(tRange), isClassBased) : undefined;

  if (!isStylingValuePresent(higherPriorityValue)) {
    // We don't have a next duplicate, or we did not find a duplicate value.
    if (!isStylingValuePresent(value)) {
      // We should delete current value or restore to lower priority value.
      if (getTStylingRangePrevDuplicate(tRange)) {
        // We have a possible prev duplicate, let's retrieve it.
        value = findStylingValue(tData, null, lView, prop, bindingIndex, isClassBased);
      }
    }

    var rNode = getNativeByIndex(getSelectedIndex(), lView);
    applyStyling(renderer, isClassBased, rNode, prop, value);
  }
}
/**
 * Search for styling value with higher priority which is overwriting current value, or a
 * value of lower priority to which we should fall back if the value is `undefined`.
 *
 * When value is being applied at a location, related values need to be consulted.
 * - If there is a higher priority binding, we should be using that one instead.
 *   For example `<div  [style]="{color:exp1}" [style.color]="exp2">` change to `exp1`
 *   requires that we check `exp2` to see if it is set to value other than `undefined`.
 * - If there is a lower priority binding and we are changing to `undefined`
 *   For example `<div  [style]="{color:exp1}" [style.color]="exp2">` change to `exp2` to
 *   `undefined` requires that we check `exp1` (and static values) and use that as new value.
 *
 * NOTE: The styling stores two values.
 * 1. The raw value which came from the application is stored at `index + 0` location. (This value
 *    is used for dirty checking).
 * 2. The normalized value is stored at `index + 1`.
 *
 * @param tData `TData` used for traversing the priority.
 * @param tNode `TNode` to use for resolving static styling. Also controls search direction.
 *   - `TNode` search next and quit as soon as `isStylingValuePresent(value)` is true.
 *      If no value found consult `tNode.residualStyle`/`tNode.residualClass` for default value.
 *   - `null` search prev and go all the way to end. Return last value where
 *     `isStylingValuePresent(value)` is true.
 * @param lView `LView` used for retrieving the actual values.
 * @param prop Property which we are interested in.
 * @param index Starting index in the linked list of styling bindings where the search should start.
 * @param isClassBased `true` if `class` (`false` if `style`)
 */


function findStylingValue(tData, tNode, lView, prop, index, isClassBased) {
  // `TNode` to use for resolving static styling. Also controls search direction.
  //   - `TNode` search next and quit as soon as `isStylingValuePresent(value)` is true.
  //      If no value found consult `tNode.residualStyle`/`tNode.residualClass` for default value.
  //   - `null` search prev and go all the way to end. Return last value where
  //     `isStylingValuePresent(value)` is true.
  var isPrevDirection = tNode === null;
  var value = undefined;

  while (index > 0) {
    var rawKey = tData[index];
    var containsStatics = Array.isArray(rawKey); // Unwrap the key if we contain static values.

    var key = containsStatics ? rawKey[1] : rawKey;
    var isStylingMap = key === null;
    var valueAtLViewIndex = lView[index + 1];

    if (valueAtLViewIndex === NO_CHANGE) {
      // In firstUpdatePass the styling instructions create a linked list of styling.
      // On subsequent passes it is possible for a styling instruction to try to read a binding
      // which
      // has not yet executed. In that case we will find `NO_CHANGE` and we should assume that
      // we have `undefined` (or empty array in case of styling-map instruction) instead. This
      // allows the resolution to apply the value (which may later be overwritten when the
      // binding actually executes.)
      valueAtLViewIndex = isStylingMap ? EMPTY_ARRAY$3 : undefined;
    }

    var currentValue = isStylingMap ? keyValueArrayGet(valueAtLViewIndex, prop) : key === prop ? valueAtLViewIndex : undefined;

    if (containsStatics && !isStylingValuePresent(currentValue)) {
      currentValue = keyValueArrayGet(rawKey, prop);
    }

    if (isStylingValuePresent(currentValue)) {
      value = currentValue;

      if (isPrevDirection) {
        return value;
      }
    }

    var tRange = tData[index + 1];
    index = isPrevDirection ? getTStylingRangePrev(tRange) : getTStylingRangeNext(tRange);
  }

  if (tNode !== null) {
    // in case where we are going in next direction AND we did not find anything, we need to
    // consult residual styling
    var residual = isClassBased ? tNode.residualClasses : tNode.residualStyles;

    if (residual != null
    /** OR residual !=== undefined */
    ) {
        value = keyValueArrayGet(residual, prop);
      }
  }

  return value;
}
/**
 * Determines if the binding value should be used (or if the value is 'undefined' and hence priority
 * resolution should be used.)
 *
 * @param value Binding style value.
 */


function isStylingValuePresent(value) {
  // Currently only `undefined` value is considered non-binding. That is `undefined` says I don't
  // have an opinion as to what this binding should be and you should consult other bindings by
  // priority to determine the valid value.
  // This is extracted into a single function so that we have a single place to control this.
  return value !== undefined;
}
/**
 * Normalizes and/or adds a suffix to the value.
 *
 * If value is `null`/`undefined` no suffix is added
 * @param value
 * @param suffix
 */


function normalizeSuffix(value, suffix) {
  if (value == null
  /** || value === undefined */
  ) {// do nothing
    } else if (typeof suffix === 'string') {
    value = value + suffix;
  } else if (typeof value === 'object') {
    value = stringify(unwrapSafeValue(value));
  }

  return value;
}
/**
 * Tests if the `TNode` has input shadow.
 *
 * An input shadow is when a directive steals (shadows) the input by using `@Input('style')` or
 * `@Input('class')` as input.
 *
 * @param tNode `TNode` which we would like to see if it has shadow.
 * @param isClassBased `true` if `class` (`false` if `style`)
 */


function hasStylingInputShadow(tNode, isClassBased) {
  return (tNode.flags & (isClassBased ? 16
  /* hasClassInput */
  : 32
  /* hasStyleInput */
  )) !== 0;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Create static text node
 *
 * @param index Index of the node in the data array
 * @param value Static string value to write.
 *
 * @codeGenApi
 */


function ɵɵtext(index) {
  var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var lView = getLView();
  var tView = getTView();
  var adjustedIndex = index + HEADER_OFFSET;
  ngDevMode && assertEqual(getBindingIndex(), tView.bindingStartIndex, 'text nodes should be created before any bindings');
  ngDevMode && assertIndexInRange(lView, adjustedIndex);
  var tNode = tView.firstCreatePass ? getOrCreateTNode(tView, index, 2
  /* Element */
  , null, null) : tView.data[adjustedIndex];
  var textNative = lView[adjustedIndex] = createTextNode(value, lView[RENDERER]);
  appendChild(tView, lView, textNative, tNode); // Text nodes are self closing.

  setCurrentTNode(tNode, false);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 *
 * Update text content with a lone bound value
 *
 * Used when a text node has 1 interpolated value in it, an no additional text
 * surrounds that interpolated value:
 *
 * ```html
 * <div>{{v0}}</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate(v0);
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate(v0) {
  ɵɵtextInterpolate1('', v0, '');
  return ɵɵtextInterpolate;
}
/**
 *
 * Update text content with single bound value surrounded by other text.
 *
 * Used when a text node has 1 interpolated value in it:
 *
 * ```html
 * <div>prefix{{v0}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate1('prefix', v0, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate1(prefix, v0, suffix) {
  var lView = getLView();
  var interpolated = interpolation1(lView, prefix, v0, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate1;
}
/**
 *
 * Update text content with 2 bound values surrounded by other text.
 *
 * Used when a text node has 2 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate2('prefix', v0, '-', v1, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate2(prefix, v0, i0, v1, suffix) {
  var lView = getLView();
  var interpolated = interpolation2(lView, prefix, v0, i0, v1, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate2;
}
/**
 *
 * Update text content with 3 bound values surrounded by other text.
 *
 * Used when a text node has 3 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate3(
 * 'prefix', v0, '-', v1, '-', v2, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate3(prefix, v0, i0, v1, i1, v2, suffix) {
  var lView = getLView();
  var interpolated = interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate3;
}
/**
 *
 * Update text content with 4 bound values surrounded by other text.
 *
 * Used when a text node has 4 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate4(
 * 'prefix', v0, '-', v1, '-', v2, '-', v3, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see ɵɵtextInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate4(prefix, v0, i0, v1, i1, v2, i2, v3, suffix) {
  var lView = getLView();
  var interpolated = interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate4;
}
/**
 *
 * Update text content with 5 bound values surrounded by other text.
 *
 * Used when a text node has 5 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate5(
 * 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate5(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix) {
  var lView = getLView();
  var interpolated = interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate5;
}
/**
 *
 * Update text content with 6 bound values surrounded by other text.
 *
 * Used when a text node has 6 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate6(
 *    'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, 'suffix');
 * ```
 *
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change. @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate6(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix) {
  var lView = getLView();
  var interpolated = interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate6;
}
/**
 *
 * Update text content with 7 bound values surrounded by other text.
 *
 * Used when a text node has 7 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate7(
 *    'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate7(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix) {
  var lView = getLView();
  var interpolated = interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate7;
}
/**
 *
 * Update text content with 8 bound values surrounded by other text.
 *
 * Used when a text node has 8 interpolated values in it:
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolate8(
 *  'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, 'suffix');
 * ```
 * @returns itself, so that it may be chained.
 * @see textInterpolateV
 * @codeGenApi
 */


function ɵɵtextInterpolate8(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix) {
  var lView = getLView();
  var interpolated = interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolate8;
}
/**
 * Update text content with 9 or more bound values other surrounded by text.
 *
 * Used when the number of interpolated values exceeds 8.
 *
 * ```html
 * <div>prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}-{{v8}}-{{v9}}suffix</div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵtextInterpolateV(
 *  ['prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, '-', v9,
 *  'suffix']);
 * ```
 *.
 * @param values The collection of values and the strings in between those values, beginning with
 * a string prefix and ending with a string suffix.
 * (e.g. `['prefix', value0, '-', value1, '-', value2, ..., value99, 'suffix']`)
 *
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵtextInterpolateV(values) {
  var lView = getLView();
  var interpolated = interpolationV(lView, values);

  if (interpolated !== NO_CHANGE) {
    textBindingInternal(lView, getSelectedIndex(), interpolated);
  }

  return ɵɵtextInterpolateV;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 *
 * Update an interpolated class on an element with single bound value surrounded by text.
 *
 * Used when the value passed to a property has 1 interpolated value in it:
 *
 * ```html
 * <div class="prefix{{v0}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate1('prefix', v0, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate1(prefix, v0, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation1(lView, prefix, v0, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 2 bound values surrounded by text.
 *
 * Used when the value passed to a property has 2 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate2('prefix', v0, '-', v1, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate2(prefix, v0, i0, v1, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation2(lView, prefix, v0, i0, v1, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 3 bound values surrounded by text.
 *
 * Used when the value passed to a property has 3 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}-{{v2}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate3(
 * 'prefix', v0, '-', v1, '-', v2, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate3(prefix, v0, i0, v1, i1, v2, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 4 bound values surrounded by text.
 *
 * Used when the value passed to a property has 4 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate4(
 * 'prefix', v0, '-', v1, '-', v2, '-', v3, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate4(prefix, v0, i0, v1, i1, v2, i2, v3, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 5 bound values surrounded by text.
 *
 * Used when the value passed to a property has 5 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate5(
 * 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate5(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 6 bound values surrounded by text.
 *
 * Used when the value passed to a property has 6 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate6(
 *    'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate6(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 7 bound values surrounded by text.
 *
 * Used when the value passed to a property has 7 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate7(
 *    'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate7(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 *
 * Update an interpolated class on an element with 8 bound values surrounded by text.
 *
 * Used when the value passed to a property has 8 interpolated values in it:
 *
 * ```html
 * <div class="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolate8(
 *  'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param i6 Static value used for concatenation only.
 * @param v7 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵclassMapInterpolate8(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 * Update an interpolated class on an element with 9 or more bound values surrounded by text.
 *
 * Used when the number of interpolated values exceeds 8.
 *
 * ```html
 * <div
 *  class="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}-{{v8}}-{{v9}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵclassMapInterpolateV(
 *  ['prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, '-', v9,
 *  'suffix']);
 * ```
 *.
 * @param values The collection of values and the strings in-between those values, beginning with
 * a string prefix and ending with a string suffix.
 * (e.g. `['prefix', value0, '-', value1, '-', value2, ..., value99, 'suffix']`)
 * @codeGenApi
 */


function ɵɵclassMapInterpolateV(values) {
  var lView = getLView();
  var interpolatedValue = interpolationV(lView, values);
  checkStylingMap(keyValueArraySet, classStringParser, interpolatedValue, true);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 *
 * Update an interpolated style on an element with single bound value surrounded by text.
 *
 * Used when the value passed to a property has 1 interpolated value in it:
 *
 * ```html
 * <div style="key: {{v0}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate1('key: ', v0, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate1(prefix, v0, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation1(lView, prefix, v0, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 2 bound values surrounded by text.
 *
 * Used when the value passed to a property has 2 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key1: {{v1}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate2('key: ', v0, '; key1: ', v1, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate2(prefix, v0, i0, v1, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation2(lView, prefix, v0, i0, v1, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 3 bound values surrounded by text.
 *
 * Used when the value passed to a property has 3 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key2: {{v1}}; key2: {{v2}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate3(
 *     'key: ', v0, '; key1: ', v1, '; key2: ', v2, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate3(prefix, v0, i0, v1, i1, v2, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 4 bound values surrounded by text.
 *
 * Used when the value passed to a property has 4 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key1: {{v1}}; key2: {{v2}}; key3: {{v3}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate4(
 *     'key: ', v0, '; key1: ', v1, '; key2: ', v2, '; key3: ', v3, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate4(prefix, v0, i0, v1, i1, v2, i2, v3, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 5 bound values surrounded by text.
 *
 * Used when the value passed to a property has 5 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key1: {{v1}}; key2: {{v2}}; key3: {{v3}}; key4: {{v4}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate5(
 *     'key: ', v0, '; key1: ', v1, '; key2: ', v2, '; key3: ', v3, '; key4: ', v4, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate5(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 6 bound values surrounded by text.
 *
 * Used when the value passed to a property has 6 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key1: {{v1}}; key2: {{v2}}; key3: {{v3}}; key4: {{v4}};
 *             key5: {{v5}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate6(
 *    'key: ', v0, '; key1: ', v1, '; key2: ', v2, '; key3: ', v3, '; key4: ', v4, '; key5: ', v5,
 *    'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate6(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 7 bound values surrounded by text.
 *
 * Used when the value passed to a property has 7 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key1: {{v1}}; key2: {{v2}}; key3: {{v3}}; key4: {{v4}}; key5: {{v5}};
 *             key6: {{v6}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate7(
 *    'key: ', v0, '; key1: ', v1, '; key2: ', v2, '; key3: ', v3, '; key4: ', v4, '; key5: ', v5,
 *    '; key6: ', v6, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate7(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 *
 * Update an interpolated style on an element with 8 bound values surrounded by text.
 *
 * Used when the value passed to a property has 8 interpolated values in it:
 *
 * ```html
 * <div style="key: {{v0}}; key1: {{v1}}; key2: {{v2}}; key3: {{v3}}; key4: {{v4}}; key5: {{v5}};
 *             key6: {{v6}}; key7: {{v7}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolate8(
 *    'key: ', v0, '; key1: ', v1, '; key2: ', v2, '; key3: ', v3, '; key4: ', v4, '; key5: ', v5,
 *    '; key6: ', v6, '; key7: ', v7, 'suffix');
 * ```
 *
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param i6 Static value used for concatenation only.
 * @param v7 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @codeGenApi
 */


function ɵɵstyleMapInterpolate8(prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix) {
  var lView = getLView();
  var interpolatedValue = interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix);
  ɵɵstyleMap(interpolatedValue);
}
/**
 * Update an interpolated style on an element with 9 or more bound values surrounded by text.
 *
 * Used when the number of interpolated values exceeds 8.
 *
 * ```html
 * <div
 *  class="key: {{v0}}; key1: {{v1}}; key2: {{v2}}; key3: {{v3}}; key4: {{v4}}; key5: {{v5}};
 *         key6: {{v6}}; key7: {{v7}}; key8: {{v8}}; key9: {{v9}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstyleMapInterpolateV(
 *    ['key: ', v0, '; key1: ', v1, '; key2: ', v2, '; key3: ', v3, '; key4: ', v4, '; key5: ', v5,
 *     '; key6: ', v6, '; key7: ', v7, '; key8: ', v8, '; key9: ', v9, 'suffix']);
 * ```
 *.
 * @param values The collection of values and the strings in-between those values, beginning with
 * a string prefix and ending with a string suffix.
 * (e.g. `['prefix', value0, '; key2: ', value1, '; key2: ', value2, ..., value99, 'suffix']`)
 * @codeGenApi
 */


function ɵɵstyleMapInterpolateV(values) {
  var lView = getLView();
  var interpolatedValue = interpolationV(lView, values);
  ɵɵstyleMap(interpolatedValue);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 *
 * Update an interpolated style property on an element with single bound value surrounded by text.
 *
 * Used when the value passed to a property has 1 interpolated value in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate1(0, 'prefix', v0, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate1(prop, prefix, v0, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation1(lView, prefix, v0, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate1;
}
/**
 *
 * Update an interpolated style property on an element with 2 bound values surrounded by text.
 *
 * Used when the value passed to a property has 2 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate2(0, 'prefix', v0, '-', v1, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate2(prop, prefix, v0, i0, v1, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation2(lView, prefix, v0, i0, v1, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate2;
}
/**
 *
 * Update an interpolated style property on an element with 3 bound values surrounded by text.
 *
 * Used when the value passed to a property has 3 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}-{{v2}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate3(0, 'prefix', v0, '-', v1, '-', v2, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate3(prop, prefix, v0, i0, v1, i1, v2, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation3(lView, prefix, v0, i0, v1, i1, v2, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate3;
}
/**
 *
 * Update an interpolated style property on an element with 4 bound values surrounded by text.
 *
 * Used when the value passed to a property has 4 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate4(0, 'prefix', v0, '-', v1, '-', v2, '-', v3, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate4(prop, prefix, v0, i0, v1, i1, v2, i2, v3, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation4(lView, prefix, v0, i0, v1, i1, v2, i2, v3, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate4;
}
/**
 *
 * Update an interpolated style property on an element with 5 bound values surrounded by text.
 *
 * Used when the value passed to a property has 5 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate5(0, 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate5(prop, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation5(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate5;
}
/**
 *
 * Update an interpolated style property on an element with 6 bound values surrounded by text.
 *
 * Used when the value passed to a property has 6 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate6(0, 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate6(prop, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation6(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate6;
}
/**
 *
 * Update an interpolated style property on an element with 7 bound values surrounded by text.
 *
 * Used when the value passed to a property has 7 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate7(
 *    0, 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate7(prop, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation7(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate7;
}
/**
 *
 * Update an interpolated style property on an element with 8 bound values surrounded by text.
 *
 * Used when the value passed to a property has 8 interpolated values in it:
 *
 * ```html
 * <div style.color="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}suffix"></div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolate8(0, 'prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6,
 * '-', v7, 'suffix');
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`.
 * @param prefix Static value used for concatenation only.
 * @param v0 Value checked for change.
 * @param i0 Static value used for concatenation only.
 * @param v1 Value checked for change.
 * @param i1 Static value used for concatenation only.
 * @param v2 Value checked for change.
 * @param i2 Static value used for concatenation only.
 * @param v3 Value checked for change.
 * @param i3 Static value used for concatenation only.
 * @param v4 Value checked for change.
 * @param i4 Static value used for concatenation only.
 * @param v5 Value checked for change.
 * @param i5 Static value used for concatenation only.
 * @param v6 Value checked for change.
 * @param i6 Static value used for concatenation only.
 * @param v7 Value checked for change.
 * @param suffix Static value used for concatenation only.
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolate8(prop, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolation8(lView, prefix, v0, i0, v1, i1, v2, i2, v3, i3, v4, i4, v5, i5, v6, i6, v7, suffix);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolate8;
}
/**
 * Update an interpolated style property on an element with 9 or more bound values surrounded by
 * text.
 *
 * Used when the number of interpolated values exceeds 8.
 *
 * ```html
 * <div
 *  style.color="prefix{{v0}}-{{v1}}-{{v2}}-{{v3}}-{{v4}}-{{v5}}-{{v6}}-{{v7}}-{{v8}}-{{v9}}suffix">
 * </div>
 * ```
 *
 * Its compiled representation is:
 *
 * ```ts
 * ɵɵstylePropInterpolateV(
 *  0, ['prefix', v0, '-', v1, '-', v2, '-', v3, '-', v4, '-', v5, '-', v6, '-', v7, '-', v9,
 *  'suffix']);
 * ```
 *
 * @param styleIndex Index of style to update. This index value refers to the
 *        index of the style in the style bindings array that was passed into
 *        `styling`..
 * @param values The collection of values and the strings in-between those values, beginning with
 * a string prefix and ending with a string suffix.
 * (e.g. `['prefix', value0, '-', value1, '-', value2, ..., value99, 'suffix']`)
 * @param valueSuffix Optional suffix. Used with scalar values to add unit such as `px`.
 * @returns itself, so that it may be chained.
 * @codeGenApi
 */


function ɵɵstylePropInterpolateV(prop, values, valueSuffix) {
  var lView = getLView();
  var interpolatedValue = interpolationV(lView, values);
  checkStylingProperty(prop, interpolatedValue, valueSuffix, false);
  return ɵɵstylePropInterpolateV;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Update a property on a host element. Only applies to native node properties, not inputs.
 *
 * Operates on the element selected by index via the {@link select} instruction.
 *
 * @param propName Name of property. Because it is going to DOM, this is not subject to
 *        renaming as part of minification.
 * @param value New value to write.
 * @param sanitizer An optional function used to sanitize the value.
 * @returns This function returns itself so that it may be chained
 * (e.g. `property('name', ctx.name)('title', ctx.title)`)
 *
 * @codeGenApi
 */


function ɵɵhostProperty(propName, value, sanitizer) {
  var lView = getLView();
  var bindingIndex = nextBindingIndex();

  if (bindingUpdated(lView, bindingIndex, value)) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    elementPropertyInternal(tView, tNode, lView, propName, value, lView[RENDERER], sanitizer, true);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, bindingIndex);
  }

  return ɵɵhostProperty;
}
/**
 * Updates a synthetic host binding (e.g. `[@foo]`) on a component or directive.
 *
 * This instruction is for compatibility purposes and is designed to ensure that a
 * synthetic host binding (e.g. `@HostBinding('@foo')`) properly gets rendered in
 * the component's renderer. Normally all host bindings are evaluated with the parent
 * component's renderer, but, in the case of animation @triggers, they need to be
 * evaluated with the sub component's renderer (because that's where the animation
 * triggers are defined).
 *
 * Do not use this instruction as a replacement for `elementProperty`. This instruction
 * only exists to ensure compatibility with the ViewEngine's host binding behavior.
 *
 * @param index The index of the element to update in the data array
 * @param propName Name of property. Because it is going to DOM, this is not subject to
 *        renaming as part of minification.
 * @param value New value to write.
 * @param sanitizer An optional function used to sanitize the value.
 *
 * @codeGenApi
 */


function ɵɵsyntheticHostProperty(propName, value, sanitizer) {
  var lView = getLView();
  var bindingIndex = nextBindingIndex();

  if (bindingUpdated(lView, bindingIndex, value)) {
    var tView = getTView();
    var tNode = getSelectedTNode();
    var currentDef = getCurrentDirectiveDef(tView.data);
    var renderer = loadComponentRenderer(currentDef, tNode, lView);
    elementPropertyInternal(tView, tNode, lView, propName, value, renderer, sanitizer, true);
    ngDevMode && storePropertyBindingMetadata(tView.data, tNode, propName, bindingIndex);
  }

  return ɵɵsyntheticHostProperty;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Resolves the providers which are defined in the DirectiveDef.
 *
 * When inserting the tokens and the factories in their respective arrays, we can assume that
 * this method is called first for the component (if any), and then for other directives on the same
 * node.
 * As a consequence,the providers are always processed in that order:
 * 1) The view providers of the component
 * 2) The providers of the component
 * 3) The providers of the other directives
 * This matches the structure of the injectables arrays of a view (for each node).
 * So the tokens and the factories can be pushed at the end of the arrays, except
 * in one case for multi providers.
 *
 * @param def the directive definition
 * @param providers: Array of `providers`.
 * @param viewProviders: Array of `viewProviders`.
 */


function providersResolver(def, providers, viewProviders) {
  var tView = getTView();

  if (tView.firstCreatePass) {
    var isComponent = isComponentDef(def); // The list of view providers is processed first, and the flags are updated

    resolveProvider$1(viewProviders, tView.data, tView.blueprint, isComponent, true); // Then, the list of providers is processed, and the flags are updated

    resolveProvider$1(providers, tView.data, tView.blueprint, isComponent, false);
  }
}
/**
 * Resolves a provider and publishes it to the DI system.
 */


function resolveProvider$1(provider, tInjectables, lInjectablesBlueprint, isComponent, isViewProvider) {
  provider = resolveForwardRef(provider);

  if (Array.isArray(provider)) {
    // Recursively call `resolveProvider`
    // Recursion is OK in this case because this code will not be in hot-path once we implement
    // cloning of the initial state.
    for (var i = 0; i < provider.length; i++) {
      resolveProvider$1(provider[i], tInjectables, lInjectablesBlueprint, isComponent, isViewProvider);
    }
  } else {
    var tView = getTView();
    var lView = getLView();
    var token = isTypeProvider(provider) ? provider : resolveForwardRef(provider.provide);
    var providerFactory = providerToFactory(provider);
    var tNode = getCurrentTNode();
    var beginIndex = tNode.providerIndexes & 1048575
    /* ProvidersStartIndexMask */
    ;
    var endIndex = tNode.directiveStart;
    var cptViewProvidersCount = tNode.providerIndexes >> 20
    /* CptViewProvidersCountShift */
    ;

    if (isTypeProvider(provider) || !provider.multi) {
      // Single provider case: the factory is created and pushed immediately
      var factory = new NodeInjectorFactory(providerFactory, isViewProvider, ɵɵdirectiveInject);
      var existingFactoryIndex = indexOf(token, tInjectables, isViewProvider ? beginIndex : beginIndex + cptViewProvidersCount, endIndex);

      if (existingFactoryIndex === -1) {
        diPublicInInjector(getOrCreateNodeInjectorForNode(tNode, lView), tView, token);
        registerDestroyHooksIfSupported(tView, provider, tInjectables.length);
        tInjectables.push(token);
        tNode.directiveStart++;
        tNode.directiveEnd++;

        if (isViewProvider) {
          tNode.providerIndexes += 1048576
          /* CptViewProvidersCountShifter */
          ;
        }

        lInjectablesBlueprint.push(factory);
        lView.push(factory);
      } else {
        lInjectablesBlueprint[existingFactoryIndex] = factory;
        lView[existingFactoryIndex] = factory;
      }
    } else {
      // Multi provider case:
      // We create a multi factory which is going to aggregate all the values.
      // Since the output of such a factory depends on content or view injection,
      // we create two of them, which are linked together.
      //
      // The first one (for view providers) is always in the first block of the injectables array,
      // and the second one (for providers) is always in the second block.
      // This is important because view providers have higher priority. When a multi token
      // is being looked up, the view providers should be found first.
      // Note that it is not possible to have a multi factory in the third block (directive block).
      //
      // The algorithm to process multi providers is as follows:
      // 1) If the multi provider comes from the `viewProviders` of the component:
      //   a) If the special view providers factory doesn't exist, it is created and pushed.
      //   b) Else, the multi provider is added to the existing multi factory.
      // 2) If the multi provider comes from the `providers` of the component or of another
      // directive:
      //   a) If the multi factory doesn't exist, it is created and provider pushed into it.
      //      It is also linked to the multi factory for view providers, if it exists.
      //   b) Else, the multi provider is added to the existing multi factory.
      var existingProvidersFactoryIndex = indexOf(token, tInjectables, beginIndex + cptViewProvidersCount, endIndex);
      var existingViewProvidersFactoryIndex = indexOf(token, tInjectables, beginIndex, beginIndex + cptViewProvidersCount);
      var doesProvidersFactoryExist = existingProvidersFactoryIndex >= 0 && lInjectablesBlueprint[existingProvidersFactoryIndex];
      var doesViewProvidersFactoryExist = existingViewProvidersFactoryIndex >= 0 && lInjectablesBlueprint[existingViewProvidersFactoryIndex];

      if (isViewProvider && !doesViewProvidersFactoryExist || !isViewProvider && !doesProvidersFactoryExist) {
        // Cases 1.a and 2.a
        diPublicInInjector(getOrCreateNodeInjectorForNode(tNode, lView), tView, token);

        var _factory = multiFactory(isViewProvider ? multiViewProvidersFactoryResolver : multiProvidersFactoryResolver, lInjectablesBlueprint.length, isViewProvider, isComponent, providerFactory);

        if (!isViewProvider && doesViewProvidersFactoryExist) {
          lInjectablesBlueprint[existingViewProvidersFactoryIndex].providerFactory = _factory;
        }

        registerDestroyHooksIfSupported(tView, provider, tInjectables.length, 0);
        tInjectables.push(token);
        tNode.directiveStart++;
        tNode.directiveEnd++;

        if (isViewProvider) {
          tNode.providerIndexes += 1048576
          /* CptViewProvidersCountShifter */
          ;
        }

        lInjectablesBlueprint.push(_factory);
        lView.push(_factory);
      } else {
        // Cases 1.b and 2.b
        var indexInFactory = multiFactoryAdd(lInjectablesBlueprint[isViewProvider ? existingViewProvidersFactoryIndex : existingProvidersFactoryIndex], providerFactory, !isViewProvider && isComponent);
        registerDestroyHooksIfSupported(tView, provider, existingProvidersFactoryIndex > -1 ? existingProvidersFactoryIndex : existingViewProvidersFactoryIndex, indexInFactory);
      }

      if (!isViewProvider && isComponent && doesViewProvidersFactoryExist) {
        lInjectablesBlueprint[existingViewProvidersFactoryIndex].componentProviders++;
      }
    }
  }
}
/**
 * Registers the `ngOnDestroy` hook of a provider, if the provider supports destroy hooks.
 * @param tView `TView` in which to register the hook.
 * @param provider Provider whose hook should be registered.
 * @param contextIndex Index under which to find the context for the hook when it's being invoked.
 * @param indexInFactory Only required for `multi` providers. Index of the provider in the multi
 * provider factory.
 */


function registerDestroyHooksIfSupported(tView, provider, contextIndex, indexInFactory) {
  var providerIsTypeProvider = isTypeProvider(provider);

  if (providerIsTypeProvider || isClassProvider(provider)) {
    var prototype = (provider.useClass || provider).prototype;
    var ngOnDestroy = prototype.ngOnDestroy;

    if (ngOnDestroy) {
      var hooks = tView.destroyHooks || (tView.destroyHooks = []);

      if (!providerIsTypeProvider && provider.multi) {
        ngDevMode && assertDefined(indexInFactory, 'indexInFactory when registering multi factory destroy hook');
        var existingCallbacksIndex = hooks.indexOf(contextIndex);

        if (existingCallbacksIndex === -1) {
          hooks.push(contextIndex, [indexInFactory, ngOnDestroy]);
        } else {
          hooks[existingCallbacksIndex + 1].push(indexInFactory, ngOnDestroy);
        }
      } else {
        hooks.push(contextIndex, ngOnDestroy);
      }
    }
  }
}
/**
 * Add a factory in a multi factory.
 * @returns Index at which the factory was inserted.
 */


function multiFactoryAdd(multiFactory, factory, isComponentProvider) {
  if (isComponentProvider) {
    multiFactory.componentProviders++;
  }

  return multiFactory.multi.push(factory) - 1;
}
/**
 * Returns the index of item in the array, but only in the begin to end range.
 */


function indexOf(item, arr, begin, end) {
  for (var i = begin; i < end; i++) {
    if (arr[i] === item) return i;
  }

  return -1;
}
/**
 * Use this with `multi` `providers`.
 */


function multiProvidersFactoryResolver(_, tData, lData, tNode) {
  return multiResolve(this.multi, []);
}
/**
 * Use this with `multi` `viewProviders`.
 *
 * This factory knows how to concatenate itself with the existing `multi` `providers`.
 */


function multiViewProvidersFactoryResolver(_, tData, lView, tNode) {
  var factories = this.multi;
  var result;

  if (this.providerFactory) {
    var componentCount = this.providerFactory.componentProviders;
    var multiProviders = getNodeInjectable(lView, lView[TVIEW], this.providerFactory.index, tNode); // Copy the section of the array which contains `multi` `providers` from the component

    result = multiProviders.slice(0, componentCount); // Insert the `viewProvider` instances.

    multiResolve(factories, result); // Copy the section of the array which contains `multi` `providers` from other directives

    for (var i = componentCount; i < multiProviders.length; i++) {
      result.push(multiProviders[i]);
    }
  } else {
    result = []; // Insert the `viewProvider` instances.

    multiResolve(factories, result);
  }

  return result;
}
/**
 * Maps an array of factories into an array of values.
 */


function multiResolve(factories, result) {
  for (var i = 0; i < factories.length; i++) {
    var factory = factories[i];
    result.push(factory());
  }

  return result;
}
/**
 * Creates a multi factory.
 */


function multiFactory(factoryFn, index, isViewProvider, isComponent, f) {
  var factory = new NodeInjectorFactory(factoryFn, isViewProvider, ɵɵdirectiveInject);
  factory.multi = [];
  factory.index = index;
  factory.componentProviders = 0;
  multiFactoryAdd(factory, f, isComponent && !isViewProvider);
  return factory;
}
/**
 * This feature resolves the providers of a directive (or component),
 * and publish them into the DI system, making it visible to others for injection.
 *
 * For example:
 * ```ts
 * class ComponentWithProviders {
 *   constructor(private greeter: GreeterDE) {}
 *
 *   static ɵcmp = defineComponent({
 *     type: ComponentWithProviders,
 *     selectors: [['component-with-providers']],
 *    factory: () => new ComponentWithProviders(directiveInject(GreeterDE as any)),
 *    decls: 1,
 *    vars: 1,
 *    template: function(fs: RenderFlags, ctx: ComponentWithProviders) {
 *      if (fs & RenderFlags.Create) {
 *        ɵɵtext(0);
 *      }
 *      if (fs & RenderFlags.Update) {
 *        ɵɵtextInterpolate(ctx.greeter.greet());
 *      }
 *    },
 *    features: [ɵɵProvidersFeature([GreeterDE])]
 *  });
 * }
 * ```
 *
 * @param definition
 *
 * @codeGenApi
 */


function ɵɵProvidersFeature(providers) {
  var viewProviders = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  return function (definition) {
    definition.providersResolver = function (def, processProvidersFn) {
      return providersResolver(def, //
      processProvidersFn ? processProvidersFn(providers) : providers, //
      viewProviders);
    };
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents a component created by a `ComponentFactory`.
 * Provides access to the component instance and related objects,
 * and provides the means of destroying the instance.
 *
 * @publicApi
 */


var ComponentRef = function ComponentRef() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentRef);
};
/**
 * Base class for a factory that can create a component dynamically.
 * Instantiate a factory for a given type of component with `resolveComponentFactory()`.
 * Use the resulting `ComponentFactory.create()` method to create a component of that type.
 *
 * @see [Dynamic Components](guide/dynamic-component-loader)
 *
 * @publicApi
 */


var ComponentFactory = function ComponentFactory() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentFactory);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function noComponentFactoryError(component) {
  var error = Error("No component factory found for ".concat(stringify(component), ". Did you add it to @NgModule.entryComponents?"));
  error[ERROR_COMPONENT] = component;
  return error;
}

var ERROR_COMPONENT = 'ngComponent';

function getComponent$1(error) {
  return error[ERROR_COMPONENT];
}

var _NullComponentFactoryResolver = /*#__PURE__*/function () {
  function _NullComponentFactoryResolver() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, _NullComponentFactoryResolver);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(_NullComponentFactoryResolver, [{
    key: "resolveComponentFactory",
    value: function resolveComponentFactory(component) {
      throw noComponentFactoryError(component);
    }
  }]);

  return _NullComponentFactoryResolver;
}();
/**
 * A simple registry that maps `Components` to generated `ComponentFactory` classes
 * that can be used to create instances of components.
 * Use to obtain the factory for a given component type,
 * then use the factory's `create()` method to create a component of that type.
 *
 * @see [Dynamic Components](guide/dynamic-component-loader)
 * @publicApi
 */


var ComponentFactoryResolver = function ComponentFactoryResolver() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentFactoryResolver);
};

ComponentFactoryResolver.NULL = new _NullComponentFactoryResolver();

var CodegenComponentFactoryResolver = /*#__PURE__*/function () {
  function CodegenComponentFactoryResolver(factories, _parent, _ngModule) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, CodegenComponentFactoryResolver);

    this._parent = _parent;
    this._ngModule = _ngModule;
    this._factories = new Map();

    for (var i = 0; i < factories.length; i++) {
      var factory = factories[i];

      this._factories.set(factory.componentType, factory);
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(CodegenComponentFactoryResolver, [{
    key: "resolveComponentFactory",
    value: function resolveComponentFactory(component) {
      var factory = this._factories.get(component);

      if (!factory && this._parent) {
        factory = this._parent.resolveComponentFactory(component);
      }

      if (!factory) {
        throw noComponentFactoryError(component);
      }

      return new ComponentFactoryBoundToModule(factory, this._ngModule);
    }
  }]);

  return CodegenComponentFactoryResolver;
}();

var ComponentFactoryBoundToModule = /*#__PURE__*/function (_ComponentFactory) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ComponentFactoryBoundToModule, _ComponentFactory);

  var _super10 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ComponentFactoryBoundToModule);

  function ComponentFactoryBoundToModule(factory, ngModule) {
    var _this8;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentFactoryBoundToModule);

    _this8 = _super10.call(this);
    _this8.factory = factory;
    _this8.ngModule = ngModule;
    _this8.selector = factory.selector;
    _this8.componentType = factory.componentType;
    _this8.ngContentSelectors = factory.ngContentSelectors;
    _this8.inputs = factory.inputs;
    _this8.outputs = factory.outputs;
    return _this8;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ComponentFactoryBoundToModule, [{
    key: "create",
    value: function create(injector, projectableNodes, rootSelectorOrNode, ngModule) {
      return this.factory.create(injector, projectableNodes, rootSelectorOrNode, ngModule || this.ngModule);
    }
  }]);

  return ComponentFactoryBoundToModule;
}(ComponentFactory);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function noop() {// Do nothing.
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A wrapper around a native element inside of a View.
 *
 * An `ElementRef` is backed by a render-specific element. In the browser, this is usually a DOM
 * element.
 *
 * @security Permitting direct access to the DOM can make your application more vulnerable to
 * XSS attacks. Carefully review any use of `ElementRef` in your code. For more detail, see the
 * [Security Guide](http://g.co/ng/security).
 *
 * @publicApi
 */
// Note: We don't expose things like `Injector`, `ViewContainer`, ... here,
// i.e. users have to ask for what they need. With that, we can build better analysis tools
// and could do better codegen in the future.


var ElementRef = function ElementRef(nativeElement) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ElementRef);

  this.nativeElement = nativeElement;
};
/**
 * @internal
 * @nocollapse
 */


ElementRef.__NG_ELEMENT_ID__ = function () {
  return SWITCH_ELEMENT_REF_FACTORY(ElementRef);
};

var SWITCH_ELEMENT_REF_FACTORY__POST_R3__ = injectElementRef;
var SWITCH_ELEMENT_REF_FACTORY__PRE_R3__ = noop;
var SWITCH_ELEMENT_REF_FACTORY = SWITCH_ELEMENT_REF_FACTORY__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var Renderer2Interceptor = new InjectionToken('Renderer2Interceptor');
/**
 * Creates and initializes a custom renderer that implements the `Renderer2` base class.
 *
 * @publicApi
 */

var RendererFactory2 = function RendererFactory2() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, RendererFactory2);
};
/**
 * Flags for renderer-specific style modifiers.
 * @publicApi
 */


var RendererStyleFlags2;

(function (RendererStyleFlags2) {
  // TODO(misko): This needs to be refactored into a separate file so that it can be imported from
  // `node_manipulation.ts` Currently doing the import cause resolution order to change and fails
  // the tests. The work around is to have hard coded value in `node_manipulation.ts` for now.

  /**
   * Marks a style as important.
   */
  RendererStyleFlags2[RendererStyleFlags2["Important"] = 1] = "Important";
  /**
   * Marks a style as using dash case naming (this-is-dash-case).
   */

  RendererStyleFlags2[RendererStyleFlags2["DashCase"] = 2] = "DashCase";
})(RendererStyleFlags2 || (RendererStyleFlags2 = {}));
/**
 * Extend this base class to implement custom rendering. By default, Angular
 * renders a template into DOM. You can use custom rendering to intercept
 * rendering calls, or to render to something other than DOM.
 *
 * Create your custom renderer using `RendererFactory2`.
 *
 * Use a custom renderer to bypass Angular's templating and
 * make custom UI changes that can't be expressed declaratively.
 * For example if you need to set a property or an attribute whose name is
 * not statically known, use the `setProperty()` or
 * `setAttribute()` method.
 *
 * @publicApi
 */


var Renderer2 = function Renderer2() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Renderer2);
};
/**
 * @internal
 * @nocollapse
 */


Renderer2.__NG_ELEMENT_ID__ = function () {
  return SWITCH_RENDERER2_FACTORY();
};

var SWITCH_RENDERER2_FACTORY__POST_R3__ = injectRenderer2;
var SWITCH_RENDERER2_FACTORY__PRE_R3__ = noop;
var SWITCH_RENDERER2_FACTORY = SWITCH_RENDERER2_FACTORY__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Sanitizer is used by the views to sanitize potentially dangerous values.
 *
 * @publicApi
 */

var Sanitizer = function Sanitizer() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Sanitizer);
};
/** @nocollapse */


Sanitizer.ɵprov = ɵɵdefineInjectable({
  token: Sanitizer,
  providedIn: 'root',
  factory: function factory() {
    return null;
  }
});
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description Represents the version of Angular
 *
 * @publicApi
 */

var Version = function Version(full) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Version);

  this.full = full;
  this.major = full.split('.')[0];
  this.minor = full.split('.')[1];
  this.patch = full.split('.').slice(2).join('.');
};
/**
 * @publicApi
 */


var VERSION = new Version('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var DefaultIterableDifferFactory = /*#__PURE__*/function () {
  function DefaultIterableDifferFactory() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DefaultIterableDifferFactory);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DefaultIterableDifferFactory, [{
    key: "supports",
    value: function supports(obj) {
      return isListLikeIterable(obj);
    }
  }, {
    key: "create",
    value: function create(trackByFn) {
      return new DefaultIterableDiffer(trackByFn);
    }
  }]);

  return DefaultIterableDifferFactory;
}();

var trackByIdentity = function trackByIdentity(index, item) {
  return item;
};

var ɵ0$c = trackByIdentity;
/**
 * @deprecated v4.0.0 - Should not be part of public API.
 * @publicApi
 */

var DefaultIterableDiffer = /*#__PURE__*/function () {
  function DefaultIterableDiffer(trackByFn) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DefaultIterableDiffer);

    this.length = 0; // Keeps track of the used records at any point in time (during & across `_check()` calls)

    this._linkedRecords = null; // Keeps track of the removed records at any point in time during `_check()` calls.

    this._unlinkedRecords = null;
    this._previousItHead = null;
    this._itHead = null;
    this._itTail = null;
    this._additionsHead = null;
    this._additionsTail = null;
    this._movesHead = null;
    this._movesTail = null;
    this._removalsHead = null;
    this._removalsTail = null; // Keeps track of records where custom track by is the same, but item identity has changed

    this._identityChangesHead = null;
    this._identityChangesTail = null;
    this._trackByFn = trackByFn || trackByIdentity;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DefaultIterableDiffer, [{
    key: "forEachItem",
    value: function forEachItem(fn) {
      var record;

      for (record = this._itHead; record !== null; record = record._next) {
        fn(record);
      }
    }
  }, {
    key: "forEachOperation",
    value: function forEachOperation(fn) {
      var nextIt = this._itHead;
      var nextRemove = this._removalsHead;
      var addRemoveOffset = 0;
      var moveOffsets = null;

      while (nextIt || nextRemove) {
        // Figure out which is the next record to process
        // Order: remove, add, move
        var record = !nextRemove || nextIt && nextIt.currentIndex < getPreviousIndex(nextRemove, addRemoveOffset, moveOffsets) ? nextIt : nextRemove;
        var adjPreviousIndex = getPreviousIndex(record, addRemoveOffset, moveOffsets);
        var currentIndex = record.currentIndex; // consume the item, and adjust the addRemoveOffset and update moveDistance if necessary

        if (record === nextRemove) {
          addRemoveOffset--;
          nextRemove = nextRemove._nextRemoved;
        } else {
          nextIt = nextIt._next;

          if (record.previousIndex == null) {
            addRemoveOffset++;
          } else {
            // INVARIANT:  currentIndex < previousIndex
            if (!moveOffsets) moveOffsets = [];
            var localMovePreviousIndex = adjPreviousIndex - addRemoveOffset;
            var localCurrentIndex = currentIndex - addRemoveOffset;

            if (localMovePreviousIndex != localCurrentIndex) {
              for (var i = 0; i < localMovePreviousIndex; i++) {
                var offset = i < moveOffsets.length ? moveOffsets[i] : moveOffsets[i] = 0;
                var index = offset + i;

                if (localCurrentIndex <= index && index < localMovePreviousIndex) {
                  moveOffsets[i] = offset + 1;
                }
              }

              var previousIndex = record.previousIndex;
              moveOffsets[previousIndex] = localCurrentIndex - localMovePreviousIndex;
            }
          }
        }

        if (adjPreviousIndex !== currentIndex) {
          fn(record, adjPreviousIndex, currentIndex);
        }
      }
    }
  }, {
    key: "forEachPreviousItem",
    value: function forEachPreviousItem(fn) {
      var record;

      for (record = this._previousItHead; record !== null; record = record._nextPrevious) {
        fn(record);
      }
    }
  }, {
    key: "forEachAddedItem",
    value: function forEachAddedItem(fn) {
      var record;

      for (record = this._additionsHead; record !== null; record = record._nextAdded) {
        fn(record);
      }
    }
  }, {
    key: "forEachMovedItem",
    value: function forEachMovedItem(fn) {
      var record;

      for (record = this._movesHead; record !== null; record = record._nextMoved) {
        fn(record);
      }
    }
  }, {
    key: "forEachRemovedItem",
    value: function forEachRemovedItem(fn) {
      var record;

      for (record = this._removalsHead; record !== null; record = record._nextRemoved) {
        fn(record);
      }
    }
  }, {
    key: "forEachIdentityChange",
    value: function forEachIdentityChange(fn) {
      var record;

      for (record = this._identityChangesHead; record !== null; record = record._nextIdentityChange) {
        fn(record);
      }
    }
  }, {
    key: "diff",
    value: function diff(collection) {
      if (collection == null) collection = [];

      if (!isListLikeIterable(collection)) {
        throw new Error("Error trying to diff '".concat(stringify(collection), "'. Only arrays and iterables are allowed"));
      }

      if (this.check(collection)) {
        return this;
      } else {
        return null;
      }
    }
  }, {
    key: "onDestroy",
    value: function onDestroy() {}
  }, {
    key: "check",
    value: function check(collection) {
      var _this9 = this;

      this._reset();

      var record = this._itHead;
      var mayBeDirty = false;
      var index;
      var item;
      var itemTrackBy;

      if (Array.isArray(collection)) {
        this.length = collection.length;

        for (var _index = 0; _index < this.length; _index++) {
          item = collection[_index];
          itemTrackBy = this._trackByFn(_index, item);

          if (record === null || !Object.is(record.trackById, itemTrackBy)) {
            record = this._mismatch(record, item, itemTrackBy, _index);
            mayBeDirty = true;
          } else {
            if (mayBeDirty) {
              // TODO(misko): can we limit this to duplicates only?
              record = this._verifyReinsertion(record, item, itemTrackBy, _index);
            }

            if (!Object.is(record.item, item)) this._addIdentityChange(record, item);
          }

          record = record._next;
        }
      } else {
        index = 0;
        iterateListLike(collection, function (item) {
          itemTrackBy = _this9._trackByFn(index, item);

          if (record === null || !Object.is(record.trackById, itemTrackBy)) {
            record = _this9._mismatch(record, item, itemTrackBy, index);
            mayBeDirty = true;
          } else {
            if (mayBeDirty) {
              // TODO(misko): can we limit this to duplicates only?
              record = _this9._verifyReinsertion(record, item, itemTrackBy, index);
            }

            if (!Object.is(record.item, item)) _this9._addIdentityChange(record, item);
          }

          record = record._next;
          index++;
        });
        this.length = index;
      }

      this._truncate(record);

      this.collection = collection;
      return this.isDirty;
    }
    /* CollectionChanges is considered dirty if it has any additions, moves, removals, or identity
     * changes.
     */

  }, {
    key: "_reset",

    /**
     * Reset the state of the change objects to show no changes. This means set previousKey to
     * currentKey, and clear all of the queues (additions, moves, removals).
     * Set the previousIndexes of moved and added items to their currentIndexes
     * Reset the list of additions, moves and removals
     *
     * @internal
     */
    value: function _reset() {
      if (this.isDirty) {
        var record;

        for (record = this._previousItHead = this._itHead; record !== null; record = record._next) {
          record._nextPrevious = record._next;
        }

        for (record = this._additionsHead; record !== null; record = record._nextAdded) {
          record.previousIndex = record.currentIndex;
        }

        this._additionsHead = this._additionsTail = null;

        for (record = this._movesHead; record !== null; record = record._nextMoved) {
          record.previousIndex = record.currentIndex;
        }

        this._movesHead = this._movesTail = null;
        this._removalsHead = this._removalsTail = null;
        this._identityChangesHead = this._identityChangesTail = null; // TODO(vicb): when assert gets supported
        // assert(!this.isDirty);
      }
    }
    /**
     * This is the core function which handles differences between collections.
     *
     * - `record` is the record which we saw at this position last time. If null then it is a new
     *   item.
     * - `item` is the current item in the collection
     * - `index` is the position of the item in the collection
     *
     * @internal
     */

  }, {
    key: "_mismatch",
    value: function _mismatch(record, item, itemTrackBy, index) {
      // The previous record after which we will append the current one.
      var previousRecord;

      if (record === null) {
        previousRecord = this._itTail;
      } else {
        previousRecord = record._prev; // Remove the record from the collection since we know it does not match the item.

        this._remove(record);
      } // Attempt to see if we have seen the item before.


      record = this._linkedRecords === null ? null : this._linkedRecords.get(itemTrackBy, index);

      if (record !== null) {
        // We have seen this before, we need to move it forward in the collection.
        // But first we need to check if identity changed, so we can update in view if necessary
        if (!Object.is(record.item, item)) this._addIdentityChange(record, item);

        this._moveAfter(record, previousRecord, index);
      } else {
        // Never seen it, check evicted list.
        record = this._unlinkedRecords === null ? null : this._unlinkedRecords.get(itemTrackBy, null);

        if (record !== null) {
          // It is an item which we have evicted earlier: reinsert it back into the list.
          // But first we need to check if identity changed, so we can update in view if necessary
          if (!Object.is(record.item, item)) this._addIdentityChange(record, item);

          this._reinsertAfter(record, previousRecord, index);
        } else {
          // It is a new item: add it.
          record = this._addAfter(new IterableChangeRecord_(item, itemTrackBy), previousRecord, index);
        }
      }

      return record;
    }
    /**
     * This check is only needed if an array contains duplicates. (Short circuit of nothing dirty)
     *
     * Use case: `[a, a]` => `[b, a, a]`
     *
     * If we did not have this check then the insertion of `b` would:
     *   1) evict first `a`
     *   2) insert `b` at `0` index.
     *   3) leave `a` at index `1` as is. <-- this is wrong!
     *   3) reinsert `a` at index 2. <-- this is wrong!
     *
     * The correct behavior is:
     *   1) evict first `a`
     *   2) insert `b` at `0` index.
     *   3) reinsert `a` at index 1.
     *   3) move `a` at from `1` to `2`.
     *
     *
     * Double check that we have not evicted a duplicate item. We need to check if the item type may
     * have already been removed:
     * The insertion of b will evict the first 'a'. If we don't reinsert it now it will be reinserted
     * at the end. Which will show up as the two 'a's switching position. This is incorrect, since a
     * better way to think of it is as insert of 'b' rather then switch 'a' with 'b' and then add 'a'
     * at the end.
     *
     * @internal
     */

  }, {
    key: "_verifyReinsertion",
    value: function _verifyReinsertion(record, item, itemTrackBy, index) {
      var reinsertRecord = this._unlinkedRecords === null ? null : this._unlinkedRecords.get(itemTrackBy, null);

      if (reinsertRecord !== null) {
        record = this._reinsertAfter(reinsertRecord, record._prev, index);
      } else if (record.currentIndex != index) {
        record.currentIndex = index;

        this._addToMoves(record, index);
      }

      return record;
    }
    /**
     * Get rid of any excess {@link IterableChangeRecord_}s from the previous collection
     *
     * - `record` The first excess {@link IterableChangeRecord_}.
     *
     * @internal
     */

  }, {
    key: "_truncate",
    value: function _truncate(record) {
      // Anything after that needs to be removed;
      while (record !== null) {
        var nextRecord = record._next;

        this._addToRemovals(this._unlink(record));

        record = nextRecord;
      }

      if (this._unlinkedRecords !== null) {
        this._unlinkedRecords.clear();
      }

      if (this._additionsTail !== null) {
        this._additionsTail._nextAdded = null;
      }

      if (this._movesTail !== null) {
        this._movesTail._nextMoved = null;
      }

      if (this._itTail !== null) {
        this._itTail._next = null;
      }

      if (this._removalsTail !== null) {
        this._removalsTail._nextRemoved = null;
      }

      if (this._identityChangesTail !== null) {
        this._identityChangesTail._nextIdentityChange = null;
      }
    }
    /** @internal */

  }, {
    key: "_reinsertAfter",
    value: function _reinsertAfter(record, prevRecord, index) {
      if (this._unlinkedRecords !== null) {
        this._unlinkedRecords.remove(record);
      }

      var prev = record._prevRemoved;
      var next = record._nextRemoved;

      if (prev === null) {
        this._removalsHead = next;
      } else {
        prev._nextRemoved = next;
      }

      if (next === null) {
        this._removalsTail = prev;
      } else {
        next._prevRemoved = prev;
      }

      this._insertAfter(record, prevRecord, index);

      this._addToMoves(record, index);

      return record;
    }
    /** @internal */

  }, {
    key: "_moveAfter",
    value: function _moveAfter(record, prevRecord, index) {
      this._unlink(record);

      this._insertAfter(record, prevRecord, index);

      this._addToMoves(record, index);

      return record;
    }
    /** @internal */

  }, {
    key: "_addAfter",
    value: function _addAfter(record, prevRecord, index) {
      this._insertAfter(record, prevRecord, index);

      if (this._additionsTail === null) {
        // TODO(vicb):
        // assert(this._additionsHead === null);
        this._additionsTail = this._additionsHead = record;
      } else {
        // TODO(vicb):
        // assert(_additionsTail._nextAdded === null);
        // assert(record._nextAdded === null);
        this._additionsTail = this._additionsTail._nextAdded = record;
      }

      return record;
    }
    /** @internal */

  }, {
    key: "_insertAfter",
    value: function _insertAfter(record, prevRecord, index) {
      // TODO(vicb):
      // assert(record != prevRecord);
      // assert(record._next === null);
      // assert(record._prev === null);
      var next = prevRecord === null ? this._itHead : prevRecord._next; // TODO(vicb):
      // assert(next != record);
      // assert(prevRecord != record);

      record._next = next;
      record._prev = prevRecord;

      if (next === null) {
        this._itTail = record;
      } else {
        next._prev = record;
      }

      if (prevRecord === null) {
        this._itHead = record;
      } else {
        prevRecord._next = record;
      }

      if (this._linkedRecords === null) {
        this._linkedRecords = new _DuplicateMap();
      }

      this._linkedRecords.put(record);

      record.currentIndex = index;
      return record;
    }
    /** @internal */

  }, {
    key: "_remove",
    value: function _remove(record) {
      return this._addToRemovals(this._unlink(record));
    }
    /** @internal */

  }, {
    key: "_unlink",
    value: function _unlink(record) {
      if (this._linkedRecords !== null) {
        this._linkedRecords.remove(record);
      }

      var prev = record._prev;
      var next = record._next; // TODO(vicb):
      // assert((record._prev = null) === null);
      // assert((record._next = null) === null);

      if (prev === null) {
        this._itHead = next;
      } else {
        prev._next = next;
      }

      if (next === null) {
        this._itTail = prev;
      } else {
        next._prev = prev;
      }

      return record;
    }
    /** @internal */

  }, {
    key: "_addToMoves",
    value: function _addToMoves(record, toIndex) {
      // TODO(vicb):
      // assert(record._nextMoved === null);
      if (record.previousIndex === toIndex) {
        return record;
      }

      if (this._movesTail === null) {
        // TODO(vicb):
        // assert(_movesHead === null);
        this._movesTail = this._movesHead = record;
      } else {
        // TODO(vicb):
        // assert(_movesTail._nextMoved === null);
        this._movesTail = this._movesTail._nextMoved = record;
      }

      return record;
    }
  }, {
    key: "_addToRemovals",
    value: function _addToRemovals(record) {
      if (this._unlinkedRecords === null) {
        this._unlinkedRecords = new _DuplicateMap();
      }

      this._unlinkedRecords.put(record);

      record.currentIndex = null;
      record._nextRemoved = null;

      if (this._removalsTail === null) {
        // TODO(vicb):
        // assert(_removalsHead === null);
        this._removalsTail = this._removalsHead = record;
        record._prevRemoved = null;
      } else {
        // TODO(vicb):
        // assert(_removalsTail._nextRemoved === null);
        // assert(record._nextRemoved === null);
        record._prevRemoved = this._removalsTail;
        this._removalsTail = this._removalsTail._nextRemoved = record;
      }

      return record;
    }
    /** @internal */

  }, {
    key: "_addIdentityChange",
    value: function _addIdentityChange(record, item) {
      record.item = item;

      if (this._identityChangesTail === null) {
        this._identityChangesTail = this._identityChangesHead = record;
      } else {
        this._identityChangesTail = this._identityChangesTail._nextIdentityChange = record;
      }

      return record;
    }
  }, {
    key: "isDirty",
    get: function get() {
      return this._additionsHead !== null || this._movesHead !== null || this._removalsHead !== null || this._identityChangesHead !== null;
    }
  }]);

  return DefaultIterableDiffer;
}();

var IterableChangeRecord_ = function IterableChangeRecord_(item, trackById) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, IterableChangeRecord_);

  this.item = item;
  this.trackById = trackById;
  this.currentIndex = null;
  this.previousIndex = null;
  /** @internal */

  this._nextPrevious = null;
  /** @internal */

  this._prev = null;
  /** @internal */

  this._next = null;
  /** @internal */

  this._prevDup = null;
  /** @internal */

  this._nextDup = null;
  /** @internal */

  this._prevRemoved = null;
  /** @internal */

  this._nextRemoved = null;
  /** @internal */

  this._nextAdded = null;
  /** @internal */

  this._nextMoved = null;
  /** @internal */

  this._nextIdentityChange = null;
}; // A linked list of CollectionChangeRecords with the same IterableChangeRecord_.item


var _DuplicateItemRecordList = /*#__PURE__*/function () {
  function _DuplicateItemRecordList() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, _DuplicateItemRecordList);

    /** @internal */
    this._head = null;
    /** @internal */

    this._tail = null;
  }
  /**
   * Append the record to the list of duplicates.
   *
   * Note: by design all records in the list of duplicates hold the same value in record.item.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(_DuplicateItemRecordList, [{
    key: "add",
    value: function add(record) {
      if (this._head === null) {
        this._head = this._tail = record;
        record._nextDup = null;
        record._prevDup = null;
      } else {
        // TODO(vicb):
        // assert(record.item ==  _head.item ||
        //       record.item is num && record.item.isNaN && _head.item is num && _head.item.isNaN);
        this._tail._nextDup = record;
        record._prevDup = this._tail;
        record._nextDup = null;
        this._tail = record;
      }
    } // Returns a IterableChangeRecord_ having IterableChangeRecord_.trackById == trackById and
    // IterableChangeRecord_.currentIndex >= atOrAfterIndex

  }, {
    key: "get",
    value: function get(trackById, atOrAfterIndex) {
      var record;

      for (record = this._head; record !== null; record = record._nextDup) {
        if ((atOrAfterIndex === null || atOrAfterIndex <= record.currentIndex) && Object.is(record.trackById, trackById)) {
          return record;
        }
      }

      return null;
    }
    /**
     * Remove one {@link IterableChangeRecord_} from the list of duplicates.
     *
     * Returns whether the list of duplicates is empty.
     */

  }, {
    key: "remove",
    value: function remove(record) {
      // TODO(vicb):
      // assert(() {
      //  // verify that the record being removed is in the list.
      //  for (IterableChangeRecord_ cursor = _head; cursor != null; cursor = cursor._nextDup) {
      //    if (identical(cursor, record)) return true;
      //  }
      //  return false;
      //});
      var prev = record._prevDup;
      var next = record._nextDup;

      if (prev === null) {
        this._head = next;
      } else {
        prev._nextDup = next;
      }

      if (next === null) {
        this._tail = prev;
      } else {
        next._prevDup = prev;
      }

      return this._head === null;
    }
  }]);

  return _DuplicateItemRecordList;
}();

var _DuplicateMap = /*#__PURE__*/function () {
  function _DuplicateMap() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, _DuplicateMap);

    this.map = new Map();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(_DuplicateMap, [{
    key: "put",
    value: function put(record) {
      var key = record.trackById;
      var duplicates = this.map.get(key);

      if (!duplicates) {
        duplicates = new _DuplicateItemRecordList();
        this.map.set(key, duplicates);
      }

      duplicates.add(record);
    }
    /**
     * Retrieve the `value` using key. Because the IterableChangeRecord_ value may be one which we
     * have already iterated over, we use the `atOrAfterIndex` to pretend it is not there.
     *
     * Use case: `[a, b, c, a, a]` if we are at index `3` which is the second `a` then asking if we
     * have any more `a`s needs to return the second `a`.
     */

  }, {
    key: "get",
    value: function get(trackById, atOrAfterIndex) {
      var key = trackById;
      var recordList = this.map.get(key);
      return recordList ? recordList.get(trackById, atOrAfterIndex) : null;
    }
    /**
     * Removes a {@link IterableChangeRecord_} from the list of duplicates.
     *
     * The list of duplicates also is removed from the map if it gets empty.
     */

  }, {
    key: "remove",
    value: function remove(record) {
      var key = record.trackById;
      var recordList = this.map.get(key); // Remove the list of duplicates when it gets empty

      if (recordList.remove(record)) {
        this.map.delete(key);
      }

      return record;
    }
  }, {
    key: "clear",
    value: function clear() {
      this.map.clear();
    }
  }, {
    key: "isEmpty",
    get: function get() {
      return this.map.size === 0;
    }
  }]);

  return _DuplicateMap;
}();

function getPreviousIndex(item, addRemoveOffset, moveOffsets) {
  var previousIndex = item.previousIndex;
  if (previousIndex === null) return previousIndex;
  var moveOffset = 0;

  if (moveOffsets && previousIndex < moveOffsets.length) {
    moveOffset = moveOffsets[previousIndex];
  }

  return previousIndex + addRemoveOffset + moveOffset;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var DefaultKeyValueDifferFactory = /*#__PURE__*/function () {
  function DefaultKeyValueDifferFactory() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DefaultKeyValueDifferFactory);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DefaultKeyValueDifferFactory, [{
    key: "supports",
    value: function supports(obj) {
      return obj instanceof Map || isJsObject(obj);
    }
  }, {
    key: "create",
    value: function create() {
      return new DefaultKeyValueDiffer();
    }
  }]);

  return DefaultKeyValueDifferFactory;
}();

var DefaultKeyValueDiffer = /*#__PURE__*/function () {
  function DefaultKeyValueDiffer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DefaultKeyValueDiffer);

    this._records = new Map();
    this._mapHead = null; // _appendAfter is used in the check loop

    this._appendAfter = null;
    this._previousMapHead = null;
    this._changesHead = null;
    this._changesTail = null;
    this._additionsHead = null;
    this._additionsTail = null;
    this._removalsHead = null;
    this._removalsTail = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DefaultKeyValueDiffer, [{
    key: "forEachItem",
    value: function forEachItem(fn) {
      var record;

      for (record = this._mapHead; record !== null; record = record._next) {
        fn(record);
      }
    }
  }, {
    key: "forEachPreviousItem",
    value: function forEachPreviousItem(fn) {
      var record;

      for (record = this._previousMapHead; record !== null; record = record._nextPrevious) {
        fn(record);
      }
    }
  }, {
    key: "forEachChangedItem",
    value: function forEachChangedItem(fn) {
      var record;

      for (record = this._changesHead; record !== null; record = record._nextChanged) {
        fn(record);
      }
    }
  }, {
    key: "forEachAddedItem",
    value: function forEachAddedItem(fn) {
      var record;

      for (record = this._additionsHead; record !== null; record = record._nextAdded) {
        fn(record);
      }
    }
  }, {
    key: "forEachRemovedItem",
    value: function forEachRemovedItem(fn) {
      var record;

      for (record = this._removalsHead; record !== null; record = record._nextRemoved) {
        fn(record);
      }
    }
  }, {
    key: "diff",
    value: function diff(map) {
      if (!map) {
        map = new Map();
      } else if (!(map instanceof Map || isJsObject(map))) {
        throw new Error("Error trying to diff '".concat(stringify(map), "'. Only maps and objects are allowed"));
      }

      return this.check(map) ? this : null;
    }
  }, {
    key: "onDestroy",
    value: function onDestroy() {}
    /**
     * Check the current state of the map vs the previous.
     * The algorithm is optimised for when the keys do no change.
     */

  }, {
    key: "check",
    value: function check(map) {
      var _this10 = this;

      this._reset();

      var insertBefore = this._mapHead;
      this._appendAfter = null;

      this._forEach(map, function (value, key) {
        if (insertBefore && insertBefore.key === key) {
          _this10._maybeAddToChanges(insertBefore, value);

          _this10._appendAfter = insertBefore;
          insertBefore = insertBefore._next;
        } else {
          var record = _this10._getOrCreateRecordForKey(key, value);

          insertBefore = _this10._insertBeforeOrAppend(insertBefore, record);
        }
      }); // Items remaining at the end of the list have been deleted


      if (insertBefore) {
        if (insertBefore._prev) {
          insertBefore._prev._next = null;
        }

        this._removalsHead = insertBefore;

        for (var record = insertBefore; record !== null; record = record._nextRemoved) {
          if (record === this._mapHead) {
            this._mapHead = null;
          }

          this._records.delete(record.key);

          record._nextRemoved = record._next;
          record.previousValue = record.currentValue;
          record.currentValue = null;
          record._prev = null;
          record._next = null;
        }
      } // Make sure tails have no next records from previous runs


      if (this._changesTail) this._changesTail._nextChanged = null;
      if (this._additionsTail) this._additionsTail._nextAdded = null;
      return this.isDirty;
    }
    /**
     * Inserts a record before `before` or append at the end of the list when `before` is null.
     *
     * Notes:
     * - This method appends at `this._appendAfter`,
     * - This method updates `this._appendAfter`,
     * - The return value is the new value for the insertion pointer.
     */

  }, {
    key: "_insertBeforeOrAppend",
    value: function _insertBeforeOrAppend(before, record) {
      if (before) {
        var prev = before._prev;
        record._next = before;
        record._prev = prev;
        before._prev = record;

        if (prev) {
          prev._next = record;
        }

        if (before === this._mapHead) {
          this._mapHead = record;
        }

        this._appendAfter = before;
        return before;
      }

      if (this._appendAfter) {
        this._appendAfter._next = record;
        record._prev = this._appendAfter;
      } else {
        this._mapHead = record;
      }

      this._appendAfter = record;
      return null;
    }
  }, {
    key: "_getOrCreateRecordForKey",
    value: function _getOrCreateRecordForKey(key, value) {
      if (this._records.has(key)) {
        var _record = this._records.get(key);

        this._maybeAddToChanges(_record, value);

        var prev = _record._prev;
        var next = _record._next;

        if (prev) {
          prev._next = next;
        }

        if (next) {
          next._prev = prev;
        }

        _record._next = null;
        _record._prev = null;
        return _record;
      }

      var record = new KeyValueChangeRecord_(key);

      this._records.set(key, record);

      record.currentValue = value;

      this._addToAdditions(record);

      return record;
    }
    /** @internal */

  }, {
    key: "_reset",
    value: function _reset() {
      if (this.isDirty) {
        var record; // let `_previousMapHead` contain the state of the map before the changes

        this._previousMapHead = this._mapHead;

        for (record = this._previousMapHead; record !== null; record = record._next) {
          record._nextPrevious = record._next;
        } // Update `record.previousValue` with the value of the item before the changes
        // We need to update all changed items (that's those which have been added and changed)


        for (record = this._changesHead; record !== null; record = record._nextChanged) {
          record.previousValue = record.currentValue;
        }

        for (record = this._additionsHead; record != null; record = record._nextAdded) {
          record.previousValue = record.currentValue;
        }

        this._changesHead = this._changesTail = null;
        this._additionsHead = this._additionsTail = null;
        this._removalsHead = null;
      }
    } // Add the record or a given key to the list of changes only when the value has actually changed

  }, {
    key: "_maybeAddToChanges",
    value: function _maybeAddToChanges(record, newValue) {
      if (!Object.is(newValue, record.currentValue)) {
        record.previousValue = record.currentValue;
        record.currentValue = newValue;

        this._addToChanges(record);
      }
    }
  }, {
    key: "_addToAdditions",
    value: function _addToAdditions(record) {
      if (this._additionsHead === null) {
        this._additionsHead = this._additionsTail = record;
      } else {
        this._additionsTail._nextAdded = record;
        this._additionsTail = record;
      }
    }
  }, {
    key: "_addToChanges",
    value: function _addToChanges(record) {
      if (this._changesHead === null) {
        this._changesHead = this._changesTail = record;
      } else {
        this._changesTail._nextChanged = record;
        this._changesTail = record;
      }
    }
    /** @internal */

  }, {
    key: "_forEach",
    value: function _forEach(obj, fn) {
      if (obj instanceof Map) {
        obj.forEach(fn);
      } else {
        Object.keys(obj).forEach(function (k) {
          return fn(obj[k], k);
        });
      }
    }
  }, {
    key: "isDirty",
    get: function get() {
      return this._additionsHead !== null || this._changesHead !== null || this._removalsHead !== null;
    }
  }]);

  return DefaultKeyValueDiffer;
}();

var KeyValueChangeRecord_ = function KeyValueChangeRecord_(key) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, KeyValueChangeRecord_);

  this.key = key;
  this.previousValue = null;
  this.currentValue = null;
  /** @internal */

  this._nextPrevious = null;
  /** @internal */

  this._next = null;
  /** @internal */

  this._prev = null;
  /** @internal */

  this._nextAdded = null;
  /** @internal */

  this._nextRemoved = null;
  /** @internal */

  this._nextChanged = null;
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A repository of different iterable diffing strategies used by NgFor, NgClass, and others.
 *
 * @publicApi
 */


var IterableDiffers = /*#__PURE__*/function () {
  function IterableDiffers(factories) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, IterableDiffers);

    this.factories = factories;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(IterableDiffers, [{
    key: "find",
    value: function find(iterable) {
      var factory = this.factories.find(function (f) {
        return f.supports(iterable);
      });

      if (factory != null) {
        return factory;
      } else {
        throw new Error("Cannot find a differ supporting object '".concat(iterable, "' of type '").concat(getTypeNameForDebugging(iterable), "'"));
      }
    }
  }], [{
    key: "create",
    value: function create(factories, parent) {
      if (parent != null) {
        var copied = parent.factories.slice();
        factories = factories.concat(copied);
      }

      return new IterableDiffers(factories);
    }
    /**
     * Takes an array of {@link IterableDifferFactory} and returns a provider used to extend the
     * inherited {@link IterableDiffers} instance with the provided factories and return a new
     * {@link IterableDiffers} instance.
     *
     * @usageNotes
     * ### Example
     *
     * The following example shows how to extend an existing list of factories,
     * which will only be applied to the injector for this component and its children.
     * This step is all that's required to make a new {@link IterableDiffer} available.
     *
     * ```
     * @Component({
     *   viewProviders: [
     *     IterableDiffers.extend([new ImmutableListDiffer()])
     *   ]
     * })
     * ```
     */

  }, {
    key: "extend",
    value: function extend(factories) {
      return {
        provide: IterableDiffers,
        useFactory: function useFactory(parent) {
          if (!parent) {
            // Typically would occur when calling IterableDiffers.extend inside of dependencies passed
            // to
            // bootstrap(), which would override default pipes instead of extending them.
            throw new Error('Cannot extend IterableDiffers without a parent injector');
          }

          return IterableDiffers.create(factories, parent);
        },
        // Dependency technically isn't optional, but we can provide a better error message this way.
        deps: [[IterableDiffers, new SkipSelf(), new Optional()]]
      };
    }
  }]);

  return IterableDiffers;
}();
/** @nocollapse */


IterableDiffers.ɵprov = ɵɵdefineInjectable({
  token: IterableDiffers,
  providedIn: 'root',
  factory: function factory() {
    return new IterableDiffers([new DefaultIterableDifferFactory()]);
  }
});

function getTypeNameForDebugging(type) {
  return type['name'] || typeof type;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A repository of different Map diffing strategies used by NgClass, NgStyle, and others.
 *
 * @publicApi
 */


var KeyValueDiffers = /*#__PURE__*/function () {
  function KeyValueDiffers(factories) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, KeyValueDiffers);

    this.factories = factories;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(KeyValueDiffers, [{
    key: "find",
    value: function find(kv) {
      var factory = this.factories.find(function (f) {
        return f.supports(kv);
      });

      if (factory) {
        return factory;
      }

      throw new Error("Cannot find a differ supporting object '".concat(kv, "'"));
    }
  }], [{
    key: "create",
    value: function create(factories, parent) {
      if (parent) {
        var copied = parent.factories.slice();
        factories = factories.concat(copied);
      }

      return new KeyValueDiffers(factories);
    }
    /**
     * Takes an array of {@link KeyValueDifferFactory} and returns a provider used to extend the
     * inherited {@link KeyValueDiffers} instance with the provided factories and return a new
     * {@link KeyValueDiffers} instance.
     *
     * @usageNotes
     * ### Example
     *
     * The following example shows how to extend an existing list of factories,
     * which will only be applied to the injector for this component and its children.
     * This step is all that's required to make a new {@link KeyValueDiffer} available.
     *
     * ```
     * @Component({
     *   viewProviders: [
     *     KeyValueDiffers.extend([new ImmutableMapDiffer()])
     *   ]
     * })
     * ```
     */

  }, {
    key: "extend",
    value: function extend(factories) {
      return {
        provide: KeyValueDiffers,
        useFactory: function useFactory(parent) {
          if (!parent) {
            // Typically would occur when calling KeyValueDiffers.extend inside of dependencies passed
            // to bootstrap(), which would override default pipes instead of extending them.
            throw new Error('Cannot extend KeyValueDiffers without a parent injector');
          }

          return KeyValueDiffers.create(factories, parent);
        },
        // Dependency technically isn't optional, but we can provide a better error message this way.
        deps: [[KeyValueDiffers, new SkipSelf(), new Optional()]]
      };
    }
  }]);

  return KeyValueDiffers;
}();
/** @nocollapse */


KeyValueDiffers.ɵprov = ɵɵdefineInjectable({
  token: KeyValueDiffers,
  providedIn: 'root',
  factory: function factory() {
    return new KeyValueDiffers([new DefaultKeyValueDifferFactory()]);
  }
});
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Structural diffing for `Object`s and `Map`s.
 */

var keyValDiff = [new DefaultKeyValueDifferFactory()];
/**
 * Structural diffing for `Iterable` types such as `Array`s.
 */

var iterableDiff = [new DefaultIterableDifferFactory()];
var defaultIterableDiffers = new IterableDiffers(iterableDiff);
var defaultKeyValueDiffers = new KeyValueDiffers(keyValDiff);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents an embedded template that can be used to instantiate embedded views.
 * To instantiate embedded views based on a template, use the `ViewContainerRef`
 * method `createEmbeddedView()`.
 *
 * Access a `TemplateRef` instance by placing a directive on an `<ng-template>`
 * element (or directive prefixed with `*`). The `TemplateRef` for the embedded view
 * is injected into the constructor of the directive,
 * using the `TemplateRef` token.
 *
 * You can also use a `Query` to find a `TemplateRef` associated with
 * a component or a directive.
 *
 * @see `ViewContainerRef`
 * @see [Navigate the Component Tree with DI](guide/dependency-injection-navtree)
 *
 * @publicApi
 */

var TemplateRef = function TemplateRef() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TemplateRef);
};
/**
 * @internal
 * @nocollapse
 */


TemplateRef.__NG_ELEMENT_ID__ = function () {
  return SWITCH_TEMPLATE_REF_FACTORY(TemplateRef, ElementRef);
};

var SWITCH_TEMPLATE_REF_FACTORY__POST_R3__ = injectTemplateRef;
var SWITCH_TEMPLATE_REF_FACTORY__PRE_R3__ = noop;
var SWITCH_TEMPLATE_REF_FACTORY = SWITCH_TEMPLATE_REF_FACTORY__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents a container where one or more views can be attached to a component.
 *
 * Can contain *host views* (created by instantiating a
 * component with the `createComponent()` method), and *embedded views*
 * (created by instantiating a `TemplateRef` with the `createEmbeddedView()` method).
 *
 * A view container instance can contain other view containers,
 * creating a [view hierarchy](guide/glossary#view-tree).
 *
 * @see `ComponentRef`
 * @see `EmbeddedViewRef`
 *
 * @publicApi
 */

var ViewContainerRef = function ViewContainerRef() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ViewContainerRef);
};
/**
 * @internal
 * @nocollapse
 */


ViewContainerRef.__NG_ELEMENT_ID__ = function () {
  return SWITCH_VIEW_CONTAINER_REF_FACTORY(ViewContainerRef, ElementRef);
};

var SWITCH_VIEW_CONTAINER_REF_FACTORY__POST_R3__ = injectViewContainerRef;
var SWITCH_VIEW_CONTAINER_REF_FACTORY__PRE_R3__ = noop;
var SWITCH_VIEW_CONTAINER_REF_FACTORY = SWITCH_VIEW_CONTAINER_REF_FACTORY__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function expressionChangedAfterItHasBeenCheckedError(context, oldValue, currValue, isFirstCheck) {
  var msg = "ExpressionChangedAfterItHasBeenCheckedError: Expression has changed after it was checked. Previous value: '".concat(oldValue, "'. Current value: '").concat(currValue, "'.");

  if (isFirstCheck) {
    msg += " It seems like the view has been created after its parent and its children have been dirty checked." + " Has it been created in a change detection hook ?";
  }

  return viewDebugError(msg, context);
}

function viewWrappedDebugError(err, context) {
  if (!(err instanceof Error)) {
    // errors that are not Error instances don't have a stack,
    // so it is ok to wrap them into a new Error object...
    err = new Error(err.toString());
  }

  _addDebugContext(err, context);

  return err;
}

function viewDebugError(msg, context) {
  var err = new Error(msg);

  _addDebugContext(err, context);

  return err;
}

function _addDebugContext(err, context) {
  err[ERROR_DEBUG_CONTEXT] = context;
  err[ERROR_LOGGER] = context.logError.bind(context);
}

function isViewDebugError(err) {
  return !!getDebugContext(err);
}

function viewDestroyedError(action) {
  return new Error("ViewDestroyedError: Attempt to use a destroyed view: ".concat(action));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Called before each cycle of a view's check to detect whether this is in the
// initState for which we need to call ngOnInit, ngAfterContentInit or ngAfterViewInit
// lifecycle methods. Returns true if this check cycle should call lifecycle
// methods.


function shiftInitState(view, priorInitState, newInitState) {
  // Only update the InitState if we are currently in the prior state.
  // For example, only move into CallingInit if we are in BeforeInit. Only
  // move into CallingContentInit if we are in CallingInit. Normally this will
  // always be true because of how checkCycle is called in checkAndUpdateView.
  // However, if checkAndUpdateView is called recursively or if an exception is
  // thrown while checkAndUpdateView is running, checkAndUpdateView starts over
  // from the beginning. This ensures the state is monotonically increasing,
  // terminating in the AfterInit state, which ensures the Init methods are called
  // at least once and only once.
  var state = view.state;
  var initState = state & 1792
  /* InitState_Mask */
  ;

  if (initState === priorInitState) {
    view.state = state & ~1792
    /* InitState_Mask */
    | newInitState;
    view.initIndex = -1;
    return true;
  }

  return initState === newInitState;
} // Returns true if the lifecycle init method should be called for the node with
// the given init index.


function shouldCallLifecycleInitHook(view, initState, index) {
  if ((view.state & 1792
  /* InitState_Mask */
  ) === initState && view.initIndex <= index) {
    view.initIndex = index + 1;
    return true;
  }

  return false;
}
/**
 * Node instance data.
 *
 * We have a separate type per NodeType to save memory
 * (TextData | ElementData | ProviderData | PureExpressionData | QueryList<any>)
 *
 * To keep our code monomorphic,
 * we prohibit using `NodeData` directly but enforce the use of accessors (`asElementData`, ...).
 * This way, no usage site can get a `NodeData` from view.nodes and then use it for different
 * purposes.
 */


var NodeData = function NodeData() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NodeData);
};
/**
 * Accessor for view.nodes, enforcing that every usage site stays monomorphic.
 */


function asTextData(view, index) {
  return view.nodes[index];
}
/**
 * Accessor for view.nodes, enforcing that every usage site stays monomorphic.
 */


function asElementData(view, index) {
  return view.nodes[index];
}
/**
 * Accessor for view.nodes, enforcing that every usage site stays monomorphic.
 */


function asProviderData(view, index) {
  return view.nodes[index];
}
/**
 * Accessor for view.nodes, enforcing that every usage site stays monomorphic.
 */


function asPureExpressionData(view, index) {
  return view.nodes[index];
}
/**
 * Accessor for view.nodes, enforcing that every usage site stays monomorphic.
 */


function asQueryList(view, index) {
  return view.nodes[index];
}

var DebugContext = function DebugContext() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugContext);
};
/**
 * This object is used to prevent cycles in the source files and to have a place where
 * debug mode can hook it. It is lazily filled when `isDevMode` is known.
 */


var Services = {
  setCurrentNode: undefined,
  createRootView: undefined,
  createEmbeddedView: undefined,
  createComponentView: undefined,
  createNgModuleRef: undefined,
  overrideProvider: undefined,
  overrideComponentView: undefined,
  clearOverrides: undefined,
  checkAndUpdateView: undefined,
  checkNoChangesView: undefined,
  destroyView: undefined,
  resolveDep: undefined,
  createDebugContext: undefined,
  handleEvent: undefined,
  updateDirectives: undefined,
  updateRenderer: undefined,
  dirtyParentQueries: undefined
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var NOOP = function NOOP() {};

var _tokenKeyCache = new Map();

function tokenKey(token) {
  var key = _tokenKeyCache.get(token);

  if (!key) {
    key = stringify(token) + '_' + _tokenKeyCache.size;

    _tokenKeyCache.set(token, key);
  }

  return key;
}

function unwrapValue(view, nodeIdx, bindingIdx, value) {
  if (WrappedValue.isWrapped(value)) {
    value = WrappedValue.unwrap(value);
    var globalBindingIdx = view.def.nodes[nodeIdx].bindingIndex + bindingIdx;
    var oldValue = WrappedValue.unwrap(view.oldValues[globalBindingIdx]);
    view.oldValues[globalBindingIdx] = new WrappedValue(oldValue);
  }

  return value;
}

var UNDEFINED_RENDERER_TYPE_ID = '$$undefined';
var EMPTY_RENDERER_TYPE_ID = '$$empty'; // Attention: this function is called as top level function.
// Putting any logic in here will destroy closure tree shaking!

function createRendererType2(values) {
  return {
    id: UNDEFINED_RENDERER_TYPE_ID,
    styles: values.styles,
    encapsulation: values.encapsulation,
    data: values.data
  };
}

var _renderCompCount$1 = 0;

function resolveRendererType2(type) {
  if (type && type.id === UNDEFINED_RENDERER_TYPE_ID) {
    // first time we see this RendererType2. Initialize it...
    var isFilled = type.encapsulation != null && type.encapsulation !== ViewEncapsulation$1.None || type.styles.length || Object.keys(type.data).length;

    if (isFilled) {
      type.id = "c".concat(_renderCompCount$1++);
    } else {
      type.id = EMPTY_RENDERER_TYPE_ID;
    }
  }

  if (type && type.id === EMPTY_RENDERER_TYPE_ID) {
    type = null;
  }

  return type || null;
}

function checkBinding(view, def, bindingIdx, value) {
  var oldValues = view.oldValues;

  if (view.state & 2
  /* FirstCheck */
  || !Object.is(oldValues[def.bindingIndex + bindingIdx], value)) {
    return true;
  }

  return false;
}

function checkAndUpdateBinding(view, def, bindingIdx, value) {
  if (checkBinding(view, def, bindingIdx, value)) {
    view.oldValues[def.bindingIndex + bindingIdx] = value;
    return true;
  }

  return false;
}

function checkBindingNoChanges(view, def, bindingIdx, value) {
  var oldValue = view.oldValues[def.bindingIndex + bindingIdx];

  if (view.state & 1
  /* BeforeFirstCheck */
  || !devModeEqual(oldValue, value)) {
    var bindingName = def.bindings[bindingIdx].name;
    throw expressionChangedAfterItHasBeenCheckedError(Services.createDebugContext(view, def.nodeIndex), "".concat(bindingName, ": ").concat(oldValue), "".concat(bindingName, ": ").concat(value), (view.state & 1
    /* BeforeFirstCheck */
    ) !== 0);
  }
}

function markParentViewsForCheck(view) {
  var currView = view;

  while (currView) {
    if (currView.def.flags & 2
    /* OnPush */
    ) {
        currView.state |= 8
        /* ChecksEnabled */
        ;
      }

    currView = currView.viewContainerParent || currView.parent;
  }
}

function markParentViewsForCheckProjectedViews(view, endView) {
  var currView = view;

  while (currView && currView !== endView) {
    currView.state |= 64
    /* CheckProjectedViews */
    ;
    currView = currView.viewContainerParent || currView.parent;
  }
}

function dispatchEvent(view, nodeIndex, eventName, event) {
  try {
    var nodeDef = view.def.nodes[nodeIndex];
    var startView = nodeDef.flags & 33554432
    /* ComponentView */
    ? asElementData(view, nodeIndex).componentView : view;
    markParentViewsForCheck(startView);
    return Services.handleEvent(view, nodeIndex, eventName, event);
  } catch (e) {
    // Attention: Don't rethrow, as it would cancel Observable subscriptions!
    view.root.errorHandler.handleError(e);
  }
}

function declaredViewContainer(view) {
  if (view.parent) {
    var parentView = view.parent;
    return asElementData(parentView, view.parentNodeDef.nodeIndex);
  }

  return null;
}
/**
 * for component views, this is the host element.
 * for embedded views, this is the index of the parent node
 * that contains the view container.
 */


function viewParentEl(view) {
  var parentView = view.parent;

  if (parentView) {
    return view.parentNodeDef.parent;
  } else {
    return null;
  }
}

function renderNode(view, def) {
  switch (def.flags & 201347067
  /* Types */
  ) {
    case 1
    /* TypeElement */
    :
      return asElementData(view, def.nodeIndex).renderElement;

    case 2
    /* TypeText */
    :
      return asTextData(view, def.nodeIndex).renderText;
  }
}

function elementEventFullName(target, name) {
  return target ? "".concat(target, ":").concat(name) : name;
}

function isComponentView(view) {
  return !!view.parent && !!(view.parentNodeDef.flags & 32768
  /* Component */
  );
}

function isEmbeddedView(view) {
  return !!view.parent && !(view.parentNodeDef.flags & 32768
  /* Component */
  );
}

function filterQueryId(queryId) {
  return 1 << queryId % 32;
}

function splitMatchedQueriesDsl(matchedQueriesDsl) {
  var matchedQueries = {};
  var matchedQueryIds = 0;
  var references = {};

  if (matchedQueriesDsl) {
    matchedQueriesDsl.forEach(function (_ref) {
      var _ref2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_ref, 2),
          queryId = _ref2[0],
          valueType = _ref2[1];

      if (typeof queryId === 'number') {
        matchedQueries[queryId] = valueType;
        matchedQueryIds |= filterQueryId(queryId);
      } else {
        references[queryId] = valueType;
      }
    });
  }

  return {
    matchedQueries: matchedQueries,
    references: references,
    matchedQueryIds: matchedQueryIds
  };
}

function splitDepsDsl(deps, sourceName) {
  return deps.map(function (value) {
    var token;
    var flags;

    if (Array.isArray(value)) {
      var _value = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(value, 2);

      flags = _value[0];
      token = _value[1];
    } else {
      flags = 0
      /* None */
      ;
      token = value;
    }

    if (token && (typeof token === 'function' || typeof token === 'object') && sourceName) {
      Object.defineProperty(token, SOURCE, {
        value: sourceName,
        configurable: true
      });
    }

    return {
      flags: flags,
      token: token,
      tokenKey: tokenKey(token)
    };
  });
}

function getParentRenderElement(view, renderHost, def) {
  var renderParent = def.renderParent;

  if (renderParent) {
    if ((renderParent.flags & 1
    /* TypeElement */
    ) === 0 || (renderParent.flags & 33554432
    /* ComponentView */
    ) === 0 || renderParent.element.componentRendererType && renderParent.element.componentRendererType.encapsulation === ViewEncapsulation$1.Native) {
      // only children of non components, or children of components with native encapsulation should
      // be attached.
      return asElementData(view, def.renderParent.nodeIndex).renderElement;
    }
  } else {
    return renderHost;
  }
}

var DEFINITION_CACHE = new WeakMap();

function resolveDefinition(factory) {
  var value = DEFINITION_CACHE.get(factory);

  if (!value) {
    value = factory(function () {
      return NOOP;
    });
    value.factory = factory;
    DEFINITION_CACHE.set(factory, value);
  }

  return value;
}

function rootRenderNodes(view) {
  var renderNodes = [];
  visitRootRenderNodes(view, 0
  /* Collect */
  , undefined, undefined, renderNodes);
  return renderNodes;
}

function visitRootRenderNodes(view, action, parentNode, nextSibling, target) {
  // We need to re-compute the parent node in case the nodes have been moved around manually
  if (action === 3
  /* RemoveChild */
  ) {
      parentNode = view.renderer.parentNode(renderNode(view, view.def.lastRenderRootNode));
    }

  visitSiblingRenderNodes(view, action, 0, view.def.nodes.length - 1, parentNode, nextSibling, target);
}

function visitSiblingRenderNodes(view, action, startIndex, endIndex, parentNode, nextSibling, target) {
  for (var i = startIndex; i <= endIndex; i++) {
    var nodeDef = view.def.nodes[i];

    if (nodeDef.flags & (1
    /* TypeElement */
    | 2
    /* TypeText */
    | 8
    /* TypeNgContent */
    )) {
      visitRenderNode(view, nodeDef, action, parentNode, nextSibling, target);
    } // jump to next sibling


    i += nodeDef.childCount;
  }
}

function visitProjectedRenderNodes(view, ngContentIndex, action, parentNode, nextSibling, target) {
  var compView = view;

  while (compView && !isComponentView(compView)) {
    compView = compView.parent;
  }

  var hostView = compView.parent;
  var hostElDef = viewParentEl(compView);
  var startIndex = hostElDef.nodeIndex + 1;
  var endIndex = hostElDef.nodeIndex + hostElDef.childCount;

  for (var i = startIndex; i <= endIndex; i++) {
    var nodeDef = hostView.def.nodes[i];

    if (nodeDef.ngContentIndex === ngContentIndex) {
      visitRenderNode(hostView, nodeDef, action, parentNode, nextSibling, target);
    } // jump to next sibling


    i += nodeDef.childCount;
  }

  if (!hostView.parent) {
    // a root view
    var projectedNodes = view.root.projectableNodes[ngContentIndex];

    if (projectedNodes) {
      for (var _i6 = 0; _i6 < projectedNodes.length; _i6++) {
        execRenderNodeAction(view, projectedNodes[_i6], action, parentNode, nextSibling, target);
      }
    }
  }
}

function visitRenderNode(view, nodeDef, action, parentNode, nextSibling, target) {
  if (nodeDef.flags & 8
  /* TypeNgContent */
  ) {
      visitProjectedRenderNodes(view, nodeDef.ngContent.index, action, parentNode, nextSibling, target);
    } else {
    var rn = renderNode(view, nodeDef);

    if (action === 3
    /* RemoveChild */
    && nodeDef.flags & 33554432
    /* ComponentView */
    && nodeDef.bindingFlags & 48
    /* CatSyntheticProperty */
    ) {
      // Note: we might need to do both actions.
      if (nodeDef.bindingFlags & 16
      /* SyntheticProperty */
      ) {
        execRenderNodeAction(view, rn, action, parentNode, nextSibling, target);
      }

      if (nodeDef.bindingFlags & 32
      /* SyntheticHostProperty */
      ) {
        var compView = asElementData(view, nodeDef.nodeIndex).componentView;
        execRenderNodeAction(compView, rn, action, parentNode, nextSibling, target);
      }
    } else {
      execRenderNodeAction(view, rn, action, parentNode, nextSibling, target);
    }

    if (nodeDef.flags & 16777216
    /* EmbeddedViews */
    ) {
        var embeddedViews = asElementData(view, nodeDef.nodeIndex).viewContainer._embeddedViews;

        for (var k = 0; k < embeddedViews.length; k++) {
          visitRootRenderNodes(embeddedViews[k], action, parentNode, nextSibling, target);
        }
      }

    if (nodeDef.flags & 1
    /* TypeElement */
    && !nodeDef.element.name) {
      visitSiblingRenderNodes(view, action, nodeDef.nodeIndex + 1, nodeDef.nodeIndex + nodeDef.childCount, parentNode, nextSibling, target);
    }
  }
}

function execRenderNodeAction(view, renderNode, action, parentNode, nextSibling, target) {
  var renderer = view.renderer;

  switch (action) {
    case 1
    /* AppendChild */
    :
      renderer.appendChild(parentNode, renderNode);
      break;

    case 2
    /* InsertBefore */
    :
      renderer.insertBefore(parentNode, renderNode, nextSibling);
      break;

    case 3
    /* RemoveChild */
    :
      renderer.removeChild(parentNode, renderNode);
      break;

    case 0
    /* Collect */
    :
      target.push(renderNode);
      break;
  }
}

var NS_PREFIX_RE = /^:([^:]+):(.+)$/;

function splitNamespace(name) {
  if (name[0] === ':') {
    var match = name.match(NS_PREFIX_RE);
    return [match[1], match[2]];
  }

  return ['', name];
}

function calcBindingFlags(bindings) {
  var flags = 0;

  for (var i = 0; i < bindings.length; i++) {
    flags |= bindings[i].flags;
  }

  return flags;
}

function interpolate(valueCount, constAndInterp) {
  var result = '';

  for (var i = 0; i < valueCount * 2; i = i + 2) {
    result = result + constAndInterp[i] + _toStringWithNull(constAndInterp[i + 1]);
  }

  return result + constAndInterp[valueCount * 2];
}

function inlineInterpolate(valueCount, c0, a1, c1, a2, c2, a3, c3, a4, c4, a5, c5, a6, c6, a7, c7, a8, c8, a9, c9) {
  switch (valueCount) {
    case 1:
      return c0 + _toStringWithNull(a1) + c1;

    case 2:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2;

    case 3:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3;

    case 4:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3 + _toStringWithNull(a4) + c4;

    case 5:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3 + _toStringWithNull(a4) + c4 + _toStringWithNull(a5) + c5;

    case 6:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3 + _toStringWithNull(a4) + c4 + _toStringWithNull(a5) + c5 + _toStringWithNull(a6) + c6;

    case 7:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3 + _toStringWithNull(a4) + c4 + _toStringWithNull(a5) + c5 + _toStringWithNull(a6) + c6 + _toStringWithNull(a7) + c7;

    case 8:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3 + _toStringWithNull(a4) + c4 + _toStringWithNull(a5) + c5 + _toStringWithNull(a6) + c6 + _toStringWithNull(a7) + c7 + _toStringWithNull(a8) + c8;

    case 9:
      return c0 + _toStringWithNull(a1) + c1 + _toStringWithNull(a2) + c2 + _toStringWithNull(a3) + c3 + _toStringWithNull(a4) + c4 + _toStringWithNull(a5) + c5 + _toStringWithNull(a6) + c6 + _toStringWithNull(a7) + c7 + _toStringWithNull(a8) + c8 + _toStringWithNull(a9) + c9;

    default:
      throw new Error("Does not support more than 9 expressions");
  }
}

function _toStringWithNull(v) {
  return v != null ? v.toString() : '';
}

var EMPTY_ARRAY$4 = [];
var EMPTY_MAP = {};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var UNDEFINED_VALUE = {};
var InjectorRefTokenKey = tokenKey(Injector);
var INJECTORRefTokenKey = tokenKey(INJECTOR);
var NgModuleRefTokenKey = tokenKey(NgModuleRef);

function moduleProvideDef(flags, token, value, deps) {
  // Need to resolve forwardRefs as e.g. for `useValue` we
  // lowered the expression and then stopped evaluating it,
  // i.e. also didn't unwrap it.
  value = resolveForwardRef(value);
  var depDefs = splitDepsDsl(deps, stringify(token));
  return {
    // will bet set by the module definition
    index: -1,
    deps: depDefs,
    flags: flags,
    token: token,
    value: value
  };
}

function moduleDef(providers) {
  var providersByKey = {};
  var modules = [];
  var scope = null;

  for (var i = 0; i < providers.length; i++) {
    var provider = providers[i];

    if (provider.token === INJECTOR_SCOPE) {
      scope = provider.value;
    }

    if (provider.flags & 1073741824
    /* TypeNgModule */
    ) {
        modules.push(provider.token);
      }

    provider.index = i;
    providersByKey[tokenKey(provider.token)] = provider;
  }

  return {
    // Will be filled later...
    factory: null,
    providersByKey: providersByKey,
    providers: providers,
    modules: modules,
    scope: scope
  };
}

function initNgModule(data) {
  var def = data._def;
  var providers = data._providers = newArray(def.providers.length);

  for (var i = 0; i < def.providers.length; i++) {
    var provDef = def.providers[i];

    if (!(provDef.flags & 4096
    /* LazyProvider */
    )) {
      // Make sure the provider has not been already initialized outside this loop.
      if (providers[i] === undefined) {
        providers[i] = _createProviderInstance(data, provDef);
      }
    }
  }
}

function resolveNgModuleDep(data, depDef) {
  var notFoundValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Injector.THROW_IF_NOT_FOUND;
  var former = setCurrentInjector(data);

  try {
    if (depDef.flags & 8
    /* Value */
    ) {
        return depDef.token;
      }

    if (depDef.flags & 2
    /* Optional */
    ) {
        notFoundValue = null;
      }

    if (depDef.flags & 1
    /* SkipSelf */
    ) {
        return data._parent.get(depDef.token, notFoundValue);
      }

    var _tokenKey = depDef.tokenKey;

    switch (_tokenKey) {
      case InjectorRefTokenKey:
      case INJECTORRefTokenKey:
      case NgModuleRefTokenKey:
        return data;
    }

    var _providerDef = data._def.providersByKey[_tokenKey];
    var injectableDef;

    if (_providerDef) {
      var providerInstance = data._providers[_providerDef.index];

      if (providerInstance === undefined) {
        providerInstance = data._providers[_providerDef.index] = _createProviderInstance(data, _providerDef);
      }

      return providerInstance === UNDEFINED_VALUE ? undefined : providerInstance;
    } else if ((injectableDef = getInjectableDef(depDef.token)) && targetsModule(data, injectableDef)) {
      var index = data._providers.length;
      data._def.providers[index] = data._def.providersByKey[depDef.tokenKey] = {
        flags: 1024
        /* TypeFactoryProvider */
        | 4096
        /* LazyProvider */
        ,
        value: injectableDef.factory,
        deps: [],
        index: index,
        token: depDef.token
      };
      data._providers[index] = UNDEFINED_VALUE;
      return data._providers[index] = _createProviderInstance(data, data._def.providersByKey[depDef.tokenKey]);
    } else if (depDef.flags & 4
    /* Self */
    ) {
        return notFoundValue;
      }

    return data._parent.get(depDef.token, notFoundValue);
  } finally {
    setCurrentInjector(former);
  }
}

function moduleTransitivelyPresent(ngModule, scope) {
  return ngModule._def.modules.indexOf(scope) > -1;
}

function targetsModule(ngModule, def) {
  var providedIn = def.providedIn;
  return providedIn != null && (providedIn === 'any' || providedIn === ngModule._def.scope || moduleTransitivelyPresent(ngModule, providedIn));
}

function _createProviderInstance(ngModule, providerDef) {
  var injectable;

  switch (providerDef.flags & 201347067
  /* Types */
  ) {
    case 512
    /* TypeClassProvider */
    :
      injectable = _createClass(ngModule, providerDef.value, providerDef.deps);
      break;

    case 1024
    /* TypeFactoryProvider */
    :
      injectable = _callFactory(ngModule, providerDef.value, providerDef.deps);
      break;

    case 2048
    /* TypeUseExistingProvider */
    :
      injectable = resolveNgModuleDep(ngModule, providerDef.deps[0]);
      break;

    case 256
    /* TypeValueProvider */
    :
      injectable = providerDef.value;
      break;
  } // The read of `ngOnDestroy` here is slightly expensive as it's megamorphic, so it should be
  // avoided if possible. The sequence of checks here determines whether ngOnDestroy needs to be
  // checked. It might not if the `injectable` isn't an object or if NodeFlags.OnDestroy is already
  // set (ngOnDestroy was detected statically).


  if (injectable !== UNDEFINED_VALUE && injectable !== null && typeof injectable === 'object' && !(providerDef.flags & 131072
  /* OnDestroy */
  ) && typeof injectable.ngOnDestroy === 'function') {
    providerDef.flags |= 131072
    /* OnDestroy */
    ;
  }

  return injectable === undefined ? UNDEFINED_VALUE : injectable;
}

function _createClass(ngModule, ctor, deps) {
  var len = deps.length;

  switch (len) {
    case 0:
      return new ctor();

    case 1:
      return new ctor(resolveNgModuleDep(ngModule, deps[0]));

    case 2:
      return new ctor(resolveNgModuleDep(ngModule, deps[0]), resolveNgModuleDep(ngModule, deps[1]));

    case 3:
      return new ctor(resolveNgModuleDep(ngModule, deps[0]), resolveNgModuleDep(ngModule, deps[1]), resolveNgModuleDep(ngModule, deps[2]));

    default:
      var depValues = [];

      for (var i = 0; i < len; i++) {
        depValues[i] = resolveNgModuleDep(ngModule, deps[i]);
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(ctor, depValues);
  }
}

function _callFactory(ngModule, factory, deps) {
  var len = deps.length;

  switch (len) {
    case 0:
      return factory();

    case 1:
      return factory(resolveNgModuleDep(ngModule, deps[0]));

    case 2:
      return factory(resolveNgModuleDep(ngModule, deps[0]), resolveNgModuleDep(ngModule, deps[1]));

    case 3:
      return factory(resolveNgModuleDep(ngModule, deps[0]), resolveNgModuleDep(ngModule, deps[1]), resolveNgModuleDep(ngModule, deps[2]));

    default:
      var depValues = [];

      for (var i = 0; i < len; i++) {
        depValues[i] = resolveNgModuleDep(ngModule, deps[i]);
      }

      return factory.apply(void 0, depValues);
  }
}

function callNgModuleLifecycle(ngModule, lifecycles) {
  var def = ngModule._def;
  var destroyed = new Set();

  for (var i = 0; i < def.providers.length; i++) {
    var provDef = def.providers[i];

    if (provDef.flags & 131072
    /* OnDestroy */
    ) {
        var instance = ngModule._providers[i];

        if (instance && instance !== UNDEFINED_VALUE) {
          var onDestroy = instance.ngOnDestroy;

          if (typeof onDestroy === 'function' && !destroyed.has(instance)) {
            onDestroy.apply(instance);
            destroyed.add(instance);
          }
        }
      }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function attachEmbeddedView(parentView, elementData, viewIndex, view) {
  var embeddedViews = elementData.viewContainer._embeddedViews;

  if (viewIndex === null || viewIndex === undefined) {
    viewIndex = embeddedViews.length;
  }

  view.viewContainerParent = parentView;
  addToArray(embeddedViews, viewIndex, view);
  attachProjectedView(elementData, view);
  Services.dirtyParentQueries(view);
  var prevView = viewIndex > 0 ? embeddedViews[viewIndex - 1] : null;
  renderAttachEmbeddedView(elementData, prevView, view);
}

function attachProjectedView(vcElementData, view) {
  var dvcElementData = declaredViewContainer(view);

  if (!dvcElementData || dvcElementData === vcElementData || view.state & 16
  /* IsProjectedView */
  ) {
      return;
    } // Note: For performance reasons, we
  // - add a view to template._projectedViews only 1x throughout its lifetime,
  //   and remove it not until the view is destroyed.
  //   (hard, as when a parent view is attached/detached we would need to attach/detach all
  //    nested projected views as well, even across component boundaries).
  // - don't track the insertion order of views in the projected views array
  //   (hard, as when the views of the same template are inserted different view containers)


  view.state |= 16
  /* IsProjectedView */
  ;
  var projectedViews = dvcElementData.template._projectedViews;

  if (!projectedViews) {
    projectedViews = dvcElementData.template._projectedViews = [];
  }

  projectedViews.push(view); // Note: we are changing the NodeDef here as we cannot calculate
  // the fact whether a template is used for projection during compilation.

  markNodeAsProjectedTemplate(view.parent.def, view.parentNodeDef);
}

function markNodeAsProjectedTemplate(viewDef, nodeDef) {
  if (nodeDef.flags & 4
  /* ProjectedTemplate */
  ) {
      return;
    }

  viewDef.nodeFlags |= 4
  /* ProjectedTemplate */
  ;
  nodeDef.flags |= 4
  /* ProjectedTemplate */
  ;
  var parentNodeDef = nodeDef.parent;

  while (parentNodeDef) {
    parentNodeDef.childFlags |= 4
    /* ProjectedTemplate */
    ;
    parentNodeDef = parentNodeDef.parent;
  }
}

function detachEmbeddedView(elementData, viewIndex) {
  var embeddedViews = elementData.viewContainer._embeddedViews;

  if (viewIndex == null || viewIndex >= embeddedViews.length) {
    viewIndex = embeddedViews.length - 1;
  }

  if (viewIndex < 0) {
    return null;
  }

  var view = embeddedViews[viewIndex];
  view.viewContainerParent = null;
  removeFromArray(embeddedViews, viewIndex); // See attachProjectedView for why we don't update projectedViews here.

  Services.dirtyParentQueries(view);
  renderDetachView$1(view);
  return view;
}

function detachProjectedView(view) {
  if (!(view.state & 16
  /* IsProjectedView */
  )) {
    return;
  }

  var dvcElementData = declaredViewContainer(view);

  if (dvcElementData) {
    var projectedViews = dvcElementData.template._projectedViews;

    if (projectedViews) {
      removeFromArray(projectedViews, projectedViews.indexOf(view));
      Services.dirtyParentQueries(view);
    }
  }
}

function moveEmbeddedView(elementData, oldViewIndex, newViewIndex) {
  var embeddedViews = elementData.viewContainer._embeddedViews;
  var view = embeddedViews[oldViewIndex];
  removeFromArray(embeddedViews, oldViewIndex);

  if (newViewIndex == null) {
    newViewIndex = embeddedViews.length;
  }

  addToArray(embeddedViews, newViewIndex, view); // Note: Don't need to change projectedViews as the order in there
  // as always invalid...

  Services.dirtyParentQueries(view);
  renderDetachView$1(view);
  var prevView = newViewIndex > 0 ? embeddedViews[newViewIndex - 1] : null;
  renderAttachEmbeddedView(elementData, prevView, view);
  return view;
}

function renderAttachEmbeddedView(elementData, prevView, view) {
  var prevRenderNode = prevView ? renderNode(prevView, prevView.def.lastRenderRootNode) : elementData.renderElement;
  var parentNode = view.renderer.parentNode(prevRenderNode);
  var nextSibling = view.renderer.nextSibling(prevRenderNode); // Note: We can't check if `nextSibling` is present, as on WebWorkers it will always be!
  // However, browsers automatically do `appendChild` when there is no `nextSibling`.

  visitRootRenderNodes(view, 2
  /* InsertBefore */
  , parentNode, nextSibling, undefined);
}

function renderDetachView$1(view) {
  visitRootRenderNodes(view, 3
  /* RemoveChild */
  , null, null, undefined);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var EMPTY_CONTEXT = {}; // Attention: this function is called as top level function.
// Putting any logic in here will destroy closure tree shaking!

function createComponentFactory(selector, componentType, viewDefFactory, inputs, outputs, ngContentSelectors) {
  return new ComponentFactory_(selector, componentType, viewDefFactory, inputs, outputs, ngContentSelectors);
}

function getComponentViewDefinitionFactory(componentFactory) {
  return componentFactory.viewDefFactory;
}

var ComponentFactory_ = /*#__PURE__*/function (_ComponentFactory2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ComponentFactory_, _ComponentFactory2);

  var _super11 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ComponentFactory_);

  function ComponentFactory_(selector, componentType, viewDefFactory, _inputs, _outputs, ngContentSelectors) {
    var _this11;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentFactory_);

    // Attention: this ctor is called as top level function.
    // Putting any logic in here will destroy closure tree shaking!
    _this11 = _super11.call(this);
    _this11.selector = selector;
    _this11.componentType = componentType;
    _this11._inputs = _inputs;
    _this11._outputs = _outputs;
    _this11.ngContentSelectors = ngContentSelectors;
    _this11.viewDefFactory = viewDefFactory;
    return _this11;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ComponentFactory_, [{
    key: "create",

    /**
     * Creates a new component.
     */
    value: function create(injector, projectableNodes, rootSelectorOrNode, ngModule) {
      if (!ngModule) {
        throw new Error('ngModule should be provided');
      }

      var viewDef = resolveDefinition(this.viewDefFactory);
      var componentNodeIndex = viewDef.nodes[0].element.componentProvider.nodeIndex;
      var view = Services.createRootView(injector, projectableNodes || [], rootSelectorOrNode, viewDef, ngModule, EMPTY_CONTEXT);
      var component = asProviderData(view, componentNodeIndex).instance;

      if (rootSelectorOrNode) {
        view.renderer.setAttribute(asElementData(view, 0).renderElement, 'ng-version', VERSION.full);
      }

      return new ComponentRef_(view, new ViewRef_(view), component);
    }
  }, {
    key: "inputs",
    get: function get() {
      var inputsArr = [];
      var inputs = this._inputs;

      for (var propName in inputs) {
        var templateName = inputs[propName];
        inputsArr.push({
          propName: propName,
          templateName: templateName
        });
      }

      return inputsArr;
    }
  }, {
    key: "outputs",
    get: function get() {
      var outputsArr = [];

      for (var propName in this._outputs) {
        var templateName = this._outputs[propName];
        outputsArr.push({
          propName: propName,
          templateName: templateName
        });
      }

      return outputsArr;
    }
  }]);

  return ComponentFactory_;
}(ComponentFactory);

var ComponentRef_ = /*#__PURE__*/function (_ComponentRef) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ComponentRef_, _ComponentRef);

  var _super12 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ComponentRef_);

  function ComponentRef_(_view, _viewRef, _component) {
    var _this12;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentRef_);

    _this12 = _super12.call(this);
    _this12._view = _view;
    _this12._viewRef = _viewRef;
    _this12._component = _component;
    _this12._elDef = _this12._view.def.nodes[0];
    _this12.hostView = _viewRef;
    _this12.changeDetectorRef = _viewRef;
    _this12.instance = _component;
    return _this12;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ComponentRef_, [{
    key: "destroy",
    value: function destroy() {
      this._viewRef.destroy();
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      this._viewRef.onDestroy(callback);
    }
  }, {
    key: "location",
    get: function get() {
      return new ElementRef(asElementData(this._view, this._elDef.nodeIndex).renderElement);
    }
  }, {
    key: "injector",
    get: function get() {
      return new Injector_(this._view, this._elDef);
    }
  }, {
    key: "componentType",
    get: function get() {
      return this._component.constructor;
    }
  }]);

  return ComponentRef_;
}(ComponentRef);

function createViewContainerData(view, elDef, elData) {
  return new ViewContainerRef_(view, elDef, elData);
}

var ViewContainerRef_ = /*#__PURE__*/function () {
  function ViewContainerRef_(_view, _elDef, _data) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ViewContainerRef_);

    this._view = _view;
    this._elDef = _elDef;
    this._data = _data;
    /**
     * @internal
     */

    this._embeddedViews = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ViewContainerRef_, [{
    key: "clear",
    value: function clear() {
      var len = this._embeddedViews.length;

      for (var i = len - 1; i >= 0; i--) {
        var view = detachEmbeddedView(this._data, i);
        Services.destroyView(view);
      }
    }
  }, {
    key: "get",
    value: function get(index) {
      var view = this._embeddedViews[index];

      if (view) {
        var ref = new ViewRef_(view);
        ref.attachToViewContainerRef(this);
        return ref;
      }

      return null;
    }
  }, {
    key: "createEmbeddedView",
    value: function createEmbeddedView(templateRef, context, index) {
      var viewRef = templateRef.createEmbeddedView(context || {});
      this.insert(viewRef, index);
      return viewRef;
    }
  }, {
    key: "createComponent",
    value: function createComponent(componentFactory, index, injector, projectableNodes, ngModuleRef) {
      var contextInjector = injector || this.parentInjector;

      if (!ngModuleRef && !(componentFactory instanceof ComponentFactoryBoundToModule)) {
        ngModuleRef = contextInjector.get(NgModuleRef);
      }

      var componentRef = componentFactory.create(contextInjector, projectableNodes, undefined, ngModuleRef);
      this.insert(componentRef.hostView, index);
      return componentRef;
    }
  }, {
    key: "insert",
    value: function insert(viewRef, index) {
      if (viewRef.destroyed) {
        throw new Error('Cannot insert a destroyed View in a ViewContainer!');
      }

      var viewRef_ = viewRef;
      var viewData = viewRef_._view;
      attachEmbeddedView(this._view, this._data, index, viewData);
      viewRef_.attachToViewContainerRef(this);
      return viewRef;
    }
  }, {
    key: "move",
    value: function move(viewRef, currentIndex) {
      if (viewRef.destroyed) {
        throw new Error('Cannot move a destroyed View in a ViewContainer!');
      }

      var previousIndex = this._embeddedViews.indexOf(viewRef._view);

      moveEmbeddedView(this._data, previousIndex, currentIndex);
      return viewRef;
    }
  }, {
    key: "indexOf",
    value: function indexOf(viewRef) {
      return this._embeddedViews.indexOf(viewRef._view);
    }
  }, {
    key: "remove",
    value: function remove(index) {
      var viewData = detachEmbeddedView(this._data, index);

      if (viewData) {
        Services.destroyView(viewData);
      }
    }
  }, {
    key: "detach",
    value: function detach(index) {
      var view = detachEmbeddedView(this._data, index);
      return view ? new ViewRef_(view) : null;
    }
  }, {
    key: "element",
    get: function get() {
      return new ElementRef(this._data.renderElement);
    }
  }, {
    key: "injector",
    get: function get() {
      return new Injector_(this._view, this._elDef);
    }
    /** @deprecated No replacement */

  }, {
    key: "parentInjector",
    get: function get() {
      var view = this._view;
      var elDef = this._elDef.parent;

      while (!elDef && view) {
        elDef = viewParentEl(view);
        view = view.parent;
      }

      return view ? new Injector_(view, elDef) : new Injector_(this._view, null);
    }
  }, {
    key: "length",
    get: function get() {
      return this._embeddedViews.length;
    }
  }]);

  return ViewContainerRef_;
}();

function createChangeDetectorRef(view) {
  return new ViewRef_(view);
}

var ViewRef_ = /*#__PURE__*/function () {
  function ViewRef_(_view) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ViewRef_);

    this._view = _view;
    this._viewContainerRef = null;
    this._appRef = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ViewRef_, [{
    key: "markForCheck",
    value: function markForCheck() {
      markParentViewsForCheck(this._view);
    }
  }, {
    key: "detach",
    value: function detach() {
      this._view.state &= ~4
      /* Attached */
      ;
    }
  }, {
    key: "detectChanges",
    value: function detectChanges() {
      var fs = this._view.root.rendererFactory;

      if (fs.begin) {
        fs.begin();
      }

      try {
        Services.checkAndUpdateView(this._view);
      } finally {
        if (fs.end) {
          fs.end();
        }
      }
    }
  }, {
    key: "checkNoChanges",
    value: function checkNoChanges() {
      Services.checkNoChangesView(this._view);
    }
  }, {
    key: "reattach",
    value: function reattach() {
      this._view.state |= 4
      /* Attached */
      ;
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      if (!this._view.disposables) {
        this._view.disposables = [];
      }

      this._view.disposables.push(callback);
    }
  }, {
    key: "destroy",
    value: function destroy() {
      if (this._appRef) {
        this._appRef.detachView(this);
      } else if (this._viewContainerRef) {
        this._viewContainerRef.detach(this._viewContainerRef.indexOf(this));
      }

      Services.destroyView(this._view);
    }
  }, {
    key: "detachFromAppRef",
    value: function detachFromAppRef() {
      this._appRef = null;
      renderDetachView$1(this._view);
      Services.dirtyParentQueries(this._view);
    }
  }, {
    key: "attachToAppRef",
    value: function attachToAppRef(appRef) {
      if (this._viewContainerRef) {
        throw new Error('This view is already attached to a ViewContainer!');
      }

      this._appRef = appRef;
    }
  }, {
    key: "attachToViewContainerRef",
    value: function attachToViewContainerRef(vcRef) {
      if (this._appRef) {
        throw new Error('This view is already attached directly to the ApplicationRef!');
      }

      this._viewContainerRef = vcRef;
    }
  }, {
    key: "rootNodes",
    get: function get() {
      return rootRenderNodes(this._view);
    }
  }, {
    key: "context",
    get: function get() {
      return this._view.context;
    }
  }, {
    key: "destroyed",
    get: function get() {
      return (this._view.state & 128
      /* Destroyed */
      ) !== 0;
    }
  }]);

  return ViewRef_;
}();

function createTemplateData(view, def) {
  return new TemplateRef_(view, def);
}

var TemplateRef_ = /*#__PURE__*/function (_TemplateRef) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(TemplateRef_, _TemplateRef);

  var _super13 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(TemplateRef_);

  function TemplateRef_(_parentView, _def) {
    var _this13;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TemplateRef_);

    _this13 = _super13.call(this);
    _this13._parentView = _parentView;
    _this13._def = _def;
    return _this13;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TemplateRef_, [{
    key: "createEmbeddedView",
    value: function createEmbeddedView(context) {
      return new ViewRef_(Services.createEmbeddedView(this._parentView, this._def, this._def.element.template, context));
    }
  }, {
    key: "elementRef",
    get: function get() {
      return new ElementRef(asElementData(this._parentView, this._def.nodeIndex).renderElement);
    }
  }]);

  return TemplateRef_;
}(TemplateRef);

function createInjector$1(view, elDef) {
  return new Injector_(view, elDef);
}

var Injector_ = /*#__PURE__*/function () {
  function Injector_(view, elDef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Injector_);

    this.view = view;
    this.elDef = elDef;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(Injector_, [{
    key: "get",
    value: function get(token) {
      var notFoundValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Injector.THROW_IF_NOT_FOUND;
      var allowPrivateServices = this.elDef ? (this.elDef.flags & 33554432
      /* ComponentView */
      ) !== 0 : false;
      return Services.resolveDep(this.view, this.elDef, allowPrivateServices, {
        flags: 0
        /* None */
        ,
        token: token,
        tokenKey: tokenKey(token)
      }, notFoundValue);
    }
  }]);

  return Injector_;
}();

function nodeValue(view, index) {
  var def = view.def.nodes[index];

  if (def.flags & 1
  /* TypeElement */
  ) {
      var elData = asElementData(view, def.nodeIndex);
      return def.element.template ? elData.template : elData.renderElement;
    } else if (def.flags & 2
  /* TypeText */
  ) {
      return asTextData(view, def.nodeIndex).renderText;
    } else if (def.flags & (20224
  /* CatProvider */
  | 16
  /* TypePipe */
  )) {
    return asProviderData(view, def.nodeIndex).instance;
  }

  throw new Error("Illegal state: read nodeValue for node index ".concat(index));
}

function createNgModuleRef(moduleType, parent, bootstrapComponents, def) {
  return new NgModuleRef_(moduleType, parent, bootstrapComponents, def);
}

var NgModuleRef_ = /*#__PURE__*/function () {
  function NgModuleRef_(_moduleType, _parent, _bootstrapComponents, _def) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleRef_);

    this._moduleType = _moduleType;
    this._parent = _parent;
    this._bootstrapComponents = _bootstrapComponents;
    this._def = _def;
    this._destroyListeners = [];
    this._destroyed = false;
    this.injector = this;
    initNgModule(this);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NgModuleRef_, [{
    key: "get",
    value: function get(token) {
      var notFoundValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Injector.THROW_IF_NOT_FOUND;
      var injectFlags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : InjectFlags.Default;
      var flags = 0
      /* None */
      ;

      if (injectFlags & InjectFlags.SkipSelf) {
        flags |= 1
        /* SkipSelf */
        ;
      } else if (injectFlags & InjectFlags.Self) {
        flags |= 4
        /* Self */
        ;
      }

      return resolveNgModuleDep(this, {
        token: token,
        tokenKey: tokenKey(token),
        flags: flags
      }, notFoundValue);
    }
  }, {
    key: "destroy",
    value: function destroy() {
      if (this._destroyed) {
        throw new Error("The ng module ".concat(stringify(this.instance.constructor), " has already been destroyed."));
      }

      this._destroyed = true;
      callNgModuleLifecycle(this, 131072
      /* OnDestroy */
      );

      this._destroyListeners.forEach(function (listener) {
        return listener();
      });
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      this._destroyListeners.push(callback);
    }
  }, {
    key: "instance",
    get: function get() {
      return this.get(this._moduleType);
    }
  }, {
    key: "componentFactoryResolver",
    get: function get() {
      return this.get(ComponentFactoryResolver);
    }
  }]);

  return NgModuleRef_;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var Renderer2TokenKey = tokenKey(Renderer2);
var ElementRefTokenKey = tokenKey(ElementRef);
var ViewContainerRefTokenKey = tokenKey(ViewContainerRef);
var TemplateRefTokenKey = tokenKey(TemplateRef);
var ChangeDetectorRefTokenKey = tokenKey(ChangeDetectorRef);
var InjectorRefTokenKey$1 = tokenKey(Injector);
var INJECTORRefTokenKey$1 = tokenKey(INJECTOR);

function directiveDef(checkIndex, flags, matchedQueries, childCount, ctor, deps, props, outputs) {
  var bindings = [];

  if (props) {
    for (var prop in props) {
      var _props$prop = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(props[prop], 2),
          bindingIndex = _props$prop[0],
          nonMinifiedName = _props$prop[1];

      bindings[bindingIndex] = {
        flags: 8
        /* TypeProperty */
        ,
        name: prop,
        nonMinifiedName: nonMinifiedName,
        ns: null,
        securityContext: null,
        suffix: null
      };
    }
  }

  var outputDefs = [];

  if (outputs) {
    for (var propName in outputs) {
      outputDefs.push({
        type: 1
        /* DirectiveOutput */
        ,
        propName: propName,
        target: null,
        eventName: outputs[propName]
      });
    }
  }

  flags |= 16384
  /* TypeDirective */
  ;
  return _def(checkIndex, flags, matchedQueries, childCount, ctor, ctor, deps, bindings, outputDefs);
}

function pipeDef(flags, ctor, deps) {
  flags |= 16
  /* TypePipe */
  ;
  return _def(-1, flags, null, 0, ctor, ctor, deps);
}

function providerDef(flags, matchedQueries, token, value, deps) {
  return _def(-1, flags, matchedQueries, 0, token, value, deps);
}

function _def(checkIndex, flags, matchedQueriesDsl, childCount, token, value, deps, bindings, outputs) {
  var _splitMatchedQueriesD = splitMatchedQueriesDsl(matchedQueriesDsl),
      matchedQueries = _splitMatchedQueriesD.matchedQueries,
      references = _splitMatchedQueriesD.references,
      matchedQueryIds = _splitMatchedQueriesD.matchedQueryIds;

  if (!outputs) {
    outputs = [];
  }

  if (!bindings) {
    bindings = [];
  } // Need to resolve forwardRefs as e.g. for `useValue` we
  // lowered the expression and then stopped evaluating it,
  // i.e. also didn't unwrap it.


  value = resolveForwardRef(value);
  var depDefs = splitDepsDsl(deps, stringify(token));
  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    checkIndex: checkIndex,
    flags: flags,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    matchedQueries: matchedQueries,
    matchedQueryIds: matchedQueryIds,
    references: references,
    ngContentIndex: -1,
    childCount: childCount,
    bindings: bindings,
    bindingFlags: calcBindingFlags(bindings),
    outputs: outputs,
    element: null,
    provider: {
      token: token,
      value: value,
      deps: depDefs
    },
    text: null,
    query: null,
    ngContent: null
  };
}

function createProviderInstance(view, def) {
  return _createProviderInstance$1(view, def);
}

function createPipeInstance(view, def) {
  // deps are looked up from component.
  var compView = view;

  while (compView.parent && !isComponentView(compView)) {
    compView = compView.parent;
  } // pipes can see the private services of the component


  var allowPrivateServices = true; // pipes are always eager and classes!

  return createClass(compView.parent, viewParentEl(compView), allowPrivateServices, def.provider.value, def.provider.deps);
}

function createDirectiveInstance(view, def) {
  // components can see other private services, other directives can't.
  var allowPrivateServices = (def.flags & 32768
  /* Component */
  ) > 0; // directives are always eager and classes!

  var instance = createClass(view, def.parent, allowPrivateServices, def.provider.value, def.provider.deps);

  if (def.outputs.length) {
    for (var i = 0; i < def.outputs.length; i++) {
      var output = def.outputs[i];
      var outputObservable = instance[output.propName];

      if (isObservable(outputObservable)) {
        var subscription = outputObservable.subscribe(eventHandlerClosure(view, def.parent.nodeIndex, output.eventName));
        view.disposables[def.outputIndex + i] = subscription.unsubscribe.bind(subscription);
      } else {
        throw new Error("@Output ".concat(output.propName, " not initialized in '").concat(instance.constructor.name, "'."));
      }
    }
  }

  return instance;
}

function eventHandlerClosure(view, index, eventName) {
  return function (event) {
    return dispatchEvent(view, index, eventName, event);
  };
}

function checkAndUpdateDirectiveInline(view, def, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var providerData = asProviderData(view, def.nodeIndex);
  var directive = providerData.instance;
  var changed = false;
  var changes = undefined;
  var bindLen = def.bindings.length;

  if (bindLen > 0 && checkBinding(view, def, 0, v0)) {
    changed = true;
    changes = updateProp(view, providerData, def, 0, v0, changes);
  }

  if (bindLen > 1 && checkBinding(view, def, 1, v1)) {
    changed = true;
    changes = updateProp(view, providerData, def, 1, v1, changes);
  }

  if (bindLen > 2 && checkBinding(view, def, 2, v2)) {
    changed = true;
    changes = updateProp(view, providerData, def, 2, v2, changes);
  }

  if (bindLen > 3 && checkBinding(view, def, 3, v3)) {
    changed = true;
    changes = updateProp(view, providerData, def, 3, v3, changes);
  }

  if (bindLen > 4 && checkBinding(view, def, 4, v4)) {
    changed = true;
    changes = updateProp(view, providerData, def, 4, v4, changes);
  }

  if (bindLen > 5 && checkBinding(view, def, 5, v5)) {
    changed = true;
    changes = updateProp(view, providerData, def, 5, v5, changes);
  }

  if (bindLen > 6 && checkBinding(view, def, 6, v6)) {
    changed = true;
    changes = updateProp(view, providerData, def, 6, v6, changes);
  }

  if (bindLen > 7 && checkBinding(view, def, 7, v7)) {
    changed = true;
    changes = updateProp(view, providerData, def, 7, v7, changes);
  }

  if (bindLen > 8 && checkBinding(view, def, 8, v8)) {
    changed = true;
    changes = updateProp(view, providerData, def, 8, v8, changes);
  }

  if (bindLen > 9 && checkBinding(view, def, 9, v9)) {
    changed = true;
    changes = updateProp(view, providerData, def, 9, v9, changes);
  }

  if (changes) {
    directive.ngOnChanges(changes);
  }

  if (def.flags & 65536
  /* OnInit */
  && shouldCallLifecycleInitHook(view, 256
  /* InitState_CallingOnInit */
  , def.nodeIndex)) {
    directive.ngOnInit();
  }

  if (def.flags & 262144
  /* DoCheck */
  ) {
      directive.ngDoCheck();
    }

  return changed;
}

function checkAndUpdateDirectiveDynamic(view, def, values) {
  var providerData = asProviderData(view, def.nodeIndex);
  var directive = providerData.instance;
  var changed = false;
  var changes = undefined;

  for (var i = 0; i < values.length; i++) {
    if (checkBinding(view, def, i, values[i])) {
      changed = true;
      changes = updateProp(view, providerData, def, i, values[i], changes);
    }
  }

  if (changes) {
    directive.ngOnChanges(changes);
  }

  if (def.flags & 65536
  /* OnInit */
  && shouldCallLifecycleInitHook(view, 256
  /* InitState_CallingOnInit */
  , def.nodeIndex)) {
    directive.ngOnInit();
  }

  if (def.flags & 262144
  /* DoCheck */
  ) {
      directive.ngDoCheck();
    }

  return changed;
}

function _createProviderInstance$1(view, def) {
  // private services can see other private services
  var allowPrivateServices = (def.flags & 8192
  /* PrivateProvider */
  ) > 0;
  var providerDef = def.provider;

  switch (def.flags & 201347067
  /* Types */
  ) {
    case 512
    /* TypeClassProvider */
    :
      return createClass(view, def.parent, allowPrivateServices, providerDef.value, providerDef.deps);

    case 1024
    /* TypeFactoryProvider */
    :
      return callFactory(view, def.parent, allowPrivateServices, providerDef.value, providerDef.deps);

    case 2048
    /* TypeUseExistingProvider */
    :
      return resolveDep(view, def.parent, allowPrivateServices, providerDef.deps[0]);

    case 256
    /* TypeValueProvider */
    :
      return providerDef.value;
  }
}

function createClass(view, elDef, allowPrivateServices, ctor, deps) {
  var len = deps.length;

  switch (len) {
    case 0:
      return new ctor();

    case 1:
      return new ctor(resolveDep(view, elDef, allowPrivateServices, deps[0]));

    case 2:
      return new ctor(resolveDep(view, elDef, allowPrivateServices, deps[0]), resolveDep(view, elDef, allowPrivateServices, deps[1]));

    case 3:
      return new ctor(resolveDep(view, elDef, allowPrivateServices, deps[0]), resolveDep(view, elDef, allowPrivateServices, deps[1]), resolveDep(view, elDef, allowPrivateServices, deps[2]));

    default:
      var depValues = [];

      for (var i = 0; i < len; i++) {
        depValues.push(resolveDep(view, elDef, allowPrivateServices, deps[i]));
      }

      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_12__["default"])(ctor, depValues);
  }
}

function callFactory(view, elDef, allowPrivateServices, factory, deps) {
  var len = deps.length;

  switch (len) {
    case 0:
      return factory();

    case 1:
      return factory(resolveDep(view, elDef, allowPrivateServices, deps[0]));

    case 2:
      return factory(resolveDep(view, elDef, allowPrivateServices, deps[0]), resolveDep(view, elDef, allowPrivateServices, deps[1]));

    case 3:
      return factory(resolveDep(view, elDef, allowPrivateServices, deps[0]), resolveDep(view, elDef, allowPrivateServices, deps[1]), resolveDep(view, elDef, allowPrivateServices, deps[2]));

    default:
      var depValues = [];

      for (var i = 0; i < len; i++) {
        depValues.push(resolveDep(view, elDef, allowPrivateServices, deps[i]));
      }

      return factory.apply(void 0, depValues);
  }
} // This default value is when checking the hierarchy for a token.
//
// It means both:
// - the token is not provided by the current injector,
// - only the element injectors should be checked (ie do not check module injectors
//
//          mod1
//         /
//       el1   mod2
//         \  /
//         el2
//
// When requesting el2.injector.get(token), we should check in the following order and return the
// first found value:
// - el2.injector.get(token, default)
// - el1.injector.get(token, NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR) -> do not check the module
// - mod2.injector.get(token, default)


var NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR = {};

function resolveDep(view, elDef, allowPrivateServices, depDef) {
  var notFoundValue = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : Injector.THROW_IF_NOT_FOUND;

  if (depDef.flags & 8
  /* Value */
  ) {
      return depDef.token;
    }

  var startView = view;

  if (depDef.flags & 2
  /* Optional */
  ) {
      notFoundValue = null;
    }

  var tokenKey = depDef.tokenKey;

  if (tokenKey === ChangeDetectorRefTokenKey) {
    // directives on the same element as a component should be able to control the change detector
    // of that component as well.
    allowPrivateServices = !!(elDef && elDef.element.componentView);
  }

  if (elDef && depDef.flags & 1
  /* SkipSelf */
  ) {
    allowPrivateServices = false;
    elDef = elDef.parent;
  }

  var searchView = view;

  while (searchView) {
    if (elDef) {
      switch (tokenKey) {
        case Renderer2TokenKey:
          {
            var compView = findCompView(searchView, elDef, allowPrivateServices);
            return compView.renderer;
          }

        case ElementRefTokenKey:
          return new ElementRef(asElementData(searchView, elDef.nodeIndex).renderElement);

        case ViewContainerRefTokenKey:
          return asElementData(searchView, elDef.nodeIndex).viewContainer;

        case TemplateRefTokenKey:
          {
            if (elDef.element.template) {
              return asElementData(searchView, elDef.nodeIndex).template;
            }

            break;
          }

        case ChangeDetectorRefTokenKey:
          {
            var cdView = findCompView(searchView, elDef, allowPrivateServices);
            return createChangeDetectorRef(cdView);
          }

        case InjectorRefTokenKey$1:
        case INJECTORRefTokenKey$1:
          return createInjector$1(searchView, elDef);

        default:
          var _providerDef2 = (allowPrivateServices ? elDef.element.allProviders : elDef.element.publicProviders)[tokenKey];

          if (_providerDef2) {
            var providerData = asProviderData(searchView, _providerDef2.nodeIndex);

            if (!providerData) {
              providerData = {
                instance: _createProviderInstance$1(searchView, _providerDef2)
              };
              searchView.nodes[_providerDef2.nodeIndex] = providerData;
            }

            return providerData.instance;
          }

      }
    }

    allowPrivateServices = isComponentView(searchView);
    elDef = viewParentEl(searchView);
    searchView = searchView.parent;

    if (depDef.flags & 4
    /* Self */
    ) {
        searchView = null;
      }
  }

  var value = startView.root.injector.get(depDef.token, NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR);

  if (value !== NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR || notFoundValue === NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR) {
    // Return the value from the root element injector when
    // - it provides it
    //   (value !== NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR)
    // - the module injector should not be checked
    //   (notFoundValue === NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR)
    return value;
  }

  return startView.root.ngModule.injector.get(depDef.token, notFoundValue);
}

function findCompView(view, elDef, allowPrivateServices) {
  var compView;

  if (allowPrivateServices) {
    compView = asElementData(view, elDef.nodeIndex).componentView;
  } else {
    compView = view;

    while (compView.parent && !isComponentView(compView)) {
      compView = compView.parent;
    }
  }

  return compView;
}

function updateProp(view, providerData, def, bindingIdx, value, changes) {
  if (def.flags & 32768
  /* Component */
  ) {
      var compView = asElementData(view, def.parent.nodeIndex).componentView;

      if (compView.def.flags & 2
      /* OnPush */
      ) {
          compView.state |= 8
          /* ChecksEnabled */
          ;
        }
    }

  var binding = def.bindings[bindingIdx];
  var propName = binding.name; // Note: This is still safe with Closure Compiler as
  // the user passed in the property name as an object has to `providerDef`,
  // so Closure Compiler will have renamed the property correctly already.

  providerData.instance[propName] = value;

  if (def.flags & 524288
  /* OnChanges */
  ) {
      changes = changes || {};
      var oldValue = WrappedValue.unwrap(view.oldValues[def.bindingIndex + bindingIdx]);
      var _binding = def.bindings[bindingIdx];
      changes[_binding.nonMinifiedName] = new SimpleChange(oldValue, value, (view.state & 2
      /* FirstCheck */
      ) !== 0);
    }

  view.oldValues[def.bindingIndex + bindingIdx] = value;
  return changes;
} // This function calls the ngAfterContentCheck, ngAfterContentInit,
// ngAfterViewCheck, and ngAfterViewInit lifecycle hooks (depending on the node
// flags in lifecycle). Unlike ngDoCheck, ngOnChanges and ngOnInit, which are
// called during a pre-order traversal of the view tree (that is calling the
// parent hooks before the child hooks) these events are sent in using a
// post-order traversal of the tree (children before parents). This changes the
// meaning of initIndex in the view state. For ngOnInit, initIndex tracks the
// expected nodeIndex which a ngOnInit should be called. When sending
// ngAfterContentInit and ngAfterViewInit it is the expected count of
// ngAfterContentInit or ngAfterViewInit methods that have been called. This
// ensure that despite being called recursively or after picking up after an
// exception, the ngAfterContentInit or ngAfterViewInit will be called on the
// correct nodes. Consider for example, the following (where E is an element
// and D is a directive)
//  Tree:       pre-order index  post-order index
//    E1        0                6
//      E2      1                1
//       D3     2                0
//      E4      3                5
//       E5     4                4
//        E6    5                2
//        E7    6                3
// As can be seen, the post-order index has an unclear relationship to the
// pre-order index (postOrderIndex === preOrderIndex - parentCount +
// childCount). Since number of calls to ngAfterContentInit and ngAfterViewInit
// are stable (will be the same for the same view regardless of exceptions or
// recursion) we just need to count them which will roughly correspond to the
// post-order index (it skips elements and directives that do not have
// lifecycle hooks).
//
// For example, if an exception is raised in the E6.onAfterViewInit() the
// initIndex is left at 3 (by shouldCallLifecycleInitHook() which set it to
// initIndex + 1). When checkAndUpdateView() is called again D3, E2 and E6 will
// not have their ngAfterViewInit() called but, starting with E7, the rest of
// the view will begin getting ngAfterViewInit() called until a check and
// pass is complete.
//
// This algorthim also handles recursion. Consider if E4's ngAfterViewInit()
// indirectly calls E1's ChangeDetectorRef.detectChanges(). The expected
// initIndex is set to 6, the recusive checkAndUpdateView() starts walk again.
// D3, E2, E6, E7, E5 and E4 are skipped, ngAfterViewInit() is called on E1.
// When the recursion returns the initIndex will be 7 so E1 is skipped as it
// has already been called in the recursively called checkAnUpdateView().


function callLifecycleHooksChildrenFirst(view, lifecycles) {
  if (!(view.def.nodeFlags & lifecycles)) {
    return;
  }

  var nodes = view.def.nodes;
  var initIndex = 0;

  for (var i = 0; i < nodes.length; i++) {
    var nodeDef = nodes[i];
    var parent = nodeDef.parent;

    if (!parent && nodeDef.flags & lifecycles) {
      // matching root node (e.g. a pipe)
      callProviderLifecycles(view, i, nodeDef.flags & lifecycles, initIndex++);
    }

    if ((nodeDef.childFlags & lifecycles) === 0) {
      // no child matches one of the lifecycles
      i += nodeDef.childCount;
    }

    while (parent && parent.flags & 1
    /* TypeElement */
    && i === parent.nodeIndex + parent.childCount) {
      // last child of an element
      if (parent.directChildFlags & lifecycles) {
        initIndex = callElementProvidersLifecycles(view, parent, lifecycles, initIndex);
      }

      parent = parent.parent;
    }
  }
}

function callElementProvidersLifecycles(view, elDef, lifecycles, initIndex) {
  for (var i = elDef.nodeIndex + 1; i <= elDef.nodeIndex + elDef.childCount; i++) {
    var nodeDef = view.def.nodes[i];

    if (nodeDef.flags & lifecycles) {
      callProviderLifecycles(view, i, nodeDef.flags & lifecycles, initIndex++);
    } // only visit direct children


    i += nodeDef.childCount;
  }

  return initIndex;
}

function callProviderLifecycles(view, index, lifecycles, initIndex) {
  var providerData = asProviderData(view, index);

  if (!providerData) {
    return;
  }

  var provider = providerData.instance;

  if (!provider) {
    return;
  }

  Services.setCurrentNode(view, index);

  if (lifecycles & 1048576
  /* AfterContentInit */
  && shouldCallLifecycleInitHook(view, 512
  /* InitState_CallingAfterContentInit */
  , initIndex)) {
    provider.ngAfterContentInit();
  }

  if (lifecycles & 2097152
  /* AfterContentChecked */
  ) {
      provider.ngAfterContentChecked();
    }

  if (lifecycles & 4194304
  /* AfterViewInit */
  && shouldCallLifecycleInitHook(view, 768
  /* InitState_CallingAfterViewInit */
  , initIndex)) {
    provider.ngAfterViewInit();
  }

  if (lifecycles & 8388608
  /* AfterViewChecked */
  ) {
      provider.ngAfterViewChecked();
    }

  if (lifecycles & 131072
  /* OnDestroy */
  ) {
      provider.ngOnDestroy();
    }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ComponentFactoryResolver$1 = /*#__PURE__*/function (_ComponentFactoryReso) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ComponentFactoryResolver$1, _ComponentFactoryReso);

  var _super14 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ComponentFactoryResolver$1);

  /**
   * @param ngModule The NgModuleRef to which all resolved factories are bound.
   */
  function ComponentFactoryResolver$1(ngModule) {
    var _this14;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentFactoryResolver$1);

    _this14 = _super14.call(this);
    _this14.ngModule = ngModule;
    return _this14;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ComponentFactoryResolver$1, [{
    key: "resolveComponentFactory",
    value: function resolveComponentFactory(component) {
      ngDevMode && assertComponentType(component);
      var componentDef = getComponentDef(component);
      return new ComponentFactory$1(componentDef, this.ngModule);
    }
  }]);

  return ComponentFactoryResolver$1;
}(ComponentFactoryResolver);

function toRefArray(map) {
  var array = [];

  for (var nonMinified in map) {
    if (map.hasOwnProperty(nonMinified)) {
      var minified = map[nonMinified];
      array.push({
        propName: minified,
        templateName: nonMinified
      });
    }
  }

  return array;
}

function getNamespace$1(elementName) {
  var name = elementName.toLowerCase();
  return name === 'svg' ? SVG_NAMESPACE : name === 'math' ? MATH_ML_NAMESPACE : null;
}
/**
 * A change detection scheduler token for {@link RootContext}. This token is the default value used
 * for the default `RootContext` found in the {@link ROOT_CONTEXT} token.
 */


var SCHEDULER = new InjectionToken('SCHEDULER_TOKEN', {
  providedIn: 'root',
  factory: function factory() {
    return defaultScheduler;
  }
});

function createChainedInjector(rootViewInjector, moduleInjector) {
  return {
    get: function get(token, notFoundValue, flags) {
      var value = rootViewInjector.get(token, NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR, flags);

      if (value !== NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR || notFoundValue === NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR) {
        // Return the value from the root element injector when
        // - it provides it
        //   (value !== NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR)
        // - the module injector should not be checked
        //   (notFoundValue === NOT_FOUND_CHECK_ONLY_ELEMENT_INJECTOR)
        return value;
      }

      return moduleInjector.get(token, notFoundValue, flags);
    }
  };
}
/**
 * Render3 implementation of {@link viewEngine_ComponentFactory}.
 */


var ComponentFactory$1 = /*#__PURE__*/function (_ComponentFactory3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ComponentFactory$1, _ComponentFactory3);

  var _super15 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ComponentFactory$1);

  /**
   * @param componentDef The component definition.
   * @param ngModule The NgModuleRef to which the factory is bound.
   */
  function ComponentFactory$1(componentDef, ngModule) {
    var _this15;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentFactory$1);

    _this15 = _super15.call(this);
    _this15.componentDef = componentDef;
    _this15.ngModule = ngModule;
    _this15.componentType = componentDef.type;
    _this15.selector = stringifyCSSSelectorList(componentDef.selectors);
    _this15.ngContentSelectors = componentDef.ngContentSelectors ? componentDef.ngContentSelectors : [];
    _this15.isBoundToModule = !!ngModule;
    return _this15;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ComponentFactory$1, [{
    key: "create",
    value: function create(injector, projectableNodes, rootSelectorOrNode, ngModule) {
      ngModule = ngModule || this.ngModule;
      var rootViewInjector = ngModule ? createChainedInjector(injector, ngModule.injector) : injector;
      var rendererFactory = rootViewInjector.get(RendererFactory2, domRendererFactory3);
      var sanitizer = rootViewInjector.get(Sanitizer, null);
      var hostRenderer = rendererFactory.createRenderer(null, this.componentDef); // Determine a tag name used for creating host elements when this component is created
      // dynamically. Default to 'div' if this component did not specify any tag name in its selector.

      var elementName = this.componentDef.selectors[0][0] || 'div';
      var hostRNode = rootSelectorOrNode ? locateHostElement(hostRenderer, rootSelectorOrNode, this.componentDef.encapsulation) : elementCreate(elementName, rendererFactory.createRenderer(null, this.componentDef), getNamespace$1(elementName));
      var rootFlags = this.componentDef.onPush ? 64
      /* Dirty */
      | 512
      /* IsRoot */
      : 16
      /* CheckAlways */
      | 512
      /* IsRoot */
      ;
      var rootContext = createRootContext(); // Create the root view. Uses empty TView and ContentTemplate.

      var rootTView = createTView(0
      /* Root */
      , null, null, 1, 0, null, null, null, null, null);
      var rootLView = createLView(null, rootTView, rootContext, rootFlags, null, null, rendererFactory, hostRenderer, sanitizer, rootViewInjector); // rootView is the parent when bootstrapping
      // TODO(misko): it looks like we are entering view here but we don't really need to as
      // `renderView` does that. However as the code is written it is needed because
      // `createRootComponentView` and `createRootComponent` both read global state. Fixing those
      // issues would allow us to drop this.

      enterView(rootLView);
      var component;
      var tElementNode;

      try {
        var componentView = createRootComponentView(hostRNode, this.componentDef, rootLView, rendererFactory, hostRenderer);

        if (hostRNode) {
          if (rootSelectorOrNode) {
            setUpAttributes(hostRenderer, hostRNode, ['ng-version', VERSION.full]);
          } else {
            // If host element is created as a part of this function call (i.e. `rootSelectorOrNode`
            // is not defined), also apply attributes and classes extracted from component selector.
            // Extract attributes and classes from the first selector only to match VE behavior.
            var _extractAttrsAndClass = extractAttrsAndClassesFromSelector(this.componentDef.selectors[0]),
                attrs = _extractAttrsAndClass.attrs,
                classes = _extractAttrsAndClass.classes;

            if (attrs) {
              setUpAttributes(hostRenderer, hostRNode, attrs);
            }

            if (classes && classes.length > 0) {
              writeDirectClass(hostRenderer, hostRNode, classes.join(' '));
            }
          }
        }

        tElementNode = getTNode(rootTView, 0);

        if (projectableNodes !== undefined) {
          var projection = tElementNode.projection = [];

          for (var i = 0; i < this.ngContentSelectors.length; i++) {
            var nodesforSlot = projectableNodes[i]; // Projectable nodes can be passed as array of arrays or an array of iterables (ngUpgrade
            // case). Here we do normalize passed data structure to be an array of arrays to avoid
            // complex checks down the line.
            // We also normalize the length of the passed in projectable nodes (to match the number of
            // <ng-container> slots defined by a component).

            projection.push(nodesforSlot != null ? Array.from(nodesforSlot) : null);
          }
        } // TODO: should LifecycleHooksFeature and other host features be generated by the compiler and
        // executed here?
        // Angular 5 reference: https://stackblitz.com/edit/lifecycle-hooks-vcref


        component = createRootComponent(componentView, this.componentDef, rootLView, rootContext, [LifecycleHooksFeature]);
        renderView(rootTView, rootLView, null);
      } finally {
        leaveView();
      }

      return new ComponentRef$1(this.componentType, component, createElementRef(ElementRef, tElementNode, rootLView), rootLView, tElementNode);
    }
  }, {
    key: "inputs",
    get: function get() {
      return toRefArray(this.componentDef.inputs);
    }
  }, {
    key: "outputs",
    get: function get() {
      return toRefArray(this.componentDef.outputs);
    }
  }]);

  return ComponentFactory$1;
}(ComponentFactory);

var componentFactoryResolver = new ComponentFactoryResolver$1();
/**
 * Creates a ComponentFactoryResolver and stores it on the injector. Or, if the
 * ComponentFactoryResolver
 * already exists, retrieves the existing ComponentFactoryResolver.
 *
 * @returns The ComponentFactoryResolver instance to use
 */

function injectComponentFactoryResolver() {
  return componentFactoryResolver;
}
/**
 * Represents an instance of a Component created via a {@link ComponentFactory}.
 *
 * `ComponentRef` provides access to the Component Instance as well other objects related to this
 * Component Instance and allows you to destroy the Component Instance via the {@link #destroy}
 * method.
 *
 */


var ComponentRef$1 = /*#__PURE__*/function (_ComponentRef2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ComponentRef$1, _ComponentRef2);

  var _super16 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ComponentRef$1);

  function ComponentRef$1(componentType, instance, location, _rootLView, _tNode) {
    var _this16;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ComponentRef$1);

    _this16 = _super16.call(this);
    _this16.location = location;
    _this16._rootLView = _rootLView;
    _this16._tNode = _tNode;
    _this16.destroyCbs = [];
    _this16.instance = instance;
    _this16.hostView = _this16.changeDetectorRef = new RootViewRef(_rootLView);
    _this16.componentType = componentType;
    return _this16;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ComponentRef$1, [{
    key: "destroy",
    value: function destroy() {
      if (this.destroyCbs) {
        this.destroyCbs.forEach(function (fn) {
          return fn();
        });
        this.destroyCbs = null;
        !this.hostView.destroyed && this.hostView.destroy();
      }
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      if (this.destroyCbs) {
        this.destroyCbs.push(callback);
      }
    }
  }, {
    key: "injector",
    get: function get() {
      return new NodeInjector(this._tNode, this._rootLView);
    }
  }]);

  return ComponentRef$1;
}(ComponentRef);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// THIS CODE IS GENERATED - DO NOT MODIFY
// See angular/tools/gulp-tasks/cldr/extract.js


var u = undefined;

function plural(n) {
  var i = Math.floor(Math.abs(n)),
      v = n.toString().replace(/^[^.]*\.?/, '').length;
  if (i === 1 && v === 0) return 1;
  return 5;
}

var localeEn = ['en', [['a', 'p'], ['AM', 'PM'], u], [['AM', 'PM'], u, u], [['S', 'M', 'T', 'W', 'T', 'F', 'S'], ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'], ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'], ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa']], u, [['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D'], ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'], ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']], u, [['B', 'A'], ['BC', 'AD'], ['Before Christ', 'Anno Domini']], 0, [6, 0], ['M/d/yy', 'MMM d, y', 'MMMM d, y', 'EEEE, MMMM d, y'], ['h:mm a', 'h:mm:ss a', 'h:mm:ss a z', 'h:mm:ss a zzzz'], ['{1}, {0}', u, '{1} \'at\' {0}', u], ['.', ',', ';', '%', '+', '-', 'E', '×', '‰', '∞', 'NaN', ':'], ['#,##0.###', '#,##0%', '¤#,##0.00', '#E0'], 'USD', '$', 'US Dollar', {}, 'ltr', plural];
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This const is used to store the locale data registered with `registerLocaleData`
 */

var LOCALE_DATA = {};
/**
 * Register locale data to be used internally by Angular. See the
 * ["I18n guide"](guide/i18n#i18n-pipes) to know how to import additional locale data.
 *
 * The signature `registerLocaleData(data: any, extraData?: any)` is deprecated since v5.1
 */

function registerLocaleData(data, localeId, extraData) {
  if (typeof localeId !== 'string') {
    extraData = localeId;
    localeId = data[LocaleDataIndex.LocaleId];
  }

  localeId = localeId.toLowerCase().replace(/_/g, '-');
  LOCALE_DATA[localeId] = data;

  if (extraData) {
    LOCALE_DATA[localeId][LocaleDataIndex.ExtraData] = extraData;
  }
}
/**
 * Finds the locale data for a given locale.
 *
 * @param locale The locale code.
 * @returns The locale data.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 */


function findLocaleData(locale) {
  var normalizedLocale = normalizeLocale(locale);
  var match = getLocaleData(normalizedLocale);

  if (match) {
    return match;
  } // let's try to find a parent locale


  var parentLocale = normalizedLocale.split('-')[0];
  match = getLocaleData(parentLocale);

  if (match) {
    return match;
  }

  if (parentLocale === 'en') {
    return localeEn;
  }

  throw new Error("Missing locale data for the locale \"".concat(locale, "\"."));
}
/**
 * Retrieves the default currency code for the given locale.
 *
 * The default is defined as the first currency which is still in use.
 *
 * @param locale The code of the locale whose currency code we want.
 * @returns The code of the default currency for the given locale.
 *
 */


function getLocaleCurrencyCode(locale) {
  var data = findLocaleData(locale);
  return data[LocaleDataIndex.CurrencyCode] || null;
}
/**
 * Retrieves the plural function used by ICU expressions to determine the plural case to use
 * for a given locale.
 * @param locale A locale code for the locale format rules to use.
 * @returns The plural function for the locale.
 * @see `NgPlural`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 */


function getLocalePluralCase(locale) {
  var data = findLocaleData(locale);
  return data[LocaleDataIndex.PluralCase];
}
/**
 * Helper function to get the given `normalizedLocale` from `LOCALE_DATA`
 * or from the global `ng.common.locale`.
 */


function getLocaleData(normalizedLocale) {
  if (!(normalizedLocale in LOCALE_DATA)) {
    LOCALE_DATA[normalizedLocale] = _global.ng && _global.ng.common && _global.ng.common.locales && _global.ng.common.locales[normalizedLocale];
  }

  return LOCALE_DATA[normalizedLocale];
}
/**
 * Helper function to remove all the locale data from `LOCALE_DATA`.
 */


function unregisterAllLocaleData() {
  LOCALE_DATA = {};
}
/**
 * Index of each type of locale data from the locale data array
 */


var LocaleDataIndex;

(function (LocaleDataIndex) {
  LocaleDataIndex[LocaleDataIndex["LocaleId"] = 0] = "LocaleId";
  LocaleDataIndex[LocaleDataIndex["DayPeriodsFormat"] = 1] = "DayPeriodsFormat";
  LocaleDataIndex[LocaleDataIndex["DayPeriodsStandalone"] = 2] = "DayPeriodsStandalone";
  LocaleDataIndex[LocaleDataIndex["DaysFormat"] = 3] = "DaysFormat";
  LocaleDataIndex[LocaleDataIndex["DaysStandalone"] = 4] = "DaysStandalone";
  LocaleDataIndex[LocaleDataIndex["MonthsFormat"] = 5] = "MonthsFormat";
  LocaleDataIndex[LocaleDataIndex["MonthsStandalone"] = 6] = "MonthsStandalone";
  LocaleDataIndex[LocaleDataIndex["Eras"] = 7] = "Eras";
  LocaleDataIndex[LocaleDataIndex["FirstDayOfWeek"] = 8] = "FirstDayOfWeek";
  LocaleDataIndex[LocaleDataIndex["WeekendRange"] = 9] = "WeekendRange";
  LocaleDataIndex[LocaleDataIndex["DateFormat"] = 10] = "DateFormat";
  LocaleDataIndex[LocaleDataIndex["TimeFormat"] = 11] = "TimeFormat";
  LocaleDataIndex[LocaleDataIndex["DateTimeFormat"] = 12] = "DateTimeFormat";
  LocaleDataIndex[LocaleDataIndex["NumberSymbols"] = 13] = "NumberSymbols";
  LocaleDataIndex[LocaleDataIndex["NumberFormats"] = 14] = "NumberFormats";
  LocaleDataIndex[LocaleDataIndex["CurrencyCode"] = 15] = "CurrencyCode";
  LocaleDataIndex[LocaleDataIndex["CurrencySymbol"] = 16] = "CurrencySymbol";
  LocaleDataIndex[LocaleDataIndex["CurrencyName"] = 17] = "CurrencyName";
  LocaleDataIndex[LocaleDataIndex["Currencies"] = 18] = "Currencies";
  LocaleDataIndex[LocaleDataIndex["Directionality"] = 19] = "Directionality";
  LocaleDataIndex[LocaleDataIndex["PluralCase"] = 20] = "PluralCase";
  LocaleDataIndex[LocaleDataIndex["ExtraData"] = 21] = "ExtraData";
})(LocaleDataIndex || (LocaleDataIndex = {}));
/**
 * Returns the canonical form of a locale name - lowercase with `_` replaced with `-`.
 */


function normalizeLocale(locale) {
  return locale.toLowerCase().replace(/_/g, '-');
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var pluralMapping = ['zero', 'one', 'two', 'few', 'many'];
/**
 * Returns the plural case based on the locale
 */

function getPluralCase(value, locale) {
  var plural = getLocalePluralCase(locale)(parseInt(value, 10));
  var result = pluralMapping[plural];
  return result !== undefined ? result : 'other';
}
/**
 * The locale id that the application is using by default (for translations and ICU expressions).
 */


var DEFAULT_LOCALE_ID = 'en-US';
/**
 * USD currency code that the application uses by default for CurrencyPipe when no
 * DEFAULT_CURRENCY_CODE is provided.
 */

var USD_CURRENCY_CODE = 'USD';
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The locale id that the application is currently using (for translations and ICU expressions).
 * This is the ivy version of `LOCALE_ID` that was defined as an injection token for the view engine
 * but is now defined as a global value.
 */

var LOCALE_ID = DEFAULT_LOCALE_ID;
/**
 * Sets the locale id that will be used for translations and ICU expressions.
 * This is the ivy version of `LOCALE_ID` that was defined as an injection token for the view engine
 * but is now defined as a global value.
 *
 * @param localeId
 */

function setLocaleId(localeId) {
  assertDefined(localeId, "Expected localeId to be defined");

  if (typeof localeId === 'string') {
    LOCALE_ID = localeId.toLowerCase().replace(/_/g, '-');
  }
}
/**
 * Gets the locale id that will be used for translations and ICU expressions.
 * This is the ivy version of `LOCALE_ID` that was defined as an injection token for the view engine
 * but is now defined as a global value.
 */


function getLocaleId() {
  return LOCALE_ID;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * NOTE: changes to the `ngI18nClosureMode` name must be synced with `compiler-cli/src/tooling.ts`.
 */


if (typeof ngI18nClosureMode === 'undefined') {
  // These property accesses can be ignored because ngI18nClosureMode will be set to false
  // when optimizing code and the whole if statement will be dropped.
  // Make sure to refer to ngI18nClosureMode as ['ngI18nClosureMode'] for closure.
  // NOTE: we need to have it in IIFE so that the tree-shaker is happy.
  (function () {
    // tslint:disable-next-line:no-toplevel-property-access
    _global['ngI18nClosureMode'] = // TODO(FW-1250): validate that this actually, you know, works.
    // tslint:disable-next-line:no-toplevel-property-access
    typeof goog !== 'undefined' && typeof goog.getMsg === 'function';
  })();
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function getParentFromI18nMutateOpCode(mergedCode) {
  return mergedCode >>> 17
  /* SHIFT_PARENT */
  ;
}

function getRefFromI18nMutateOpCode(mergedCode) {
  return (mergedCode & 131064
  /* MASK_REF */
  ) >>> 3
  /* SHIFT_REF */
  ;
}

function getInstructionFromI18nMutateOpCode(mergedCode) {
  return mergedCode & 7
  /* MASK_INSTRUCTION */
  ;
}
/**
 * Marks that the next string is an element name.
 *
 * See `I18nMutateOpCodes` documentation.
 */


var ELEMENT_MARKER = {
  marker: 'element'
};
/**
 * Marks that the next string is comment text.
 *
 * See `I18nMutateOpCodes` documentation.
 */

var COMMENT_MARKER = {
  marker: 'comment'
}; // Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.

var unusedValueExportToPlacateAjd$6 = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var i18nIndexStack = [];
var i18nIndexStackPointer = -1;

function popI18nIndex() {
  return i18nIndexStack[i18nIndexStackPointer--];
}

function pushI18nIndex(index) {
  i18nIndexStack[++i18nIndexStackPointer] = index;
}

var changeMask = 0;
var shiftsCounter = 0;

function setMaskBit(bit) {
  if (bit) {
    changeMask = changeMask | 1 << shiftsCounter;
  }

  shiftsCounter++;
}

function applyI18n(tView, lView, index) {
  if (shiftsCounter > 0) {
    ngDevMode && assertDefined(tView, "tView should be defined");
    var tI18n = tView.data[index + HEADER_OFFSET];
    var updateOpCodes;
    var tIcus = null;

    if (Array.isArray(tI18n)) {
      updateOpCodes = tI18n;
    } else {
      updateOpCodes = tI18n.update;
      tIcus = tI18n.icus;
    }

    var bindingsStartIndex = getBindingIndex() - shiftsCounter - 1;
    applyUpdateOpCodes(tView, tIcus, lView, updateOpCodes, bindingsStartIndex, changeMask); // Reset changeMask & maskBit to default for the next update cycle

    changeMask = 0;
    shiftsCounter = 0;
  }
}
/**
 * Apply `I18nMutateOpCodes` OpCodes.
 *
 * @param tView Current `TView`
 * @param rootIndex Pointer to the root (parent) tNode for the i18n.
 * @param createOpCodes OpCodes to process
 * @param lView Current `LView`
 */


function applyCreateOpCodes(tView, rootindex, createOpCodes, lView) {
  var renderer = lView[RENDERER];
  var currentTNode = null;
  var previousTNode = null;
  var visitedNodes = [];

  for (var i = 0; i < createOpCodes.length; i++) {
    var opCode = createOpCodes[i];

    if (typeof opCode == 'string') {
      var textRNode = createTextNode(opCode, renderer);
      var textNodeIndex = createOpCodes[++i];
      ngDevMode && ngDevMode.rendererCreateTextNode++;
      previousTNode = currentTNode;
      currentTNode = createDynamicNodeAtIndex(tView, lView, textNodeIndex, 2
      /* Element */
      , textRNode, null);
      visitedNodes.push(textNodeIndex);
      setCurrentTNodeAsNotParent();
    } else if (typeof opCode == 'number') {
      switch (opCode & 7
      /* MASK_INSTRUCTION */
      ) {
        case 1
        /* AppendChild */
        :
          var destinationNodeIndex = opCode >>> 17
          /* SHIFT_PARENT */
          ;
          var destinationTNode = void 0;

          if (destinationNodeIndex === rootindex) {
            // If the destination node is `i18nStart`, we don't have a
            // top-level node and we should use the host node instead
            destinationTNode = lView[T_HOST];
          } else {
            destinationTNode = getTNode(tView, destinationNodeIndex);
          }

          ngDevMode && assertDefined(currentTNode, "You need to create or select a node before you can insert it into the DOM");
          previousTNode = appendI18nNode(tView, currentTNode, destinationTNode, previousTNode, lView);
          break;

        case 0
        /* Select */
        :
          // Negative indices indicate that a given TNode is a sibling node, not a parent node
          // (see `i18nStartFirstPass` for additional information).
          var isParent = opCode >= 0; // FIXME(misko): This SHIFT_REF looks suspect as it does not have mask.

          var nodeIndex = (isParent ? opCode : ~opCode) >>> 3
          /* SHIFT_REF */
          ;
          visitedNodes.push(nodeIndex);
          previousTNode = currentTNode;
          currentTNode = getTNode(tView, nodeIndex);

          if (currentTNode) {
            setCurrentTNode(currentTNode, isParent);
          }

          break;

        case 5
        /* ElementEnd */
        :
          var elementIndex = opCode >>> 3
          /* SHIFT_REF */
          ;
          previousTNode = currentTNode = getTNode(tView, elementIndex);
          setCurrentTNode(currentTNode, false);
          break;

        case 4
        /* Attr */
        :
          var elementNodeIndex = opCode >>> 3
          /* SHIFT_REF */
          ;
          var attrName = createOpCodes[++i];
          var attrValue = createOpCodes[++i]; // This code is used for ICU expressions only, since we don't support
          // directives/components in ICUs, we don't need to worry about inputs here

          elementAttributeInternal(getTNode(tView, elementNodeIndex), lView, attrName, attrValue, null, null);
          break;

        default:
          throw new Error("Unable to determine the type of mutate operation for \"".concat(opCode, "\""));
      }
    } else {
      switch (opCode) {
        case COMMENT_MARKER:
          var commentValue = createOpCodes[++i];
          var commentNodeIndex = createOpCodes[++i];
          ngDevMode && assertEqual(typeof commentValue, 'string', "Expected \"".concat(commentValue, "\" to be a comment node value"));
          var commentRNode = renderer.createComment(commentValue);
          ngDevMode && ngDevMode.rendererCreateComment++;
          previousTNode = currentTNode;
          currentTNode = createDynamicNodeAtIndex(tView, lView, commentNodeIndex, 4
          /* IcuContainer */
          , commentRNode, null);
          visitedNodes.push(commentNodeIndex);
          attachPatchData(commentRNode, lView); // We will add the case nodes later, during the update phase

          setCurrentTNodeAsNotParent();
          break;

        case ELEMENT_MARKER:
          var tagNameValue = createOpCodes[++i];
          var _elementNodeIndex = createOpCodes[++i];
          ngDevMode && assertEqual(typeof tagNameValue, 'string', "Expected \"".concat(tagNameValue, "\" to be an element node tag name"));
          var elementRNode = renderer.createElement(tagNameValue);
          ngDevMode && ngDevMode.rendererCreateElement++;
          previousTNode = currentTNode;
          currentTNode = createDynamicNodeAtIndex(tView, lView, _elementNodeIndex, 2
          /* Element */
          , elementRNode, tagNameValue);
          visitedNodes.push(_elementNodeIndex);
          break;

        default:
          throw new Error("Unable to determine the type of mutate operation for \"".concat(opCode, "\""));
      }
    }
  }

  setCurrentTNodeAsNotParent();
  return visitedNodes;
}
/**
 * Apply `I18nUpdateOpCodes` OpCodes
 *
 * @param tView Current `TView`
 * @param tIcus If ICUs present than this contains them.
 * @param lView Current `LView`
 * @param updateOpCodes OpCodes to process
 * @param bindingsStartIndex Location of the first `ɵɵi18nApply`
 * @param changeMask Each bit corresponds to a `ɵɵi18nExp` (Counting backwards from
 *     `bindingsStartIndex`)
 */


function applyUpdateOpCodes(tView, tIcus, lView, updateOpCodes, bindingsStartIndex, changeMask) {
  var caseCreated = false;

  for (var i = 0; i < updateOpCodes.length; i++) {
    // bit code to check if we should apply the next update
    var checkBit = updateOpCodes[i]; // Number of opCodes to skip until next set of update codes

    var skipCodes = updateOpCodes[++i];

    if (checkBit & changeMask) {
      // The value has been updated since last checked
      var value = '';

      for (var j = i + 1; j <= i + skipCodes; j++) {
        var opCode = updateOpCodes[j];

        if (typeof opCode == 'string') {
          value += opCode;
        } else if (typeof opCode == 'number') {
          if (opCode < 0) {
            // Negative opCode represent `i18nExp` values offset.
            value += renderStringify(lView[bindingsStartIndex - opCode]);
          } else {
            var nodeIndex = opCode >>> 2
            /* SHIFT_REF */
            ;

            switch (opCode & 3
            /* MASK_OPCODE */
            ) {
              case 1
              /* Attr */
              :
                var propName = updateOpCodes[++j];
                var sanitizeFn = updateOpCodes[++j];
                elementPropertyInternal(tView, getTNode(tView, nodeIndex), lView, propName, value, lView[RENDERER], sanitizeFn, false);
                break;

              case 0
              /* Text */
              :
                textBindingInternal(lView, nodeIndex, value);
                break;

              case 2
              /* IcuSwitch */
              :
                caseCreated = applyIcuSwitchCase(tView, tIcus, updateOpCodes[++j], lView, value);
                break;

              case 3
              /* IcuUpdate */
              :
                applyIcuUpdateCase(tView, tIcus, updateOpCodes[++j], bindingsStartIndex, lView, caseCreated);
                break;
            }
          }
        }
      }
    }

    i += skipCodes;
  }
}
/**
 * Apply OpCodes associated with updating an existing ICU.
 *
 * @param tView Current `TView`
 * @param tIcus ICUs active at this location.
 * @param tIcuIndex Index into `tIcus` to process.
 * @param bindingsStartIndex Location of the first `ɵɵi18nApply`
 * @param lView Current `LView`
 * @param changeMask Each bit corresponds to a `ɵɵi18nExp` (Counting backwards from
 *     `bindingsStartIndex`)
 */


function applyIcuUpdateCase(tView, tIcus, tIcuIndex, bindingsStartIndex, lView, caseCreated) {
  ngDevMode && assertIndexInRange(tIcus, tIcuIndex);
  var tIcu = tIcus[tIcuIndex];
  ngDevMode && assertIndexInRange(lView, tIcu.currentCaseLViewIndex);
  var activeCaseIndex = lView[tIcu.currentCaseLViewIndex];

  if (activeCaseIndex !== null) {
    var mask = caseCreated ? -1 : // -1 is same as all bits on, which simulates creation since it marks all bits dirty
    changeMask;
    applyUpdateOpCodes(tView, tIcus, lView, tIcu.update[activeCaseIndex], bindingsStartIndex, mask);
  }
}
/**
 * Apply OpCodes associated with switching a case on ICU.
 *
 * This involves tearing down existing case and than building up a new case.
 *
 * @param tView Current `TView`
 * @param tIcus ICUs active at this location.
 * @param tICuIndex Index into `tIcus` to process.
 * @param lView Current `LView`
 * @param value Value of the case to update to.
 * @returns true if a new case was created (needed so that the update executes regardless of the
 *     bitmask)
 */


function applyIcuSwitchCase(tView, tIcus, tICuIndex, lView, value) {
  applyIcuSwitchCaseRemove(tView, tIcus, tICuIndex, lView); // Rebuild a new case for this ICU

  var caseCreated = false;
  var tIcu = tIcus[tICuIndex];
  var caseIndex = getCaseIndex(tIcu, value);
  lView[tIcu.currentCaseLViewIndex] = caseIndex !== -1 ? caseIndex : null;

  if (caseIndex > -1) {
    // Add the nodes for the new case
    applyCreateOpCodes(tView, -1, // -1 means we don't have parent node
    tIcu.create[caseIndex], lView);
    caseCreated = true;
  }

  return caseCreated;
}
/**
 * Apply OpCodes associated with tearing down of DOM.
 *
 * This involves tearing down existing case and than building up a new case.
 *
 * @param tView Current `TView`
 * @param tIcus ICUs active at this location.
 * @param tIcuIndex Index into `tIcus` to process.
 * @param lView Current `LView`
 * @returns true if a new case was created (needed so that the update executes regardless of the
 *     bitmask)
 */


function applyIcuSwitchCaseRemove(tView, tIcus, tIcuIndex, lView) {
  ngDevMode && assertIndexInRange(tIcus, tIcuIndex);
  var tIcu = tIcus[tIcuIndex];
  var activeCaseIndex = lView[tIcu.currentCaseLViewIndex];

  if (activeCaseIndex !== null) {
    var removeCodes = tIcu.remove[activeCaseIndex];

    for (var k = 0; k < removeCodes.length; k++) {
      var removeOpCode = removeCodes[k];
      var nodeOrIcuIndex = removeOpCode >>> 3
      /* SHIFT_REF */
      ;

      switch (removeOpCode & 7
      /* MASK_INSTRUCTION */
      ) {
        case 3
        /* Remove */
        :
          // FIXME(misko): this comment is wrong!
          // Remove DOM element, but do *not* mark TNode as detached, since we are
          // just switching ICU cases (while keeping the same TNode), so a DOM element
          // representing a new ICU case will be re-created.
          removeNode(tView, lView, nodeOrIcuIndex,
          /* markAsDetached */
          false);
          break;

        case 6
        /* RemoveNestedIcu */
        :
          applyIcuSwitchCaseRemove(tView, tIcus, nodeOrIcuIndex, lView);
          break;
      }
    }
  }
}

function appendI18nNode(tView, tNode, parentTNode, previousTNode, lView) {
  ngDevMode && ngDevMode.rendererMoveNode++;
  var nextNode = tNode.next;

  if (!previousTNode) {
    previousTNode = parentTNode;
  } // Re-organize node tree to put this node in the correct position.


  if (previousTNode === parentTNode && tNode !== parentTNode.child) {
    tNode.next = parentTNode.child; // FIXME(misko): Checking `tNode.parent` is a temporary workaround until we properly
    // refactor the i18n code in #38707 and this code will be deleted.

    if (tNode.parent === null) {
      tView.firstChild = tNode;
    } else {
      parentTNode.child = tNode;
    }
  } else if (previousTNode !== parentTNode && tNode !== previousTNode.next) {
    tNode.next = previousTNode.next;
    previousTNode.next = tNode;
  } else {
    tNode.next = null;
  }

  if (parentTNode !== lView[T_HOST]) {
    tNode.parent = parentTNode;
  } // If tNode was moved around, we might need to fix a broken link.


  var cursor = tNode.next;

  while (cursor) {
    if (cursor.next === tNode) {
      cursor.next = nextNode;
    }

    cursor = cursor.next;
  } // If the placeholder to append is a projection, we need to move the projected nodes instead


  if (tNode.type === 1
  /* Projection */
  ) {
      applyProjection(tView, lView, tNode);
      return tNode;
    }

  appendChild(tView, lView, getNativeByTNode(tNode, lView), tNode);
  var slotValue = lView[tNode.index];

  if (tNode.type !== 0
  /* Container */
  && isLContainer(slotValue)) {
    // Nodes that inject ViewContainerRef also have a comment node that should be moved
    appendChild(tView, lView, slotValue[NATIVE], tNode);
  }

  return tNode;
}
/**
 * See `i18nEnd` above.
 */


function i18nEndFirstPass(tView, lView) {
  ngDevMode && assertEqual(getBindingIndex(), tView.bindingStartIndex, 'i18nEnd should be called before any binding');
  var rootIndex = popI18nIndex();
  var tI18n = tView.data[rootIndex + HEADER_OFFSET];
  ngDevMode && assertDefined(tI18n, "You should call i18nStart before i18nEnd"); // Find the last node that was added before `i18nEnd`

  var lastCreatedNode = getCurrentTNode(); // Read the instructions to insert/move/remove DOM elements

  var visitedNodes = applyCreateOpCodes(tView, rootIndex, tI18n.create, lView); // Remove deleted nodes

  var index = rootIndex + 1;

  while (lastCreatedNode !== null && index <= lastCreatedNode.index - HEADER_OFFSET) {
    if (visitedNodes.indexOf(index) === -1) {
      removeNode(tView, lView, index,
      /* markAsDetached */
      true);
    } // Check if an element has any local refs and skip them


    var tNode = getTNode(tView, index);

    if (tNode && (tNode.type === 0
    /* Container */
    || tNode.type === 2
    /* Element */
    || tNode.type === 3
    /* ElementContainer */
    ) && tNode.localNames !== null) {
      // Divide by 2 to get the number of local refs,
      // since they are stored as an array that also includes directive indexes,
      // i.e. ["localRef", directiveIndex, ...]
      index += tNode.localNames.length >> 1;
    }

    index++;
  }
}

function removeNode(tView, lView, index, markAsDetached) {
  var removedPhTNode = getTNode(tView, index);
  var removedPhRNode = getNativeByIndex(index, lView);

  if (removedPhRNode) {
    nativeRemoveNode(lView[RENDERER], removedPhRNode);
  }

  var slotValue = load(lView, index);

  if (isLContainer(slotValue)) {
    var lContainer = slotValue;

    if (removedPhTNode.type !== 0
    /* Container */
    ) {
        nativeRemoveNode(lView[RENDERER], lContainer[NATIVE]);
      }
  }

  if (markAsDetached && removedPhTNode) {
    // Define this node as detached to avoid projecting it later
    removedPhTNode.flags |= 64
    /* isDetached */
    ;
  }

  ngDevMode && ngDevMode.rendererRemoveNode++;
}
/**
 * Creates and stores the dynamic TNode, and unhooks it from the tree for now.
 */


function createDynamicNodeAtIndex(tView, lView, index, type, native, name) {
  var currentTNode = getCurrentTNode();
  ngDevMode && assertIndexInRange(lView, index + HEADER_OFFSET);
  lView[index + HEADER_OFFSET] = native; // FIXME(misko): Why does this create A TNode??? I would not expect this to be here.

  var tNode = getOrCreateTNode(tView, index, type, name, null); // We are creating a dynamic node, the previous tNode might not be pointing at this node.
  // We will link ourselves into the tree later with `appendI18nNode`.

  if (currentTNode && currentTNode.next === tNode) {
    currentTNode.next = null;
  }

  return tNode;
}
/**
 * Returns the index of the current case of an ICU expression depending on the main binding value
 *
 * @param icuExpression
 * @param bindingValue The value of the main binding used by this ICU expression
 */


function getCaseIndex(icuExpression, bindingValue) {
  var index = icuExpression.cases.indexOf(bindingValue);

  if (index === -1) {
    switch (icuExpression.type) {
      case 1
      /* plural */
      :
        {
          var resolvedCase = getPluralCase(bindingValue, getLocaleId());
          index = icuExpression.cases.indexOf(resolvedCase);

          if (index === -1 && resolvedCase !== 'other') {
            index = icuExpression.cases.indexOf('other');
          }

          break;
        }

      case 0
      /* select */
      :
        {
          index = icuExpression.cases.indexOf('other');
          break;
        }
    }
  }

  return index;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Converts `I18nUpdateOpCodes` array into a human readable format.
 *
 * This function is attached to the `I18nUpdateOpCodes.debug` property if `ngDevMode` is enabled.
 * This function provides a human readable view of the opcodes. This is useful when debugging the
 * application as well as writing more readable tests.
 *
 * @param this `I18nUpdateOpCodes` if attached as a method.
 * @param opcodes `I18nUpdateOpCodes` if invoked as a function.
 */


function i18nUpdateOpCodesToString(opcodes) {
  var parser = new OpCodeParser(opcodes || (Array.isArray(this) ? this : []));
  var lines = [];

  function consumeOpCode(value) {
    var ref = value >>> 2
    /* SHIFT_REF */
    ;
    var opCode = value & 3
    /* MASK_OPCODE */
    ;

    switch (opCode) {
      case 0
      /* Text */
      :
        return "(lView[".concat(ref, "] as Text).textContent = $$$");

      case 1
      /* Attr */
      :
        var attrName = parser.consumeString();
        var sanitizationFn = parser.consumeFunction();

        var _value2 = sanitizationFn ? "(".concat(sanitizationFn, ")($$$)") : '$$$';

        return "(lView[".concat(ref, "] as Element).setAttribute('").concat(attrName, "', ").concat(_value2, ")");

      case 2
      /* IcuSwitch */
      :
        return "icuSwitchCase(lView[".concat(ref, "] as Comment, ").concat(parser.consumeNumber(), ", $$$)");

      case 3
      /* IcuUpdate */
      :
        return "icuUpdateCase(lView[".concat(ref, "] as Comment, ").concat(parser.consumeNumber(), ")");
    }

    throw new Error('unexpected OpCode');
  }

  while (parser.hasMore()) {
    var mask = parser.consumeNumber();
    var size = parser.consumeNumber();
    var end = parser.i + size;
    var statements = [];
    var statement = '';

    while (parser.i < end) {
      var value = parser.consumeNumberOrString();

      if (typeof value === 'string') {
        statement += value;
      } else if (value < 0) {
        // Negative numbers are ref indexes
        statement += '${lView[' + (0 - value) + ']}';
      } else {
        // Positive numbers are operations.
        var opCodeText = consumeOpCode(value);
        statements.push(opCodeText.replace('$$$', '`' + statement + '`') + ';');
        statement = '';
      }
    }

    lines.push("if (mask & 0b".concat(mask.toString(2), ") { ").concat(statements.join(' '), " }"));
  }

  return lines;
}
/**
 * Converts `I18nMutableOpCodes` array into a human readable format.
 *
 * This function is attached to the `I18nMutableOpCodes.debug` if `ngDevMode` is enabled. This
 * function provides a human readable view of the opcodes. This is useful when debugging the
 * application as well as writing more readable tests.
 *
 * @param this `I18nMutableOpCodes` if attached as a method.
 * @param opcodes `I18nMutableOpCodes` if invoked as a function.
 */


function i18nMutateOpCodesToString(opcodes) {
  var parser = new OpCodeParser(opcodes || (Array.isArray(this) ? this : []));
  var lines = [];

  function consumeOpCode(opCode) {
    var parent = getParentFromI18nMutateOpCode(opCode);
    var ref = getRefFromI18nMutateOpCode(opCode);

    switch (getInstructionFromI18nMutateOpCode(opCode)) {
      case 0
      /* Select */
      :
        lastRef = ref;
        return '';

      case 1
      /* AppendChild */
      :
        return "(lView[".concat(parent, "] as Element).appendChild(lView[").concat(lastRef, "])");

      case 3
      /* Remove */
      :
        return "(lView[".concat(parent, "] as Element).remove(lView[").concat(ref, "])");

      case 4
      /* Attr */
      :
        return "(lView[".concat(ref, "] as Element).setAttribute(\"").concat(parser.consumeString(), "\", \"").concat(parser.consumeString(), "\")");

      case 5
      /* ElementEnd */
      :
        return "setCurrentTNode(tView.data[".concat(ref, "] as TNode)");

      case 6
      /* RemoveNestedIcu */
      :
        return "removeNestedICU(".concat(ref, ")");
    }

    throw new Error('Unexpected OpCode');
  }

  var lastRef = -1;

  while (parser.hasMore()) {
    var value = parser.consumeNumberStringOrMarker();

    if (value === COMMENT_MARKER) {
      var text = parser.consumeString();
      lastRef = parser.consumeNumber();
      lines.push("lView[".concat(lastRef, "] = document.createComment(\"").concat(text, "\")"));
    } else if (value === ELEMENT_MARKER) {
      var _text = parser.consumeString();

      lastRef = parser.consumeNumber();
      lines.push("lView[".concat(lastRef, "] = document.createElement(\"").concat(_text, "\")"));
    } else if (typeof value === 'string') {
      lastRef = parser.consumeNumber();
      lines.push("lView[".concat(lastRef, "] = document.createTextNode(\"").concat(value, "\")"));
    } else if (typeof value === 'number') {
      var line = consumeOpCode(value);
      line && lines.push(line);
    } else {
      throw new Error('Unexpected value');
    }
  }

  return lines;
}

var OpCodeParser = /*#__PURE__*/function () {
  function OpCodeParser(codes) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, OpCodeParser);

    this.i = 0;
    this.codes = codes;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(OpCodeParser, [{
    key: "hasMore",
    value: function hasMore() {
      return this.i < this.codes.length;
    }
  }, {
    key: "consumeNumber",
    value: function consumeNumber() {
      var value = this.codes[this.i++];
      assertNumber(value, 'expecting number in OpCode');
      return value;
    }
  }, {
    key: "consumeString",
    value: function consumeString() {
      var value = this.codes[this.i++];
      assertString(value, 'expecting string in OpCode');
      return value;
    }
  }, {
    key: "consumeFunction",
    value: function consumeFunction() {
      var value = this.codes[this.i++];

      if (value === null || typeof value === 'function') {
        return value;
      }

      throw new Error('expecting function in OpCode');
    }
  }, {
    key: "consumeNumberOrString",
    value: function consumeNumberOrString() {
      var value = this.codes[this.i++];

      if (typeof value === 'string') {
        return value;
      }

      assertNumber(value, 'expecting number or string in OpCode');
      return value;
    }
  }, {
    key: "consumeNumberStringOrMarker",
    value: function consumeNumberStringOrMarker() {
      var value = this.codes[this.i++];

      if (typeof value === 'string' || typeof value === 'number' || value == COMMENT_MARKER || value == ELEMENT_MARKER) {
        return value;
      }

      assertNumber(value, 'expecting number, string, COMMENT_MARKER or ELEMENT_MARKER in OpCode');
      return value;
    }
  }]);

  return OpCodeParser;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var BINDING_REGEXP = /�(\d+):?\d*�/gi;
var ICU_REGEXP = /({\s*�\d+:?\d*�\s*,\s*\S{6}\s*,[\s\S]*})/gi;
var NESTED_ICU = /�(\d+)�/;
var ICU_BLOCK_REGEXP = /^\s*(�\d+:?\d*�)\s*,\s*(select|plural)\s*,/; // Count for the number of vars that will be allocated for each i18n block.
// It is global because this is used in multiple functions that include loops and recursive calls.
// This is reset to 0 when `i18nStartFirstPass` is called.

var i18nVarsCount;
var parentIndexStack = [];
var MARKER = "\uFFFD";
var SUBTEMPLATE_REGEXP = /�\/?\*(\d+:\d+)�/gi;
var PH_REGEXP = /�(\/?[#*!]\d+):?\d*�/gi;
/**
 * Angular Dart introduced &ngsp; as a placeholder for non-removable space, see:
 * https://github.com/dart-lang/angular/blob/0bb611387d29d65b5af7f9d2515ab571fd3fbee4/_tests/test/compiler/preserve_whitespace_test.dart#L25-L32
 * In Angular Dart &ngsp; is converted to the 0xE500 PUA (Private Use Areas) unicode character
 * and later on replaced by a space. We are re-implementing the same idea here, since translations
 * might contain this special character.
 */

var NGSP_UNICODE_REGEXP = /\uE500/g;

function replaceNgsp(value) {
  return value.replace(NGSP_UNICODE_REGEXP, ' ');
}
/**
 * See `i18nStart` above.
 */


function i18nStartFirstPass(lView, tView, index, message, subTemplateIndex) {
  var startIndex = tView.blueprint.length - HEADER_OFFSET;
  i18nVarsCount = 0;
  var currentTNode = getCurrentTNode();
  var parentTNode = isCurrentTNodeParent() ? currentTNode : currentTNode && currentTNode.parent;
  var parentIndex = parentTNode && parentTNode !== lView[T_HOST] ? parentTNode.index - HEADER_OFFSET : index;
  var parentIndexPointer = 0;
  parentIndexStack[parentIndexPointer] = parentIndex;
  var createOpCodes = [];

  if (ngDevMode) {
    attachDebugGetter(createOpCodes, i18nMutateOpCodesToString);
  } // If the previous node wasn't the direct parent then we have a translation without top level
  // element and we need to keep a reference of the previous element if there is one. We should also
  // keep track whether an element was a parent node or not, so that the logic that consumes
  // the generated `I18nMutateOpCode`s can leverage this information to properly set TNode state
  // (whether it's a parent or sibling).


  if (index > 0 && currentTNode !== parentTNode) {
    var previousTNodeIndex = currentTNode.index - HEADER_OFFSET; // If current TNode is a sibling node, encode it using a negative index. This information is
    // required when the `Select` action is processed (see the `readCreateOpCodes` function).

    if (!isCurrentTNodeParent()) {
      previousTNodeIndex = ~previousTNodeIndex;
    } // Create an OpCode to select the previous TNode


    createOpCodes.push(previousTNodeIndex << 3
    /* SHIFT_REF */
    | 0
    /* Select */
    );
  }

  var updateOpCodes = [];

  if (ngDevMode) {
    attachDebugGetter(updateOpCodes, i18nUpdateOpCodesToString);
  }

  var icuExpressions = [];

  if (message === '' && isRootTemplateMessage(subTemplateIndex)) {
    // If top level translation is an empty string, do not invoke additional processing
    // and just create op codes for empty text node instead.
    createOpCodes.push(message, allocNodeIndex(startIndex), parentIndex << 17
    /* SHIFT_PARENT */
    | 1
    /* AppendChild */
    );
  } else {
    var templateTranslation = getTranslationForTemplate(message, subTemplateIndex);
    var msgParts = replaceNgsp(templateTranslation).split(PH_REGEXP);

    for (var i = 0; i < msgParts.length; i++) {
      var value = msgParts[i];

      if (i & 1) {
        // Odd indexes are placeholders (elements and sub-templates)
        if (value.charAt(0) === '/') {
          // It is a closing tag
          if (value.charAt(1) === "#"
          /* ELEMENT */
          ) {
              var phIndex = parseInt(value.substr(2), 10);
              parentIndex = parentIndexStack[--parentIndexPointer];
              createOpCodes.push(phIndex << 3
              /* SHIFT_REF */
              | 5
              /* ElementEnd */
              );
            }
        } else {
          var _phIndex = parseInt(value.substr(1), 10);

          var isElement = value.charAt(0) === "#"
          /* ELEMENT */
          ; // The value represents a placeholder that we move to the designated index.
          // Note: positive indicies indicate that a TNode with a given index should also be marked
          // as parent while executing `Select` instruction.

          createOpCodes.push((isElement ? _phIndex : ~_phIndex) << 3
          /* SHIFT_REF */
          | 0
          /* Select */
          , parentIndex << 17
          /* SHIFT_PARENT */
          | 1
          /* AppendChild */
          );

          if (isElement) {
            parentIndexStack[++parentIndexPointer] = parentIndex = _phIndex;
          }
        }
      } else {
        // Even indexes are text (including bindings & ICU expressions)
        var parts = extractParts(value);

        for (var j = 0; j < parts.length; j++) {
          if (j & 1) {
            // Odd indexes are ICU expressions
            var icuExpression = parts[j]; // Verify that ICU expression has the right shape. Translations might contain invalid
            // constructions (while original messages were correct), so ICU parsing at runtime may
            // not succeed (thus `icuExpression` remains a string).

            if (typeof icuExpression !== 'object') {
              throw new Error("Unable to parse ICU expression in \"".concat(templateTranslation, "\" message."));
            } // Create the comment node that will anchor the ICU expression


            var icuNodeIndex = allocNodeIndex(startIndex);
            createOpCodes.push(COMMENT_MARKER, ngDevMode ? "ICU ".concat(icuNodeIndex) : '', icuNodeIndex, parentIndex << 17
            /* SHIFT_PARENT */
            | 1
            /* AppendChild */
            ); // Update codes for the ICU expression

            var mask = getBindingMask(icuExpression);
            icuStart(icuExpressions, icuExpression, icuNodeIndex, icuNodeIndex); // Since this is recursive, the last TIcu that was pushed is the one we want

            var tIcuIndex = icuExpressions.length - 1;
            updateOpCodes.push(toMaskBit(icuExpression.mainBinding), // mask of the main binding
            3, // skip 3 opCodes if not changed
            -1 - icuExpression.mainBinding, icuNodeIndex << 2
            /* SHIFT_REF */
            | 2
            /* IcuSwitch */
            , tIcuIndex, mask, // mask of all the bindings of this ICU expression
            2, // skip 2 opCodes if not changed
            icuNodeIndex << 2
            /* SHIFT_REF */
            | 3
            /* IcuUpdate */
            , tIcuIndex);
          } else if (parts[j] !== '') {
            var text = parts[j]; // Even indexes are text (including bindings)

            var hasBinding = text.match(BINDING_REGEXP); // Create text nodes

            var textNodeIndex = allocNodeIndex(startIndex);
            createOpCodes.push( // If there is a binding, the value will be set during update
            hasBinding ? '' : text, textNodeIndex, parentIndex << 17
            /* SHIFT_PARENT */
            | 1
            /* AppendChild */
            );

            if (hasBinding) {
              addAllToArray(generateBindingUpdateOpCodes(text, textNodeIndex), updateOpCodes);
            }
          }
        }
      }
    }
  }

  if (i18nVarsCount > 0) {
    allocExpando(tView, lView, i18nVarsCount);
  } // NOTE: local var needed to properly assert the type of `TI18n`.


  var tI18n = {
    vars: i18nVarsCount,
    create: createOpCodes,
    update: updateOpCodes,
    icus: icuExpressions.length ? icuExpressions : null
  };
  tView.data[index + HEADER_OFFSET] = tI18n;
}
/**
 * See `i18nAttributes` above.
 */


function i18nAttributesFirstPass(lView, tView, index, values) {
  var previousElement = getCurrentTNode();
  var previousElementIndex = previousElement.index - HEADER_OFFSET;
  var updateOpCodes = [];

  if (ngDevMode) {
    attachDebugGetter(updateOpCodes, i18nUpdateOpCodesToString);
  }

  for (var i = 0; i < values.length; i += 2) {
    var attrName = values[i];
    var message = values[i + 1];
    var parts = message.split(ICU_REGEXP);

    for (var j = 0; j < parts.length; j++) {
      var value = parts[j];

      if (j & 1) {
        // Odd indexes are ICU expressions
        // TODO(ocombe): support ICU expressions in attributes
        throw new Error('ICU expressions are not yet supported in attributes');
      } else if (value !== '') {
        // Even indexes are text (including bindings)
        var hasBinding = !!value.match(BINDING_REGEXP);

        if (hasBinding) {
          if (tView.firstCreatePass && tView.data[index + HEADER_OFFSET] === null) {
            addAllToArray(generateBindingUpdateOpCodes(value, previousElementIndex, attrName), updateOpCodes);
          }
        } else {
          var tNode = getTNode(tView, previousElementIndex); // Set attributes for Elements only, for other types (like ElementContainer),
          // only set inputs below

          if (tNode.type === 2
          /* Element */
          ) {
              elementAttributeInternal(tNode, lView, attrName, value, null, null);
            } // Check if that attribute is a directive input


          var dataValue = tNode.inputs !== null && tNode.inputs[attrName];

          if (dataValue) {
            setInputsForProperty(tView, lView, dataValue, attrName, value);

            if (ngDevMode) {
              var element = getNativeByIndex(previousElementIndex, lView);
              setNgReflectProperties(lView, element, tNode.type, dataValue, value);
            }
          }
        }
      }
    }
  }

  if (tView.firstCreatePass && tView.data[index + HEADER_OFFSET] === null) {
    tView.data[index + HEADER_OFFSET] = updateOpCodes;
  }
}
/**
 * Generate the OpCodes to update the bindings of a string.
 *
 * @param str The string containing the bindings.
 * @param destinationNode Index of the destination node which will receive the binding.
 * @param attrName Name of the attribute, if the string belongs to an attribute.
 * @param sanitizeFn Sanitization function used to sanitize the string after update, if necessary.
 */


function generateBindingUpdateOpCodes(str, destinationNode, attrName) {
  var sanitizeFn = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
  var updateOpCodes = [null, null]; // Alloc space for mask and size

  if (ngDevMode) {
    attachDebugGetter(updateOpCodes, i18nUpdateOpCodesToString);
  }

  var textParts = str.split(BINDING_REGEXP);
  var mask = 0;

  for (var j = 0; j < textParts.length; j++) {
    var textValue = textParts[j];

    if (j & 1) {
      // Odd indexes are bindings
      var bindingIndex = parseInt(textValue, 10);
      updateOpCodes.push(-1 - bindingIndex);
      mask = mask | toMaskBit(bindingIndex);
    } else if (textValue !== '') {
      // Even indexes are text
      updateOpCodes.push(textValue);
    }
  }

  updateOpCodes.push(destinationNode << 2
  /* SHIFT_REF */
  | (attrName ? 1
  /* Attr */
  : 0
  /* Text */
  ));

  if (attrName) {
    updateOpCodes.push(attrName, sanitizeFn);
  }

  updateOpCodes[0] = mask;
  updateOpCodes[1] = updateOpCodes.length - 2;
  return updateOpCodes;
}

function getBindingMask(icuExpression) {
  var mask = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  mask = mask | toMaskBit(icuExpression.mainBinding);
  var match;

  for (var i = 0; i < icuExpression.values.length; i++) {
    var valueArr = icuExpression.values[i];

    for (var j = 0; j < valueArr.length; j++) {
      var value = valueArr[j];

      if (typeof value === 'string') {
        while (match = BINDING_REGEXP.exec(value)) {
          mask = mask | toMaskBit(parseInt(match[1], 10));
        }
      } else {
        mask = getBindingMask(value, mask);
      }
    }
  }

  return mask;
}

function allocNodeIndex(startIndex) {
  return startIndex + i18nVarsCount++;
}
/**
 * Convert binding index to mask bit.
 *
 * Each index represents a single bit on the bit-mask. Because bit-mask only has 32 bits, we make
 * the 32nd bit share all masks for all bindings higher than 32. Since it is extremely rare to have
 * more than 32 bindings this will be hit very rarely. The downside of hitting this corner case is
 * that we will execute binding code more often than necessary. (penalty of performance)
 */


function toMaskBit(bindingIndex) {
  return 1 << Math.min(bindingIndex, 31);
}

function isRootTemplateMessage(subTemplateIndex) {
  return subTemplateIndex === undefined;
}
/**
 * Removes everything inside the sub-templates of a message.
 */


function removeInnerTemplateTranslation(message) {
  var match;
  var res = '';
  var index = 0;
  var inTemplate = false;
  var tagMatched;

  while ((match = SUBTEMPLATE_REGEXP.exec(message)) !== null) {
    if (!inTemplate) {
      res += message.substring(index, match.index + match[0].length);
      tagMatched = match[1];
      inTemplate = true;
    } else {
      if (match[0] === "".concat(MARKER, "/*").concat(tagMatched).concat(MARKER)) {
        index = match.index;
        inTemplate = false;
      }
    }
  }

  ngDevMode && assertEqual(inTemplate, false, "Tag mismatch: unable to find the end of the sub-template in the translation \"".concat(message, "\""));
  res += message.substr(index);
  return res;
}
/**
 * Extracts a part of a message and removes the rest.
 *
 * This method is used for extracting a part of the message associated with a template. A translated
 * message can span multiple templates.
 *
 * Example:
 * ```
 * <div i18n>Translate <span *ngIf>me</span>!</div>
 * ```
 *
 * @param message The message to crop
 * @param subTemplateIndex Index of the sub-template to extract. If undefined it returns the
 * external template and removes all sub-templates.
 */


function getTranslationForTemplate(message, subTemplateIndex) {
  if (isRootTemplateMessage(subTemplateIndex)) {
    // We want the root template message, ignore all sub-templates
    return removeInnerTemplateTranslation(message);
  } else {
    // We want a specific sub-template
    var start = message.indexOf(":".concat(subTemplateIndex).concat(MARKER)) + 2 + subTemplateIndex.toString().length;
    var end = message.search(new RegExp("".concat(MARKER, "\\/\\*\\d+:").concat(subTemplateIndex).concat(MARKER)));
    return removeInnerTemplateTranslation(message.substring(start, end));
  }
}
/**
 * Generate the OpCodes for ICU expressions.
 *
 * @param tIcus
 * @param icuExpression
 * @param startIndex
 * @param expandoStartIndex
 */


function icuStart(tIcus, icuExpression, startIndex, expandoStartIndex) {
  var createCodes = [];
  var removeCodes = [];
  var updateCodes = [];
  var vars = [];
  var childIcus = [];
  var values = icuExpression.values;

  for (var i = 0; i < values.length; i++) {
    // Each value is an array of strings & other ICU expressions
    var valueArr = values[i];
    var nestedIcus = [];

    for (var j = 0; j < valueArr.length; j++) {
      var value = valueArr[j];

      if (typeof value !== 'string') {
        // It is an nested ICU expression
        var icuIndex = nestedIcus.push(value) - 1; // Replace nested ICU expression by a comment node

        valueArr[j] = "<!--\uFFFD".concat(icuIndex, "\uFFFD-->");
      }
    }

    var icuCase = parseIcuCase(valueArr.join(''), startIndex, nestedIcus, tIcus, expandoStartIndex);
    createCodes.push(icuCase.create);
    removeCodes.push(icuCase.remove);
    updateCodes.push(icuCase.update);
    vars.push(icuCase.vars);
    childIcus.push(icuCase.childIcus);
  }

  var tIcu = {
    type: icuExpression.type,
    vars: vars,
    currentCaseLViewIndex: HEADER_OFFSET + expandoStartIndex // expandoStartIndex does not include the header so add it.
    + 1,
    childIcus: childIcus,
    cases: icuExpression.cases,
    create: createCodes,
    remove: removeCodes,
    update: updateCodes
  };
  tIcus.push(tIcu); // Adding the maximum possible of vars needed (based on the cases with the most vars)

  i18nVarsCount += Math.max.apply(Math, vars);
}
/**
 * Parses text containing an ICU expression and produces a JSON object for it.
 * Original code from closure library, modified for Angular.
 *
 * @param pattern Text containing an ICU expression that needs to be parsed.
 *
 */


function parseICUBlock(pattern) {
  var cases = [];
  var values = [];
  var icuType = 1
  /* plural */
  ;
  var mainBinding = 0;
  pattern = pattern.replace(ICU_BLOCK_REGEXP, function (str, binding, type) {
    if (type === 'select') {
      icuType = 0
      /* select */
      ;
    } else {
      icuType = 1
      /* plural */
      ;
    }

    mainBinding = parseInt(binding.substr(1), 10);
    return '';
  });
  var parts = extractParts(pattern); // Looking for (key block)+ sequence. One of the keys has to be "other".

  for (var pos = 0; pos < parts.length;) {
    var key = parts[pos++].trim();

    if (icuType === 1
    /* plural */
    ) {
        // Key can be "=x", we just want "x"
        key = key.replace(/\s*(?:=)?(\w+)\s*/, '$1');
      }

    if (key.length) {
      cases.push(key);
    }

    var blocks = extractParts(parts[pos++]);

    if (cases.length > values.length) {
      values.push(blocks);
    }
  } // TODO(ocombe): support ICU expressions in attributes, see #21615


  return {
    type: icuType,
    mainBinding: mainBinding,
    cases: cases,
    values: values
  };
}
/**
 * Transforms a string template into an HTML template and a list of instructions used to update
 * attributes or nodes that contain bindings.
 *
 * @param unsafeHtml The string to parse
 * @param parentIndex
 * @param nestedIcus
 * @param tIcus
 * @param expandoStartIndex
 */


function parseIcuCase(unsafeHtml, parentIndex, nestedIcus, tIcus, expandoStartIndex) {
  var inertBodyHelper = getInertBodyHelper(getDocument());
  var inertBodyElement = inertBodyHelper.getInertBodyElement(unsafeHtml);

  if (!inertBodyElement) {
    throw new Error('Unable to generate inert body element');
  }

  var wrapper = getTemplateContent(inertBodyElement) || inertBodyElement;
  var opCodes = {
    vars: 1,
    childIcus: [],
    create: [],
    remove: [],
    update: []
  };

  if (ngDevMode) {
    attachDebugGetter(opCodes.create, i18nMutateOpCodesToString);
    attachDebugGetter(opCodes.remove, i18nMutateOpCodesToString);
    attachDebugGetter(opCodes.update, i18nUpdateOpCodesToString);
  }

  parseNodes(wrapper.firstChild, opCodes, parentIndex, nestedIcus, tIcus, expandoStartIndex);
  return opCodes;
}
/**
 * Breaks pattern into strings and top level {...} blocks.
 * Can be used to break a message into text and ICU expressions, or to break an ICU expression into
 * keys and cases.
 * Original code from closure library, modified for Angular.
 *
 * @param pattern (sub)Pattern to be broken.
 *
 */


function extractParts(pattern) {
  if (!pattern) {
    return [];
  }

  var prevPos = 0;
  var braceStack = [];
  var results = [];
  var braces = /[{}]/g; // lastIndex doesn't get set to 0 so we have to.

  braces.lastIndex = 0;
  var match;

  while (match = braces.exec(pattern)) {
    var pos = match.index;

    if (match[0] == '}') {
      braceStack.pop();

      if (braceStack.length == 0) {
        // End of the block.
        var block = pattern.substring(prevPos, pos);

        if (ICU_BLOCK_REGEXP.test(block)) {
          results.push(parseICUBlock(block));
        } else {
          results.push(block);
        }

        prevPos = pos + 1;
      }
    } else {
      if (braceStack.length == 0) {
        var _substring = pattern.substring(prevPos, pos);

        results.push(_substring);
        prevPos = pos + 1;
      }

      braceStack.push('{');
    }
  }

  var substring = pattern.substring(prevPos);
  results.push(substring);
  return results;
}
/**
 * Parses a node, its children and its siblings, and generates the mutate & update OpCodes.
 *
 * @param currentNode The first node to parse
 * @param icuCase The data for the ICU expression case that contains those nodes
 * @param parentIndex Index of the current node's parent
 * @param nestedIcus Data for the nested ICU expressions that this case contains
 * @param tIcus Data for all ICU expressions of the current message
 * @param expandoStartIndex Expando start index for the current ICU expression
 */


function parseNodes(currentNode, icuCase, parentIndex, nestedIcus, tIcus, expandoStartIndex) {
  if (currentNode) {
    var nestedIcusToCreate = [];

    while (currentNode) {
      var nextNode = currentNode.nextSibling;
      var newIndex = expandoStartIndex + ++icuCase.vars;

      switch (currentNode.nodeType) {
        case Node.ELEMENT_NODE:
          var element = currentNode;
          var tagName = element.tagName.toLowerCase();

          if (!VALID_ELEMENTS.hasOwnProperty(tagName)) {
            // This isn't a valid element, we won't create an element for it
            icuCase.vars--;
          } else {
            icuCase.create.push(ELEMENT_MARKER, tagName, newIndex, parentIndex << 17
            /* SHIFT_PARENT */
            | 1
            /* AppendChild */
            );
            var elAttrs = element.attributes;

            for (var i = 0; i < elAttrs.length; i++) {
              var attr = elAttrs.item(i);
              var lowerAttrName = attr.name.toLowerCase();

              var _hasBinding = !!attr.value.match(BINDING_REGEXP); // we assume the input string is safe, unless it's using a binding


              if (_hasBinding) {
                if (VALID_ATTRS.hasOwnProperty(lowerAttrName)) {
                  if (URI_ATTRS[lowerAttrName]) {
                    addAllToArray(generateBindingUpdateOpCodes(attr.value, newIndex, attr.name, _sanitizeUrl), icuCase.update);
                  } else if (SRCSET_ATTRS[lowerAttrName]) {
                    addAllToArray(generateBindingUpdateOpCodes(attr.value, newIndex, attr.name, sanitizeSrcset), icuCase.update);
                  } else {
                    addAllToArray(generateBindingUpdateOpCodes(attr.value, newIndex, attr.name), icuCase.update);
                  }
                } else {
                  ngDevMode && console.warn("WARNING: ignoring unsafe attribute value ".concat(lowerAttrName, " on element ").concat(tagName, " (see http://g.co/ng/security#xss)"));
                }
              } else {
                icuCase.create.push(newIndex << 3
                /* SHIFT_REF */
                | 4
                /* Attr */
                , attr.name, attr.value);
              }
            } // Parse the children of this node (if any)


            parseNodes(currentNode.firstChild, icuCase, newIndex, nestedIcus, tIcus, expandoStartIndex); // Remove the parent node after the children

            icuCase.remove.push(newIndex << 3
            /* SHIFT_REF */
            | 3
            /* Remove */
            );
          }

          break;

        case Node.TEXT_NODE:
          var value = currentNode.textContent || '';
          var hasBinding = value.match(BINDING_REGEXP);
          icuCase.create.push(hasBinding ? '' : value, newIndex, parentIndex << 17
          /* SHIFT_PARENT */
          | 1
          /* AppendChild */
          );
          icuCase.remove.push(newIndex << 3
          /* SHIFT_REF */
          | 3
          /* Remove */
          );

          if (hasBinding) {
            addAllToArray(generateBindingUpdateOpCodes(value, newIndex), icuCase.update);
          }

          break;

        case Node.COMMENT_NODE:
          // Check if the comment node is a placeholder for a nested ICU
          var match = NESTED_ICU.exec(currentNode.textContent || '');

          if (match) {
            var nestedIcuIndex = parseInt(match[1], 10);
            var newLocal = ngDevMode ? "nested ICU ".concat(nestedIcuIndex) : ''; // Create the comment node that will anchor the ICU expression

            icuCase.create.push(COMMENT_MARKER, newLocal, newIndex, parentIndex << 17
            /* SHIFT_PARENT */
            | 1
            /* AppendChild */
            );
            var nestedIcu = nestedIcus[nestedIcuIndex];
            nestedIcusToCreate.push([nestedIcu, newIndex]);
          } else {
            // We do not handle any other type of comment
            icuCase.vars--;
          }

          break;

        default:
          // We do not handle any other type of element
          icuCase.vars--;
      }

      currentNode = nextNode;
    }

    for (var _i7 = 0; _i7 < nestedIcusToCreate.length; _i7++) {
      var _nestedIcu = nestedIcusToCreate[_i7][0];
      var nestedIcuNodeIndex = nestedIcusToCreate[_i7][1];
      icuStart(tIcus, _nestedIcu, nestedIcuNodeIndex, expandoStartIndex + icuCase.vars); // Since this is recursive, the last TIcu that was pushed is the one we want

      var nestTIcuIndex = tIcus.length - 1;
      icuCase.vars += Math.max.apply(Math, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(tIcus[nestTIcuIndex].vars));
      icuCase.childIcus.push(nestTIcuIndex);
      var mask = getBindingMask(_nestedIcu);
      icuCase.update.push(toMaskBit(_nestedIcu.mainBinding), // mask of the main binding
      3, // skip 3 opCodes if not changed
      -1 - _nestedIcu.mainBinding, nestedIcuNodeIndex << 2
      /* SHIFT_REF */
      | 2
      /* IcuSwitch */
      , // FIXME(misko): Index should be part of the opcode
      nestTIcuIndex, mask, // mask of all the bindings of this ICU expression
      2, // skip 2 opCodes if not changed
      nestedIcuNodeIndex << 2
      /* SHIFT_REF */
      | 3
      /* IcuUpdate */
      , nestTIcuIndex);
      icuCase.remove.push(nestTIcuIndex << 3
      /* SHIFT_REF */
      | 6
      /* RemoveNestedIcu */
      , // FIXME(misko): Index should be part of the opcode
      nestedIcuNodeIndex << 3
      /* SHIFT_REF */
      | 3
      /* Remove */
      );
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// i18nPostprocess consts


var ROOT_TEMPLATE_ID = 0;
var PP_MULTI_VALUE_PLACEHOLDERS_REGEXP = /\[(�.+?�?)\]/;
var PP_PLACEHOLDERS_REGEXP = /\[(�.+?�?)\]|(�\/?\*\d+:\d+�)/g;
var PP_ICU_VARS_REGEXP = /({\s*)(VAR_(PLURAL|SELECT)(_\d+)?)(\s*,)/g;
var PP_ICU_PLACEHOLDERS_REGEXP = /{([A-Z0-9_]+)}/g;
var PP_ICUS_REGEXP = /�I18N_EXP_(ICU(_\d+)?)�/g;
var PP_CLOSE_TEMPLATE_REGEXP = /\/\*/;
var PP_TEMPLATE_ID_REGEXP = /\d+\:(\d+)/;
/**
 * Handles message string post-processing for internationalization.
 *
 * Handles message string post-processing by transforming it from intermediate
 * format (that might contain some markers that we need to replace) to the final
 * form, consumable by i18nStart instruction. Post processing steps include:
 *
 * 1. Resolve all multi-value cases (like [�*1:1��#2:1�|�#4:1�|�5�])
 * 2. Replace all ICU vars (like "VAR_PLURAL")
 * 3. Replace all placeholders used inside ICUs in a form of {PLACEHOLDER}
 * 4. Replace all ICU references with corresponding values (like �ICU_EXP_ICU_1�)
 *    in case multiple ICUs have the same placeholder name
 *
 * @param message Raw translation string for post processing
 * @param replacements Set of replacements that should be applied
 *
 * @returns Transformed string that can be consumed by i18nStart instruction
 *
 * @codeGenApi
 */

function i18nPostprocess(message) {
  var replacements = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  /**
   * Step 1: resolve all multi-value placeholders like [�#5�|�*1:1��#2:1�|�#4:1�]
   *
   * Note: due to the way we process nested templates (BFS), multi-value placeholders are typically
   * grouped by templates, for example: [�#5�|�#6�|�#1:1�|�#3:2�] where �#5� and �#6� belong to root
   * template, �#1:1� belong to nested template with index 1 and �#1:2� - nested template with index
   * 3. However in real templates the order might be different: i.e. �#1:1� and/or �#3:2� may go in
   * front of �#6�. The post processing step restores the right order by keeping track of the
   * template id stack and looks for placeholders that belong to the currently active template.
   */
  var result = message;

  if (PP_MULTI_VALUE_PLACEHOLDERS_REGEXP.test(message)) {
    var matches = {};
    var templateIdsStack = [ROOT_TEMPLATE_ID];
    result = result.replace(PP_PLACEHOLDERS_REGEXP, function (m, phs, tmpl) {
      var content = phs || tmpl;
      var placeholders = matches[content] || [];

      if (!placeholders.length) {
        content.split('|').forEach(function (placeholder) {
          var match = placeholder.match(PP_TEMPLATE_ID_REGEXP);
          var templateId = match ? parseInt(match[1], 10) : ROOT_TEMPLATE_ID;
          var isCloseTemplateTag = PP_CLOSE_TEMPLATE_REGEXP.test(placeholder);
          placeholders.push([templateId, isCloseTemplateTag, placeholder]);
        });
        matches[content] = placeholders;
      }

      if (!placeholders.length) {
        throw new Error("i18n postprocess: unmatched placeholder - ".concat(content));
      }

      var currentTemplateId = templateIdsStack[templateIdsStack.length - 1];
      var idx = 0; // find placeholder index that matches current template id

      for (var i = 0; i < placeholders.length; i++) {
        if (placeholders[i][0] === currentTemplateId) {
          idx = i;
          break;
        }
      } // update template id stack based on the current tag extracted


      var _placeholders$idx = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(placeholders[idx], 3),
          templateId = _placeholders$idx[0],
          isCloseTemplateTag = _placeholders$idx[1],
          placeholder = _placeholders$idx[2];

      if (isCloseTemplateTag) {
        templateIdsStack.pop();
      } else if (currentTemplateId !== templateId) {
        templateIdsStack.push(templateId);
      } // remove processed tag from the list


      placeholders.splice(idx, 1);
      return placeholder;
    });
  } // return current result if no replacements specified


  if (!Object.keys(replacements).length) {
    return result;
  }
  /**
   * Step 2: replace all ICU vars (like "VAR_PLURAL")
   */


  result = result.replace(PP_ICU_VARS_REGEXP, function (match, start, key, _type, _idx, end) {
    return replacements.hasOwnProperty(key) ? "".concat(start).concat(replacements[key]).concat(end) : match;
  });
  /**
   * Step 3: replace all placeholders used inside ICUs in a form of {PLACEHOLDER}
   */

  result = result.replace(PP_ICU_PLACEHOLDERS_REGEXP, function (match, key) {
    return replacements.hasOwnProperty(key) ? replacements[key] : match;
  });
  /**
   * Step 4: replace all ICU references with corresponding values (like �ICU_EXP_ICU_1�) in case
   * multiple ICUs have the same placeholder name
   */

  result = result.replace(PP_ICUS_REGEXP, function (match, key) {
    if (replacements.hasOwnProperty(key)) {
      var list = replacements[key];

      if (!list.length) {
        throw new Error("i18n postprocess: unmatched ICU - ".concat(match, " with key: ").concat(key));
      }

      return list.shift();
    }

    return match;
  });
  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Marks a block of text as translatable.
 *
 * The instructions `i18nStart` and `i18nEnd` mark the translation block in the template.
 * The translation `message` is the value which is locale specific. The translation string may
 * contain placeholders which associate inner elements and sub-templates within the translation.
 *
 * The translation `message` placeholders are:
 * - `�{index}(:{block})�`: *Binding Placeholder*: Marks a location where an expression will be
 *   interpolated into. The placeholder `index` points to the expression binding index. An optional
 *   `block` that matches the sub-template in which it was declared.
 * - `�#{index}(:{block})�`/`�/#{index}(:{block})�`: *Element Placeholder*:  Marks the beginning
 *   and end of DOM element that were embedded in the original translation block. The placeholder
 *   `index` points to the element index in the template instructions set. An optional `block` that
 *   matches the sub-template in which it was declared.
 * - `�!{index}(:{block})�`/`�/!{index}(:{block})�`: *Projection Placeholder*:  Marks the
 *   beginning and end of <ng-content> that was embedded in the original translation block.
 *   The placeholder `index` points to the element index in the template instructions set.
 *   An optional `block` that matches the sub-template in which it was declared.
 * - `�*{index}:{block}�`/`�/*{index}:{block}�`: *Sub-template Placeholder*: Sub-templates must be
 *   split up and translated separately in each angular template function. The `index` points to the
 *   `template` instruction index. A `block` that matches the sub-template in which it was declared.
 *
 * @param index A unique index of the translation in the static block.
 * @param messageIndex An index of the translation message from the `def.consts` array.
 * @param subTemplateIndex Optional sub-template index in the `message`.
 *
 * @codeGenApi
 */


function ɵɵi18nStart(index, messageIndex, subTemplateIndex) {
  var tView = getTView();
  ngDevMode && assertDefined(tView, "tView should be defined");
  var message = getConstant(tView.consts, messageIndex);
  pushI18nIndex(index); // We need to delay projections until `i18nEnd`

  setDelayProjection(true);

  if (tView.firstCreatePass && tView.data[index + HEADER_OFFSET] === null) {
    i18nStartFirstPass(getLView(), tView, index, message, subTemplateIndex);
  }
}
/**
 * Translates a translation block marked by `i18nStart` and `i18nEnd`. It inserts the text/ICU nodes
 * into the render tree, moves the placeholder nodes and removes the deleted nodes.
 *
 * @codeGenApi
 */


function ɵɵi18nEnd() {
  var lView = getLView();
  var tView = getTView();
  ngDevMode && assertDefined(tView, "tView should be defined");
  i18nEndFirstPass(tView, lView); // Stop delaying projections

  setDelayProjection(false);
}
/**
 *
 * Use this instruction to create a translation block that doesn't contain any placeholder.
 * It calls both {@link i18nStart} and {@link i18nEnd} in one instruction.
 *
 * The translation `message` is the value which is locale specific. The translation string may
 * contain placeholders which associate inner elements and sub-templates within the translation.
 *
 * The translation `message` placeholders are:
 * - `�{index}(:{block})�`: *Binding Placeholder*: Marks a location where an expression will be
 *   interpolated into. The placeholder `index` points to the expression binding index. An optional
 *   `block` that matches the sub-template in which it was declared.
 * - `�#{index}(:{block})�`/`�/#{index}(:{block})�`: *Element Placeholder*:  Marks the beginning
 *   and end of DOM element that were embedded in the original translation block. The placeholder
 *   `index` points to the element index in the template instructions set. An optional `block` that
 *   matches the sub-template in which it was declared.
 * - `�*{index}:{block}�`/`�/*{index}:{block}�`: *Sub-template Placeholder*: Sub-templates must be
 *   split up and translated separately in each angular template function. The `index` points to the
 *   `template` instruction index. A `block` that matches the sub-template in which it was declared.
 *
 * @param index A unique index of the translation in the static block.
 * @param messageIndex An index of the translation message from the `def.consts` array.
 * @param subTemplateIndex Optional sub-template index in the `message`.
 *
 * @codeGenApi
 */


function ɵɵi18n(index, messageIndex, subTemplateIndex) {
  ɵɵi18nStart(index, messageIndex, subTemplateIndex);
  ɵɵi18nEnd();
}
/**
 * Marks a list of attributes as translatable.
 *
 * @param index A unique index in the static block
 * @param values
 *
 * @codeGenApi
 */


function ɵɵi18nAttributes(index, attrsIndex) {
  var lView = getLView();
  var tView = getTView();
  ngDevMode && assertDefined(tView, "tView should be defined");
  var attrs = getConstant(tView.consts, attrsIndex);
  i18nAttributesFirstPass(lView, tView, index, attrs);
}
/**
 * Stores the values of the bindings during each update cycle in order to determine if we need to
 * update the translated nodes.
 *
 * @param value The binding's value
 * @returns This function returns itself so that it may be chained
 * (e.g. `i18nExp(ctx.name)(ctx.title)`)
 *
 * @codeGenApi
 */


function ɵɵi18nExp(value) {
  var lView = getLView();
  setMaskBit(bindingUpdated(lView, nextBindingIndex(), value));
  return ɵɵi18nExp;
}
/**
 * Updates a translation block or an i18n attribute when the bindings have changed.
 *
 * @param index Index of either {@link i18nStart} (translation block) or {@link i18nAttributes}
 * (i18n attribute) on which it should update the content.
 *
 * @codeGenApi
 */


function ɵɵi18nApply(index) {
  applyI18n(getTView(), getLView(), index);
}
/**
 * Handles message string post-processing for internationalization.
 *
 * Handles message string post-processing by transforming it from intermediate
 * format (that might contain some markers that we need to replace) to the final
 * form, consumable by i18nStart instruction. Post processing steps include:
 *
 * 1. Resolve all multi-value cases (like [�*1:1��#2:1�|�#4:1�|�5�])
 * 2. Replace all ICU vars (like "VAR_PLURAL")
 * 3. Replace all placeholders used inside ICUs in a form of {PLACEHOLDER}
 * 4. Replace all ICU references with corresponding values (like �ICU_EXP_ICU_1�)
 *    in case multiple ICUs have the same placeholder name
 *
 * @param message Raw translation string for post processing
 * @param replacements Set of replacements that should be applied
 *
 * @returns Transformed string that can be consumed by i18nStart instruction
 *
 * @codeGenApi
 */


function ɵɵi18nPostprocess(message) {
  var replacements = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return i18nPostprocess(message, replacements);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Adds decorator, constructor, and property metadata to a given type via static metadata fields
 * on the type.
 *
 * These metadata fields can later be read with Angular's `ReflectionCapabilities` API.
 *
 * Calls to `setClassMetadata` can be marked as pure, resulting in the metadata assignments being
 * tree-shaken away during production builds.
 */


function setClassMetadata(type, decorators, ctorParameters, propDecorators) {
  return noSideEffects(function () {
    var clazz = type; // We determine whether a class has its own metadata by taking the metadata from the
    // parent constructor and checking whether it's the same as the subclass metadata below.
    // We can't use `hasOwnProperty` here because it doesn't work correctly in IE10 for
    // static fields that are defined by TS. See
    // https://github.com/angular/angular/pull/28439#issuecomment-459349218.

    var parentPrototype = clazz.prototype ? Object.getPrototypeOf(clazz.prototype) : null;
    var parentConstructor = parentPrototype && parentPrototype.constructor;

    if (decorators !== null) {
      if (clazz.decorators !== undefined && (!parentConstructor || parentConstructor.decorators !== clazz.decorators)) {
        var _clazz$decorators;

        (_clazz$decorators = clazz.decorators).push.apply(_clazz$decorators, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(decorators));
      } else {
        clazz.decorators = decorators;
      }
    }

    if (ctorParameters !== null) {
      // Rather than merging, clobber the existing parameters. If other projects exist which
      // use tsickle-style annotations and reflect over them in the same way, this could
      // cause issues, but that is vanishingly unlikely.
      clazz.ctorParameters = ctorParameters;
    }

    if (propDecorators !== null) {
      // The property decorator objects are merged as it is possible different fields have
      // different decorator types. Decorators on individual fields are not merged, as it's
      // also incredibly unlikely that a field will be decorated both with an Angular
      // decorator and a non-Angular decorator that's also been downleveled.
      if (clazz.propDecorators !== undefined && (!parentConstructor || parentConstructor.propDecorators !== clazz.propDecorators)) {
        clazz.propDecorators = Object.assign(Object.assign({}, clazz.propDecorators), propDecorators);
      } else {
        clazz.propDecorators = propDecorators;
      }
    }
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Map of module-id to the corresponding NgModule.
 * - In pre Ivy we track NgModuleFactory,
 * - In post Ivy we track the NgModuleType
 */


var modules = new Map();
/**
 * Registers a loaded module. Should only be called from generated NgModuleFactory code.
 * @publicApi
 */

function registerModuleFactory(id, factory) {
  var existing = modules.get(id);
  assertSameOrNotExisting(id, existing && existing.moduleType, factory.moduleType);
  modules.set(id, factory);
}

function assertSameOrNotExisting(id, type, incoming) {
  if (type && type !== incoming) {
    throw new Error("Duplicate module registered for ".concat(id, " - ").concat(stringify(type), " vs ").concat(stringify(type.name)));
  }
}

function registerNgModuleType(ngModuleType) {
  if (ngModuleType.ɵmod.id !== null) {
    var id = ngModuleType.ɵmod.id;
    var existing = modules.get(id);
    assertSameOrNotExisting(id, existing, ngModuleType);
    modules.set(id, ngModuleType);
  }

  var imports = ngModuleType.ɵmod.imports;

  if (imports instanceof Function) {
    imports = imports();
  }

  if (imports) {
    imports.forEach(function (i) {
      return registerNgModuleType(i);
    });
  }
}

function clearModulesForTest() {
  modules.clear();
}

function getRegisteredNgModuleType(id) {
  return modules.get(id) || autoRegisterModuleById[id];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NgModuleRef$1 = /*#__PURE__*/function (_NgModuleRef) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(NgModuleRef$1, _NgModuleRef);

  var _super17 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(NgModuleRef$1);

  function NgModuleRef$1(ngModuleType, _parent) {
    var _this17;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleRef$1);

    _this17 = _super17.call(this);
    _this17._parent = _parent; // tslint:disable-next-line:require-internal-with-underscore

    _this17._bootstrapComponents = [];
    _this17.injector = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this17);
    _this17.destroyCbs = []; // When bootstrapping a module we have a dependency graph that looks like this:
    // ApplicationRef -> ComponentFactoryResolver -> NgModuleRef. The problem is that if the
    // module being resolved tries to inject the ComponentFactoryResolver, it'll create a
    // circular dependency which will result in a runtime error, because the injector doesn't
    // exist yet. We work around the issue by creating the ComponentFactoryResolver ourselves
    // and providing it, rather than letting the injector resolve it.

    _this17.componentFactoryResolver = new ComponentFactoryResolver$1(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this17));
    var ngModuleDef = getNgModuleDef(ngModuleType);
    ngDevMode && assertDefined(ngModuleDef, "NgModule '".concat(stringify(ngModuleType), "' is not a subtype of 'NgModuleType'."));
    var ngLocaleIdDef = getNgLocaleIdDef(ngModuleType);
    ngLocaleIdDef && setLocaleId(ngLocaleIdDef);
    _this17._bootstrapComponents = maybeUnwrapFn(ngModuleDef.bootstrap);
    _this17._r3Injector = createInjectorWithoutInjectorInstances(ngModuleType, _parent, [{
      provide: NgModuleRef,
      useValue: Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_2__["default"])(_this17)
    }, {
      provide: ComponentFactoryResolver,
      useValue: _this17.componentFactoryResolver
    }], stringify(ngModuleType)); // We need to resolve the injector types separately from the injector creation, because
    // the module might be trying to use this ref in its contructor for DI which will cause a
    // circular error that will eventually error out, because the injector isn't created yet.

    _this17._r3Injector._resolveInjectorDefTypes();

    _this17.instance = _this17.get(ngModuleType);
    return _this17;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NgModuleRef$1, [{
    key: "get",
    value: function get(token) {
      var notFoundValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Injector.THROW_IF_NOT_FOUND;
      var injectFlags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : InjectFlags.Default;

      if (token === Injector || token === NgModuleRef || token === INJECTOR) {
        return this;
      }

      return this._r3Injector.get(token, notFoundValue, injectFlags);
    }
  }, {
    key: "destroy",
    value: function destroy() {
      ngDevMode && assertDefined(this.destroyCbs, 'NgModule already destroyed');
      var injector = this._r3Injector;
      !injector.destroyed && injector.destroy();
      this.destroyCbs.forEach(function (fn) {
        return fn();
      });
      this.destroyCbs = null;
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      ngDevMode && assertDefined(this.destroyCbs, 'NgModule already destroyed');
      this.destroyCbs.push(callback);
    }
  }]);

  return NgModuleRef$1;
}(NgModuleRef);

var NgModuleFactory$1 = /*#__PURE__*/function (_NgModuleFactory) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(NgModuleFactory$1, _NgModuleFactory);

  var _super18 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(NgModuleFactory$1);

  function NgModuleFactory$1(moduleType) {
    var _this18;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleFactory$1);

    _this18 = _super18.call(this);
    _this18.moduleType = moduleType;
    var ngModuleDef = getNgModuleDef(moduleType);

    if (ngModuleDef !== null) {
      // Register the NgModule with Angular's module registry. The location (and hence timing) of
      // this call is critical to ensure this works correctly (modules get registered when expected)
      // without bloating bundles (modules are registered when otherwise not referenced).
      //
      // In View Engine, registration occurs in the .ngfactory.js file as a side effect. This has
      // several practical consequences:
      //
      // - If an .ngfactory file is not imported from, the module won't be registered (and can be
      //   tree shaken).
      // - If an .ngfactory file is imported from, the module will be registered even if an instance
      //   is not actually created (via `create` below).
      // - Since an .ngfactory file in View Engine references the .ngfactory files of the NgModule's
      //   imports,
      //
      // In Ivy, things are a bit different. .ngfactory files still exist for compatibility, but are
      // not a required API to use - there are other ways to obtain an NgModuleFactory for a given
      // NgModule. Thus, relying on a side effect in the .ngfactory file is not sufficient. Instead,
      // the side effect of registration is added here, in the constructor of NgModuleFactory,
      // ensuring no matter how a factory is created, the module is registered correctly.
      //
      // An alternative would be to include the registration side effect inline following the actual
      // NgModule definition. This also has the correct timing, but breaks tree-shaking - modules
      // will be registered and retained even if they're otherwise never referenced.
      registerNgModuleType(moduleType);
    }

    return _this18;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NgModuleFactory$1, [{
    key: "create",
    value: function create(parentInjector) {
      return new NgModuleRef$1(this.moduleType, parentInjector);
    }
  }]);

  return NgModuleFactory$1;
}(NgModuleFactory);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Bindings for pure functions are stored after regular bindings.
 *
 * |-------decls------|---------vars---------|                 |----- hostVars (dir1) ------|
 * ------------------------------------------------------------------------------------------
 * | nodes/refs/pipes | bindings | fn slots  | injector | dir1 | host bindings | host slots |
 * ------------------------------------------------------------------------------------------
 *                    ^                      ^
 *      TView.bindingStartIndex      TView.expandoStartIndex
 *
 * Pure function instructions are given an offset from the binding root. Adding the offset to the
 * binding root gives the first index where the bindings are stored. In component views, the binding
 * root is the bindingStartIndex. In host bindings, the binding root is the expandoStartIndex +
 * any directive instances + any hostVars in directives evaluated before it.
 *
 * See VIEW_DATA.md for more information about host binding resolution.
 */

/**
 * If the value hasn't been saved, calls the pure function to store and return the
 * value. If it has been saved, returns the saved value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn Function that returns a value
 * @param thisArg Optional calling context of pureFn
 * @returns value
 *
 * @codeGenApi
 */


function ɵɵpureFunction0(slotOffset, pureFn, thisArg) {
  var bindingIndex = getBindingRoot() + slotOffset;
  var lView = getLView();
  return lView[bindingIndex] === NO_CHANGE ? updateBinding(lView, bindingIndex, thisArg ? pureFn.call(thisArg) : pureFn()) : getBinding(lView, bindingIndex);
}
/**
 * If the value of the provided exp has changed, calls the pure function to return
 * an updated value. Or if the value has not changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn Function that returns an updated value
 * @param exp Updated expression value
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction1(slotOffset, pureFn, exp, thisArg) {
  return pureFunction1Internal(getLView(), getBindingRoot(), slotOffset, pureFn, exp, thisArg);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction2(slotOffset, pureFn, exp1, exp2, thisArg) {
  return pureFunction2Internal(getLView(), getBindingRoot(), slotOffset, pureFn, exp1, exp2, thisArg);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction3(slotOffset, pureFn, exp1, exp2, exp3, thisArg) {
  return pureFunction3Internal(getLView(), getBindingRoot(), slotOffset, pureFn, exp1, exp2, exp3, thisArg);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param exp4
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction4(slotOffset, pureFn, exp1, exp2, exp3, exp4, thisArg) {
  return pureFunction4Internal(getLView(), getBindingRoot(), slotOffset, pureFn, exp1, exp2, exp3, exp4, thisArg);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param exp4
 * @param exp5
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction5(slotOffset, pureFn, exp1, exp2, exp3, exp4, exp5, thisArg) {
  var bindingIndex = getBindingRoot() + slotOffset;
  var lView = getLView();
  var different = bindingUpdated4(lView, bindingIndex, exp1, exp2, exp3, exp4);
  return bindingUpdated(lView, bindingIndex + 4, exp5) || different ? updateBinding(lView, bindingIndex + 5, thisArg ? pureFn.call(thisArg, exp1, exp2, exp3, exp4, exp5) : pureFn(exp1, exp2, exp3, exp4, exp5)) : getBinding(lView, bindingIndex + 5);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param exp4
 * @param exp5
 * @param exp6
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction6(slotOffset, pureFn, exp1, exp2, exp3, exp4, exp5, exp6, thisArg) {
  var bindingIndex = getBindingRoot() + slotOffset;
  var lView = getLView();
  var different = bindingUpdated4(lView, bindingIndex, exp1, exp2, exp3, exp4);
  return bindingUpdated2(lView, bindingIndex + 4, exp5, exp6) || different ? updateBinding(lView, bindingIndex + 6, thisArg ? pureFn.call(thisArg, exp1, exp2, exp3, exp4, exp5, exp6) : pureFn(exp1, exp2, exp3, exp4, exp5, exp6)) : getBinding(lView, bindingIndex + 6);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param exp4
 * @param exp5
 * @param exp6
 * @param exp7
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction7(slotOffset, pureFn, exp1, exp2, exp3, exp4, exp5, exp6, exp7, thisArg) {
  var bindingIndex = getBindingRoot() + slotOffset;
  var lView = getLView();
  var different = bindingUpdated4(lView, bindingIndex, exp1, exp2, exp3, exp4);
  return bindingUpdated3(lView, bindingIndex + 4, exp5, exp6, exp7) || different ? updateBinding(lView, bindingIndex + 7, thisArg ? pureFn.call(thisArg, exp1, exp2, exp3, exp4, exp5, exp6, exp7) : pureFn(exp1, exp2, exp3, exp4, exp5, exp6, exp7)) : getBinding(lView, bindingIndex + 7);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param exp4
 * @param exp5
 * @param exp6
 * @param exp7
 * @param exp8
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunction8(slotOffset, pureFn, exp1, exp2, exp3, exp4, exp5, exp6, exp7, exp8, thisArg) {
  var bindingIndex = getBindingRoot() + slotOffset;
  var lView = getLView();
  var different = bindingUpdated4(lView, bindingIndex, exp1, exp2, exp3, exp4);
  return bindingUpdated4(lView, bindingIndex + 4, exp5, exp6, exp7, exp8) || different ? updateBinding(lView, bindingIndex + 8, thisArg ? pureFn.call(thisArg, exp1, exp2, exp3, exp4, exp5, exp6, exp7, exp8) : pureFn(exp1, exp2, exp3, exp4, exp5, exp6, exp7, exp8)) : getBinding(lView, bindingIndex + 8);
}
/**
 * pureFunction instruction that can support any number of bindings.
 *
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn A pure function that takes binding values and builds an object or array
 * containing those values.
 * @param exps An array of binding values
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 * @codeGenApi
 */


function ɵɵpureFunctionV(slotOffset, pureFn, exps, thisArg) {
  return pureFunctionVInternal(getLView(), getBindingRoot(), slotOffset, pureFn, exps, thisArg);
}
/**
 * Results of a pure function invocation are stored in LView in a dedicated slot that is initialized
 * to NO_CHANGE. In rare situations a pure pipe might throw an exception on the very first
 * invocation and not produce any valid results. In this case LView would keep holding the NO_CHANGE
 * value. The NO_CHANGE is not something that we can use in expressions / bindings thus we convert
 * it to `undefined`.
 */


function getPureFunctionReturnValue(lView, returnValueIndex) {
  ngDevMode && assertIndexInRange(lView, returnValueIndex);
  var lastReturnValue = lView[returnValueIndex];
  return lastReturnValue === NO_CHANGE ? undefined : lastReturnValue;
}
/**
 * If the value of the provided exp has changed, calls the pure function to return
 * an updated value. Or if the value has not changed, returns cached value.
 *
 * @param lView LView in which the function is being executed.
 * @param bindingRoot Binding root index.
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn Function that returns an updated value
 * @param exp Updated expression value
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 */


function pureFunction1Internal(lView, bindingRoot, slotOffset, pureFn, exp, thisArg) {
  var bindingIndex = bindingRoot + slotOffset;
  return bindingUpdated(lView, bindingIndex, exp) ? updateBinding(lView, bindingIndex + 1, thisArg ? pureFn.call(thisArg, exp) : pureFn(exp)) : getPureFunctionReturnValue(lView, bindingIndex + 1);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param lView LView in which the function is being executed.
 * @param bindingRoot Binding root index.
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 */


function pureFunction2Internal(lView, bindingRoot, slotOffset, pureFn, exp1, exp2, thisArg) {
  var bindingIndex = bindingRoot + slotOffset;
  return bindingUpdated2(lView, bindingIndex, exp1, exp2) ? updateBinding(lView, bindingIndex + 2, thisArg ? pureFn.call(thisArg, exp1, exp2) : pureFn(exp1, exp2)) : getPureFunctionReturnValue(lView, bindingIndex + 2);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param lView LView in which the function is being executed.
 * @param bindingRoot Binding root index.
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 */


function pureFunction3Internal(lView, bindingRoot, slotOffset, pureFn, exp1, exp2, exp3, thisArg) {
  var bindingIndex = bindingRoot + slotOffset;
  return bindingUpdated3(lView, bindingIndex, exp1, exp2, exp3) ? updateBinding(lView, bindingIndex + 3, thisArg ? pureFn.call(thisArg, exp1, exp2, exp3) : pureFn(exp1, exp2, exp3)) : getPureFunctionReturnValue(lView, bindingIndex + 3);
}
/**
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param lView LView in which the function is being executed.
 * @param bindingRoot Binding root index.
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn
 * @param exp1
 * @param exp2
 * @param exp3
 * @param exp4
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 *
 */


function pureFunction4Internal(lView, bindingRoot, slotOffset, pureFn, exp1, exp2, exp3, exp4, thisArg) {
  var bindingIndex = bindingRoot + slotOffset;
  return bindingUpdated4(lView, bindingIndex, exp1, exp2, exp3, exp4) ? updateBinding(lView, bindingIndex + 4, thisArg ? pureFn.call(thisArg, exp1, exp2, exp3, exp4) : pureFn(exp1, exp2, exp3, exp4)) : getPureFunctionReturnValue(lView, bindingIndex + 4);
}
/**
 * pureFunction instruction that can support any number of bindings.
 *
 * If the value of any provided exp has changed, calls the pure function to return
 * an updated value. Or if no values have changed, returns cached value.
 *
 * @param lView LView in which the function is being executed.
 * @param bindingRoot Binding root index.
 * @param slotOffset the offset from binding root to the reserved slot
 * @param pureFn A pure function that takes binding values and builds an object or array
 * containing those values.
 * @param exps An array of binding values
 * @param thisArg Optional calling context of pureFn
 * @returns Updated or cached value
 */


function pureFunctionVInternal(lView, bindingRoot, slotOffset, pureFn, exps, thisArg) {
  var bindingIndex = bindingRoot + slotOffset;
  var different = false;

  for (var i = 0; i < exps.length; i++) {
    bindingUpdated(lView, bindingIndex++, exps[i]) && (different = true);
  }

  return different ? updateBinding(lView, bindingIndex, pureFn.apply(thisArg, exps)) : getPureFunctionReturnValue(lView, bindingIndex);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Create a pipe.
 *
 * @param index Pipe index where the pipe will be stored.
 * @param pipeName The name of the pipe
 * @returns T the instance of the pipe.
 *
 * @codeGenApi
 */


function ɵɵpipe(index, pipeName) {
  var tView = getTView();
  var pipeDef;
  var adjustedIndex = index + HEADER_OFFSET;

  if (tView.firstCreatePass) {
    pipeDef = getPipeDef$1(pipeName, tView.pipeRegistry);
    tView.data[adjustedIndex] = pipeDef;

    if (pipeDef.onDestroy) {
      (tView.destroyHooks || (tView.destroyHooks = [])).push(adjustedIndex, pipeDef.onDestroy);
    }
  } else {
    pipeDef = tView.data[adjustedIndex];
  }

  var pipeFactory = pipeDef.factory || (pipeDef.factory = getFactoryDef(pipeDef.type, true));
  var previousInjectImplementation = setInjectImplementation(ɵɵdirectiveInject);

  try {
    // DI for pipes is supposed to behave like directives when placed on a component
    // host node, which means that we have to disable access to `viewProviders`.
    var previousIncludeViewProviders = setIncludeViewProviders(false);
    var pipeInstance = pipeFactory();
    setIncludeViewProviders(previousIncludeViewProviders);
    store(tView, getLView(), index, pipeInstance);
    return pipeInstance;
  } finally {
    // we have to restore the injector implementation in finally, just in case the creation of the
    // pipe throws an error.
    setInjectImplementation(previousInjectImplementation);
  }
}
/**
 * Searches the pipe registry for a pipe with the given name. If one is found,
 * returns the pipe. Otherwise, an error is thrown because the pipe cannot be resolved.
 *
 * @param name Name of pipe to resolve
 * @param registry Full list of available pipes
 * @returns Matching PipeDef
 */


function getPipeDef$1(name, registry) {
  if (registry) {
    for (var i = registry.length - 1; i >= 0; i--) {
      var _pipeDef = registry[i];

      if (name === _pipeDef.name) {
        return _pipeDef;
      }
    }
  }

  throw new Error("The pipe '".concat(name, "' could not be found!"));
}
/**
 * Invokes a pipe with 1 arguments.
 *
 * This instruction acts as a guard to {@link PipeTransform#transform} invoking
 * the pipe only when an input to the pipe changes.
 *
 * @param index Pipe index where the pipe was stored on creation.
 * @param slotOffset the offset in the reserved slot space
 * @param v1 1st argument to {@link PipeTransform#transform}.
 *
 * @codeGenApi
 */


function ɵɵpipeBind1(index, slotOffset, v1) {
  var lView = getLView();
  var pipeInstance = load(lView, index);
  return unwrapValue$1(lView, isPure(lView, index) ? pureFunction1Internal(lView, getBindingRoot(), slotOffset, pipeInstance.transform, v1, pipeInstance) : pipeInstance.transform(v1));
}
/**
 * Invokes a pipe with 2 arguments.
 *
 * This instruction acts as a guard to {@link PipeTransform#transform} invoking
 * the pipe only when an input to the pipe changes.
 *
 * @param index Pipe index where the pipe was stored on creation.
 * @param slotOffset the offset in the reserved slot space
 * @param v1 1st argument to {@link PipeTransform#transform}.
 * @param v2 2nd argument to {@link PipeTransform#transform}.
 *
 * @codeGenApi
 */


function ɵɵpipeBind2(index, slotOffset, v1, v2) {
  var lView = getLView();
  var pipeInstance = load(lView, index);
  return unwrapValue$1(lView, isPure(lView, index) ? pureFunction2Internal(lView, getBindingRoot(), slotOffset, pipeInstance.transform, v1, v2, pipeInstance) : pipeInstance.transform(v1, v2));
}
/**
 * Invokes a pipe with 3 arguments.
 *
 * This instruction acts as a guard to {@link PipeTransform#transform} invoking
 * the pipe only when an input to the pipe changes.
 *
 * @param index Pipe index where the pipe was stored on creation.
 * @param slotOffset the offset in the reserved slot space
 * @param v1 1st argument to {@link PipeTransform#transform}.
 * @param v2 2nd argument to {@link PipeTransform#transform}.
 * @param v3 4rd argument to {@link PipeTransform#transform}.
 *
 * @codeGenApi
 */


function ɵɵpipeBind3(index, slotOffset, v1, v2, v3) {
  var lView = getLView();
  var pipeInstance = load(lView, index);
  return unwrapValue$1(lView, isPure(lView, index) ? pureFunction3Internal(lView, getBindingRoot(), slotOffset, pipeInstance.transform, v1, v2, v3, pipeInstance) : pipeInstance.transform(v1, v2, v3));
}
/**
 * Invokes a pipe with 4 arguments.
 *
 * This instruction acts as a guard to {@link PipeTransform#transform} invoking
 * the pipe only when an input to the pipe changes.
 *
 * @param index Pipe index where the pipe was stored on creation.
 * @param slotOffset the offset in the reserved slot space
 * @param v1 1st argument to {@link PipeTransform#transform}.
 * @param v2 2nd argument to {@link PipeTransform#transform}.
 * @param v3 3rd argument to {@link PipeTransform#transform}.
 * @param v4 4th argument to {@link PipeTransform#transform}.
 *
 * @codeGenApi
 */


function ɵɵpipeBind4(index, slotOffset, v1, v2, v3, v4) {
  var lView = getLView();
  var pipeInstance = load(lView, index);
  return unwrapValue$1(lView, isPure(lView, index) ? pureFunction4Internal(lView, getBindingRoot(), slotOffset, pipeInstance.transform, v1, v2, v3, v4, pipeInstance) : pipeInstance.transform(v1, v2, v3, v4));
}
/**
 * Invokes a pipe with variable number of arguments.
 *
 * This instruction acts as a guard to {@link PipeTransform#transform} invoking
 * the pipe only when an input to the pipe changes.
 *
 * @param index Pipe index where the pipe was stored on creation.
 * @param slotOffset the offset in the reserved slot space
 * @param values Array of arguments to pass to {@link PipeTransform#transform} method.
 *
 * @codeGenApi
 */


function ɵɵpipeBindV(index, slotOffset, values) {
  var lView = getLView();
  var pipeInstance = load(lView, index);
  return unwrapValue$1(lView, isPure(lView, index) ? pureFunctionVInternal(lView, getBindingRoot(), slotOffset, pipeInstance.transform, values, pipeInstance) : pipeInstance.transform.apply(pipeInstance, values));
}

function isPure(lView, index) {
  return lView[TVIEW].data[index + HEADER_OFFSET].pure;
}
/**
 * Unwrap the output of a pipe transformation.
 * In order to trick change detection into considering that the new value is always different from
 * the old one, the old value is overwritten by NO_CHANGE.
 *
 * @param newValue the pipe transformation output.
 */


function unwrapValue$1(lView, newValue) {
  if (WrappedValue.isWrapped(newValue)) {
    newValue = WrappedValue.unwrap(newValue); // The NO_CHANGE value needs to be written at the index where the impacted binding value is
    // stored

    var bindingToInvalidateIdx = getBindingIndex();
    lView[bindingToInvalidateIdx] = NO_CHANGE;
  }

  return newValue;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var EventEmitter_ = /*#__PURE__*/function (_Subject) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(EventEmitter_, _Subject);

  var _super19 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(EventEmitter_);

  function EventEmitter_() {
    var _this19;

    var isAsync = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, EventEmitter_);

    _this19 = _super19.call(this);
    _this19.__isAsync = isAsync;
    return _this19;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(EventEmitter_, [{
    key: "emit",
    value: function emit(value) {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(EventEmitter_.prototype), "next", this).call(this, value);
    }
  }, {
    key: "subscribe",
    value: function subscribe(generatorOrNext, error, complete) {
      var schedulerFn;

      var errorFn = function errorFn(err) {
        return null;
      };

      var completeFn = function completeFn() {
        return null;
      };

      if (generatorOrNext && typeof generatorOrNext === 'object') {
        schedulerFn = this.__isAsync ? function (value) {
          setTimeout(function () {
            return generatorOrNext.next(value);
          });
        } : function (value) {
          generatorOrNext.next(value);
        };

        if (generatorOrNext.error) {
          errorFn = this.__isAsync ? function (err) {
            setTimeout(function () {
              return generatorOrNext.error(err);
            });
          } : function (err) {
            generatorOrNext.error(err);
          };
        }

        if (generatorOrNext.complete) {
          completeFn = this.__isAsync ? function () {
            setTimeout(function () {
              return generatorOrNext.complete();
            });
          } : function () {
            generatorOrNext.complete();
          };
        }
      } else {
        schedulerFn = this.__isAsync ? function (value) {
          setTimeout(function () {
            return generatorOrNext(value);
          });
        } : function (value) {
          generatorOrNext(value);
        };

        if (error) {
          errorFn = this.__isAsync ? function (err) {
            setTimeout(function () {
              return error(err);
            });
          } : function (err) {
            error(err);
          };
        }

        if (complete) {
          completeFn = this.__isAsync ? function () {
            setTimeout(function () {
              return complete();
            });
          } : function () {
            complete();
          };
        }
      }

      var sink = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(EventEmitter_.prototype), "subscribe", this).call(this, schedulerFn, errorFn, completeFn);

      if (generatorOrNext instanceof rxjs__WEBPACK_IMPORTED_MODULE_13__["Subscription"]) {
        generatorOrNext.add(sink);
      }

      return sink;
    }
  }]);

  return EventEmitter_;
}(rxjs__WEBPACK_IMPORTED_MODULE_13__["Subject"]);
/**
 * @publicApi
 */


var EventEmitter = EventEmitter_;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function symbolIterator() {
  return this._results[getSymbolIterator()]();
}
/**
 * An unmodifiable list of items that Angular keeps up to date when the state
 * of the application changes.
 *
 * The type of object that {@link ViewChildren}, {@link ContentChildren}, and {@link QueryList}
 * provide.
 *
 * Implements an iterable interface, therefore it can be used in both ES6
 * javascript `for (var i of items)` loops as well as in Angular templates with
 * `*ngFor="let i of myList"`.
 *
 * Changes can be observed by subscribing to the changes `Observable`.
 *
 * NOTE: In the future this class will implement an `Observable` interface.
 *
 * @usageNotes
 * ### Example
 * ```typescript
 * @Component({...})
 * class Container {
 *   @ViewChildren(Item) items:QueryList<Item>;
 * }
 * ```
 *
 * @publicApi
 */


var QueryList = /*#__PURE__*/function () {
  function QueryList() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, QueryList);

    this.dirty = true;
    this._results = [];
    this.changes = new EventEmitter();
    this.length = 0; // This function should be declared on the prototype, but doing so there will cause the class
    // declaration to have side-effects and become not tree-shakable. For this reason we do it in
    // the constructor.
    // [getSymbolIterator()](): Iterator<T> { ... }

    var symbol = getSymbolIterator();
    var proto = QueryList.prototype;
    if (!proto[symbol]) proto[symbol] = symbolIterator;
  }
  /**
   * See
   * [Array.map](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/map)
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(QueryList, [{
    key: "map",
    value: function map(fn) {
      return this._results.map(fn);
    }
    /**
     * See
     * [Array.filter](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/filter)
     */

  }, {
    key: "filter",
    value: function filter(fn) {
      return this._results.filter(fn);
    }
    /**
     * See
     * [Array.find](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/find)
     */

  }, {
    key: "find",
    value: function find(fn) {
      return this._results.find(fn);
    }
    /**
     * See
     * [Array.reduce](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/reduce)
     */

  }, {
    key: "reduce",
    value: function reduce(fn, init) {
      return this._results.reduce(fn, init);
    }
    /**
     * See
     * [Array.forEach](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/forEach)
     */

  }, {
    key: "forEach",
    value: function forEach(fn) {
      this._results.forEach(fn);
    }
    /**
     * See
     * [Array.some](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/some)
     */

  }, {
    key: "some",
    value: function some(fn) {
      return this._results.some(fn);
    }
    /**
     * Returns a copy of the internal results list as an Array.
     */

  }, {
    key: "toArray",
    value: function toArray() {
      return this._results.slice();
    }
  }, {
    key: "toString",
    value: function toString() {
      return this._results.toString();
    }
    /**
     * Updates the stored data of the query list, and resets the `dirty` flag to `false`, so that
     * on change detection, it will not notify of changes to the queries, unless a new change
     * occurs.
     *
     * @param resultsTree The query results to store
     */

  }, {
    key: "reset",
    value: function reset(resultsTree) {
      this._results = flatten(resultsTree);
      this.dirty = false;
      this.length = this._results.length;
      this.last = this._results[this.length - 1];
      this.first = this._results[0];
    }
    /**
     * Triggers a change event by emitting on the `changes` {@link EventEmitter}.
     */

  }, {
    key: "notifyOnChanges",
    value: function notifyOnChanges() {
      this.changes.emit(this);
    }
    /** internal */

  }, {
    key: "setDirty",
    value: function setDirty() {
      this.dirty = true;
    }
    /** internal */

  }, {
    key: "destroy",
    value: function destroy() {
      this.changes.complete();
      this.changes.unsubscribe();
    }
  }]);

  return QueryList;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.


var unusedValueExportToPlacateAjd$7 = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Note: This hack is necessary so we don't erroneously get a circular dependency
// failure based on types.

var unusedValueExportToPlacateAjd$8 = 1;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var unusedValueToPlacateAjd$2 = unusedValueExportToPlacateAjd$7 + unusedValueExportToPlacateAjd$3 + unusedValueExportToPlacateAjd$4 + unusedValueExportToPlacateAjd$8;

var LQuery_ = /*#__PURE__*/function () {
  function LQuery_(queryList) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, LQuery_);

    this.queryList = queryList;
    this.matches = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(LQuery_, [{
    key: "clone",
    value: function clone() {
      return new LQuery_(this.queryList);
    }
  }, {
    key: "setDirty",
    value: function setDirty() {
      this.queryList.setDirty();
    }
  }]);

  return LQuery_;
}();

var LQueries_ = /*#__PURE__*/function () {
  function LQueries_() {
    var queries = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, LQueries_);

    this.queries = queries;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(LQueries_, [{
    key: "createEmbeddedView",
    value: function createEmbeddedView(tView) {
      var tQueries = tView.queries;

      if (tQueries !== null) {
        var noOfInheritedQueries = tView.contentQueries !== null ? tView.contentQueries[0] : tQueries.length;
        var viewLQueries = []; // An embedded view has queries propagated from a declaration view at the beginning of the
        // TQueries collection and up until a first content query declared in the embedded view. Only
        // propagated LQueries are created at this point (LQuery corresponding to declared content
        // queries will be instantiated from the content query instructions for each directive).

        for (var i = 0; i < noOfInheritedQueries; i++) {
          var tQuery = tQueries.getByIndex(i);
          var parentLQuery = this.queries[tQuery.indexInDeclarationView];
          viewLQueries.push(parentLQuery.clone());
        }

        return new LQueries_(viewLQueries);
      }

      return null;
    }
  }, {
    key: "insertView",
    value: function insertView(tView) {
      this.dirtyQueriesWithMatches(tView);
    }
  }, {
    key: "detachView",
    value: function detachView(tView) {
      this.dirtyQueriesWithMatches(tView);
    }
  }, {
    key: "dirtyQueriesWithMatches",
    value: function dirtyQueriesWithMatches(tView) {
      for (var i = 0; i < this.queries.length; i++) {
        if (getTQuery(tView, i).matches !== null) {
          this.queries[i].setDirty();
        }
      }
    }
  }]);

  return LQueries_;
}();

var TQueryMetadata_ = function TQueryMetadata_(predicate, descendants, isStatic) {
  var read = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TQueryMetadata_);

  this.predicate = predicate;
  this.descendants = descendants;
  this.isStatic = isStatic;
  this.read = read;
};

var TQueries_ = /*#__PURE__*/function () {
  function TQueries_() {
    var queries = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TQueries_);

    this.queries = queries;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TQueries_, [{
    key: "elementStart",
    value: function elementStart(tView, tNode) {
      ngDevMode && assertFirstCreatePass(tView, 'Queries should collect results on the first template pass only');

      for (var i = 0; i < this.queries.length; i++) {
        this.queries[i].elementStart(tView, tNode);
      }
    }
  }, {
    key: "elementEnd",
    value: function elementEnd(tNode) {
      for (var i = 0; i < this.queries.length; i++) {
        this.queries[i].elementEnd(tNode);
      }
    }
  }, {
    key: "embeddedTView",
    value: function embeddedTView(tNode) {
      var queriesForTemplateRef = null;

      for (var i = 0; i < this.length; i++) {
        var childQueryIndex = queriesForTemplateRef !== null ? queriesForTemplateRef.length : 0;
        var tqueryClone = this.getByIndex(i).embeddedTView(tNode, childQueryIndex);

        if (tqueryClone) {
          tqueryClone.indexInDeclarationView = i;

          if (queriesForTemplateRef !== null) {
            queriesForTemplateRef.push(tqueryClone);
          } else {
            queriesForTemplateRef = [tqueryClone];
          }
        }
      }

      return queriesForTemplateRef !== null ? new TQueries_(queriesForTemplateRef) : null;
    }
  }, {
    key: "template",
    value: function template(tView, tNode) {
      ngDevMode && assertFirstCreatePass(tView, 'Queries should collect results on the first template pass only');

      for (var i = 0; i < this.queries.length; i++) {
        this.queries[i].template(tView, tNode);
      }
    }
  }, {
    key: "getByIndex",
    value: function getByIndex(index) {
      ngDevMode && assertIndexInRange(this.queries, index);
      return this.queries[index];
    }
  }, {
    key: "track",
    value: function track(tquery) {
      this.queries.push(tquery);
    }
  }, {
    key: "length",
    get: function get() {
      return this.queries.length;
    }
  }]);

  return TQueries_;
}();

var TQuery_ = /*#__PURE__*/function () {
  function TQuery_(metadata) {
    var nodeIndex = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TQuery_);

    this.metadata = metadata;
    this.matches = null;
    this.indexInDeclarationView = -1;
    this.crossesNgTemplate = false;
    /**
     * A flag indicating if a given query still applies to nodes it is crossing. We use this flag
     * (alongside with _declarationNodeIndex) to know when to stop applying content queries to
     * elements in a template.
     */

    this._appliesToNextNode = true;
    this._declarationNodeIndex = nodeIndex;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TQuery_, [{
    key: "elementStart",
    value: function elementStart(tView, tNode) {
      if (this.isApplyingToNode(tNode)) {
        this.matchTNode(tView, tNode);
      }
    }
  }, {
    key: "elementEnd",
    value: function elementEnd(tNode) {
      if (this._declarationNodeIndex === tNode.index) {
        this._appliesToNextNode = false;
      }
    }
  }, {
    key: "template",
    value: function template(tView, tNode) {
      this.elementStart(tView, tNode);
    }
  }, {
    key: "embeddedTView",
    value: function embeddedTView(tNode, childQueryIndex) {
      if (this.isApplyingToNode(tNode)) {
        this.crossesNgTemplate = true; // A marker indicating a `<ng-template>` element (a placeholder for query results from
        // embedded views created based on this `<ng-template>`).

        this.addMatch(-tNode.index, childQueryIndex);
        return new TQuery_(this.metadata);
      }

      return null;
    }
  }, {
    key: "isApplyingToNode",
    value: function isApplyingToNode(tNode) {
      if (this._appliesToNextNode && this.metadata.descendants === false) {
        var declarationNodeIdx = this._declarationNodeIndex;
        var parent = tNode.parent; // Determine if a given TNode is a "direct" child of a node on which a content query was
        // declared (only direct children of query's host node can match with the descendants: false
        // option). There are 3 main use-case / conditions to consider here:
        // - <needs-target><i #target></i></needs-target>: here <i #target> parent node is a query
        // host node;
        // - <needs-target><ng-template [ngIf]="true"><i #target></i></ng-template></needs-target>:
        // here <i #target> parent node is null;
        // - <needs-target><ng-container><i #target></i></ng-container></needs-target>: here we need
        // to go past `<ng-container>` to determine <i #target> parent node (but we shouldn't traverse
        // up past the query's host node!).

        while (parent !== null && parent.type === 3
        /* ElementContainer */
        && parent.index !== declarationNodeIdx) {
          parent = parent.parent;
        }

        return declarationNodeIdx === (parent !== null ? parent.index : -1);
      }

      return this._appliesToNextNode;
    }
  }, {
    key: "matchTNode",
    value: function matchTNode(tView, tNode) {
      var predicate = this.metadata.predicate;

      if (Array.isArray(predicate)) {
        for (var i = 0; i < predicate.length; i++) {
          var name = predicate[i];
          this.matchTNodeWithReadOption(tView, tNode, getIdxOfMatchingSelector(tNode, name)); // Also try matching the name to a provider since strings can be used as DI tokens too.

          this.matchTNodeWithReadOption(tView, tNode, locateDirectiveOrProvider(tNode, tView, name, false, false));
        }
      } else {
        if (predicate === TemplateRef) {
          if (tNode.type === 0
          /* Container */
          ) {
              this.matchTNodeWithReadOption(tView, tNode, -1);
            }
        } else {
          this.matchTNodeWithReadOption(tView, tNode, locateDirectiveOrProvider(tNode, tView, predicate, false, false));
        }
      }
    }
  }, {
    key: "matchTNodeWithReadOption",
    value: function matchTNodeWithReadOption(tView, tNode, nodeMatchIdx) {
      if (nodeMatchIdx !== null) {
        var read = this.metadata.read;

        if (read !== null) {
          if (read === ElementRef || read === ViewContainerRef || read === TemplateRef && tNode.type === 0
          /* Container */
          ) {
              this.addMatch(tNode.index, -2);
            } else {
            var directiveOrProviderIdx = locateDirectiveOrProvider(tNode, tView, read, false, false);

            if (directiveOrProviderIdx !== null) {
              this.addMatch(tNode.index, directiveOrProviderIdx);
            }
          }
        } else {
          this.addMatch(tNode.index, nodeMatchIdx);
        }
      }
    }
  }, {
    key: "addMatch",
    value: function addMatch(tNodeIdx, matchIdx) {
      if (this.matches === null) {
        this.matches = [tNodeIdx, matchIdx];
      } else {
        this.matches.push(tNodeIdx, matchIdx);
      }
    }
  }]);

  return TQuery_;
}();
/**
 * Iterates over local names for a given node and returns directive index
 * (or -1 if a local name points to an element).
 *
 * @param tNode static data of a node to check
 * @param selector selector to match
 * @returns directive index, -1 or null if a selector didn't match any of the local names
 */


function getIdxOfMatchingSelector(tNode, selector) {
  var localNames = tNode.localNames;

  if (localNames !== null) {
    for (var i = 0; i < localNames.length; i += 2) {
      if (localNames[i] === selector) {
        return localNames[i + 1];
      }
    }
  }

  return null;
}

function createResultByTNodeType(tNode, currentView) {
  if (tNode.type === 2
  /* Element */
  || tNode.type === 3
  /* ElementContainer */
  ) {
      return createElementRef(ElementRef, tNode, currentView);
    } else if (tNode.type === 0
  /* Container */
  ) {
      return createTemplateRef(TemplateRef, ElementRef, tNode, currentView);
    }

  return null;
}

function createResultForNode(lView, tNode, matchingIdx, read) {
  if (matchingIdx === -1) {
    // if read token and / or strategy is not specified, detect it using appropriate tNode type
    return createResultByTNodeType(tNode, lView);
  } else if (matchingIdx === -2) {
    // read a special token from a node injector
    return createSpecialToken(lView, tNode, read);
  } else {
    // read a token
    return getNodeInjectable(lView, lView[TVIEW], matchingIdx, tNode);
  }
}

function createSpecialToken(lView, tNode, read) {
  if (read === ElementRef) {
    return createElementRef(ElementRef, tNode, lView);
  } else if (read === TemplateRef) {
    return createTemplateRef(TemplateRef, ElementRef, tNode, lView);
  } else if (read === ViewContainerRef) {
    ngDevMode && assertNodeOfPossibleTypes(tNode, [2
    /* Element */
    , 0
    /* Container */
    , 3
    /* ElementContainer */
    ]);
    return createContainerRef(ViewContainerRef, ElementRef, tNode, lView);
  } else {
    ngDevMode && throwError("Special token to read should be one of ElementRef, TemplateRef or ViewContainerRef but got ".concat(stringify(read), "."));
  }
}
/**
 * A helper function that creates query results for a given view. This function is meant to do the
 * processing once and only once for a given view instance (a set of results for a given view
 * doesn't change).
 */


function materializeViewResults(tView, lView, tQuery, queryIndex) {
  var lQuery = lView[QUERIES].queries[queryIndex];

  if (lQuery.matches === null) {
    var tViewData = tView.data;
    var tQueryMatches = tQuery.matches;
    var result = [];

    for (var i = 0; i < tQueryMatches.length; i += 2) {
      var matchedNodeIdx = tQueryMatches[i];

      if (matchedNodeIdx < 0) {
        // we at the <ng-template> marker which might have results in views created based on this
        // <ng-template> - those results will be in separate views though, so here we just leave
        // null as a placeholder
        result.push(null);
      } else {
        ngDevMode && assertIndexInRange(tViewData, matchedNodeIdx);
        var tNode = tViewData[matchedNodeIdx];
        result.push(createResultForNode(lView, tNode, tQueryMatches[i + 1], tQuery.metadata.read));
      }
    }

    lQuery.matches = result;
  }

  return lQuery.matches;
}
/**
 * A helper function that collects (already materialized) query results from a tree of views,
 * starting with a provided LView.
 */


function collectQueryResults(tView, lView, queryIndex, result) {
  var tQuery = tView.queries.getByIndex(queryIndex);
  var tQueryMatches = tQuery.matches;

  if (tQueryMatches !== null) {
    var lViewResults = materializeViewResults(tView, lView, tQuery, queryIndex);

    for (var i = 0; i < tQueryMatches.length; i += 2) {
      var tNodeIdx = tQueryMatches[i];

      if (tNodeIdx > 0) {
        result.push(lViewResults[i / 2]);
      } else {
        var childQueryIndex = tQueryMatches[i + 1];
        var declarationLContainer = lView[-tNodeIdx];
        ngDevMode && assertLContainer(declarationLContainer); // collect matches for views inserted in this container

        for (var _i8 = CONTAINER_HEADER_OFFSET; _i8 < declarationLContainer.length; _i8++) {
          var embeddedLView = declarationLContainer[_i8];

          if (embeddedLView[DECLARATION_LCONTAINER] === embeddedLView[PARENT]) {
            collectQueryResults(embeddedLView[TVIEW], embeddedLView, childQueryIndex, result);
          }
        } // collect matches for views created from this declaration container and inserted into
        // different containers


        if (declarationLContainer[MOVED_VIEWS] !== null) {
          var embeddedLViews = declarationLContainer[MOVED_VIEWS];

          for (var _i9 = 0; _i9 < embeddedLViews.length; _i9++) {
            var _embeddedLView = embeddedLViews[_i9];
            collectQueryResults(_embeddedLView[TVIEW], _embeddedLView, childQueryIndex, result);
          }
        }
      }
    }
  }

  return result;
}
/**
 * Refreshes a query by combining matches from all active views and removing matches from deleted
 * views.
 *
 * @returns `true` if a query got dirty during change detection or if this is a static query
 * resolving in creation mode, `false` otherwise.
 *
 * @codeGenApi
 */


function ɵɵqueryRefresh(queryList) {
  var lView = getLView();
  var tView = getTView();
  var queryIndex = getCurrentQueryIndex();
  setCurrentQueryIndex(queryIndex + 1);
  var tQuery = getTQuery(tView, queryIndex);

  if (queryList.dirty && isCreationMode(lView) === tQuery.metadata.isStatic) {
    if (tQuery.matches === null) {
      queryList.reset([]);
    } else {
      var result = tQuery.crossesNgTemplate ? collectQueryResults(tView, lView, queryIndex, []) : materializeViewResults(tView, lView, tQuery, queryIndex);
      queryList.reset(result);
      queryList.notifyOnChanges();
    }

    return true;
  }

  return false;
}
/**
 * Creates new QueryList for a static view query.
 *
 * @param predicate The type for which the query will search
 * @param descend Whether or not to descend into children
 * @param read What to save in the query
 *
 * @codeGenApi
 */


function ɵɵstaticViewQuery(predicate, descend, read) {
  viewQueryInternal(getTView(), getLView(), predicate, descend, read, true);
}
/**
 * Creates new QueryList, stores the reference in LView and returns QueryList.
 *
 * @param predicate The type for which the query will search
 * @param descend Whether or not to descend into children
 * @param read What to save in the query
 *
 * @codeGenApi
 */


function ɵɵviewQuery(predicate, descend, read) {
  viewQueryInternal(getTView(), getLView(), predicate, descend, read, false);
}

function viewQueryInternal(tView, lView, predicate, descend, read, isStatic) {
  if (tView.firstCreatePass) {
    createTQuery(tView, new TQueryMetadata_(predicate, descend, isStatic, read), -1);

    if (isStatic) {
      tView.staticViewQueries = true;
    }
  }

  createLQuery(tView, lView);
}
/**
 * Registers a QueryList, associated with a content query, for later refresh (part of a view
 * refresh).
 *
 * @param directiveIndex Current directive index
 * @param predicate The type for which the query will search
 * @param descend Whether or not to descend into children
 * @param read What to save in the query
 * @returns QueryList<T>
 *
 * @codeGenApi
 */


function ɵɵcontentQuery(directiveIndex, predicate, descend, read) {
  contentQueryInternal(getTView(), getLView(), predicate, descend, read, false, getCurrentTNode(), directiveIndex);
}
/**
 * Registers a QueryList, associated with a static content query, for later refresh
 * (part of a view refresh).
 *
 * @param directiveIndex Current directive index
 * @param predicate The type for which the query will search
 * @param descend Whether or not to descend into children
 * @param read What to save in the query
 * @returns QueryList<T>
 *
 * @codeGenApi
 */


function ɵɵstaticContentQuery(directiveIndex, predicate, descend, read) {
  contentQueryInternal(getTView(), getLView(), predicate, descend, read, true, getCurrentTNode(), directiveIndex);
}

function contentQueryInternal(tView, lView, predicate, descend, read, isStatic, tNode, directiveIndex) {
  if (tView.firstCreatePass) {
    createTQuery(tView, new TQueryMetadata_(predicate, descend, isStatic, read), tNode.index);
    saveContentQueryAndDirectiveIndex(tView, directiveIndex);

    if (isStatic) {
      tView.staticContentQueries = true;
    }
  }

  createLQuery(tView, lView);
}
/**
 * Loads a QueryList corresponding to the current view or content query.
 *
 * @codeGenApi
 */


function ɵɵloadQuery() {
  return loadQueryInternal(getLView(), getCurrentQueryIndex());
}

function loadQueryInternal(lView, queryIndex) {
  ngDevMode && assertDefined(lView[QUERIES], 'LQueries should be defined when trying to load a query');
  ngDevMode && assertIndexInRange(lView[QUERIES].queries, queryIndex);
  return lView[QUERIES].queries[queryIndex].queryList;
}

function createLQuery(tView, lView) {
  var queryList = new QueryList();
  storeCleanupWithContext(tView, lView, queryList, queryList.destroy);
  if (lView[QUERIES] === null) lView[QUERIES] = new LQueries_();
  lView[QUERIES].queries.push(new LQuery_(queryList));
}

function createTQuery(tView, metadata, nodeIndex) {
  if (tView.queries === null) tView.queries = new TQueries_();
  tView.queries.track(new TQuery_(metadata, nodeIndex));
}

function saveContentQueryAndDirectiveIndex(tView, directiveIndex) {
  var tViewContentQueries = tView.contentQueries || (tView.contentQueries = []);
  var lastSavedDirectiveIndex = tView.contentQueries.length ? tViewContentQueries[tViewContentQueries.length - 1] : -1;

  if (directiveIndex !== lastSavedDirectiveIndex) {
    tViewContentQueries.push(tView.queries.length - 1, directiveIndex);
  }
}

function getTQuery(tView, index) {
  ngDevMode && assertDefined(tView.queries, 'TQueries must be defined to retrieve a TQuery');
  return tView.queries.getByIndex(index);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Retrieves `TemplateRef` instance from `Injector` when a local reference is placed on the
 * `<ng-template>` element.
 *
 * @codeGenApi
 */


function ɵɵtemplateRefExtractor(tNode, currentView) {
  return createTemplateRef(TemplateRef, ElementRef, tNode, currentView);
}
/**
 * Returns the appropriate `ChangeDetectorRef` for a pipe.
 *
 * @codeGenApi
 */


function ɵɵinjectPipeChangeDetectorRef() {
  var flags = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : InjectFlags.Default;
  var value = injectChangeDetectorRef(true);

  if (value == null && !(flags & InjectFlags.Optional)) {
    throw new Error("No provider for ChangeDetectorRef!");
  } else {
    return value;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$d = function ɵ0$d() {
  return {
    'ɵɵattribute': ɵɵattribute,
    'ɵɵattributeInterpolate1': ɵɵattributeInterpolate1,
    'ɵɵattributeInterpolate2': ɵɵattributeInterpolate2,
    'ɵɵattributeInterpolate3': ɵɵattributeInterpolate3,
    'ɵɵattributeInterpolate4': ɵɵattributeInterpolate4,
    'ɵɵattributeInterpolate5': ɵɵattributeInterpolate5,
    'ɵɵattributeInterpolate6': ɵɵattributeInterpolate6,
    'ɵɵattributeInterpolate7': ɵɵattributeInterpolate7,
    'ɵɵattributeInterpolate8': ɵɵattributeInterpolate8,
    'ɵɵattributeInterpolateV': ɵɵattributeInterpolateV,
    'ɵɵdefineComponent': ɵɵdefineComponent,
    'ɵɵdefineDirective': ɵɵdefineDirective,
    'ɵɵdefineInjectable': ɵɵdefineInjectable,
    'ɵɵdefineInjector': ɵɵdefineInjector,
    'ɵɵdefineNgModule': ɵɵdefineNgModule,
    'ɵɵdefinePipe': ɵɵdefinePipe,
    'ɵɵdirectiveInject': ɵɵdirectiveInject,
    'ɵɵgetFactoryOf': ɵɵgetFactoryOf,
    'ɵɵgetInheritedFactory': ɵɵgetInheritedFactory,
    'ɵɵinject': ɵɵinject,
    'ɵɵinjectAttribute': ɵɵinjectAttribute,
    'ɵɵinvalidFactory': ɵɵinvalidFactory,
    'ɵɵinvalidFactoryDep': ɵɵinvalidFactoryDep,
    'ɵɵinjectPipeChangeDetectorRef': ɵɵinjectPipeChangeDetectorRef,
    'ɵɵtemplateRefExtractor': ɵɵtemplateRefExtractor,
    'ɵɵNgOnChangesFeature': ɵɵNgOnChangesFeature,
    'ɵɵProvidersFeature': ɵɵProvidersFeature,
    'ɵɵCopyDefinitionFeature': ɵɵCopyDefinitionFeature,
    'ɵɵInheritDefinitionFeature': ɵɵInheritDefinitionFeature,
    'ɵɵnextContext': ɵɵnextContext,
    'ɵɵnamespaceHTML': ɵɵnamespaceHTML,
    'ɵɵnamespaceMathML': ɵɵnamespaceMathML,
    'ɵɵnamespaceSVG': ɵɵnamespaceSVG,
    'ɵɵenableBindings': ɵɵenableBindings,
    'ɵɵdisableBindings': ɵɵdisableBindings,
    'ɵɵelementStart': ɵɵelementStart,
    'ɵɵelementEnd': ɵɵelementEnd,
    'ɵɵelement': ɵɵelement,
    'ɵɵelementContainerStart': ɵɵelementContainerStart,
    'ɵɵelementContainerEnd': ɵɵelementContainerEnd,
    'ɵɵelementContainer': ɵɵelementContainer,
    'ɵɵpureFunction0': ɵɵpureFunction0,
    'ɵɵpureFunction1': ɵɵpureFunction1,
    'ɵɵpureFunction2': ɵɵpureFunction2,
    'ɵɵpureFunction3': ɵɵpureFunction3,
    'ɵɵpureFunction4': ɵɵpureFunction4,
    'ɵɵpureFunction5': ɵɵpureFunction5,
    'ɵɵpureFunction6': ɵɵpureFunction6,
    'ɵɵpureFunction7': ɵɵpureFunction7,
    'ɵɵpureFunction8': ɵɵpureFunction8,
    'ɵɵpureFunctionV': ɵɵpureFunctionV,
    'ɵɵgetCurrentView': ɵɵgetCurrentView,
    'ɵɵrestoreView': ɵɵrestoreView,
    'ɵɵlistener': ɵɵlistener,
    'ɵɵprojection': ɵɵprojection,
    'ɵɵsyntheticHostProperty': ɵɵsyntheticHostProperty,
    'ɵɵsyntheticHostListener': ɵɵsyntheticHostListener,
    'ɵɵpipeBind1': ɵɵpipeBind1,
    'ɵɵpipeBind2': ɵɵpipeBind2,
    'ɵɵpipeBind3': ɵɵpipeBind3,
    'ɵɵpipeBind4': ɵɵpipeBind4,
    'ɵɵpipeBindV': ɵɵpipeBindV,
    'ɵɵprojectionDef': ɵɵprojectionDef,
    'ɵɵhostProperty': ɵɵhostProperty,
    'ɵɵproperty': ɵɵproperty,
    'ɵɵpropertyInterpolate': ɵɵpropertyInterpolate,
    'ɵɵpropertyInterpolate1': ɵɵpropertyInterpolate1,
    'ɵɵpropertyInterpolate2': ɵɵpropertyInterpolate2,
    'ɵɵpropertyInterpolate3': ɵɵpropertyInterpolate3,
    'ɵɵpropertyInterpolate4': ɵɵpropertyInterpolate4,
    'ɵɵpropertyInterpolate5': ɵɵpropertyInterpolate5,
    'ɵɵpropertyInterpolate6': ɵɵpropertyInterpolate6,
    'ɵɵpropertyInterpolate7': ɵɵpropertyInterpolate7,
    'ɵɵpropertyInterpolate8': ɵɵpropertyInterpolate8,
    'ɵɵpropertyInterpolateV': ɵɵpropertyInterpolateV,
    'ɵɵpipe': ɵɵpipe,
    'ɵɵqueryRefresh': ɵɵqueryRefresh,
    'ɵɵviewQuery': ɵɵviewQuery,
    'ɵɵstaticViewQuery': ɵɵstaticViewQuery,
    'ɵɵstaticContentQuery': ɵɵstaticContentQuery,
    'ɵɵloadQuery': ɵɵloadQuery,
    'ɵɵcontentQuery': ɵɵcontentQuery,
    'ɵɵreference': ɵɵreference,
    'ɵɵclassMap': ɵɵclassMap,
    'ɵɵclassMapInterpolate1': ɵɵclassMapInterpolate1,
    'ɵɵclassMapInterpolate2': ɵɵclassMapInterpolate2,
    'ɵɵclassMapInterpolate3': ɵɵclassMapInterpolate3,
    'ɵɵclassMapInterpolate4': ɵɵclassMapInterpolate4,
    'ɵɵclassMapInterpolate5': ɵɵclassMapInterpolate5,
    'ɵɵclassMapInterpolate6': ɵɵclassMapInterpolate6,
    'ɵɵclassMapInterpolate7': ɵɵclassMapInterpolate7,
    'ɵɵclassMapInterpolate8': ɵɵclassMapInterpolate8,
    'ɵɵclassMapInterpolateV': ɵɵclassMapInterpolateV,
    'ɵɵstyleMap': ɵɵstyleMap,
    'ɵɵstyleMapInterpolate1': ɵɵstyleMapInterpolate1,
    'ɵɵstyleMapInterpolate2': ɵɵstyleMapInterpolate2,
    'ɵɵstyleMapInterpolate3': ɵɵstyleMapInterpolate3,
    'ɵɵstyleMapInterpolate4': ɵɵstyleMapInterpolate4,
    'ɵɵstyleMapInterpolate5': ɵɵstyleMapInterpolate5,
    'ɵɵstyleMapInterpolate6': ɵɵstyleMapInterpolate6,
    'ɵɵstyleMapInterpolate7': ɵɵstyleMapInterpolate7,
    'ɵɵstyleMapInterpolate8': ɵɵstyleMapInterpolate8,
    'ɵɵstyleMapInterpolateV': ɵɵstyleMapInterpolateV,
    'ɵɵstyleProp': ɵɵstyleProp,
    'ɵɵstylePropInterpolate1': ɵɵstylePropInterpolate1,
    'ɵɵstylePropInterpolate2': ɵɵstylePropInterpolate2,
    'ɵɵstylePropInterpolate3': ɵɵstylePropInterpolate3,
    'ɵɵstylePropInterpolate4': ɵɵstylePropInterpolate4,
    'ɵɵstylePropInterpolate5': ɵɵstylePropInterpolate5,
    'ɵɵstylePropInterpolate6': ɵɵstylePropInterpolate6,
    'ɵɵstylePropInterpolate7': ɵɵstylePropInterpolate7,
    'ɵɵstylePropInterpolate8': ɵɵstylePropInterpolate8,
    'ɵɵstylePropInterpolateV': ɵɵstylePropInterpolateV,
    'ɵɵclassProp': ɵɵclassProp,
    'ɵɵadvance': ɵɵadvance,
    'ɵɵtemplate': ɵɵtemplate,
    'ɵɵtext': ɵɵtext,
    'ɵɵtextInterpolate': ɵɵtextInterpolate,
    'ɵɵtextInterpolate1': ɵɵtextInterpolate1,
    'ɵɵtextInterpolate2': ɵɵtextInterpolate2,
    'ɵɵtextInterpolate3': ɵɵtextInterpolate3,
    'ɵɵtextInterpolate4': ɵɵtextInterpolate4,
    'ɵɵtextInterpolate5': ɵɵtextInterpolate5,
    'ɵɵtextInterpolate6': ɵɵtextInterpolate6,
    'ɵɵtextInterpolate7': ɵɵtextInterpolate7,
    'ɵɵtextInterpolate8': ɵɵtextInterpolate8,
    'ɵɵtextInterpolateV': ɵɵtextInterpolateV,
    'ɵɵi18n': ɵɵi18n,
    'ɵɵi18nAttributes': ɵɵi18nAttributes,
    'ɵɵi18nExp': ɵɵi18nExp,
    'ɵɵi18nStart': ɵɵi18nStart,
    'ɵɵi18nEnd': ɵɵi18nEnd,
    'ɵɵi18nApply': ɵɵi18nApply,
    'ɵɵi18nPostprocess': ɵɵi18nPostprocess,
    'ɵɵresolveWindow': ɵɵresolveWindow,
    'ɵɵresolveDocument': ɵɵresolveDocument,
    'ɵɵresolveBody': ɵɵresolveBody,
    'ɵɵsetComponentScope': ɵɵsetComponentScope,
    'ɵɵsetNgModuleScope': ɵɵsetNgModuleScope,
    'ɵɵsanitizeHtml': ɵɵsanitizeHtml,
    'ɵɵsanitizeStyle': ɵɵsanitizeStyle,
    'ɵɵsanitizeResourceUrl': ɵɵsanitizeResourceUrl,
    'ɵɵsanitizeScript': ɵɵsanitizeScript,
    'ɵɵsanitizeUrl': ɵɵsanitizeUrl,
    'ɵɵsanitizeUrlOrResourceUrl': ɵɵsanitizeUrlOrResourceUrl
  };
};
/**
 * A mapping of the @angular/core API surface used in generated expressions to the actual symbols.
 *
 * This should be kept up to date with the public exports of @angular/core.
 */


var angularCoreEnv = ɵ0$d();
var jitOptions = null;

function setJitOptions(options) {
  if (jitOptions !== null) {
    if (options.defaultEncapsulation !== jitOptions.defaultEncapsulation) {
      ngDevMode && console.error('Provided value for `defaultEncapsulation` can not be changed once it has been set.');
      return;
    }

    if (options.preserveWhitespaces !== jitOptions.preserveWhitespaces) {
      ngDevMode && console.error('Provided value for `preserveWhitespaces` can not be changed once it has been set.');
      return;
    }
  }

  jitOptions = options;
}

function getJitOptions() {
  return jitOptions;
}

function resetJitOptions() {
  jitOptions = null;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var EMPTY_ARRAY$5 = [];
var moduleQueue = [];
/**
 * Enqueues moduleDef to be checked later to see if scope can be set on its
 * component declarations.
 */

function enqueueModuleForDelayedScoping(moduleType, ngModule) {
  moduleQueue.push({
    moduleType: moduleType,
    ngModule: ngModule
  });
}

var flushingModuleQueue = false;
/**
 * Loops over queued module definitions, if a given module definition has all of its
 * declarations resolved, it dequeues that module definition and sets the scope on
 * its declarations.
 */

function flushModuleScopingQueueAsMuchAsPossible() {
  if (!flushingModuleQueue) {
    flushingModuleQueue = true;

    try {
      for (var i = moduleQueue.length - 1; i >= 0; i--) {
        var _moduleQueue$i = moduleQueue[i],
            moduleType = _moduleQueue$i.moduleType,
            ngModule = _moduleQueue$i.ngModule;

        if (ngModule.declarations && ngModule.declarations.every(isResolvedDeclaration)) {
          // dequeue
          moduleQueue.splice(i, 1);
          setScopeOnDeclaredComponents(moduleType, ngModule);
        }
      }
    } finally {
      flushingModuleQueue = false;
    }
  }
}
/**
 * Returns truthy if a declaration has resolved. If the declaration happens to be
 * an array of declarations, it will recurse to check each declaration in that array
 * (which may also be arrays).
 */


function isResolvedDeclaration(declaration) {
  if (Array.isArray(declaration)) {
    return declaration.every(isResolvedDeclaration);
  }

  return !!resolveForwardRef(declaration);
}
/**
 * Compiles a module in JIT mode.
 *
 * This function automatically gets called when a class has a `@NgModule` decorator.
 */


function compileNgModule(moduleType) {
  var ngModule = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  compileNgModuleDefs(moduleType, ngModule); // Because we don't know if all declarations have resolved yet at the moment the
  // NgModule decorator is executing, we're enqueueing the setting of module scope
  // on its declarations to be run at a later time when all declarations for the module,
  // including forward refs, have resolved.

  enqueueModuleForDelayedScoping(moduleType, ngModule);
}
/**
 * Compiles and adds the `ɵmod` and `ɵinj` properties to the module class.
 *
 * It's possible to compile a module via this API which will allow duplicate declarations in its
 * root.
 */


function compileNgModuleDefs(moduleType, ngModule) {
  var allowDuplicateDeclarationsInRoot = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  ngDevMode && assertDefined(moduleType, 'Required value moduleType');
  ngDevMode && assertDefined(ngModule, 'Required value ngModule');
  var declarations = flatten(ngModule.declarations || EMPTY_ARRAY$5);
  var ngModuleDef = null;
  Object.defineProperty(moduleType, NG_MOD_DEF, {
    configurable: true,
    get: function get() {
      if (ngModuleDef === null) {
        if (ngDevMode && ngModule.imports && ngModule.imports.indexOf(moduleType) > -1) {
          // We need to assert this immediately, because allowing it to continue will cause it to
          // go into an infinite loop before we've reached the point where we throw all the errors.
          throw new Error("'".concat(stringifyForError(moduleType), "' module can't import itself"));
        }

        ngModuleDef = getCompilerFacade().compileNgModule(angularCoreEnv, "ng:///".concat(moduleType.name, "/\u0275mod.js"), {
          type: moduleType,
          bootstrap: flatten(ngModule.bootstrap || EMPTY_ARRAY$5).map(resolveForwardRef),
          declarations: declarations.map(resolveForwardRef),
          imports: flatten(ngModule.imports || EMPTY_ARRAY$5).map(resolveForwardRef).map(expandModuleWithProviders),
          exports: flatten(ngModule.exports || EMPTY_ARRAY$5).map(resolveForwardRef).map(expandModuleWithProviders),
          schemas: ngModule.schemas ? flatten(ngModule.schemas) : null,
          id: ngModule.id || null
        }); // Set `schemas` on ngModuleDef to an empty array in JIT mode to indicate that runtime
        // should verify that there are no unknown elements in a template. In AOT mode, that check
        // happens at compile time and `schemas` information is not present on Component and Module
        // defs after compilation (so the check doesn't happen the second time at runtime).

        if (!ngModuleDef.schemas) {
          ngModuleDef.schemas = [];
        }
      }

      return ngModuleDef;
    }
  });
  var ngInjectorDef = null;
  Object.defineProperty(moduleType, NG_INJ_DEF, {
    get: function get() {
      if (ngInjectorDef === null) {
        ngDevMode && verifySemanticsOfNgModuleDef(moduleType, allowDuplicateDeclarationsInRoot);
        var meta = {
          name: moduleType.name,
          type: moduleType,
          deps: reflectDependencies(moduleType),
          providers: ngModule.providers || EMPTY_ARRAY$5,
          imports: [(ngModule.imports || EMPTY_ARRAY$5).map(resolveForwardRef), (ngModule.exports || EMPTY_ARRAY$5).map(resolveForwardRef)]
        };
        ngInjectorDef = getCompilerFacade().compileInjector(angularCoreEnv, "ng:///".concat(moduleType.name, "/\u0275inj.js"), meta);
      }

      return ngInjectorDef;
    },
    // Make the property configurable in dev mode to allow overriding in tests
    configurable: !!ngDevMode
  });
}

function verifySemanticsOfNgModuleDef(moduleType, allowDuplicateDeclarationsInRoot, importingModule) {
  if (verifiedNgModule.get(moduleType)) return;
  verifiedNgModule.set(moduleType, true);
  moduleType = resolveForwardRef(moduleType);
  var ngModuleDef;

  if (importingModule) {
    ngModuleDef = getNgModuleDef(moduleType);

    if (!ngModuleDef) {
      throw new Error("Unexpected value '".concat(moduleType.name, "' imported by the module '").concat(importingModule.name, "'. Please add an @NgModule annotation."));
    }
  } else {
    ngModuleDef = getNgModuleDef(moduleType, true);
  }

  var errors = [];
  var declarations = maybeUnwrapFn(ngModuleDef.declarations);
  var imports = maybeUnwrapFn(ngModuleDef.imports);
  flatten(imports).map(unwrapModuleWithProvidersImports).forEach(function (mod) {
    verifySemanticsOfNgModuleImport(mod, moduleType);
    verifySemanticsOfNgModuleDef(mod, false, moduleType);
  });
  var exports = maybeUnwrapFn(ngModuleDef.exports);
  declarations.forEach(verifyDeclarationsHaveDefinitions);
  declarations.forEach(verifyDirectivesHaveSelector);
  var combinedDeclarations = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(declarations.map(resolveForwardRef)), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(flatten(imports.map(computeCombinedExports)).map(resolveForwardRef)));
  exports.forEach(verifyExportsAreDeclaredOrReExported);
  declarations.forEach(function (decl) {
    return verifyDeclarationIsUnique(decl, allowDuplicateDeclarationsInRoot);
  });
  declarations.forEach(verifyComponentEntryComponentsIsPartOfNgModule);
  var ngModule = getAnnotation(moduleType, 'NgModule');

  if (ngModule) {
    ngModule.imports && flatten(ngModule.imports).map(unwrapModuleWithProvidersImports).forEach(function (mod) {
      verifySemanticsOfNgModuleImport(mod, moduleType);
      verifySemanticsOfNgModuleDef(mod, false, moduleType);
    });
    ngModule.bootstrap && deepForEach(ngModule.bootstrap, verifyCorrectBootstrapType);
    ngModule.bootstrap && deepForEach(ngModule.bootstrap, verifyComponentIsPartOfNgModule);
    ngModule.entryComponents && deepForEach(ngModule.entryComponents, verifyComponentIsPartOfNgModule);
  } // Throw Error if any errors were detected.


  if (errors.length) {
    throw new Error(errors.join('\n'));
  } ////////////////////////////////////////////////////////////////////////////////////////////////


  function verifyDeclarationsHaveDefinitions(type) {
    type = resolveForwardRef(type);
    var def = getComponentDef(type) || getDirectiveDef(type) || getPipeDef(type);

    if (!def) {
      errors.push("Unexpected value '".concat(stringifyForError(type), "' declared by the module '").concat(stringifyForError(moduleType), "'. Please add a @Pipe/@Directive/@Component annotation."));
    }
  }

  function verifyDirectivesHaveSelector(type) {
    type = resolveForwardRef(type);
    var def = getDirectiveDef(type);

    if (!getComponentDef(type) && def && def.selectors.length == 0) {
      errors.push("Directive ".concat(stringifyForError(type), " has no selector, please add it!"));
    }
  }

  function verifyExportsAreDeclaredOrReExported(type) {
    type = resolveForwardRef(type);
    var kind = getComponentDef(type) && 'component' || getDirectiveDef(type) && 'directive' || getPipeDef(type) && 'pipe';

    if (kind) {
      // only checked if we are declared as Component, Directive, or Pipe
      // Modules don't need to be declared or imported.
      if (combinedDeclarations.lastIndexOf(type) === -1) {
        // We are exporting something which we don't explicitly declare or import.
        errors.push("Can't export ".concat(kind, " ").concat(stringifyForError(type), " from ").concat(stringifyForError(moduleType), " as it was neither declared nor imported!"));
      }
    }
  }

  function verifyDeclarationIsUnique(type, suppressErrors) {
    type = resolveForwardRef(type);
    var existingModule = ownerNgModule.get(type);

    if (existingModule && existingModule !== moduleType) {
      if (!suppressErrors) {
        var _modules = [existingModule, moduleType].map(stringifyForError).sort();

        errors.push("Type ".concat(stringifyForError(type), " is part of the declarations of 2 modules: ").concat(_modules[0], " and ").concat(_modules[1], "! ") + "Please consider moving ".concat(stringifyForError(type), " to a higher module that imports ").concat(_modules[0], " and ").concat(_modules[1], ". ") + "You can also create a new NgModule that exports and includes ".concat(stringifyForError(type), " then import that NgModule in ").concat(_modules[0], " and ").concat(_modules[1], "."));
      }
    } else {
      // Mark type as having owner.
      ownerNgModule.set(type, moduleType);
    }
  }

  function verifyComponentIsPartOfNgModule(type) {
    type = resolveForwardRef(type);
    var existingModule = ownerNgModule.get(type);

    if (!existingModule) {
      errors.push("Component ".concat(stringifyForError(type), " is not part of any NgModule or the module has not been imported into your module."));
    }
  }

  function verifyCorrectBootstrapType(type) {
    type = resolveForwardRef(type);

    if (!getComponentDef(type)) {
      errors.push("".concat(stringifyForError(type), " cannot be used as an entry component."));
    }
  }

  function verifyComponentEntryComponentsIsPartOfNgModule(type) {
    type = resolveForwardRef(type);

    if (getComponentDef(type)) {
      // We know we are component
      var component = getAnnotation(type, 'Component');

      if (component && component.entryComponents) {
        deepForEach(component.entryComponents, verifyComponentIsPartOfNgModule);
      }
    }
  }

  function verifySemanticsOfNgModuleImport(type, importingModule) {
    type = resolveForwardRef(type);

    if (getComponentDef(type) || getDirectiveDef(type)) {
      throw new Error("Unexpected directive '".concat(type.name, "' imported by the module '").concat(importingModule.name, "'. Please add an @NgModule annotation."));
    }

    if (getPipeDef(type)) {
      throw new Error("Unexpected pipe '".concat(type.name, "' imported by the module '").concat(importingModule.name, "'. Please add an @NgModule annotation."));
    }
  }
}

function unwrapModuleWithProvidersImports(typeOrWithProviders) {
  typeOrWithProviders = resolveForwardRef(typeOrWithProviders);
  return typeOrWithProviders.ngModule || typeOrWithProviders;
}

function getAnnotation(type, name) {
  var annotation = null;
  collect(type.__annotations__);
  collect(type.decorators);
  return annotation;

  function collect(annotations) {
    if (annotations) {
      annotations.forEach(readAnnotation);
    }
  }

  function readAnnotation(decorator) {
    if (!annotation) {
      var proto = Object.getPrototypeOf(decorator);

      if (proto.ngMetadataName == name) {
        annotation = decorator;
      } else if (decorator.type) {
        var _proto = Object.getPrototypeOf(decorator.type);

        if (_proto.ngMetadataName == name) {
          annotation = decorator.args[0];
        }
      }
    }
  }
}
/**
 * Keep track of compiled components. This is needed because in tests we often want to compile the
 * same component with more than one NgModule. This would cause an error unless we reset which
 * NgModule the component belongs to. We keep the list of compiled components here so that the
 * TestBed can reset it later.
 */


var ownerNgModule = new Map();
var verifiedNgModule = new Map();

function resetCompiledComponents() {
  ownerNgModule = new Map();
  verifiedNgModule = new Map();
  moduleQueue.length = 0;
}
/**
 * Computes the combined declarations of explicit declarations, as well as declarations inherited by
 * traversing the exports of imported modules.
 * @param type
 */


function computeCombinedExports(type) {
  type = resolveForwardRef(type);
  var ngModuleDef = getNgModuleDef(type, true);
  return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(flatten(maybeUnwrapFn(ngModuleDef.exports).map(function (type) {
    var ngModuleDef = getNgModuleDef(type);

    if (ngModuleDef) {
      verifySemanticsOfNgModuleDef(type, false);
      return computeCombinedExports(type);
    } else {
      return type;
    }
  })));
}
/**
 * Some declared components may be compiled asynchronously, and thus may not have their
 * ɵcmp set yet. If this is the case, then a reference to the module is written into
 * the `ngSelectorScope` property of the declared type.
 */


function setScopeOnDeclaredComponents(moduleType, ngModule) {
  var declarations = flatten(ngModule.declarations || EMPTY_ARRAY$5);
  var transitiveScopes = transitiveScopesFor(moduleType);
  declarations.forEach(function (declaration) {
    if (declaration.hasOwnProperty(NG_COMP_DEF)) {
      // A `ɵcmp` field exists - go ahead and patch the component directly.
      var component = declaration;
      var componentDef = getComponentDef(component);
      patchComponentDefWithScope(componentDef, transitiveScopes);
    } else if (!declaration.hasOwnProperty(NG_DIR_DEF) && !declaration.hasOwnProperty(NG_PIPE_DEF)) {
      // Set `ngSelectorScope` for future reference when the component compilation finishes.
      declaration.ngSelectorScope = moduleType;
    }
  });
}
/**
 * Patch the definition of a component with directives and pipes from the compilation scope of
 * a given module.
 */


function patchComponentDefWithScope(componentDef, transitiveScopes) {
  componentDef.directiveDefs = function () {
    return Array.from(transitiveScopes.compilation.directives).map(function (dir) {
      return dir.hasOwnProperty(NG_COMP_DEF) ? getComponentDef(dir) : getDirectiveDef(dir);
    }).filter(function (def) {
      return !!def;
    });
  };

  componentDef.pipeDefs = function () {
    return Array.from(transitiveScopes.compilation.pipes).map(function (pipe) {
      return getPipeDef(pipe);
    });
  };

  componentDef.schemas = transitiveScopes.schemas; // Since we avoid Components/Directives/Pipes recompiling in case there are no overrides, we
  // may face a problem where previously compiled defs available to a given Component/Directive
  // are cached in TView and may become stale (in case any of these defs gets recompiled). In
  // order to avoid this problem, we force fresh TView to be created.

  componentDef.tView = null;
}
/**
 * Compute the pair of transitive scopes (compilation scope and exported scope) for a given module.
 *
 * This operation is memoized and the result is cached on the module's definition. This function can
 * be called on modules with components that have not fully compiled yet, but the result should not
 * be used until they have.
 *
 * @param moduleType module that transitive scope should be calculated for.
 */


function transitiveScopesFor(moduleType) {
  if (!isNgModule(moduleType)) {
    throw new Error("".concat(moduleType.name, " does not have a module def (\u0275mod property)"));
  }

  var def = getNgModuleDef(moduleType);

  if (def.transitiveCompileScopes !== null) {
    return def.transitiveCompileScopes;
  }

  var scopes = {
    schemas: def.schemas || null,
    compilation: {
      directives: new Set(),
      pipes: new Set()
    },
    exported: {
      directives: new Set(),
      pipes: new Set()
    }
  };
  maybeUnwrapFn(def.imports).forEach(function (imported) {
    var importedType = imported;

    if (!isNgModule(importedType)) {
      throw new Error("Importing ".concat(importedType.name, " which does not have a \u0275mod property"));
    } // When this module imports another, the imported module's exported directives and pipes are
    // added to the compilation scope of this module.


    var importedScope = transitiveScopesFor(importedType);
    importedScope.exported.directives.forEach(function (entry) {
      return scopes.compilation.directives.add(entry);
    });
    importedScope.exported.pipes.forEach(function (entry) {
      return scopes.compilation.pipes.add(entry);
    });
  });
  maybeUnwrapFn(def.declarations).forEach(function (declared) {
    var declaredWithDefs = declared;

    if (getPipeDef(declaredWithDefs)) {
      scopes.compilation.pipes.add(declared);
    } else {
      // Either declared has a ɵcmp or ɵdir, or it's a component which hasn't
      // had its template compiled yet. In either case, it gets added to the compilation's
      // directives.
      scopes.compilation.directives.add(declared);
    }
  });
  maybeUnwrapFn(def.exports).forEach(function (exported) {
    var exportedType = exported; // Either the type is a module, a pipe, or a component/directive (which may not have a
    // ɵcmp as it might be compiled asynchronously).

    if (isNgModule(exportedType)) {
      // When this module exports another, the exported module's exported directives and pipes are
      // added to both the compilation and exported scopes of this module.
      var exportedScope = transitiveScopesFor(exportedType);
      exportedScope.exported.directives.forEach(function (entry) {
        scopes.compilation.directives.add(entry);
        scopes.exported.directives.add(entry);
      });
      exportedScope.exported.pipes.forEach(function (entry) {
        scopes.compilation.pipes.add(entry);
        scopes.exported.pipes.add(entry);
      });
    } else if (getPipeDef(exportedType)) {
      scopes.exported.pipes.add(exportedType);
    } else {
      scopes.exported.directives.add(exportedType);
    }
  });
  def.transitiveCompileScopes = scopes;
  return scopes;
}

function expandModuleWithProviders(value) {
  if (isModuleWithProviders(value)) {
    return value.ngModule;
  }

  return value;
}

function isModuleWithProviders(value) {
  return value.ngModule !== undefined;
}

function isNgModule(value) {
  return !!getNgModuleDef(value);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Keep track of the compilation depth to avoid reentrancy issues during JIT compilation. This
 * matters in the following scenario:
 *
 * Consider a component 'A' that extends component 'B', both declared in module 'M'. During
 * the compilation of 'A' the definition of 'B' is requested to capture the inheritance chain,
 * potentially triggering compilation of 'B'. If this nested compilation were to trigger
 * `flushModuleScopingQueueAsMuchAsPossible` it may happen that module 'M' is still pending in the
 * queue, resulting in 'A' and 'B' to be patched with the NgModule scope. As the compilation of
 * 'A' is still in progress, this would introduce a circular dependency on its compilation. To avoid
 * this issue, the module scope queue is only flushed for compilations at the depth 0, to ensure
 * all compilations have finished.
 */


var compilationDepth = 0;
/**
 * Compile an Angular component according to its decorator metadata, and patch the resulting
 * component def (ɵcmp) onto the component type.
 *
 * Compilation may be asynchronous (due to the need to resolve URLs for the component template or
 * other resources, for example). In the event that compilation is not immediate, `compileComponent`
 * will enqueue resource resolution into a global queue and will fail to return the `ɵcmp`
 * until the global queue has been resolved with a call to `resolveComponentResources`.
 */

function compileComponent(type, metadata) {
  // Initialize ngDevMode. This must be the first statement in compileComponent.
  // See the `initNgDevMode` docstring for more information.
  (typeof ngDevMode === 'undefined' || ngDevMode) && initNgDevMode();
  var ngComponentDef = null; // Metadata may have resources which need to be resolved.

  maybeQueueResolutionOfComponentResources(type, metadata); // Note that we're using the same function as `Directive`, because that's only subset of metadata
  // that we need to create the ngFactoryDef. We're avoiding using the component metadata
  // because we'd have to resolve the asynchronous templates.

  addDirectiveFactoryDef(type, metadata);
  Object.defineProperty(type, NG_COMP_DEF, {
    get: function get() {
      if (ngComponentDef === null) {
        var compiler = getCompilerFacade();

        if (componentNeedsResolution(metadata)) {
          var error = ["Component '".concat(type.name, "' is not resolved:")];

          if (metadata.templateUrl) {
            error.push(" - templateUrl: ".concat(metadata.templateUrl));
          }

          if (metadata.styleUrls && metadata.styleUrls.length) {
            error.push(" - styleUrls: ".concat(JSON.stringify(metadata.styleUrls)));
          }

          error.push("Did you run and wait for 'resolveComponentResources()'?");
          throw new Error(error.join('\n'));
        } // This const was called `jitOptions` previously but had to be renamed to `options` because
        // of a bug with Terser that caused optimized JIT builds to throw a `ReferenceError`.
        // This bug was investigated in https://github.com/angular/angular-cli/issues/17264.
        // We should not rename it back until https://github.com/terser/terser/issues/615 is fixed.


        var options = getJitOptions();
        var preserveWhitespaces = metadata.preserveWhitespaces;

        if (preserveWhitespaces === undefined) {
          if (options !== null && options.preserveWhitespaces !== undefined) {
            preserveWhitespaces = options.preserveWhitespaces;
          } else {
            preserveWhitespaces = false;
          }
        }

        var encapsulation = metadata.encapsulation;

        if (encapsulation === undefined) {
          if (options !== null && options.defaultEncapsulation !== undefined) {
            encapsulation = options.defaultEncapsulation;
          } else {
            encapsulation = ViewEncapsulation$1.Emulated;
          }
        }

        var templateUrl = metadata.templateUrl || "ng:///".concat(type.name, "/template.html");
        var meta = Object.assign(Object.assign({}, directiveMetadata(type, metadata)), {
          typeSourceSpan: compiler.createParseSourceSpan('Component', type.name, templateUrl),
          template: metadata.template || '',
          preserveWhitespaces: preserveWhitespaces,
          styles: metadata.styles || EMPTY_ARRAY,
          animations: metadata.animations,
          directives: [],
          changeDetection: metadata.changeDetection,
          pipes: new Map(),
          encapsulation: encapsulation,
          interpolation: metadata.interpolation,
          viewProviders: metadata.viewProviders || null
        });
        compilationDepth++;

        try {
          if (meta.usesInheritance) {
            addDirectiveDefToUndecoratedParents(type);
          }

          ngComponentDef = compiler.compileComponent(angularCoreEnv, templateUrl, meta);
        } finally {
          // Ensure that the compilation depth is decremented even when the compilation failed.
          compilationDepth--;
        }

        if (compilationDepth === 0) {
          // When NgModule decorator executed, we enqueued the module definition such that
          // it would only dequeue and add itself as module scope to all of its declarations,
          // but only if  if all of its declarations had resolved. This call runs the check
          // to see if any modules that are in the queue can be dequeued and add scope to
          // their declarations.
          flushModuleScopingQueueAsMuchAsPossible();
        } // If component compilation is async, then the @NgModule annotation which declares the
        // component may execute and set an ngSelectorScope property on the component type. This
        // allows the component to patch itself with directiveDefs from the module after it
        // finishes compiling.


        if (hasSelectorScope(type)) {
          var scopes = transitiveScopesFor(type.ngSelectorScope);
          patchComponentDefWithScope(ngComponentDef, scopes);
        }
      }

      return ngComponentDef;
    },
    // Make the property configurable in dev mode to allow overriding in tests
    configurable: !!ngDevMode
  });
}

function hasSelectorScope(component) {
  return component.ngSelectorScope !== undefined;
}
/**
 * Compile an Angular directive according to its decorator metadata, and patch the resulting
 * directive def onto the component type.
 *
 * In the event that compilation is not immediate, `compileDirective` will return a `Promise` which
 * will resolve when compilation completes and the directive becomes usable.
 */


function compileDirective(type, directive) {
  var ngDirectiveDef = null;
  addDirectiveFactoryDef(type, directive || {});
  Object.defineProperty(type, NG_DIR_DEF, {
    get: function get() {
      if (ngDirectiveDef === null) {
        // `directive` can be null in the case of abstract directives as a base class
        // that use `@Directive()` with no selector. In that case, pass empty object to the
        // `directiveMetadata` function instead of null.
        var meta = getDirectiveMetadata(type, directive || {});
        ngDirectiveDef = getCompilerFacade().compileDirective(angularCoreEnv, meta.sourceMapUrl, meta.metadata);
      }

      return ngDirectiveDef;
    },
    // Make the property configurable in dev mode to allow overriding in tests
    configurable: !!ngDevMode
  });
}

function getDirectiveMetadata(type, metadata) {
  var name = type && type.name;
  var sourceMapUrl = "ng:///".concat(name, "/\u0275dir.js");
  var compiler = getCompilerFacade();
  var facade = directiveMetadata(type, metadata);
  facade.typeSourceSpan = compiler.createParseSourceSpan('Directive', name, sourceMapUrl);

  if (facade.usesInheritance) {
    addDirectiveDefToUndecoratedParents(type);
  }

  return {
    metadata: facade,
    sourceMapUrl: sourceMapUrl
  };
}

function addDirectiveFactoryDef(type, metadata) {
  var ngFactoryDef = null;
  Object.defineProperty(type, NG_FACTORY_DEF, {
    get: function get() {
      if (ngFactoryDef === null) {
        var meta = getDirectiveMetadata(type, metadata);
        var compiler = getCompilerFacade();
        ngFactoryDef = compiler.compileFactory(angularCoreEnv, "ng:///".concat(type.name, "/\u0275fac.js"), Object.assign(Object.assign({}, meta.metadata), {
          injectFn: 'directiveInject',
          target: compiler.R3FactoryTarget.Directive
        }));
      }

      return ngFactoryDef;
    },
    // Make the property configurable in dev mode to allow overriding in tests
    configurable: !!ngDevMode
  });
}

function extendsDirectlyFromObject(type) {
  return Object.getPrototypeOf(type.prototype) === Object.prototype;
}
/**
 * Extract the `R3DirectiveMetadata` for a particular directive (either a `Directive` or a
 * `Component`).
 */


function directiveMetadata(type, metadata) {
  // Reflect inputs and outputs.
  var reflect = getReflect();
  var propMetadata = reflect.ownPropMetadata(type);
  return {
    name: type.name,
    type: type,
    typeArgumentCount: 0,
    selector: metadata.selector !== undefined ? metadata.selector : null,
    deps: reflectDependencies(type),
    host: metadata.host || EMPTY_OBJ,
    propMetadata: propMetadata,
    inputs: metadata.inputs || EMPTY_ARRAY,
    outputs: metadata.outputs || EMPTY_ARRAY,
    queries: extractQueriesMetadata(type, propMetadata, isContentQuery),
    lifecycle: {
      usesOnChanges: reflect.hasLifecycleHook(type, 'ngOnChanges')
    },
    typeSourceSpan: null,
    usesInheritance: !extendsDirectlyFromObject(type),
    exportAs: extractExportAs(metadata.exportAs),
    providers: metadata.providers || null,
    viewQueries: extractQueriesMetadata(type, propMetadata, isViewQuery)
  };
}
/**
 * Adds a directive definition to all parent classes of a type that don't have an Angular decorator.
 */


function addDirectiveDefToUndecoratedParents(type) {
  var objPrototype = Object.prototype;
  var parent = Object.getPrototypeOf(type.prototype).constructor; // Go up the prototype until we hit `Object`.

  while (parent && parent !== objPrototype) {
    // Since inheritance works if the class was annotated already, we only need to add
    // the def if there are no annotations and the def hasn't been created already.
    if (!getDirectiveDef(parent) && !getComponentDef(parent) && shouldAddAbstractDirective(parent)) {
      compileDirective(parent, null);
    }

    parent = Object.getPrototypeOf(parent);
  }
}

function convertToR3QueryPredicate(selector) {
  return typeof selector === 'string' ? splitByComma(selector) : resolveForwardRef(selector);
}

function convertToR3QueryMetadata(propertyName, ann) {
  return {
    propertyName: propertyName,
    predicate: convertToR3QueryPredicate(ann.selector),
    descendants: ann.descendants,
    first: ann.first,
    read: ann.read ? ann.read : null,
    static: !!ann.static
  };
}

function extractQueriesMetadata(type, propMetadata, isQueryAnn) {
  var queriesMeta = [];

  var _loop2 = function _loop2(field) {
    if (propMetadata.hasOwnProperty(field)) {
      var annotations = propMetadata[field];
      annotations.forEach(function (ann) {
        if (isQueryAnn(ann)) {
          if (!ann.selector) {
            throw new Error("Can't construct a query for the property \"".concat(field, "\" of ") + "\"".concat(stringifyForError(type), "\" since the query selector wasn't defined."));
          }

          if (annotations.some(isInputAnnotation)) {
            throw new Error("Cannot combine @Input decorators with query decorators");
          }

          queriesMeta.push(convertToR3QueryMetadata(field, ann));
        }
      });
    }
  };

  for (var field in propMetadata) {
    _loop2(field);
  }

  return queriesMeta;
}

function extractExportAs(exportAs) {
  return exportAs === undefined ? null : splitByComma(exportAs);
}

function isContentQuery(value) {
  var name = value.ngMetadataName;
  return name === 'ContentChild' || name === 'ContentChildren';
}

function isViewQuery(value) {
  var name = value.ngMetadataName;
  return name === 'ViewChild' || name === 'ViewChildren';
}

function isInputAnnotation(value) {
  return value.ngMetadataName === 'Input';
}

function splitByComma(value) {
  return value.split(',').map(function (piece) {
    return piece.trim();
  });
}

var LIFECYCLE_HOOKS = ['ngOnChanges', 'ngOnInit', 'ngOnDestroy', 'ngDoCheck', 'ngAfterViewInit', 'ngAfterViewChecked', 'ngAfterContentInit', 'ngAfterContentChecked'];

function shouldAddAbstractDirective(type) {
  var reflect = getReflect();

  if (LIFECYCLE_HOOKS.some(function (hookName) {
    return reflect.hasLifecycleHook(type, hookName);
  })) {
    return true;
  }

  var propMetadata = reflect.propMetadata(type);

  for (var field in propMetadata) {
    var annotations = propMetadata[field];

    for (var i = 0; i < annotations.length; i++) {
      var current = annotations[i];
      var metadataName = current.ngMetadataName;

      if (isInputAnnotation(current) || isContentQuery(current) || isViewQuery(current) || metadataName === 'Output' || metadataName === 'HostBinding' || metadataName === 'HostListener') {
        return true;
      }
    }
  }

  return false;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function compilePipe(type, meta) {
  var ngPipeDef = null;
  var ngFactoryDef = null;
  Object.defineProperty(type, NG_FACTORY_DEF, {
    get: function get() {
      if (ngFactoryDef === null) {
        var metadata = getPipeMetadata(type, meta);
        var compiler = getCompilerFacade();
        ngFactoryDef = compiler.compileFactory(angularCoreEnv, "ng:///".concat(metadata.name, "/\u0275fac.js"), Object.assign(Object.assign({}, metadata), {
          injectFn: 'directiveInject',
          target: compiler.R3FactoryTarget.Pipe
        }));
      }

      return ngFactoryDef;
    },
    // Make the property configurable in dev mode to allow overriding in tests
    configurable: !!ngDevMode
  });
  Object.defineProperty(type, NG_PIPE_DEF, {
    get: function get() {
      if (ngPipeDef === null) {
        var metadata = getPipeMetadata(type, meta);
        ngPipeDef = getCompilerFacade().compilePipe(angularCoreEnv, "ng:///".concat(metadata.name, "/\u0275pipe.js"), metadata);
      }

      return ngPipeDef;
    },
    // Make the property configurable in dev mode to allow overriding in tests
    configurable: !!ngDevMode
  });
}

function getPipeMetadata(type, meta) {
  return {
    type: type,
    typeArgumentCount: 0,
    name: type.name,
    deps: reflectDependencies(type),
    pipeName: meta.name,
    pure: meta.pure !== undefined ? meta.pure : true
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$e = function ɵ0$e() {
  var dir = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return dir;
},
    ɵ1$3 = function ɵ1$3(type, meta) {
  return SWITCH_COMPILE_DIRECTIVE(type, meta);
};
/**
 * Type of the Directive metadata.
 *
 * @publicApi
 */


var Directive = makeDecorator('Directive', ɵ0$e, undefined, undefined, ɵ1$3);

var ɵ2$1 = function ɵ2$1() {
  var c = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return Object.assign({
    changeDetection: ChangeDetectionStrategy.Default
  }, c);
},
    ɵ3$1 = function ɵ3$1(type, meta) {
  return SWITCH_COMPILE_COMPONENT(type, meta);
};
/**
 * Component decorator and metadata.
 *
 * @Annotation
 * @publicApi
 */


var Component = makeDecorator('Component', ɵ2$1, Directive, undefined, ɵ3$1);

var ɵ4 = function ɵ4(p) {
  return Object.assign({
    pure: true
  }, p);
},
    ɵ5 = function ɵ5(type, meta) {
  return SWITCH_COMPILE_PIPE(type, meta);
};
/**
 * @Annotation
 * @publicApi
 */


var Pipe = makeDecorator('Pipe', ɵ4, undefined, undefined, ɵ5);

var ɵ6 = function ɵ6(bindingPropertyName) {
  return {
    bindingPropertyName: bindingPropertyName
  };
};
/**
 * @Annotation
 * @publicApi
 */


var Input = makePropDecorator('Input', ɵ6);

var ɵ7 = function ɵ7(bindingPropertyName) {
  return {
    bindingPropertyName: bindingPropertyName
  };
};
/**
 * @Annotation
 * @publicApi
 */


var Output = makePropDecorator('Output', ɵ7);

var ɵ8 = function ɵ8(hostPropertyName) {
  return {
    hostPropertyName: hostPropertyName
  };
};
/**
 * @Annotation
 * @publicApi
 */


var HostBinding = makePropDecorator('HostBinding', ɵ8);

var ɵ9 = function ɵ9(eventName, args) {
  return {
    eventName: eventName,
    args: args
  };
};
/**
 * Decorator that binds a DOM event to a host listener and supplies configuration metadata.
 * Angular invokes the supplied handler method when the host element emits the specified event,
 * and updates the bound element with the result.
 *
 * If the handler method returns false, applies `preventDefault` on the bound element.
 *
 * @usageNotes
 *
 * The following example declares a directive
 * that attaches a click listener to a button and counts clicks.
 *
 * ```ts
 * @Directive({selector: 'button[counting]'})
 * class CountClicks {
 *   numberOfClicks = 0;
 *
 *   @HostListener('click', ['$event.target'])
 *   onClick(btn) {
 *     console.log('button', btn, 'number of clicks:', this.numberOfClicks++);
 *  }
 * }
 *
 * @Component({
 *   selector: 'app',
 *   template: '<button counting>Increment</button>',
 * })
 * class App {}
 *
 * ```
 *
 * The following example registers another DOM event handler that listens for key-press events.
 * ``` ts
 * import { HostListener, Component } from "@angular/core";
 *
 * @Component({
 *   selector: 'app',
 *   template: `<h1>Hello, you have pressed keys {{counter}} number of times!</h1> Press any key to
 * increment the counter.
 *   <button (click)="resetCounter()">Reset Counter</button>`
 * })
 * class AppComponent {
 *   counter = 0;
 *   @HostListener('window:keydown', ['$event'])
 *   handleKeyDown(event: KeyboardEvent) {
 *     this.counter++;
 *   }
 *   resetCounter() {
 *     this.counter = 0;
 *   }
 * }
 * ```
 *
 * @Annotation
 * @publicApi
 */


var HostListener = makePropDecorator('HostListener', ɵ9);
var SWITCH_COMPILE_COMPONENT__POST_R3__ = compileComponent;
var SWITCH_COMPILE_DIRECTIVE__POST_R3__ = compileDirective;
var SWITCH_COMPILE_PIPE__POST_R3__ = compilePipe;
var SWITCH_COMPILE_COMPONENT__PRE_R3__ = noop;
var SWITCH_COMPILE_DIRECTIVE__PRE_R3__ = noop;
var SWITCH_COMPILE_PIPE__PRE_R3__ = noop;
var SWITCH_COMPILE_COMPONENT = SWITCH_COMPILE_COMPONENT__POST_R3__;
var SWITCH_COMPILE_DIRECTIVE = SWITCH_COMPILE_DIRECTIVE__POST_R3__;
var SWITCH_COMPILE_PIPE = SWITCH_COMPILE_PIPE__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var ɵ0$f = function ɵ0$f(ngModule) {
  return ngModule;
},
    ɵ1$4 =
/**
 * Decorator that marks the following class as an NgModule, and supplies
 * configuration metadata for it.
 *
 * * The `declarations` and `entryComponents` options configure the compiler
 * with information about what belongs to the NgModule.
 * * The `providers` options configures the NgModule's injector to provide
 * dependencies the NgModule members.
 * * The `imports` and `exports` options bring in members from other modules, and make
 * this module's members available to others.
 */
function ɵ1$4(type, meta) {
  return SWITCH_COMPILE_NGMODULE(type, meta);
};
/**
 * @Annotation
 * @publicApi
 */


var NgModule = makeDecorator('NgModule', ɵ0$f, undefined, undefined, ɵ1$4);

function preR3NgModuleCompile(moduleType, metadata) {
  var imports = metadata && metadata.imports || [];

  if (metadata && metadata.exports) {
    imports = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(imports), [metadata.exports]);
  }

  moduleType.ɵinj = ɵɵdefineInjector({
    factory: convertInjectableProviderToFactory(moduleType, {
      useClass: moduleType
    }),
    providers: metadata && metadata.providers,
    imports: imports
  });
}

var SWITCH_COMPILE_NGMODULE__POST_R3__ = compileNgModule;
var SWITCH_COMPILE_NGMODULE__PRE_R3__ = preR3NgModuleCompile;
var SWITCH_COMPILE_NGMODULE = SWITCH_COMPILE_NGMODULE__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A [DI token](guide/glossary#di-token "DI token definition") that you can use to provide
 * one or more initialization functions.
 *
 * The provided functions are injected at application startup and executed during
 * app initialization. If any of these functions returns a Promise, initialization
 * does not complete until the Promise is resolved.
 *
 * You can, for example, create a factory function that loads language data
 * or an external configuration, and provide that function to the `APP_INITIALIZER` token.
 * The function is executed during the application bootstrap process,
 * and the needed data is available on startup.
 *
 * @see `ApplicationInitStatus`
 *
 * @publicApi
 */

var APP_INITIALIZER = new InjectionToken('Application Initializer');
/**
 * A class that reflects the state of running {@link APP_INITIALIZER} functions.
 *
 * @publicApi
 */

var ApplicationInitStatus = /*#__PURE__*/function () {
  function ApplicationInitStatus(appInits) {
    var _this20 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ApplicationInitStatus);

    this.appInits = appInits;
    this.initialized = false;
    this.done = false;
    this.donePromise = new Promise(function (res, rej) {
      _this20.resolve = res;
      _this20.reject = rej;
    });
  }
  /** @internal */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ApplicationInitStatus, [{
    key: "runInitializers",
    value: function runInitializers() {
      var _this21 = this;

      if (this.initialized) {
        return;
      }

      var asyncInitPromises = [];

      var complete = function complete() {
        _this21.done = true;

        _this21.resolve();
      };

      if (this.appInits) {
        for (var i = 0; i < this.appInits.length; i++) {
          var initResult = this.appInits[i]();

          if (isPromise(initResult)) {
            asyncInitPromises.push(initResult);
          }
        }
      }

      Promise.all(asyncInitPromises).then(function () {
        complete();
      }).catch(function (e) {
        _this21.reject(e);
      });

      if (asyncInitPromises.length === 0) {
        complete();
      }

      this.initialized = true;
    }
  }]);

  return ApplicationInitStatus;
}();

ApplicationInitStatus.ɵfac = function ApplicationInitStatus_Factory(t) {
  return new (t || ApplicationInitStatus)(ɵɵinject(APP_INITIALIZER, 8));
};

ApplicationInitStatus.ɵprov = ɵɵdefineInjectable({
  token: ApplicationInitStatus,
  factory: ApplicationInitStatus.ɵfac
});

ApplicationInitStatus.ctorParameters = function () {
  return [{
    type: Array,
    decorators: [{
      type: Inject,
      args: [APP_INITIALIZER]
    }, {
      type: Optional
    }]
  }];
};
/*@__PURE__*/


(function () {
  setClassMetadata(ApplicationInitStatus, [{
    type: Injectable
  }], function () {
    return [{
      type: Array,
      decorators: [{
        type: Inject,
        args: [APP_INITIALIZER]
      }, {
        type: Optional
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A [DI token](guide/glossary#di-token "DI token definition") representing a unique string ID, used
 * primarily for prefixing application attributes and CSS styles when
 * {@link ViewEncapsulation#Emulated ViewEncapsulation.Emulated} is being used.
 *
 * BY default, the value is randomly generated and assigned to the application by Angular.
 * To provide a custom ID value, use a DI provider <!-- TODO: provider --> to configure
 * the root {@link Injector} that uses this token.
 *
 * @publicApi
 */


var APP_ID = new InjectionToken('AppId');

function _appIdRandomProviderFactory() {
  return "".concat(_randomChar()).concat(_randomChar()).concat(_randomChar());
}
/**
 * Providers that generate a random `APP_ID_TOKEN`.
 * @publicApi
 */


var APP_ID_RANDOM_PROVIDER = {
  provide: APP_ID,
  useFactory: _appIdRandomProviderFactory,
  deps: []
};

function _randomChar() {
  return String.fromCharCode(97 + Math.floor(Math.random() * 25));
}
/**
 * A function that is executed when a platform is initialized.
 * @publicApi
 */


var PLATFORM_INITIALIZER = new InjectionToken('Platform Initializer');
/**
 * A token that indicates an opaque platform ID.
 * @publicApi
 */

var PLATFORM_ID = new InjectionToken('Platform ID');
/**
 * A [DI token](guide/glossary#di-token "DI token definition") that provides a set of callbacks to
 * be called for every component that is bootstrapped.
 *
 * Each callback must take a `ComponentRef` instance and return nothing.
 *
 * `(componentRef: ComponentRef) => void`
 *
 * @publicApi
 */

var APP_BOOTSTRAP_LISTENER = new InjectionToken('appBootstrapListener');
/**
 * A [DI token](guide/glossary#di-token "DI token definition") that indicates the root directory of
 * the application
 * @publicApi
 */

var PACKAGE_ROOT_URL = new InjectionToken('Application Packages Root URL');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var Console = /*#__PURE__*/function () {
  function Console() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Console);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(Console, [{
    key: "log",
    value: function log(message) {
      // tslint:disable-next-line:no-console
      console.log(message);
    } // Note: for reporting errors use `DOM.logError()` as it is platform specific

  }, {
    key: "warn",
    value: function warn(message) {
      // tslint:disable-next-line:no-console
      console.warn(message);
    }
  }]);

  return Console;
}();

Console.ɵfac = function Console_Factory(t) {
  return new (t || Console)();
};

Console.ɵprov = ɵɵdefineInjectable({
  token: Console,
  factory: Console.ɵfac
});
/*@__PURE__*/

(function () {
  setClassMetadata(Console, [{
    type: Injectable
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Provide this token to set the locale of your application.
 * It is used for i18n extraction, by i18n pipes (DatePipe, I18nPluralPipe, CurrencyPipe,
 * DecimalPipe and PercentPipe) and by ICU expressions.
 *
 * See the [i18n guide](guide/i18n#setting-up-locale) for more information.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * import { LOCALE_ID } from '@angular/core';
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 * import { AppModule } from './app/app.module';
 *
 * platformBrowserDynamic().bootstrapModule(AppModule, {
 *   providers: [{provide: LOCALE_ID, useValue: 'en-US' }]
 * });
 * ```
 *
 * @publicApi
 */


var LOCALE_ID$1 = new InjectionToken('LocaleId');
/**
 * Provide this token to set the default currency code your application uses for
 * CurrencyPipe when there is no currency code passed into it. This is only used by
 * CurrencyPipe and has no relation to locale currency. Defaults to USD if not configured.
 *
 * See the [i18n guide](guide/i18n#setting-up-locale) for more information.
 *
 * <div class="alert is-helpful">
 *
 * **Deprecation notice:**
 *
 * The default currency code is currently always `USD` but this is deprecated from v9.
 *
 * **In v10 the default currency code will be taken from the current locale.**
 *
 * If you need the previous behavior then set it by creating a `DEFAULT_CURRENCY_CODE` provider in
 * your application `NgModule`:
 *
 * ```ts
 * {provide: DEFAULT_CURRENCY_CODE, useValue: 'USD'}
 * ```
 *
 * </div>
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 * import { AppModule } from './app/app.module';
 *
 * platformBrowserDynamic().bootstrapModule(AppModule, {
 *   providers: [{provide: DEFAULT_CURRENCY_CODE, useValue: 'EUR' }]
 * });
 * ```
 *
 * @publicApi
 */

var DEFAULT_CURRENCY_CODE = new InjectionToken('DefaultCurrencyCode');
/**
 * Use this token at bootstrap to provide the content of your translation file (`xtb`,
 * `xlf` or `xlf2`) when you want to translate your application in another language.
 *
 * See the [i18n guide](guide/i18n#merge) for more information.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * import { TRANSLATIONS } from '@angular/core';
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 * import { AppModule } from './app/app.module';
 *
 * // content of your translation file
 * const translations = '....';
 *
 * platformBrowserDynamic().bootstrapModule(AppModule, {
 *   providers: [{provide: TRANSLATIONS, useValue: translations }]
 * });
 * ```
 *
 * @publicApi
 */

var TRANSLATIONS = new InjectionToken('Translations');
/**
 * Provide this token at bootstrap to set the format of your {@link TRANSLATIONS}: `xtb`,
 * `xlf` or `xlf2`.
 *
 * See the [i18n guide](guide/i18n#merge) for more information.
 *
 * @usageNotes
 * ### Example
 *
 * ```typescript
 * import { TRANSLATIONS_FORMAT } from '@angular/core';
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 * import { AppModule } from './app/app.module';
 *
 * platformBrowserDynamic().bootstrapModule(AppModule, {
 *   providers: [{provide: TRANSLATIONS_FORMAT, useValue: 'xlf' }]
 * });
 * ```
 *
 * @publicApi
 */

var TRANSLATIONS_FORMAT = new InjectionToken('TranslationsFormat');
/**
 * Use this enum at bootstrap as an option of `bootstrapModule` to define the strategy
 * that the compiler should use in case of missing translations:
 * - Error: throw if you have missing translations.
 * - Warning (default): show a warning in the console and/or shell.
 * - Ignore: do nothing.
 *
 * See the [i18n guide](guide/i18n#missing-translation) for more information.
 *
 * @usageNotes
 * ### Example
 * ```typescript
 * import { MissingTranslationStrategy } from '@angular/core';
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 * import { AppModule } from './app/app.module';
 *
 * platformBrowserDynamic().bootstrapModule(AppModule, {
 *   missingTranslation: MissingTranslationStrategy.Error
 * });
 * ```
 *
 * @publicApi
 */

var MissingTranslationStrategy;

(function (MissingTranslationStrategy) {
  MissingTranslationStrategy[MissingTranslationStrategy["Error"] = 0] = "Error";
  MissingTranslationStrategy[MissingTranslationStrategy["Warning"] = 1] = "Warning";
  MissingTranslationStrategy[MissingTranslationStrategy["Ignore"] = 2] = "Ignore";
})(MissingTranslationStrategy || (MissingTranslationStrategy = {}));
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SWITCH_IVY_ENABLED__POST_R3__ = true;
var SWITCH_IVY_ENABLED__PRE_R3__ = false;
var ivyEnabled = SWITCH_IVY_ENABLED__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Combination of NgModuleFactory and ComponentFactorys.
 *
 * @publicApi
 */

var ModuleWithComponentFactories = function ModuleWithComponentFactories(ngModuleFactory, componentFactories) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ModuleWithComponentFactories);

  this.ngModuleFactory = ngModuleFactory;
  this.componentFactories = componentFactories;
};

function _throwError() {
  throw new Error("Runtime compiler is not loaded");
}

var Compiler_compileModuleSync__PRE_R3__ = _throwError;

var Compiler_compileModuleSync__POST_R3__ = function Compiler_compileModuleSync__POST_R3__(moduleType) {
  return new NgModuleFactory$1(moduleType);
};

var Compiler_compileModuleSync = Compiler_compileModuleSync__POST_R3__;
var Compiler_compileModuleAsync__PRE_R3__ = _throwError;

var Compiler_compileModuleAsync__POST_R3__ = function Compiler_compileModuleAsync__POST_R3__(moduleType) {
  return Promise.resolve(Compiler_compileModuleSync__POST_R3__(moduleType));
};

var Compiler_compileModuleAsync = Compiler_compileModuleAsync__POST_R3__;
var Compiler_compileModuleAndAllComponentsSync__PRE_R3__ = _throwError;

var Compiler_compileModuleAndAllComponentsSync__POST_R3__ = function Compiler_compileModuleAndAllComponentsSync__POST_R3__(moduleType) {
  var ngModuleFactory = Compiler_compileModuleSync__POST_R3__(moduleType);
  var moduleDef = getNgModuleDef(moduleType);
  var componentFactories = maybeUnwrapFn(moduleDef.declarations).reduce(function (factories, declaration) {
    var componentDef = getComponentDef(declaration);
    componentDef && factories.push(new ComponentFactory$1(componentDef));
    return factories;
  }, []);
  return new ModuleWithComponentFactories(ngModuleFactory, componentFactories);
};

var Compiler_compileModuleAndAllComponentsSync = Compiler_compileModuleAndAllComponentsSync__POST_R3__;
var Compiler_compileModuleAndAllComponentsAsync__PRE_R3__ = _throwError;

var Compiler_compileModuleAndAllComponentsAsync__POST_R3__ = function Compiler_compileModuleAndAllComponentsAsync__POST_R3__(moduleType) {
  return Promise.resolve(Compiler_compileModuleAndAllComponentsSync__POST_R3__(moduleType));
};

var Compiler_compileModuleAndAllComponentsAsync = Compiler_compileModuleAndAllComponentsAsync__POST_R3__;
/**
 * Low-level service for running the angular compiler during runtime
 * to create {@link ComponentFactory}s, which
 * can later be used to create and render a Component instance.
 *
 * Each `@NgModule` provides an own `Compiler` to its injector,
 * that will use the directives/pipes of the ng module for compilation
 * of components.
 *
 * @publicApi
 */

var Compiler = /*#__PURE__*/function () {
  function Compiler() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Compiler);

    /**
     * Compiles the given NgModule and all of its components. All templates of the components listed
     * in `entryComponents` have to be inlined.
     */
    this.compileModuleSync = Compiler_compileModuleSync;
    /**
     * Compiles the given NgModule and all of its components
     */

    this.compileModuleAsync = Compiler_compileModuleAsync;
    /**
     * Same as {@link #compileModuleSync} but also creates ComponentFactories for all components.
     */

    this.compileModuleAndAllComponentsSync = Compiler_compileModuleAndAllComponentsSync;
    /**
     * Same as {@link #compileModuleAsync} but also creates ComponentFactories for all components.
     */

    this.compileModuleAndAllComponentsAsync = Compiler_compileModuleAndAllComponentsAsync;
  }
  /**
   * Clears all caches.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(Compiler, [{
    key: "clearCache",
    value: function clearCache() {}
    /**
     * Clears the cache for the given component/ngModule.
     */

  }, {
    key: "clearCacheFor",
    value: function clearCacheFor(type) {}
    /**
     * Returns the id for a given NgModule, if one is defined and known to the compiler.
     */

  }, {
    key: "getModuleId",
    value: function getModuleId(moduleType) {
      return undefined;
    }
  }]);

  return Compiler;
}();

Compiler.ɵfac = function Compiler_Factory(t) {
  return new (t || Compiler)();
};

Compiler.ɵprov = ɵɵdefineInjectable({
  token: Compiler,
  factory: Compiler.ɵfac
});
/*@__PURE__*/

(function () {
  setClassMetadata(Compiler, [{
    type: Injectable
  }], function () {
    return [];
  }, null);
})();
/**
 * Token to provide CompilerOptions in the platform injector.
 *
 * @publicApi
 */


var COMPILER_OPTIONS = new InjectionToken('compilerOptions');
/**
 * A factory for creating a Compiler
 *
 * @publicApi
 */

var CompilerFactory = function CompilerFactory() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, CompilerFactory);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var promise = function () {
  return Promise.resolve(0);
}();

function scheduleMicroTask(fn) {
  if (typeof Zone === 'undefined') {
    // use promise to schedule microTask instead of use Zone
    promise.then(function () {
      fn && fn.apply(null, null);
    });
  } else {
    Zone.current.scheduleMicroTask('scheduleMicrotask', fn);
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function getNativeRequestAnimationFrame() {
  var nativeRequestAnimationFrame = _global['requestAnimationFrame'];
  var nativeCancelAnimationFrame = _global['cancelAnimationFrame'];

  if (typeof Zone !== 'undefined' && nativeRequestAnimationFrame && nativeCancelAnimationFrame) {
    // use unpatched version of requestAnimationFrame(native delegate) if possible
    // to avoid another Change detection
    var unpatchedRequestAnimationFrame = nativeRequestAnimationFrame[Zone.__symbol__('OriginalDelegate')];

    if (unpatchedRequestAnimationFrame) {
      nativeRequestAnimationFrame = unpatchedRequestAnimationFrame;
    }

    var unpatchedCancelAnimationFrame = nativeCancelAnimationFrame[Zone.__symbol__('OriginalDelegate')];

    if (unpatchedCancelAnimationFrame) {
      nativeCancelAnimationFrame = unpatchedCancelAnimationFrame;
    }
  }

  return {
    nativeRequestAnimationFrame: nativeRequestAnimationFrame,
    nativeCancelAnimationFrame: nativeCancelAnimationFrame
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An injectable service for executing work inside or outside of the Angular zone.
 *
 * The most common use of this service is to optimize performance when starting a work consisting of
 * one or more asynchronous tasks that don't require UI updates or error handling to be handled by
 * Angular. Such tasks can be kicked off via {@link #runOutsideAngular} and if needed, these tasks
 * can reenter the Angular zone via {@link #run}.
 *
 * <!-- TODO: add/fix links to:
 *   - docs explaining zones and the use of zones in Angular and change-detection
 *   - link to runOutsideAngular/run (throughout this file!)
 *   -->
 *
 * @usageNotes
 * ### Example
 *
 * ```
 * import {Component, NgZone} from '@angular/core';
 * import {NgIf} from '@angular/common';
 *
 * @Component({
 *   selector: 'ng-zone-demo',
 *   template: `
 *     <h2>Demo: NgZone</h2>
 *
 *     <p>Progress: {{progress}}%</p>
 *     <p *ngIf="progress >= 100">Done processing {{label}} of Angular zone!</p>
 *
 *     <button (click)="processWithinAngularZone()">Process within Angular zone</button>
 *     <button (click)="processOutsideOfAngularZone()">Process outside of Angular zone</button>
 *   `,
 * })
 * export class NgZoneDemo {
 *   progress: number = 0;
 *   label: string;
 *
 *   constructor(private _ngZone: NgZone) {}
 *
 *   // Loop inside the Angular zone
 *   // so the UI DOES refresh after each setTimeout cycle
 *   processWithinAngularZone() {
 *     this.label = 'inside';
 *     this.progress = 0;
 *     this._increaseProgress(() => console.log('Inside Done!'));
 *   }
 *
 *   // Loop outside of the Angular zone
 *   // so the UI DOES NOT refresh after each setTimeout cycle
 *   processOutsideOfAngularZone() {
 *     this.label = 'outside';
 *     this.progress = 0;
 *     this._ngZone.runOutsideAngular(() => {
 *       this._increaseProgress(() => {
 *         // reenter the Angular zone and display done
 *         this._ngZone.run(() => { console.log('Outside Done!'); });
 *       });
 *     });
 *   }
 *
 *   _increaseProgress(doneCallback: () => void) {
 *     this.progress += 1;
 *     console.log(`Current progress: ${this.progress}%`);
 *
 *     if (this.progress < 100) {
 *       window.setTimeout(() => this._increaseProgress(doneCallback), 10);
 *     } else {
 *       doneCallback();
 *     }
 *   }
 * }
 * ```
 *
 * @publicApi
 */


var NgZone = /*#__PURE__*/function () {
  function NgZone(_ref3) {
    var _ref3$enableLongStack = _ref3.enableLongStackTrace,
        enableLongStackTrace = _ref3$enableLongStack === void 0 ? false : _ref3$enableLongStack,
        _ref3$shouldCoalesceE = _ref3.shouldCoalesceEventChangeDetection,
        shouldCoalesceEventChangeDetection = _ref3$shouldCoalesceE === void 0 ? false : _ref3$shouldCoalesceE;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgZone);

    this.hasPendingMacrotasks = false;
    this.hasPendingMicrotasks = false;
    /**
     * Whether there are no outstanding microtasks or macrotasks.
     */

    this.isStable = true;
    /**
     * Notifies when code enters Angular Zone. This gets fired first on VM Turn.
     */

    this.onUnstable = new EventEmitter(false);
    /**
     * Notifies when there is no more microtasks enqueued in the current VM Turn.
     * This is a hint for Angular to do change detection, which may enqueue more microtasks.
     * For this reason this event can fire multiple times per VM Turn.
     */

    this.onMicrotaskEmpty = new EventEmitter(false);
    /**
     * Notifies when the last `onMicrotaskEmpty` has run and there are no more microtasks, which
     * implies we are about to relinquish VM turn.
     * This event gets called just once.
     */

    this.onStable = new EventEmitter(false);
    /**
     * Notifies that an error has been delivered.
     */

    this.onError = new EventEmitter(false);

    if (typeof Zone == 'undefined') {
      throw new Error("In this configuration Angular requires Zone.js");
    }

    Zone.assertZonePatched();
    var self = this;
    self._nesting = 0;
    self._outer = self._inner = Zone.current;

    if (Zone['wtfZoneSpec']) {
      self._inner = self._inner.fork(Zone['wtfZoneSpec']);
    }

    if (Zone['TaskTrackingZoneSpec']) {
      self._inner = self._inner.fork(new Zone['TaskTrackingZoneSpec']());
    }

    if (enableLongStackTrace && Zone['longStackTraceZoneSpec']) {
      self._inner = self._inner.fork(Zone['longStackTraceZoneSpec']);
    }

    self.shouldCoalesceEventChangeDetection = shouldCoalesceEventChangeDetection;
    self.lastRequestAnimationFrameId = -1;
    self.nativeRequestAnimationFrame = getNativeRequestAnimationFrame().nativeRequestAnimationFrame;
    forkInnerZoneWithAngularBehavior(self);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NgZone, [{
    key: "run",

    /**
     * Executes the `fn` function synchronously within the Angular zone and returns value returned by
     * the function.
     *
     * Running functions via `run` allows you to reenter Angular zone from a task that was executed
     * outside of the Angular zone (typically started via {@link #runOutsideAngular}).
     *
     * Any future tasks or microtasks scheduled from within this function will continue executing from
     * within the Angular zone.
     *
     * If a synchronous error happens it will be rethrown and not reported via `onError`.
     */
    value: function run(fn, applyThis, applyArgs) {
      return this._inner.run(fn, applyThis, applyArgs);
    }
    /**
     * Executes the `fn` function synchronously within the Angular zone as a task and returns value
     * returned by the function.
     *
     * Running functions via `run` allows you to reenter Angular zone from a task that was executed
     * outside of the Angular zone (typically started via {@link #runOutsideAngular}).
     *
     * Any future tasks or microtasks scheduled from within this function will continue executing from
     * within the Angular zone.
     *
     * If a synchronous error happens it will be rethrown and not reported via `onError`.
     */

  }, {
    key: "runTask",
    value: function runTask(fn, applyThis, applyArgs, name) {
      var zone = this._inner;
      var task = zone.scheduleEventTask('NgZoneEvent: ' + name, fn, EMPTY_PAYLOAD, noop$1, noop$1);

      try {
        return zone.runTask(task, applyThis, applyArgs);
      } finally {
        zone.cancelTask(task);
      }
    }
    /**
     * Same as `run`, except that synchronous errors are caught and forwarded via `onError` and not
     * rethrown.
     */

  }, {
    key: "runGuarded",
    value: function runGuarded(fn, applyThis, applyArgs) {
      return this._inner.runGuarded(fn, applyThis, applyArgs);
    }
    /**
     * Executes the `fn` function synchronously in Angular's parent zone and returns value returned by
     * the function.
     *
     * Running functions via {@link #runOutsideAngular} allows you to escape Angular's zone and do
     * work that
     * doesn't trigger Angular change-detection or is subject to Angular's error handling.
     *
     * Any future tasks or microtasks scheduled from within this function will continue executing from
     * outside of the Angular zone.
     *
     * Use {@link #run} to reenter the Angular zone and do work that updates the application model.
     */

  }, {
    key: "runOutsideAngular",
    value: function runOutsideAngular(fn) {
      return this._outer.run(fn);
    }
  }], [{
    key: "isInAngularZone",
    value: function isInAngularZone() {
      return Zone.current.get('isAngularZone') === true;
    }
  }, {
    key: "assertInAngularZone",
    value: function assertInAngularZone() {
      if (!NgZone.isInAngularZone()) {
        throw new Error('Expected to be in Angular Zone, but it is not!');
      }
    }
  }, {
    key: "assertNotInAngularZone",
    value: function assertNotInAngularZone() {
      if (NgZone.isInAngularZone()) {
        throw new Error('Expected to not be in Angular Zone, but it is!');
      }
    }
  }]);

  return NgZone;
}();

function noop$1() {}

var EMPTY_PAYLOAD = {};

function checkStable(zone) {
  if (zone._nesting == 0 && !zone.hasPendingMicrotasks && !zone.isStable) {
    try {
      zone._nesting++;
      zone.onMicrotaskEmpty.emit(null);
    } finally {
      zone._nesting--;

      if (!zone.hasPendingMicrotasks) {
        try {
          zone.runOutsideAngular(function () {
            return zone.onStable.emit(null);
          });
        } finally {
          zone.isStable = true;
        }
      }
    }
  }
}

function delayChangeDetectionForEvents(zone) {
  if (zone.lastRequestAnimationFrameId !== -1) {
    return;
  }

  zone.lastRequestAnimationFrameId = zone.nativeRequestAnimationFrame.call(_global, function () {
    // This is a work around for https://github.com/angular/angular/issues/36839.
    // The core issue is that when event coalescing is enabled it is possible for microtasks
    // to get flushed too early (As is the case with `Promise.then`) between the
    // coalescing eventTasks.
    //
    // To workaround this we schedule a "fake" eventTask before we process the
    // coalescing eventTasks. The benefit of this is that the "fake" container eventTask
    //  will prevent the microtasks queue from getting drained in between the coalescing
    // eventTask execution.
    if (!zone.fakeTopEventTask) {
      zone.fakeTopEventTask = Zone.root.scheduleEventTask('fakeTopEventTask', function () {
        zone.lastRequestAnimationFrameId = -1;
        updateMicroTaskStatus(zone);
        checkStable(zone);
      }, undefined, function () {}, function () {});
    }

    zone.fakeTopEventTask.invoke();
  });
  updateMicroTaskStatus(zone);
}

function forkInnerZoneWithAngularBehavior(zone) {
  var delayChangeDetectionForEventsDelegate = function delayChangeDetectionForEventsDelegate() {
    delayChangeDetectionForEvents(zone);
  };

  var maybeDelayChangeDetection = !!zone.shouldCoalesceEventChangeDetection && zone.nativeRequestAnimationFrame && delayChangeDetectionForEventsDelegate;
  zone._inner = zone._inner.fork({
    name: 'angular',
    properties: {
      'isAngularZone': true,
      'maybeDelayChangeDetection': maybeDelayChangeDetection
    },
    onInvokeTask: function onInvokeTask(delegate, current, target, task, applyThis, applyArgs) {
      try {
        onEnter(zone);
        return delegate.invokeTask(target, task, applyThis, applyArgs);
      } finally {
        if (maybeDelayChangeDetection && task.type === 'eventTask') {
          maybeDelayChangeDetection();
        }

        onLeave(zone);
      }
    },
    onInvoke: function onInvoke(delegate, current, target, callback, applyThis, applyArgs, source) {
      try {
        onEnter(zone);
        return delegate.invoke(target, callback, applyThis, applyArgs, source);
      } finally {
        onLeave(zone);
      }
    },
    onHasTask: function onHasTask(delegate, current, target, hasTaskState) {
      delegate.hasTask(target, hasTaskState);

      if (current === target) {
        // We are only interested in hasTask events which originate from our zone
        // (A child hasTask event is not interesting to us)
        if (hasTaskState.change == 'microTask') {
          zone._hasPendingMicrotasks = hasTaskState.microTask;
          updateMicroTaskStatus(zone);
          checkStable(zone);
        } else if (hasTaskState.change == 'macroTask') {
          zone.hasPendingMacrotasks = hasTaskState.macroTask;
        }
      }
    },
    onHandleError: function onHandleError(delegate, current, target, error) {
      delegate.handleError(target, error);
      zone.runOutsideAngular(function () {
        return zone.onError.emit(error);
      });
      return false;
    }
  });
}

function updateMicroTaskStatus(zone) {
  if (zone._hasPendingMicrotasks || zone.shouldCoalesceEventChangeDetection && zone.lastRequestAnimationFrameId !== -1) {
    zone.hasPendingMicrotasks = true;
  } else {
    zone.hasPendingMicrotasks = false;
  }
}

function onEnter(zone) {
  zone._nesting++;

  if (zone.isStable) {
    zone.isStable = false;
    zone.onUnstable.emit(null);
  }
}

function onLeave(zone) {
  zone._nesting--;
  checkStable(zone);
}
/**
 * Provides a noop implementation of `NgZone` which does nothing. This zone requires explicit calls
 * to framework to perform rendering.
 */


var NoopNgZone = /*#__PURE__*/function () {
  function NoopNgZone() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NoopNgZone);

    this.hasPendingMicrotasks = false;
    this.hasPendingMacrotasks = false;
    this.isStable = true;
    this.onUnstable = new EventEmitter();
    this.onMicrotaskEmpty = new EventEmitter();
    this.onStable = new EventEmitter();
    this.onError = new EventEmitter();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NoopNgZone, [{
    key: "run",
    value: function run(fn, applyThis, applyArgs) {
      return fn.apply(applyThis, applyArgs);
    }
  }, {
    key: "runGuarded",
    value: function runGuarded(fn, applyThis, applyArgs) {
      return fn.apply(applyThis, applyArgs);
    }
  }, {
    key: "runOutsideAngular",
    value: function runOutsideAngular(fn) {
      return fn();
    }
  }, {
    key: "runTask",
    value: function runTask(fn, applyThis, applyArgs, name) {
      return fn.apply(applyThis, applyArgs);
    }
  }]);

  return NoopNgZone;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The Testability service provides testing hooks that can be accessed from
 * the browser and by services such as Protractor. Each bootstrapped Angular
 * application on the page will have an instance of Testability.
 * @publicApi
 */


var Testability = /*#__PURE__*/function () {
  function Testability(_ngZone) {
    var _this22 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, Testability);

    this._ngZone = _ngZone;
    this._pendingCount = 0;
    this._isZoneStable = true;
    /**
     * Whether any work was done since the last 'whenStable' callback. This is
     * useful to detect if this could have potentially destabilized another
     * component while it is stabilizing.
     * @internal
     */

    this._didWork = false;
    this._callbacks = [];
    this.taskTrackingZone = null;

    this._watchAngularEvents();

    _ngZone.run(function () {
      _this22.taskTrackingZone = typeof Zone == 'undefined' ? null : Zone.current.get('TaskTrackingZone');
    });
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(Testability, [{
    key: "_watchAngularEvents",
    value: function _watchAngularEvents() {
      var _this23 = this;

      this._ngZone.onUnstable.subscribe({
        next: function next() {
          _this23._didWork = true;
          _this23._isZoneStable = false;
        }
      });

      this._ngZone.runOutsideAngular(function () {
        _this23._ngZone.onStable.subscribe({
          next: function next() {
            NgZone.assertNotInAngularZone();
            scheduleMicroTask(function () {
              _this23._isZoneStable = true;

              _this23._runCallbacksIfReady();
            });
          }
        });
      });
    }
    /**
     * Increases the number of pending request
     * @deprecated pending requests are now tracked with zones.
     */

  }, {
    key: "increasePendingRequestCount",
    value: function increasePendingRequestCount() {
      this._pendingCount += 1;
      this._didWork = true;
      return this._pendingCount;
    }
    /**
     * Decreases the number of pending request
     * @deprecated pending requests are now tracked with zones
     */

  }, {
    key: "decreasePendingRequestCount",
    value: function decreasePendingRequestCount() {
      this._pendingCount -= 1;

      if (this._pendingCount < 0) {
        throw new Error('pending async requests below zero');
      }

      this._runCallbacksIfReady();

      return this._pendingCount;
    }
    /**
     * Whether an associated application is stable
     */

  }, {
    key: "isStable",
    value: function isStable() {
      return this._isZoneStable && this._pendingCount === 0 && !this._ngZone.hasPendingMacrotasks;
    }
  }, {
    key: "_runCallbacksIfReady",
    value: function _runCallbacksIfReady() {
      var _this24 = this;

      if (this.isStable()) {
        // Schedules the call backs in a new frame so that it is always async.
        scheduleMicroTask(function () {
          while (_this24._callbacks.length !== 0) {
            var cb = _this24._callbacks.pop();

            clearTimeout(cb.timeoutId);
            cb.doneCb(_this24._didWork);
          }

          _this24._didWork = false;
        });
      } else {
        // Still not stable, send updates.
        var pending = this.getPendingTasks();
        this._callbacks = this._callbacks.filter(function (cb) {
          if (cb.updateCb && cb.updateCb(pending)) {
            clearTimeout(cb.timeoutId);
            return false;
          }

          return true;
        });
        this._didWork = true;
      }
    }
  }, {
    key: "getPendingTasks",
    value: function getPendingTasks() {
      if (!this.taskTrackingZone) {
        return [];
      } // Copy the tasks data so that we don't leak tasks.


      return this.taskTrackingZone.macroTasks.map(function (t) {
        return {
          source: t.source,
          // From TaskTrackingZone:
          // https://github.com/angular/zone.js/blob/master/lib/zone-spec/task-tracking.ts#L40
          creationLocation: t.creationLocation,
          data: t.data
        };
      });
    }
  }, {
    key: "addCallback",
    value: function addCallback(cb, timeout, updateCb) {
      var _this25 = this;

      var timeoutId = -1;

      if (timeout && timeout > 0) {
        timeoutId = setTimeout(function () {
          _this25._callbacks = _this25._callbacks.filter(function (cb) {
            return cb.timeoutId !== timeoutId;
          });
          cb(_this25._didWork, _this25.getPendingTasks());
        }, timeout);
      }

      this._callbacks.push({
        doneCb: cb,
        timeoutId: timeoutId,
        updateCb: updateCb
      });
    }
    /**
     * Wait for the application to be stable with a timeout. If the timeout is reached before that
     * happens, the callback receives a list of the macro tasks that were pending, otherwise null.
     *
     * @param doneCb The callback to invoke when Angular is stable or the timeout expires
     *    whichever comes first.
     * @param timeout Optional. The maximum time to wait for Angular to become stable. If not
     *    specified, whenStable() will wait forever.
     * @param updateCb Optional. If specified, this callback will be invoked whenever the set of
     *    pending macrotasks changes. If this callback returns true doneCb will not be invoked
     *    and no further updates will be issued.
     */

  }, {
    key: "whenStable",
    value: function whenStable(doneCb, timeout, updateCb) {
      if (updateCb && !this.taskTrackingZone) {
        throw new Error('Task tracking zone is required when passing an update callback to ' + 'whenStable(). Is "zone.js/dist/task-tracking.js" loaded?');
      } // These arguments are 'Function' above to keep the public API simple.


      this.addCallback(doneCb, timeout, updateCb);

      this._runCallbacksIfReady();
    }
    /**
     * Get the number of pending requests
     * @deprecated pending requests are now tracked with zones
     */

  }, {
    key: "getPendingRequestCount",
    value: function getPendingRequestCount() {
      return this._pendingCount;
    }
    /**
     * Find providers by name
     * @param using The root element to search from
     * @param provider The name of binding variable
     * @param exactMatch Whether using exactMatch
     */

  }, {
    key: "findProviders",
    value: function findProviders(using, provider, exactMatch) {
      // TODO(juliemr): implement.
      return [];
    }
  }]);

  return Testability;
}();

Testability.ɵfac = function Testability_Factory(t) {
  return new (t || Testability)(ɵɵinject(NgZone));
};

Testability.ɵprov = ɵɵdefineInjectable({
  token: Testability,
  factory: Testability.ɵfac
});

Testability.ctorParameters = function () {
  return [{
    type: NgZone
  }];
};
/*@__PURE__*/


(function () {
  setClassMetadata(Testability, [{
    type: Injectable
  }], function () {
    return [{
      type: NgZone
    }];
  }, null);
})();
/**
 * A global registry of {@link Testability} instances for specific elements.
 * @publicApi
 */


var TestabilityRegistry = /*#__PURE__*/function () {
  function TestabilityRegistry() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, TestabilityRegistry);

    /** @internal */
    this._applications = new Map();

    _testabilityGetter.addToWindow(this);
  }
  /**
   * Registers an application with a testability hook so that it can be tracked
   * @param token token of application, root element
   * @param testability Testability hook
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(TestabilityRegistry, [{
    key: "registerApplication",
    value: function registerApplication(token, testability) {
      this._applications.set(token, testability);
    }
    /**
     * Unregisters an application.
     * @param token token of application, root element
     */

  }, {
    key: "unregisterApplication",
    value: function unregisterApplication(token) {
      this._applications.delete(token);
    }
    /**
     * Unregisters all applications
     */

  }, {
    key: "unregisterAllApplications",
    value: function unregisterAllApplications() {
      this._applications.clear();
    }
    /**
     * Get a testability hook associated with the application
     * @param elem root element
     */

  }, {
    key: "getTestability",
    value: function getTestability(elem) {
      return this._applications.get(elem) || null;
    }
    /**
     * Get all registered testabilities
     */

  }, {
    key: "getAllTestabilities",
    value: function getAllTestabilities() {
      return Array.from(this._applications.values());
    }
    /**
     * Get all registered applications(root elements)
     */

  }, {
    key: "getAllRootElements",
    value: function getAllRootElements() {
      return Array.from(this._applications.keys());
    }
    /**
     * Find testability of a node in the Tree
     * @param elem node
     * @param findInAncestors whether finding testability in ancestors if testability was not found in
     * current node
     */

  }, {
    key: "findTestabilityInTree",
    value: function findTestabilityInTree(elem) {
      var findInAncestors = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      return _testabilityGetter.findTestabilityInTree(this, elem, findInAncestors);
    }
  }]);

  return TestabilityRegistry;
}();

TestabilityRegistry.ɵfac = function TestabilityRegistry_Factory(t) {
  return new (t || TestabilityRegistry)();
};

TestabilityRegistry.ɵprov = ɵɵdefineInjectable({
  token: TestabilityRegistry,
  factory: TestabilityRegistry.ɵfac
});

TestabilityRegistry.ctorParameters = function () {
  return [];
};
/*@__PURE__*/


(function () {
  setClassMetadata(TestabilityRegistry, [{
    type: Injectable
  }], function () {
    return [];
  }, null);
})();

var _NoopGetTestability = /*#__PURE__*/function () {
  function _NoopGetTestability() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, _NoopGetTestability);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(_NoopGetTestability, [{
    key: "addToWindow",
    value: function addToWindow(registry) {}
  }, {
    key: "findTestabilityInTree",
    value: function findTestabilityInTree(registry, elem, findInAncestors) {
      return null;
    }
  }]);

  return _NoopGetTestability;
}();
/**
 * Set the {@link GetTestability} implementation used by the Angular testing framework.
 * @publicApi
 */


function setTestabilityGetter(getter) {
  _testabilityGetter = getter;
}

var _testabilityGetter = new _NoopGetTestability();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _platform;

var compileNgModuleFactory = compileNgModuleFactory__POST_R3__;

function compileNgModuleFactory__PRE_R3__(injector, options, moduleType) {
  var compilerFactory = injector.get(CompilerFactory);
  var compiler = compilerFactory.createCompiler([options]);
  return compiler.compileModuleAsync(moduleType);
}

function compileNgModuleFactory__POST_R3__(injector, options, moduleType) {
  ngDevMode && assertNgModuleType(moduleType);
  var moduleFactory = new NgModuleFactory$1(moduleType); // All of the logic below is irrelevant for AOT-compiled code.

  if (typeof ngJitMode !== 'undefined' && !ngJitMode) {
    return Promise.resolve(moduleFactory);
  }

  var compilerOptions = injector.get(COMPILER_OPTIONS, []).concat(options); // Configure the compiler to use the provided options. This call may fail when multiple modules
  // are bootstrapped with incompatible options, as a component can only be compiled according to
  // a single set of options.

  setJitOptions({
    defaultEncapsulation: _lastDefined(compilerOptions.map(function (opts) {
      return opts.defaultEncapsulation;
    })),
    preserveWhitespaces: _lastDefined(compilerOptions.map(function (opts) {
      return opts.preserveWhitespaces;
    }))
  });

  if (isComponentResourceResolutionQueueEmpty()) {
    return Promise.resolve(moduleFactory);
  }

  var compilerProviders = _mergeArrays(compilerOptions.map(function (o) {
    return o.providers;
  })); // In case there are no compiler providers, we just return the module factory as
  // there won't be any resource loader. This can happen with Ivy, because AOT compiled
  // modules can be still passed through "bootstrapModule". In that case we shouldn't
  // unnecessarily require the JIT compiler.


  if (compilerProviders.length === 0) {
    return Promise.resolve(moduleFactory);
  }

  var compiler = getCompilerFacade();
  var compilerInjector = Injector.create({
    providers: compilerProviders
  });
  var resourceLoader = compilerInjector.get(compiler.ResourceLoader); // The resource loader can also return a string while the "resolveComponentResources"
  // always expects a promise. Therefore we need to wrap the returned value in a promise.

  return resolveComponentResources(function (url) {
    return Promise.resolve(resourceLoader.get(url));
  }).then(function () {
    return moduleFactory;
  });
} // the `window.ng` global utilities are only available in non-VE versions of
// Angular. The function switch below will make sure that the code is not
// included into Angular when PRE mode is active.


function publishDefaultGlobalUtils__PRE_R3__() {}

function publishDefaultGlobalUtils__POST_R3__() {
  ngDevMode && publishDefaultGlobalUtils();
}

var publishDefaultGlobalUtils$1 = publishDefaultGlobalUtils__POST_R3__;
var isBoundToModule = isBoundToModule__POST_R3__;

function isBoundToModule__PRE_R3__(cf) {
  return cf instanceof ComponentFactoryBoundToModule;
}

function isBoundToModule__POST_R3__(cf) {
  return cf.isBoundToModule;
}

var ALLOW_MULTIPLE_PLATFORMS = new InjectionToken('AllowMultipleToken');
/**
 * A token for third-party components that can register themselves with NgProbe.
 *
 * @publicApi
 */

var NgProbeToken = function NgProbeToken(name, token) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgProbeToken);

  this.name = name;
  this.token = token;
};
/**
 * Creates a platform.
 * Platforms must be created on launch using this function.
 *
 * @publicApi
 */


function createPlatform(injector) {
  if (_platform && !_platform.destroyed && !_platform.injector.get(ALLOW_MULTIPLE_PLATFORMS, false)) {
    throw new Error('There can be only one platform. Destroy the previous one to create a new one.');
  }

  publishDefaultGlobalUtils$1();
  _platform = injector.get(PlatformRef);
  var inits = injector.get(PLATFORM_INITIALIZER, null);
  if (inits) inits.forEach(function (init) {
    return init();
  });
  return _platform;
}
/**
 * Creates a factory for a platform. Can be used to provide or override `Providers` specific to
 * your applciation's runtime needs, such as `PLATFORM_INITIALIZER` and `PLATFORM_ID`.
 * @param parentPlatformFactory Another platform factory to modify. Allows you to compose factories
 * to build up configurations that might be required by different libraries or parts of the
 * application.
 * @param name Identifies the new platform factory.
 * @param providers A set of dependency providers for platforms created with the new factory.
 *
 * @publicApi
 */


function createPlatformFactory(parentPlatformFactory, name) {
  var providers = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
  var desc = "Platform: ".concat(name);
  var marker = new InjectionToken(desc);
  return function () {
    var extraProviders = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var platform = getPlatform();

    if (!platform || platform.injector.get(ALLOW_MULTIPLE_PLATFORMS, false)) {
      if (parentPlatformFactory) {
        parentPlatformFactory(providers.concat(extraProviders).concat({
          provide: marker,
          useValue: true
        }));
      } else {
        var injectedProviders = providers.concat(extraProviders).concat({
          provide: marker,
          useValue: true
        }, {
          provide: INJECTOR_SCOPE,
          useValue: 'platform'
        });
        createPlatform(Injector.create({
          providers: injectedProviders,
          name: desc
        }));
      }
    }

    return assertPlatform(marker);
  };
}
/**
 * Checks that there is currently a platform that contains the given token as a provider.
 *
 * @publicApi
 */


function assertPlatform(requiredToken) {
  var platform = getPlatform();

  if (!platform) {
    throw new Error('No platform exists!');
  }

  if (!platform.injector.get(requiredToken, null)) {
    throw new Error('A platform with a different configuration has been created. Please destroy it first.');
  }

  return platform;
}
/**
 * Destroys the current Angular platform and all Angular applications on the page.
 * Destroys all modules and listeners registered with the platform.
 *
 * @publicApi
 */


function destroyPlatform() {
  if (_platform && !_platform.destroyed) {
    _platform.destroy();
  }
}
/**
 * Returns the current platform.
 *
 * @publicApi
 */


function getPlatform() {
  return _platform && !_platform.destroyed ? _platform : null;
}
/**
 * The Angular platform is the entry point for Angular on a web page.
 * Each page has exactly one platform. Services (such as reflection) which are common
 * to every Angular application running on the page are bound in its scope.
 * A page's platform is initialized implicitly when a platform is created using a platform
 * factory such as `PlatformBrowser`, or explicitly by calling the `createPlatform()` function.
 *
 * @publicApi
 */


var PlatformRef = /*#__PURE__*/function () {
  /** @internal */
  function PlatformRef(_injector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, PlatformRef);

    this._injector = _injector;
    this._modules = [];
    this._destroyListeners = [];
    this._destroyed = false;
  }
  /**
   * Creates an instance of an `@NgModule` for the given platform for offline compilation.
   *
   * @usageNotes
   *
   * The following example creates the NgModule for a browser platform.
   *
   * ```typescript
   * my_module.ts:
   *
   * @NgModule({
   *   imports: [BrowserModule]
   * })
   * class MyModule {}
   *
   * main.ts:
   * import {MyModuleNgFactory} from './my_module.ngfactory';
   * import {platformBrowser} from '@angular/platform-browser';
   *
   * let moduleRef = platformBrowser().bootstrapModuleFactory(MyModuleNgFactory);
   * ```
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(PlatformRef, [{
    key: "bootstrapModuleFactory",
    value: function bootstrapModuleFactory(moduleFactory, options) {
      var _this26 = this;

      // Note: We need to create the NgZone _before_ we instantiate the module,
      // as instantiating the module creates some providers eagerly.
      // So we create a mini parent injector that just contains the new NgZone and
      // pass that as parent to the NgModuleFactory.
      var ngZoneOption = options ? options.ngZone : undefined;
      var ngZoneEventCoalescing = options && options.ngZoneEventCoalescing || false;
      var ngZone = getNgZone(ngZoneOption, ngZoneEventCoalescing);
      var providers = [{
        provide: NgZone,
        useValue: ngZone
      }]; // Attention: Don't use ApplicationRef.run here,
      // as we want to be sure that all possible constructor calls are inside `ngZone.run`!

      return ngZone.run(function () {
        var ngZoneInjector = Injector.create({
          providers: providers,
          parent: _this26.injector,
          name: moduleFactory.moduleType.name
        });
        var moduleRef = moduleFactory.create(ngZoneInjector);
        var exceptionHandler = moduleRef.injector.get(ErrorHandler, null);

        if (!exceptionHandler) {
          throw new Error('No ErrorHandler. Is platform module (BrowserModule) included?');
        }

        moduleRef.onDestroy(function () {
          return remove(_this26._modules, moduleRef);
        });
        ngZone.runOutsideAngular(function () {
          return ngZone.onError.subscribe({
            next: function next(error) {
              exceptionHandler.handleError(error);
            }
          });
        });
        return _callAndReportToErrorHandler(exceptionHandler, ngZone, function () {
          var initStatus = moduleRef.injector.get(ApplicationInitStatus);
          initStatus.runInitializers();
          return initStatus.donePromise.then(function () {
            if (ivyEnabled) {
              // If the `LOCALE_ID` provider is defined at bootstrap then we set the value for ivy
              var localeId = moduleRef.injector.get(LOCALE_ID$1, DEFAULT_LOCALE_ID);
              setLocaleId(localeId || DEFAULT_LOCALE_ID);
            }

            _this26._moduleDoBootstrap(moduleRef);

            return moduleRef;
          });
        });
      });
    }
    /**
     * Creates an instance of an `@NgModule` for a given platform using the given runtime compiler.
     *
     * @usageNotes
     * ### Simple Example
     *
     * ```typescript
     * @NgModule({
     *   imports: [BrowserModule]
     * })
     * class MyModule {}
     *
     * let moduleRef = platformBrowser().bootstrapModule(MyModule);
     * ```
     *
     */

  }, {
    key: "bootstrapModule",
    value: function bootstrapModule(moduleType) {
      var _this27 = this;

      var compilerOptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
      var options = optionsReducer({}, compilerOptions);
      return compileNgModuleFactory(this.injector, options, moduleType).then(function (moduleFactory) {
        return _this27.bootstrapModuleFactory(moduleFactory, options);
      });
    }
  }, {
    key: "_moduleDoBootstrap",
    value: function _moduleDoBootstrap(moduleRef) {
      var appRef = moduleRef.injector.get(ApplicationRef);

      if (moduleRef._bootstrapComponents.length > 0) {
        moduleRef._bootstrapComponents.forEach(function (f) {
          return appRef.bootstrap(f);
        });
      } else if (moduleRef.instance.ngDoBootstrap) {
        moduleRef.instance.ngDoBootstrap(appRef);
      } else {
        throw new Error("The module ".concat(stringify(moduleRef.instance.constructor), " was bootstrapped, but it does not declare \"@NgModule.bootstrap\" components nor a \"ngDoBootstrap\" method. ") + "Please define one of these.");
      }

      this._modules.push(moduleRef);
    }
    /**
     * Registers a listener to be called when the platform is destroyed.
     */

  }, {
    key: "onDestroy",
    value: function onDestroy(callback) {
      this._destroyListeners.push(callback);
    }
    /**
     * Retrieves the platform {@link Injector}, which is the parent injector for
     * every Angular application on the page and provides singleton providers.
     */

  }, {
    key: "destroy",

    /**
     * Destroys the current Angular platform and all Angular applications on the page.
     * Destroys all modules and listeners registered with the platform.
     */
    value: function destroy() {
      if (this._destroyed) {
        throw new Error('The platform has already been destroyed!');
      }

      this._modules.slice().forEach(function (module) {
        return module.destroy();
      });

      this._destroyListeners.forEach(function (listener) {
        return listener();
      });

      this._destroyed = true;
    }
  }, {
    key: "injector",
    get: function get() {
      return this._injector;
    }
  }, {
    key: "destroyed",
    get: function get() {
      return this._destroyed;
    }
  }]);

  return PlatformRef;
}();

PlatformRef.ɵfac = function PlatformRef_Factory(t) {
  return new (t || PlatformRef)(ɵɵinject(Injector));
};

PlatformRef.ɵprov = ɵɵdefineInjectable({
  token: PlatformRef,
  factory: PlatformRef.ɵfac
});

PlatformRef.ctorParameters = function () {
  return [{
    type: Injector
  }];
};
/*@__PURE__*/


(function () {
  setClassMetadata(PlatformRef, [{
    type: Injectable
  }], function () {
    return [{
      type: Injector
    }];
  }, null);
})();

function getNgZone(ngZoneOption, ngZoneEventCoalescing) {
  var ngZone;

  if (ngZoneOption === 'noop') {
    ngZone = new NoopNgZone();
  } else {
    ngZone = (ngZoneOption === 'zone.js' ? undefined : ngZoneOption) || new NgZone({
      enableLongStackTrace: isDevMode(),
      shouldCoalesceEventChangeDetection: ngZoneEventCoalescing
    });
  }

  return ngZone;
}

function _callAndReportToErrorHandler(errorHandler, ngZone, callback) {
  try {
    var result = callback();

    if (isPromise(result)) {
      return result.catch(function (e) {
        ngZone.runOutsideAngular(function () {
          return errorHandler.handleError(e);
        }); // rethrow as the exception handler might not do it

        throw e;
      });
    }

    return result;
  } catch (e) {
    ngZone.runOutsideAngular(function () {
      return errorHandler.handleError(e);
    }); // rethrow as the exception handler might not do it

    throw e;
  }
}

function optionsReducer(dst, objs) {
  if (Array.isArray(objs)) {
    dst = objs.reduce(optionsReducer, dst);
  } else {
    dst = Object.assign(Object.assign({}, dst), objs);
  }

  return dst;
}
/**
 * A reference to an Angular application running on a page.
 *
 * @usageNotes
 *
 * {@a is-stable-examples}
 * ### isStable examples and caveats
 *
 * Note two important points about `isStable`, demonstrated in the examples below:
 * - the application will never be stable if you start any kind
 * of recurrent asynchronous task when the application starts
 * (for example for a polling process, started with a `setInterval`, a `setTimeout`
 * or using RxJS operators like `interval`);
 * - the `isStable` Observable runs outside of the Angular zone.
 *
 * Let's imagine that you start a recurrent task
 * (here incrementing a counter, using RxJS `interval`),
 * and at the same time subscribe to `isStable`.
 *
 * ```
 * constructor(appRef: ApplicationRef) {
 *   appRef.isStable.pipe(
 *      filter(stable => stable)
 *   ).subscribe(() => console.log('App is stable now');
 *   interval(1000).subscribe(counter => console.log(counter));
 * }
 * ```
 * In this example, `isStable` will never emit `true`,
 * and the trace "App is stable now" will never get logged.
 *
 * If you want to execute something when the app is stable,
 * you have to wait for the application to be stable
 * before starting your polling process.
 *
 * ```
 * constructor(appRef: ApplicationRef) {
 *   appRef.isStable.pipe(
 *     first(stable => stable),
 *     tap(stable => console.log('App is stable now')),
 *     switchMap(() => interval(1000))
 *   ).subscribe(counter => console.log(counter));
 * }
 * ```
 * In this example, the trace "App is stable now" will be logged
 * and then the counter starts incrementing every second.
 *
 * Note also that this Observable runs outside of the Angular zone,
 * which means that the code in the subscription
 * to this Observable will not trigger the change detection.
 *
 * Let's imagine that instead of logging the counter value,
 * you update a field of your component
 * and display it in its template.
 *
 * ```
 * constructor(appRef: ApplicationRef) {
 *   appRef.isStable.pipe(
 *     first(stable => stable),
 *     switchMap(() => interval(1000))
 *   ).subscribe(counter => this.value = counter);
 * }
 * ```
 * As the `isStable` Observable runs outside the zone,
 * the `value` field will be updated properly,
 * but the template will not be refreshed!
 *
 * You'll have to manually trigger the change detection to update the template.
 *
 * ```
 * constructor(appRef: ApplicationRef, cd: ChangeDetectorRef) {
 *   appRef.isStable.pipe(
 *     first(stable => stable),
 *     switchMap(() => interval(1000))
 *   ).subscribe(counter => {
 *     this.value = counter;
 *     cd.detectChanges();
 *   });
 * }
 * ```
 *
 * Or make the subscription callback run inside the zone.
 *
 * ```
 * constructor(appRef: ApplicationRef, zone: NgZone) {
 *   appRef.isStable.pipe(
 *     first(stable => stable),
 *     switchMap(() => interval(1000))
 *   ).subscribe(counter => zone.run(() => this.value = counter));
 * }
 * ```
 *
 * @publicApi
 */


var ApplicationRef = /*#__PURE__*/function () {
  /** @internal */
  function ApplicationRef(_zone, _console, _injector, _exceptionHandler, _componentFactoryResolver, _initStatus) {
    var _this28 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ApplicationRef);

    this._zone = _zone;
    this._console = _console;
    this._injector = _injector;
    this._exceptionHandler = _exceptionHandler;
    this._componentFactoryResolver = _componentFactoryResolver;
    this._initStatus = _initStatus;
    /** @internal */

    this._bootstrapListeners = [];
    this._views = [];
    this._runningTick = false;
    this._enforceNoNewChanges = false;
    this._stable = true;
    /**
     * Get a list of component types registered to this application.
     * This list is populated even before the component is created.
     */

    this.componentTypes = [];
    /**
     * Get a list of components registered to this application.
     */

    this.components = [];
    this._enforceNoNewChanges = isDevMode();

    this._zone.onMicrotaskEmpty.subscribe({
      next: function next() {
        _this28._zone.run(function () {
          _this28.tick();
        });
      }
    });

    var isCurrentlyStable = new rxjs__WEBPACK_IMPORTED_MODULE_13__["Observable"](function (observer) {
      _this28._stable = _this28._zone.isStable && !_this28._zone.hasPendingMacrotasks && !_this28._zone.hasPendingMicrotasks;

      _this28._zone.runOutsideAngular(function () {
        observer.next(_this28._stable);
        observer.complete();
      });
    });
    var isStable = new rxjs__WEBPACK_IMPORTED_MODULE_13__["Observable"](function (observer) {
      // Create the subscription to onStable outside the Angular Zone so that
      // the callback is run outside the Angular Zone.
      var stableSub;

      _this28._zone.runOutsideAngular(function () {
        stableSub = _this28._zone.onStable.subscribe(function () {
          NgZone.assertNotInAngularZone(); // Check whether there are no pending macro/micro tasks in the next tick
          // to allow for NgZone to update the state.

          scheduleMicroTask(function () {
            if (!_this28._stable && !_this28._zone.hasPendingMacrotasks && !_this28._zone.hasPendingMicrotasks) {
              _this28._stable = true;
              observer.next(true);
            }
          });
        });
      });

      var unstableSub = _this28._zone.onUnstable.subscribe(function () {
        NgZone.assertInAngularZone();

        if (_this28._stable) {
          _this28._stable = false;

          _this28._zone.runOutsideAngular(function () {
            observer.next(false);
          });
        }
      });

      return function () {
        stableSub.unsubscribe();
        unstableSub.unsubscribe();
      };
    });
    this.isStable = Object(rxjs__WEBPACK_IMPORTED_MODULE_13__["merge"])(isCurrentlyStable, isStable.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_14__["share"])()));
  }
  /**
   * Bootstrap a new component at the root level of the application.
   *
   * @usageNotes
   * ### Bootstrap process
   *
   * When bootstrapping a new root component into an application, Angular mounts the
   * specified application component onto DOM elements identified by the componentType's
   * selector and kicks off automatic change detection to finish initializing the component.
   *
   * Optionally, a component can be mounted onto a DOM element that does not match the
   * componentType's selector.
   *
   * ### Example
   * {@example core/ts/platform/platform.ts region='longform'}
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(ApplicationRef, [{
    key: "bootstrap",
    value: function bootstrap(componentOrFactory, rootSelectorOrNode) {
      var _this29 = this;

      if (!this._initStatus.done) {
        throw new Error('Cannot bootstrap as there are still asynchronous initializers running. Bootstrap components in the `ngDoBootstrap` method of the root module.');
      }

      var componentFactory;

      if (componentOrFactory instanceof ComponentFactory) {
        componentFactory = componentOrFactory;
      } else {
        componentFactory = this._componentFactoryResolver.resolveComponentFactory(componentOrFactory);
      }

      this.componentTypes.push(componentFactory.componentType); // Create a factory associated with the current module if it's not bound to some other

      var ngModule = isBoundToModule(componentFactory) ? undefined : this._injector.get(NgModuleRef);
      var selectorOrNode = rootSelectorOrNode || componentFactory.selector;
      var compRef = componentFactory.create(Injector.NULL, [], selectorOrNode, ngModule);
      compRef.onDestroy(function () {
        _this29._unloadComponent(compRef);
      });
      var testability = compRef.injector.get(Testability, null);

      if (testability) {
        compRef.injector.get(TestabilityRegistry).registerApplication(compRef.location.nativeElement, testability);
      }

      this._loadComponent(compRef);

      if (isDevMode()) {
        this._console.log("Angular is running in development mode. Call enableProdMode() to enable production mode.");
      }

      return compRef;
    }
    /**
     * Invoke this method to explicitly process change detection and its side-effects.
     *
     * In development mode, `tick()` also performs a second change detection cycle to ensure that no
     * further changes are detected. If additional changes are picked up during this second cycle,
     * bindings in the app have side-effects that cannot be resolved in a single change detection
     * pass.
     * In this case, Angular throws an error, since an Angular application can only have one change
     * detection pass during which all change detection must complete.
     */

  }, {
    key: "tick",
    value: function tick() {
      var _this30 = this;

      if (this._runningTick) {
        throw new Error('ApplicationRef.tick is called recursively');
      }

      try {
        this._runningTick = true;

        var _iterator4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__["default"])(this._views),
            _step4;

        try {
          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
            var _view2 = _step4.value;

            _view2.detectChanges();
          }
        } catch (err) {
          _iterator4.e(err);
        } finally {
          _iterator4.f();
        }

        if (this._enforceNoNewChanges) {
          var _iterator5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__["default"])(this._views),
              _step5;

          try {
            for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
              var view = _step5.value;
              view.checkNoChanges();
            }
          } catch (err) {
            _iterator5.e(err);
          } finally {
            _iterator5.f();
          }
        }
      } catch (e) {
        // Attention: Don't rethrow as it could cancel subscriptions to Observables!
        this._zone.runOutsideAngular(function () {
          return _this30._exceptionHandler.handleError(e);
        });
      } finally {
        this._runningTick = false;
      }
    }
    /**
     * Attaches a view so that it will be dirty checked.
     * The view will be automatically detached when it is destroyed.
     * This will throw if the view is already attached to a ViewContainer.
     */

  }, {
    key: "attachView",
    value: function attachView(viewRef) {
      var view = viewRef;

      this._views.push(view);

      view.attachToAppRef(this);
    }
    /**
     * Detaches a view from dirty checking again.
     */

  }, {
    key: "detachView",
    value: function detachView(viewRef) {
      var view = viewRef;
      remove(this._views, view);
      view.detachFromAppRef();
    }
  }, {
    key: "_loadComponent",
    value: function _loadComponent(componentRef) {
      this.attachView(componentRef.hostView);
      this.tick();
      this.components.push(componentRef); // Get the listeners lazily to prevent DI cycles.

      var listeners = this._injector.get(APP_BOOTSTRAP_LISTENER, []).concat(this._bootstrapListeners);

      listeners.forEach(function (listener) {
        return listener(componentRef);
      });
    }
  }, {
    key: "_unloadComponent",
    value: function _unloadComponent(componentRef) {
      this.detachView(componentRef.hostView);
      remove(this.components, componentRef);
    }
    /** @internal */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      // TODO(alxhub): Dispose of the NgZone.
      this._views.slice().forEach(function (view) {
        return view.destroy();
      });
    }
    /**
     * Returns the number of attached views.
     */

  }, {
    key: "viewCount",
    get: function get() {
      return this._views.length;
    }
  }]);

  return ApplicationRef;
}();

ApplicationRef.ɵfac = function ApplicationRef_Factory(t) {
  return new (t || ApplicationRef)(ɵɵinject(NgZone), ɵɵinject(Console), ɵɵinject(Injector), ɵɵinject(ErrorHandler), ɵɵinject(ComponentFactoryResolver), ɵɵinject(ApplicationInitStatus));
};

ApplicationRef.ɵprov = ɵɵdefineInjectable({
  token: ApplicationRef,
  factory: ApplicationRef.ɵfac
});

ApplicationRef.ctorParameters = function () {
  return [{
    type: NgZone
  }, {
    type: Console
  }, {
    type: Injector
  }, {
    type: ErrorHandler
  }, {
    type: ComponentFactoryResolver
  }, {
    type: ApplicationInitStatus
  }];
};
/*@__PURE__*/


(function () {
  setClassMetadata(ApplicationRef, [{
    type: Injectable
  }], function () {
    return [{
      type: NgZone
    }, {
      type: Console
    }, {
      type: Injector
    }, {
      type: ErrorHandler
    }, {
      type: ComponentFactoryResolver
    }, {
      type: ApplicationInitStatus
    }];
  }, null);
})();

function remove(list, el) {
  var index = list.indexOf(el);

  if (index > -1) {
    list.splice(index, 1);
  }
}

function _lastDefined(args) {
  for (var i = args.length - 1; i >= 0; i--) {
    if (args[i] !== undefined) {
      return args[i];
    }
  }

  return undefined;
}

function _mergeArrays(parts) {
  var result = [];
  parts.forEach(function (part) {
    return part && result.push.apply(result, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(part));
  });
  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Used to load ng module factories.
 *
 * @publicApi
 * @deprecated the `string` form of `loadChildren` is deprecated, and `NgModuleFactoryLoader` is
 * part of its implementation. See `LoadChildren` for more details.
 */


var NgModuleFactoryLoader = function NgModuleFactoryLoader() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleFactoryLoader);
};

function getModuleFactory__PRE_R3__(id) {
  var factory = getRegisteredNgModuleType(id);
  if (!factory) throw noModuleError(id);
  return factory;
}

function getModuleFactory__POST_R3__(id) {
  var type = getRegisteredNgModuleType(id);
  if (!type) throw noModuleError(id);
  return new NgModuleFactory$1(type);
}
/**
 * Returns the NgModuleFactory with the given id, if it exists and has been loaded.
 * Factories for modules that do not specify an `id` cannot be retrieved. Throws if the module
 * cannot be found.
 * @publicApi
 */


var getModuleFactory = getModuleFactory__POST_R3__;

function noModuleError(id) {
  return new Error("No module with ID ".concat(id, " loaded"));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _SEPARATOR = '#';
var FACTORY_CLASS_SUFFIX = 'NgFactory';
/**
 * Configuration for SystemJsNgModuleLoader.
 * token.
 *
 * @publicApi
 * @deprecated the `string` form of `loadChildren` is deprecated, and `SystemJsNgModuleLoaderConfig`
 * is part of its implementation. See `LoadChildren` for more details.
 */

var SystemJsNgModuleLoaderConfig = function SystemJsNgModuleLoaderConfig() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SystemJsNgModuleLoaderConfig);
};

var DEFAULT_CONFIG = {
  factoryPathPrefix: '',
  factoryPathSuffix: '.ngfactory'
};
/**
 * NgModuleFactoryLoader that uses SystemJS to load NgModuleFactory
 * @publicApi
 * @deprecated the `string` form of `loadChildren` is deprecated, and `SystemJsNgModuleLoader` is
 * part of its implementation. See `LoadChildren` for more details.
 */

var SystemJsNgModuleLoader = /*#__PURE__*/function () {
  function SystemJsNgModuleLoader(_compiler, config) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, SystemJsNgModuleLoader);

    this._compiler = _compiler;
    this._config = config || DEFAULT_CONFIG;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(SystemJsNgModuleLoader, [{
    key: "load",
    value: function load(path) {
      var legacyOfflineMode = !ivyEnabled && this._compiler instanceof Compiler;
      return legacyOfflineMode ? this.loadFactory(path) : this.loadAndCompile(path);
    }
  }, {
    key: "loadAndCompile",
    value: function loadAndCompile(path) {
      var _this31 = this;

      var _path$split = path.split(_SEPARATOR),
          _path$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_path$split, 2),
          module = _path$split2[0],
          exportName = _path$split2[1];

      if (exportName === undefined) {
        exportName = 'default';
      }

      return __webpack_require__("crnd")(module).then(function (module) {
        return module[exportName];
      }).then(function (type) {
        return checkNotEmpty(type, module, exportName);
      }).then(function (type) {
        return _this31._compiler.compileModuleAsync(type);
      });
    }
  }, {
    key: "loadFactory",
    value: function loadFactory(path) {
      var _path$split3 = path.split(_SEPARATOR),
          _path$split4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_path$split3, 2),
          module = _path$split4[0],
          exportName = _path$split4[1];

      var factoryClassSuffix = FACTORY_CLASS_SUFFIX;

      if (exportName === undefined) {
        exportName = 'default';
        factoryClassSuffix = '';
      }

      return __webpack_require__("crnd")(this._config.factoryPathPrefix + module + this._config.factoryPathSuffix).then(function (module) {
        return module[exportName + factoryClassSuffix];
      }).then(function (factory) {
        return checkNotEmpty(factory, module, exportName);
      });
    }
  }]);

  return SystemJsNgModuleLoader;
}();

SystemJsNgModuleLoader.ɵfac = function SystemJsNgModuleLoader_Factory(t) {
  return new (t || SystemJsNgModuleLoader)(ɵɵinject(Compiler), ɵɵinject(SystemJsNgModuleLoaderConfig, 8));
};

SystemJsNgModuleLoader.ɵprov = ɵɵdefineInjectable({
  token: SystemJsNgModuleLoader,
  factory: SystemJsNgModuleLoader.ɵfac
});

SystemJsNgModuleLoader.ctorParameters = function () {
  return [{
    type: Compiler
  }, {
    type: SystemJsNgModuleLoaderConfig,
    decorators: [{
      type: Optional
    }]
  }];
};
/*@__PURE__*/


(function () {
  setClassMetadata(SystemJsNgModuleLoader, [{
    type: Injectable
  }], function () {
    return [{
      type: Compiler
    }, {
      type: SystemJsNgModuleLoaderConfig,
      decorators: [{
        type: Optional
      }]
    }];
  }, null);
})();

function checkNotEmpty(value, modulePath, exportName) {
  if (!value) {
    throw new Error("Cannot find '".concat(exportName, "' in '").concat(modulePath, "'"));
  }

  return value;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents an Angular [view](guide/glossary#view "Definition").
 *
 * @see {@link ChangeDetectorRef#usage-notes Change detection usage}
 *
 * @publicApi
 */


var ViewRef$1 = /*#__PURE__*/function (_ChangeDetectorRef) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(ViewRef$1, _ChangeDetectorRef);

  var _super20 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(ViewRef$1);

  function ViewRef$1() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ViewRef$1);

    return _super20.apply(this, arguments);
  }

  return ViewRef$1;
}(ChangeDetectorRef);
/**
 * Represents an Angular [view](guide/glossary#view) in a view container.
 * An [embedded view](guide/glossary#view-tree) can be referenced from a component
 * other than the hosting component whose template defines it, or it can be defined
 * independently by a `TemplateRef`.
 *
 * Properties of elements in a view can change, but the structure (number and order) of elements in
 * a view cannot. Change the structure of elements by inserting, moving, or
 * removing nested views in a view container.
 *
 * @see `ViewContainerRef`
 *
 * @usageNotes
 *
 * The following template breaks down into two separate `TemplateRef` instances,
 * an outer one and an inner one.
 *
 * ```
 * Count: {{items.length}}
 * <ul>
 *   <li *ngFor="let  item of items">{{item}}</li>
 * </ul>
 * ```
 *
 * This is the outer `TemplateRef`:
 *
 * ```
 * Count: {{items.length}}
 * <ul>
 *   <ng-template ngFor let-item [ngForOf]="items"></ng-template>
 * </ul>
 * ```
 *
 * This is the inner `TemplateRef`:
 *
 * ```
 *   <li>{{item}}</li>
 * ```
 *
 * The outer and inner `TemplateRef` instances are assembled into views as follows:
 *
 * ```
 * <!-- ViewRef: outer-0 -->
 * Count: 2
 * <ul>
 *   <ng-template view-container-ref></ng-template>
 *   <!-- ViewRef: inner-1 --><li>first</li><!-- /ViewRef: inner-1 -->
 *   <!-- ViewRef: inner-2 --><li>second</li><!-- /ViewRef: inner-2 -->
 * </ul>
 * <!-- /ViewRef: outer-0 -->
 * ```
 * @publicApi
 */


var EmbeddedViewRef = /*#__PURE__*/function (_ViewRef$) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(EmbeddedViewRef, _ViewRef$);

  var _super21 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(EmbeddedViewRef);

  function EmbeddedViewRef() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, EmbeddedViewRef);

    return _super21.apply(this, arguments);
  }

  return EmbeddedViewRef;
}(ViewRef$1);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var DebugEventListener = function DebugEventListener(name, callback) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugEventListener);

  this.name = name;
  this.callback = callback;
};

var DebugNode__PRE_R3__ = /*#__PURE__*/function () {
  function DebugNode__PRE_R3__(nativeNode, parent, _debugContext) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugNode__PRE_R3__);

    this.listeners = [];
    this.parent = null;
    this._debugContext = _debugContext;
    this.nativeNode = nativeNode;

    if (parent && parent instanceof DebugElement__PRE_R3__) {
      parent.addChild(this);
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugNode__PRE_R3__, [{
    key: "injector",
    get: function get() {
      return this._debugContext.injector;
    }
  }, {
    key: "componentInstance",
    get: function get() {
      return this._debugContext.component;
    }
  }, {
    key: "context",
    get: function get() {
      return this._debugContext.context;
    }
  }, {
    key: "references",
    get: function get() {
      return this._debugContext.references;
    }
  }, {
    key: "providerTokens",
    get: function get() {
      return this._debugContext.providerTokens;
    }
  }]);

  return DebugNode__PRE_R3__;
}();

var DebugElement__PRE_R3__ = /*#__PURE__*/function (_DebugNode__PRE_R3__) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(DebugElement__PRE_R3__, _DebugNode__PRE_R3__);

  var _super22 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(DebugElement__PRE_R3__);

  function DebugElement__PRE_R3__(nativeNode, parent, _debugContext) {
    var _this32;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugElement__PRE_R3__);

    _this32 = _super22.call(this, nativeNode, parent, _debugContext);
    _this32.properties = {};
    _this32.attributes = {};
    _this32.classes = {};
    _this32.styles = {};
    _this32.childNodes = [];
    _this32.nativeElement = nativeNode;
    return _this32;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugElement__PRE_R3__, [{
    key: "addChild",
    value: function addChild(child) {
      if (child) {
        this.childNodes.push(child);
        child.parent = this;
      }
    }
  }, {
    key: "removeChild",
    value: function removeChild(child) {
      var childIndex = this.childNodes.indexOf(child);

      if (childIndex !== -1) {
        child.parent = null;
        this.childNodes.splice(childIndex, 1);
      }
    }
  }, {
    key: "insertChildrenAfter",
    value: function insertChildrenAfter(child, newChildren) {
      var _this33 = this;

      var siblingIndex = this.childNodes.indexOf(child);

      if (siblingIndex !== -1) {
        var _this$childNodes;

        (_this$childNodes = this.childNodes).splice.apply(_this$childNodes, [siblingIndex + 1, 0].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(newChildren)));

        newChildren.forEach(function (c) {
          if (c.parent) {
            c.parent.removeChild(c);
          }

          child.parent = _this33;
        });
      }
    }
  }, {
    key: "insertBefore",
    value: function insertBefore(refChild, newChild) {
      var refIndex = this.childNodes.indexOf(refChild);

      if (refIndex === -1) {
        this.addChild(newChild);
      } else {
        if (newChild.parent) {
          newChild.parent.removeChild(newChild);
        }

        newChild.parent = this;
        this.childNodes.splice(refIndex, 0, newChild);
      }
    }
  }, {
    key: "query",
    value: function query(predicate) {
      var results = this.queryAll(predicate);
      return results[0] || null;
    }
  }, {
    key: "queryAll",
    value: function queryAll(predicate) {
      var matches = [];

      _queryElementChildren(this, predicate, matches);

      return matches;
    }
  }, {
    key: "queryAllNodes",
    value: function queryAllNodes(predicate) {
      var matches = [];

      _queryNodeChildren(this, predicate, matches);

      return matches;
    }
  }, {
    key: "triggerEventHandler",
    value: function triggerEventHandler(eventName, eventObj) {
      this.listeners.forEach(function (listener) {
        if (listener.name == eventName) {
          listener.callback(eventObj);
        }
      });
    }
  }, {
    key: "children",
    get: function get() {
      return this.childNodes //
      .filter(function (node) {
        return node instanceof DebugElement__PRE_R3__;
      });
    }
  }]);

  return DebugElement__PRE_R3__;
}(DebugNode__PRE_R3__);
/**
 * @publicApi
 */


function asNativeElements(debugEls) {
  return debugEls.map(function (el) {
    return el.nativeElement;
  });
}

function _queryElementChildren(element, predicate, matches) {
  element.childNodes.forEach(function (node) {
    if (node instanceof DebugElement__PRE_R3__) {
      if (predicate(node)) {
        matches.push(node);
      }

      _queryElementChildren(node, predicate, matches);
    }
  });
}

function _queryNodeChildren(parentNode, predicate, matches) {
  if (parentNode instanceof DebugElement__PRE_R3__) {
    parentNode.childNodes.forEach(function (node) {
      if (predicate(node)) {
        matches.push(node);
      }

      if (node instanceof DebugElement__PRE_R3__) {
        _queryNodeChildren(node, predicate, matches);
      }
    });
  }
}

var DebugNode__POST_R3__ = /*#__PURE__*/function () {
  function DebugNode__POST_R3__(nativeNode) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugNode__POST_R3__);

    this.nativeNode = nativeNode;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugNode__POST_R3__, [{
    key: "parent",
    get: function get() {
      var parent = this.nativeNode.parentNode;
      return parent ? new DebugElement__POST_R3__(parent) : null;
    }
  }, {
    key: "injector",
    get: function get() {
      return getInjector(this.nativeNode);
    }
  }, {
    key: "componentInstance",
    get: function get() {
      var nativeElement = this.nativeNode;
      return nativeElement && (getComponent(nativeElement) || getOwningComponent(nativeElement));
    }
  }, {
    key: "context",
    get: function get() {
      return getComponent(this.nativeNode) || getContext(this.nativeNode);
    }
  }, {
    key: "listeners",
    get: function get() {
      return getListeners(this.nativeNode).filter(function (listener) {
        return listener.type === 'dom';
      });
    }
  }, {
    key: "references",
    get: function get() {
      return getLocalRefs(this.nativeNode);
    }
  }, {
    key: "providerTokens",
    get: function get() {
      return getInjectionTokens(this.nativeNode);
    }
  }]);

  return DebugNode__POST_R3__;
}();

var DebugElement__POST_R3__ = /*#__PURE__*/function (_DebugNode__POST_R3__) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(DebugElement__POST_R3__, _DebugNode__POST_R3__);

  var _super23 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(DebugElement__POST_R3__);

  function DebugElement__POST_R3__(nativeNode) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugElement__POST_R3__);

    ngDevMode && assertDomNode(nativeNode);
    return _super23.call(this, nativeNode);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugElement__POST_R3__, [{
    key: "query",
    value: function query(predicate) {
      var results = this.queryAll(predicate);
      return results[0] || null;
    }
  }, {
    key: "queryAll",
    value: function queryAll(predicate) {
      var matches = [];

      _queryAllR3(this, predicate, matches, true);

      return matches;
    }
  }, {
    key: "queryAllNodes",
    value: function queryAllNodes(predicate) {
      var matches = [];

      _queryAllR3(this, predicate, matches, false);

      return matches;
    }
  }, {
    key: "triggerEventHandler",
    value: function triggerEventHandler(eventName, eventObj) {
      var node = this.nativeNode;
      var invokedListeners = [];
      this.listeners.forEach(function (listener) {
        if (listener.name === eventName) {
          var callback = listener.callback;
          callback.call(node, eventObj);
          invokedListeners.push(callback);
        }
      }); // We need to check whether `eventListeners` exists, because it's something
      // that Zone.js only adds to `EventTarget` in browser environments.

      if (typeof node.eventListeners === 'function') {
        // Note that in Ivy we wrap event listeners with a call to `event.preventDefault` in some
        // cases. We use '__ngUnwrap__' as a special token that gives us access to the actual event
        // listener.
        node.eventListeners(eventName).forEach(function (listener) {
          // In order to ensure that we can detect the special __ngUnwrap__ token described above, we
          // use `toString` on the listener and see if it contains the token. We use this approach to
          // ensure that it still worked with compiled code since it cannot remove or rename string
          // literals. We also considered using a special function name (i.e. if(listener.name ===
          // special)) but that was more cumbersome and we were also concerned the compiled code could
          // strip the name, turning the condition in to ("" === "") and always returning true.
          if (listener.toString().indexOf('__ngUnwrap__') !== -1) {
            var unwrappedListener = listener('__ngUnwrap__');
            return invokedListeners.indexOf(unwrappedListener) === -1 && unwrappedListener.call(node, eventObj);
          }
        });
      }
    }
  }, {
    key: "nativeElement",
    get: function get() {
      return this.nativeNode.nodeType == Node.ELEMENT_NODE ? this.nativeNode : null;
    }
  }, {
    key: "name",
    get: function get() {
      try {
        var context = loadLContext(this.nativeNode);
        var lView = context.lView;
        var tData = lView[TVIEW].data;
        var tNode = tData[context.nodeIndex];
        return tNode.tagName;
      } catch (e) {
        return this.nativeNode.nodeName;
      }
    }
    /**
     *  Gets a map of property names to property values for an element.
     *
     *  This map includes:
     *  - Regular property bindings (e.g. `[id]="id"`)
     *  - Host property bindings (e.g. `host: { '[id]': "id" }`)
     *  - Interpolated property bindings (e.g. `id="{{ value }}")
     *
     *  It does not include:
     *  - input property bindings (e.g. `[myCustomInput]="value"`)
     *  - attribute bindings (e.g. `[attr.role]="menu"`)
     */

  }, {
    key: "properties",
    get: function get() {
      var context = loadLContext(this.nativeNode, false);

      if (context == null) {
        return {};
      }

      var lView = context.lView;
      var tData = lView[TVIEW].data;
      var tNode = tData[context.nodeIndex];
      var properties = {}; // Collect properties from the DOM.

      copyDomProperties(this.nativeElement, properties); // Collect properties from the bindings. This is needed for animation renderer which has
      // synthetic properties which don't get reflected into the DOM.

      collectPropertyBindings(properties, tNode, lView, tData);
      return properties;
    }
  }, {
    key: "attributes",
    get: function get() {
      var attributes = {};
      var element = this.nativeElement;

      if (!element) {
        return attributes;
      }

      var context = loadLContext(element, false);

      if (context == null) {
        return {};
      }

      var lView = context.lView;
      var tNodeAttrs = lView[TVIEW].data[context.nodeIndex].attrs;
      var lowercaseTNodeAttrs = []; // For debug nodes we take the element's attribute directly from the DOM since it allows us
      // to account for ones that weren't set via bindings (e.g. ViewEngine keeps track of the ones
      // that are set through `Renderer2`). The problem is that the browser will lowercase all names,
      // however since we have the attributes already on the TNode, we can preserve the case by going
      // through them once, adding them to the `attributes` map and putting their lower-cased name
      // into an array. Afterwards when we're going through the native DOM attributes, we can check
      // whether we haven't run into an attribute already through the TNode.

      if (tNodeAttrs) {
        var i = 0;

        while (i < tNodeAttrs.length) {
          var attrName = tNodeAttrs[i]; // Stop as soon as we hit a marker. We only care about the regular attributes. Everything
          // else will be handled below when we read the final attributes off the DOM.

          if (typeof attrName !== 'string') break;
          var attrValue = tNodeAttrs[i + 1];
          attributes[attrName] = attrValue;
          lowercaseTNodeAttrs.push(attrName.toLowerCase());
          i += 2;
        }
      }

      var eAttrs = element.attributes;

      for (var _i10 = 0; _i10 < eAttrs.length; _i10++) {
        var attr = eAttrs[_i10];
        var lowercaseName = attr.name.toLowerCase(); // Make sure that we don't assign the same attribute both in its
        // case-sensitive form and the lower-cased one from the browser.

        if (lowercaseTNodeAttrs.indexOf(lowercaseName) === -1) {
          // Save the lowercase name to align the behavior between browsers.
          // IE preserves the case, while all other browser convert it to lower case.
          attributes[lowercaseName] = attr.value;
        }
      }

      return attributes;
    }
  }, {
    key: "styles",
    get: function get() {
      if (this.nativeElement && this.nativeElement.style) {
        return this.nativeElement.style;
      }

      return {};
    }
  }, {
    key: "classes",
    get: function get() {
      var result = {};
      var element = this.nativeElement; // SVG elements return an `SVGAnimatedString` instead of a plain string for the `className`.

      var className = element.className;
      var classes = className && typeof className !== 'string' ? className.baseVal.split(' ') : className.split(' ');
      classes.forEach(function (value) {
        return result[value] = true;
      });
      return result;
    }
  }, {
    key: "childNodes",
    get: function get() {
      var childNodes = this.nativeNode.childNodes;
      var children = [];

      for (var i = 0; i < childNodes.length; i++) {
        var element = childNodes[i];
        children.push(getDebugNode__POST_R3__(element));
      }

      return children;
    }
  }, {
    key: "children",
    get: function get() {
      var nativeElement = this.nativeElement;
      if (!nativeElement) return [];
      var childNodes = nativeElement.children;
      var children = [];

      for (var i = 0; i < childNodes.length; i++) {
        var element = childNodes[i];
        children.push(getDebugNode__POST_R3__(element));
      }

      return children;
    }
  }]);

  return DebugElement__POST_R3__;
}(DebugNode__POST_R3__);

function copyDomProperties(element, properties) {
  if (element) {
    // Skip own properties (as those are patched)
    var obj = Object.getPrototypeOf(element);
    var NodePrototype = Node.prototype;

    while (obj !== null && obj !== NodePrototype) {
      var descriptors = Object.getOwnPropertyDescriptors(obj);

      for (var key in descriptors) {
        if (!key.startsWith('__') && !key.startsWith('on')) {
          // don't include properties starting with `__` and `on`.
          // `__` are patched values which should not be included.
          // `on` are listeners which also should not be included.
          var value = element[key];

          if (isPrimitiveValue(value)) {
            properties[key] = value;
          }
        }
      }

      obj = Object.getPrototypeOf(obj);
    }
  }
}

function isPrimitiveValue(value) {
  return typeof value === 'string' || typeof value === 'boolean' || typeof value === 'number' || value === null;
}

function _queryAllR3(parentElement, predicate, matches, elementsOnly) {
  var context = loadLContext(parentElement.nativeNode, false);

  if (context !== null) {
    var parentTNode = context.lView[TVIEW].data[context.nodeIndex];

    _queryNodeChildrenR3(parentTNode, context.lView, predicate, matches, elementsOnly, parentElement.nativeNode);
  } else {
    // If the context is null, then `parentElement` was either created with Renderer2 or native DOM
    // APIs.
    _queryNativeNodeDescendants(parentElement.nativeNode, predicate, matches, elementsOnly);
  }
}
/**
 * Recursively match the current TNode against the predicate, and goes on with the next ones.
 *
 * @param tNode the current TNode
 * @param lView the LView of this TNode
 * @param predicate the predicate to match
 * @param matches the list of positive matches
 * @param elementsOnly whether only elements should be searched
 * @param rootNativeNode the root native node on which predicate should not be matched
 */


function _queryNodeChildrenR3(tNode, lView, predicate, matches, elementsOnly, rootNativeNode) {
  ngDevMode && assertTNodeForLView(tNode, lView);
  var nativeNode = getNativeByTNodeOrNull(tNode, lView); // For each type of TNode, specific logic is executed.

  if (tNode.type === 2
  /* Element */
  || tNode.type === 3
  /* ElementContainer */
  ) {
      // Case 1: the TNode is an element
      // The native node has to be checked.
      _addQueryMatchR3(nativeNode, predicate, matches, elementsOnly, rootNativeNode);

      if (isComponentHost(tNode)) {
        // If the element is the host of a component, then all nodes in its view have to be processed.
        // Note: the component's content (tNode.child) will be processed from the insertion points.
        var componentView = getComponentLViewByIndex(tNode.index, lView);

        if (componentView && componentView[TVIEW].firstChild) {
          _queryNodeChildrenR3(componentView[TVIEW].firstChild, componentView, predicate, matches, elementsOnly, rootNativeNode);
        }
      } else {
        if (tNode.child) {
          // Otherwise, its children have to be processed.
          _queryNodeChildrenR3(tNode.child, lView, predicate, matches, elementsOnly, rootNativeNode);
        } // We also have to query the DOM directly in order to catch elements inserted through
        // Renderer2. Note that this is __not__ optimal, because we're walking similar trees multiple
        // times. ViewEngine could do it more efficiently, because all the insertions go through
        // Renderer2, however that's not the case in Ivy. This approach is being used because:
        // 1. Matching the ViewEngine behavior would mean potentially introducing a depedency
        //    from `Renderer2` to Ivy which could bring Ivy code into ViewEngine.
        // 2. We would have to make `Renderer3` "know" about debug nodes.
        // 3. It allows us to capture nodes that were inserted directly via the DOM.


        nativeNode && _queryNativeNodeDescendants(nativeNode, predicate, matches, elementsOnly);
      } // In all cases, if a dynamic container exists for this node, each view inside it has to be
      // processed.


      var nodeOrContainer = lView[tNode.index];

      if (isLContainer(nodeOrContainer)) {
        _queryNodeChildrenInContainerR3(nodeOrContainer, predicate, matches, elementsOnly, rootNativeNode);
      }
    } else if (tNode.type === 0
  /* Container */
  ) {
      // Case 2: the TNode is a container
      // The native node has to be checked.
      var lContainer = lView[tNode.index];

      _addQueryMatchR3(lContainer[NATIVE], predicate, matches, elementsOnly, rootNativeNode); // Each view inside the container has to be processed.


      _queryNodeChildrenInContainerR3(lContainer, predicate, matches, elementsOnly, rootNativeNode);
    } else if (tNode.type === 1
  /* Projection */
  ) {
      // Case 3: the TNode is a projection insertion point (i.e. a <ng-content>).
      // The nodes projected at this location all need to be processed.
      var _componentView = lView[DECLARATION_COMPONENT_VIEW];
      var componentHost = _componentView[T_HOST];
      var head = componentHost.projection[tNode.projection];

      if (Array.isArray(head)) {
        var _iterator6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_7__["default"])(head),
            _step6;

        try {
          for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
            var _nativeNode2 = _step6.value;

            _addQueryMatchR3(_nativeNode2, predicate, matches, elementsOnly, rootNativeNode);
          }
        } catch (err) {
          _iterator6.e(err);
        } finally {
          _iterator6.f();
        }
      } else if (head) {
        var nextLView = _componentView[PARENT];
        var nextTNode = nextLView[TVIEW].data[head.index];

        _queryNodeChildrenR3(nextTNode, nextLView, predicate, matches, elementsOnly, rootNativeNode);
      }
    } else if (tNode.child) {
    // Case 4: the TNode is a view.
    _queryNodeChildrenR3(tNode.child, lView, predicate, matches, elementsOnly, rootNativeNode);
  } // We don't want to go to the next sibling of the root node.


  if (rootNativeNode !== nativeNode) {
    // To determine the next node to be processed, we need to use the next or the projectionNext
    // link, depending on whether the current node has been projected.
    var _nextTNode = tNode.flags & 4
    /* isProjected */
    ? tNode.projectionNext : tNode.next;

    if (_nextTNode) {
      _queryNodeChildrenR3(_nextTNode, lView, predicate, matches, elementsOnly, rootNativeNode);
    }
  }
}
/**
 * Process all TNodes in a given container.
 *
 * @param lContainer the container to be processed
 * @param predicate the predicate to match
 * @param matches the list of positive matches
 * @param elementsOnly whether only elements should be searched
 * @param rootNativeNode the root native node on which predicate should not be matched
 */


function _queryNodeChildrenInContainerR3(lContainer, predicate, matches, elementsOnly, rootNativeNode) {
  for (var i = CONTAINER_HEADER_OFFSET; i < lContainer.length; i++) {
    var childView = lContainer[i];
    var firstChild = childView[TVIEW].firstChild;

    if (firstChild) {
      _queryNodeChildrenR3(firstChild, childView, predicate, matches, elementsOnly, rootNativeNode);
    }
  }
}
/**
 * Match the current native node against the predicate.
 *
 * @param nativeNode the current native node
 * @param predicate the predicate to match
 * @param matches the list of positive matches
 * @param elementsOnly whether only elements should be searched
 * @param rootNativeNode the root native node on which predicate should not be matched
 */


function _addQueryMatchR3(nativeNode, predicate, matches, elementsOnly, rootNativeNode) {
  if (rootNativeNode !== nativeNode) {
    var debugNode = getDebugNode$1(nativeNode);

    if (!debugNode) {
      return;
    } // Type of the "predicate and "matches" array are set based on the value of
    // the "elementsOnly" parameter. TypeScript is not able to properly infer these
    // types with generics, so we manually cast the parameters accordingly.


    if (elementsOnly && debugNode instanceof DebugElement__POST_R3__ && predicate(debugNode) && matches.indexOf(debugNode) === -1) {
      matches.push(debugNode);
    } else if (!elementsOnly && predicate(debugNode) && matches.indexOf(debugNode) === -1) {
      matches.push(debugNode);
    }
  }
}
/**
 * Match all the descendants of a DOM node against a predicate.
 *
 * @param nativeNode the current native node
 * @param predicate the predicate to match
 * @param matches the list where matches are stored
 * @param elementsOnly whether only elements should be searched
 */


function _queryNativeNodeDescendants(parentNode, predicate, matches, elementsOnly) {
  var nodes = parentNode.childNodes;
  var length = nodes.length;

  for (var i = 0; i < length; i++) {
    var node = nodes[i];
    var debugNode = getDebugNode$1(node);

    if (debugNode) {
      if (elementsOnly && debugNode instanceof DebugElement__POST_R3__ && predicate(debugNode) && matches.indexOf(debugNode) === -1) {
        matches.push(debugNode);
      } else if (!elementsOnly && predicate(debugNode) && matches.indexOf(debugNode) === -1) {
        matches.push(debugNode);
      }

      _queryNativeNodeDescendants(node, predicate, matches, elementsOnly);
    }
  }
}
/**
 * Iterates through the property bindings for a given node and generates
 * a map of property names to values. This map only contains property bindings
 * defined in templates, not in host bindings.
 */


function collectPropertyBindings(properties, tNode, lView, tData) {
  var bindingIndexes = tNode.propertyBindings;

  if (bindingIndexes !== null) {
    for (var i = 0; i < bindingIndexes.length; i++) {
      var bindingIndex = bindingIndexes[i];
      var propMetadata = tData[bindingIndex];
      var metadataParts = propMetadata.split(INTERPOLATION_DELIMITER);
      var propertyName = metadataParts[0];

      if (metadataParts.length > 1) {
        var value = metadataParts[1];

        for (var j = 1; j < metadataParts.length - 1; j++) {
          value += renderStringify(lView[bindingIndex + j - 1]) + metadataParts[j + 1];
        }

        properties[propertyName] = value;
      } else {
        properties[propertyName] = lView[bindingIndex];
      }
    }
  }
} // Need to keep the nodes in a global Map so that multiple angular apps are supported.


var _nativeNodeToDebugNode = new Map();

function getDebugNode__PRE_R3__(nativeNode) {
  return _nativeNodeToDebugNode.get(nativeNode) || null;
}

var NG_DEBUG_PROPERTY = '__ng_debug__';

function getDebugNode__POST_R3__(nativeNode) {
  if (nativeNode instanceof Node) {
    if (!nativeNode.hasOwnProperty(NG_DEBUG_PROPERTY)) {
      nativeNode[NG_DEBUG_PROPERTY] = nativeNode.nodeType == Node.ELEMENT_NODE ? new DebugElement__POST_R3__(nativeNode) : new DebugNode__POST_R3__(nativeNode);
    }

    return nativeNode[NG_DEBUG_PROPERTY];
  }

  return null;
}
/**
 * @publicApi
 */


var getDebugNode$1 = getDebugNode__POST_R3__;

function getDebugNodeR2__PRE_R3__(nativeNode) {
  return getDebugNode__PRE_R3__(nativeNode);
}

function getDebugNodeR2__POST_R3__(_nativeNode) {
  return null;
}

var getDebugNodeR2 = getDebugNodeR2__POST_R3__;

function getAllDebugNodes() {
  return Array.from(_nativeNodeToDebugNode.values());
}

function indexDebugNode(node) {
  _nativeNodeToDebugNode.set(node.nativeNode, node);
}

function removeDebugNodeFromIndex(node) {
  _nativeNodeToDebugNode.delete(node.nativeNode);
}
/**
 * @publicApi
 */


var DebugNode = DebugNode__POST_R3__;
/**
 * @publicApi
 */

var DebugElement = DebugElement__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var _CORE_PLATFORM_PROVIDERS = [// Set a default platform name for platforms that don't set it explicitly.
{
  provide: PLATFORM_ID,
  useValue: 'unknown'
}, {
  provide: PlatformRef,
  deps: [Injector]
}, {
  provide: TestabilityRegistry,
  deps: []
}, {
  provide: Console,
  deps: []
}];
/**
 * This platform has to be included in any other platform
 *
 * @publicApi
 */

var platformCore = createPlatformFactory(null, 'core', _CORE_PLATFORM_PROVIDERS);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function _iterableDiffersFactory() {
  return defaultIterableDiffers;
}

function _keyValueDiffersFactory() {
  return defaultKeyValueDiffers;
}

function _localeFactory(locale) {
  locale = locale || getGlobalLocale();

  if (ivyEnabled) {
    setLocaleId(locale);
  }

  return locale;
}
/**
 * Work out the locale from the potential global properties.
 *
 * * Closure Compiler: use `goog.LOCALE`.
 * * Ivy enabled: use `$localize.locale`
 */


function getGlobalLocale() {
  if (typeof ngI18nClosureMode !== 'undefined' && ngI18nClosureMode && typeof goog !== 'undefined' && goog.LOCALE !== 'en') {
    // * The default `goog.LOCALE` value is `en`, while Angular used `en-US`.
    // * In order to preserve backwards compatibility, we use Angular default value over
    //   Closure Compiler's one.
    return goog.LOCALE;
  } else {
    // KEEP `typeof $localize !== 'undefined' && $localize.locale` IN SYNC WITH THE LOCALIZE
    // COMPILE-TIME INLINER.
    //
    // * During compile time inlining of translations the expression will be replaced
    //   with a string literal that is the current locale. Other forms of this expression are not
    //   guaranteed to be replaced.
    //
    // * During runtime translation evaluation, the developer is required to set `$localize.locale`
    //   if required, or just to provide their own `LOCALE_ID` provider.
    return ivyEnabled && typeof $localize !== 'undefined' && $localize.locale || DEFAULT_LOCALE_ID;
  }
}

var ɵ0$g = USD_CURRENCY_CODE;
/**
 * A built-in [dependency injection token](guide/glossary#di-token)
 * that is used to configure the root injector for bootstrapping.
 */

var APPLICATION_MODULE_PROVIDERS = [{
  provide: ApplicationRef,
  useClass: ApplicationRef,
  deps: [NgZone, Console, Injector, ErrorHandler, ComponentFactoryResolver, ApplicationInitStatus]
}, {
  provide: SCHEDULER,
  deps: [NgZone],
  useFactory: zoneSchedulerFactory
}, {
  provide: ApplicationInitStatus,
  useClass: ApplicationInitStatus,
  deps: [[new Optional(), APP_INITIALIZER]]
}, {
  provide: Compiler,
  useClass: Compiler,
  deps: []
}, APP_ID_RANDOM_PROVIDER, {
  provide: IterableDiffers,
  useFactory: _iterableDiffersFactory,
  deps: []
}, {
  provide: KeyValueDiffers,
  useFactory: _keyValueDiffersFactory,
  deps: []
}, {
  provide: LOCALE_ID$1,
  useFactory: _localeFactory,
  deps: [[new Inject(LOCALE_ID$1), new Optional(), new SkipSelf()]]
}, {
  provide: DEFAULT_CURRENCY_CODE,
  useValue: ɵ0$g
}];
/**
 * Schedule work at next available slot.
 *
 * In Ivy this is just `requestAnimationFrame`. For compatibility reasons when bootstrapped
 * using `platformRef.bootstrap` we need to use `NgZone.onStable` as the scheduling mechanism.
 * This overrides the scheduling mechanism in Ivy to `NgZone.onStable`.
 *
 * @param ngZone NgZone to use for scheduling.
 */

function zoneSchedulerFactory(ngZone) {
  var queue = [];
  ngZone.onStable.subscribe(function () {
    while (queue.length) {
      queue.pop()();
    }
  });
  return function (fn) {
    queue.push(fn);
  };
}
/**
 * Configures the root injector for an app with
 * providers of `@angular/core` dependencies that `ApplicationRef` needs
 * to bootstrap components.
 *
 * Re-exported by `BrowserModule`, which is included automatically in the root
 * `AppModule` when you create a new app with the CLI `new` command.
 *
 * @publicApi
 */


var ApplicationModule = // Inject ApplicationRef to make it eager...
function ApplicationModule(appRef) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, ApplicationModule);
};

ApplicationModule.ɵmod = ɵɵdefineNgModule({
  type: ApplicationModule
});
ApplicationModule.ɵinj = ɵɵdefineInjector({
  factory: function ApplicationModule_Factory(t) {
    return new (t || ApplicationModule)(ɵɵinject(ApplicationRef));
  },
  providers: APPLICATION_MODULE_PROVIDERS
});

ApplicationModule.ctorParameters = function () {
  return [{
    type: ApplicationRef
  }];
};
/*@__PURE__*/


(function () {
  setClassMetadata(ApplicationModule, [{
    type: NgModule,
    args: [{
      providers: APPLICATION_MODULE_PROVIDERS
    }]
  }], function () {
    return [{
      type: ApplicationRef
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function anchorDef(flags, matchedQueriesDsl, ngContentIndex, childCount, handleEvent, templateFactory) {
  flags |= 1
  /* TypeElement */
  ;

  var _splitMatchedQueriesD2 = splitMatchedQueriesDsl(matchedQueriesDsl),
      matchedQueries = _splitMatchedQueriesD2.matchedQueries,
      references = _splitMatchedQueriesD2.references,
      matchedQueryIds = _splitMatchedQueriesD2.matchedQueryIds;

  var template = templateFactory ? resolveDefinition(templateFactory) : null;
  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    flags: flags,
    checkIndex: -1,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    matchedQueries: matchedQueries,
    matchedQueryIds: matchedQueryIds,
    references: references,
    ngContentIndex: ngContentIndex,
    childCount: childCount,
    bindings: [],
    bindingFlags: 0,
    outputs: [],
    element: {
      ns: null,
      name: null,
      attrs: null,
      template: template,
      componentProvider: null,
      componentView: null,
      componentRendererType: null,
      publicProviders: null,
      allProviders: null,
      handleEvent: handleEvent || NOOP
    },
    provider: null,
    text: null,
    query: null,
    ngContent: null
  };
}

function elementDef(checkIndex, flags, matchedQueriesDsl, ngContentIndex, childCount, namespaceAndName) {
  var fixedAttrs = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : [];
  var bindings = arguments.length > 7 ? arguments[7] : undefined;
  var outputs = arguments.length > 8 ? arguments[8] : undefined;
  var handleEvent = arguments.length > 9 ? arguments[9] : undefined;
  var componentView = arguments.length > 10 ? arguments[10] : undefined;
  var componentRendererType = arguments.length > 11 ? arguments[11] : undefined;

  if (!handleEvent) {
    handleEvent = NOOP;
  }

  var _splitMatchedQueriesD3 = splitMatchedQueriesDsl(matchedQueriesDsl),
      matchedQueries = _splitMatchedQueriesD3.matchedQueries,
      references = _splitMatchedQueriesD3.references,
      matchedQueryIds = _splitMatchedQueriesD3.matchedQueryIds;

  var ns = null;
  var name = null;

  if (namespaceAndName) {
    var _splitNamespace = splitNamespace(namespaceAndName);

    var _splitNamespace2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_splitNamespace, 2);

    ns = _splitNamespace2[0];
    name = _splitNamespace2[1];
  }

  bindings = bindings || [];
  var bindingDefs = [];

  for (var i = 0; i < bindings.length; i++) {
    var _bindings$i = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(bindings[i], 3),
        bindingFlags = _bindings$i[0],
        _namespaceAndName = _bindings$i[1],
        suffixOrSecurityContext = _bindings$i[2];

    var _splitNamespace3 = splitNamespace(_namespaceAndName),
        _splitNamespace4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_splitNamespace3, 2),
        _ns = _splitNamespace4[0],
        _name = _splitNamespace4[1];

    var securityContext = undefined;
    var suffix = undefined;

    switch (bindingFlags & 15
    /* Types */
    ) {
      case 4
      /* TypeElementStyle */
      :
        suffix = suffixOrSecurityContext;
        break;

      case 1
      /* TypeElementAttribute */
      :
      case 8
      /* TypeProperty */
      :
        securityContext = suffixOrSecurityContext;
        break;
    }

    bindingDefs[i] = {
      flags: bindingFlags,
      ns: _ns,
      name: _name,
      nonMinifiedName: _name,
      securityContext: securityContext,
      suffix: suffix
    };
  }

  outputs = outputs || [];
  var outputDefs = [];

  for (var _i11 = 0; _i11 < outputs.length; _i11++) {
    var _outputs$_i = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(outputs[_i11], 2),
        target = _outputs$_i[0],
        eventName = _outputs$_i[1];

    outputDefs[_i11] = {
      type: 0
      /* ElementOutput */
      ,
      target: target,
      eventName: eventName,
      propName: null
    };
  }

  fixedAttrs = fixedAttrs || [];
  var attrs = fixedAttrs.map(function (_ref4) {
    var _ref5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_ref4, 2),
        namespaceAndName = _ref5[0],
        value = _ref5[1];

    var _splitNamespace5 = splitNamespace(namespaceAndName),
        _splitNamespace6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(_splitNamespace5, 2),
        ns = _splitNamespace6[0],
        name = _splitNamespace6[1];

    return [ns, name, value];
  });
  componentRendererType = resolveRendererType2(componentRendererType);

  if (componentView) {
    flags |= 33554432
    /* ComponentView */
    ;
  }

  flags |= 1
  /* TypeElement */
  ;
  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    checkIndex: checkIndex,
    flags: flags,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    matchedQueries: matchedQueries,
    matchedQueryIds: matchedQueryIds,
    references: references,
    ngContentIndex: ngContentIndex,
    childCount: childCount,
    bindings: bindingDefs,
    bindingFlags: calcBindingFlags(bindingDefs),
    outputs: outputDefs,
    element: {
      ns: ns,
      name: name,
      attrs: attrs,
      template: null,
      // will bet set by the view definition
      componentProvider: null,
      componentView: componentView || null,
      componentRendererType: componentRendererType,
      publicProviders: null,
      allProviders: null,
      handleEvent: handleEvent || NOOP
    },
    provider: null,
    text: null,
    query: null,
    ngContent: null
  };
}

function createElement(view, renderHost, def) {
  var elDef = def.element;
  var rootSelectorOrNode = view.root.selectorOrNode;
  var renderer = view.renderer;
  var el;

  if (view.parent || !rootSelectorOrNode) {
    if (elDef.name) {
      el = renderer.createElement(elDef.name, elDef.ns);
    } else {
      el = renderer.createComment('');
    }

    var parentEl = getParentRenderElement(view, renderHost, def);

    if (parentEl) {
      renderer.appendChild(parentEl, el);
    }
  } else {
    // when using native Shadow DOM, do not clear the root element contents to allow slot projection
    var preserveContent = !!elDef.componentRendererType && elDef.componentRendererType.encapsulation === ViewEncapsulation$1.ShadowDom;
    el = renderer.selectRootElement(rootSelectorOrNode, preserveContent);
  }

  if (elDef.attrs) {
    for (var i = 0; i < elDef.attrs.length; i++) {
      var _elDef$attrs$i = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_3__["default"])(elDef.attrs[i], 3),
          ns = _elDef$attrs$i[0],
          name = _elDef$attrs$i[1],
          value = _elDef$attrs$i[2];

      renderer.setAttribute(el, name, value, ns);
    }
  }

  return el;
}

function listenToElementOutputs(view, compView, def, el) {
  for (var i = 0; i < def.outputs.length; i++) {
    var output = def.outputs[i];
    var handleEventClosure = renderEventHandlerClosure(view, def.nodeIndex, elementEventFullName(output.target, output.eventName));
    var listenTarget = output.target;
    var listenerView = view;

    if (output.target === 'component') {
      listenTarget = null;
      listenerView = compView;
    }

    var disposable = listenerView.renderer.listen(listenTarget || el, output.eventName, handleEventClosure);
    view.disposables[def.outputIndex + i] = disposable;
  }
}

function renderEventHandlerClosure(view, index, eventName) {
  return function (event) {
    return dispatchEvent(view, index, eventName, event);
  };
}

function checkAndUpdateElementInline(view, def, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var bindLen = def.bindings.length;
  var changed = false;
  if (bindLen > 0 && checkAndUpdateElementValue(view, def, 0, v0)) changed = true;
  if (bindLen > 1 && checkAndUpdateElementValue(view, def, 1, v1)) changed = true;
  if (bindLen > 2 && checkAndUpdateElementValue(view, def, 2, v2)) changed = true;
  if (bindLen > 3 && checkAndUpdateElementValue(view, def, 3, v3)) changed = true;
  if (bindLen > 4 && checkAndUpdateElementValue(view, def, 4, v4)) changed = true;
  if (bindLen > 5 && checkAndUpdateElementValue(view, def, 5, v5)) changed = true;
  if (bindLen > 6 && checkAndUpdateElementValue(view, def, 6, v6)) changed = true;
  if (bindLen > 7 && checkAndUpdateElementValue(view, def, 7, v7)) changed = true;
  if (bindLen > 8 && checkAndUpdateElementValue(view, def, 8, v8)) changed = true;
  if (bindLen > 9 && checkAndUpdateElementValue(view, def, 9, v9)) changed = true;
  return changed;
}

function checkAndUpdateElementDynamic(view, def, values) {
  var changed = false;

  for (var i = 0; i < values.length; i++) {
    if (checkAndUpdateElementValue(view, def, i, values[i])) changed = true;
  }

  return changed;
}

function checkAndUpdateElementValue(view, def, bindingIdx, value) {
  if (!checkAndUpdateBinding(view, def, bindingIdx, value)) {
    return false;
  }

  var binding = def.bindings[bindingIdx];
  var elData = asElementData(view, def.nodeIndex);
  var renderNode = elData.renderElement;
  var name = binding.name;

  switch (binding.flags & 15
  /* Types */
  ) {
    case 1
    /* TypeElementAttribute */
    :
      setElementAttribute(view, binding, renderNode, binding.ns, name, value);
      break;

    case 2
    /* TypeElementClass */
    :
      setElementClass(view, renderNode, name, value);
      break;

    case 4
    /* TypeElementStyle */
    :
      setElementStyle(view, binding, renderNode, name, value);
      break;

    case 8
    /* TypeProperty */
    :
      var bindView = def.flags & 33554432
      /* ComponentView */
      && binding.flags & 32
      /* SyntheticHostProperty */
      ? elData.componentView : view;
      setElementProperty(bindView, binding, renderNode, name, value);
      break;
  }

  return true;
}

function setElementAttribute(view, binding, renderNode, ns, name, value) {
  var securityContext = binding.securityContext;
  var renderValue = securityContext ? view.root.sanitizer.sanitize(securityContext, value) : value;
  renderValue = renderValue != null ? renderValue.toString() : null;
  var renderer = view.renderer;

  if (value != null) {
    renderer.setAttribute(renderNode, name, renderValue, ns);
  } else {
    renderer.removeAttribute(renderNode, name, ns);
  }
}

function setElementClass(view, renderNode, name, value) {
  var renderer = view.renderer;

  if (value) {
    renderer.addClass(renderNode, name);
  } else {
    renderer.removeClass(renderNode, name);
  }
}

function setElementStyle(view, binding, renderNode, name, value) {
  var renderValue = view.root.sanitizer.sanitize(SecurityContext.STYLE, value);

  if (renderValue != null) {
    renderValue = renderValue.toString();
    var unit = binding.suffix;

    if (unit != null) {
      renderValue = renderValue + unit;
    }
  } else {
    renderValue = null;
  }

  var renderer = view.renderer;

  if (renderValue != null) {
    renderer.setStyle(renderNode, name, renderValue);
  } else {
    renderer.removeStyle(renderNode, name);
  }
}

function setElementProperty(view, binding, renderNode, name, value) {
  var securityContext = binding.securityContext;
  var renderValue = securityContext ? view.root.sanitizer.sanitize(securityContext, value) : value;
  view.renderer.setProperty(renderNode, name, renderValue);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function queryDef(flags, id, bindings) {
  var bindingDefs = [];

  for (var propName in bindings) {
    var bindingType = bindings[propName];
    bindingDefs.push({
      propName: propName,
      bindingType: bindingType
    });
  }

  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    // TODO(vicb): check
    checkIndex: -1,
    flags: flags,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    ngContentIndex: -1,
    matchedQueries: {},
    matchedQueryIds: 0,
    references: {},
    childCount: 0,
    bindings: [],
    bindingFlags: 0,
    outputs: [],
    element: null,
    provider: null,
    text: null,
    query: {
      id: id,
      filterId: filterQueryId(id),
      bindings: bindingDefs
    },
    ngContent: null
  };
}

function createQuery() {
  return new QueryList();
}

function dirtyParentQueries(view) {
  var queryIds = view.def.nodeMatchedQueries;

  while (view.parent && isEmbeddedView(view)) {
    var tplDef = view.parentNodeDef;
    view = view.parent; // content queries

    var end = tplDef.nodeIndex + tplDef.childCount;

    for (var i = 0; i <= end; i++) {
      var nodeDef = view.def.nodes[i];

      if (nodeDef.flags & 67108864
      /* TypeContentQuery */
      && nodeDef.flags & 536870912
      /* DynamicQuery */
      && (nodeDef.query.filterId & queryIds) === nodeDef.query.filterId) {
        asQueryList(view, i).setDirty();
      }

      if (nodeDef.flags & 1
      /* TypeElement */
      && i + nodeDef.childCount < tplDef.nodeIndex || !(nodeDef.childFlags & 67108864
      /* TypeContentQuery */
      ) || !(nodeDef.childFlags & 536870912
      /* DynamicQuery */
      )) {
        // skip elements that don't contain the template element or no query.
        i += nodeDef.childCount;
      }
    }
  } // view queries


  if (view.def.nodeFlags & 134217728
  /* TypeViewQuery */
  ) {
      for (var _i12 = 0; _i12 < view.def.nodes.length; _i12++) {
        var _nodeDef = view.def.nodes[_i12];

        if (_nodeDef.flags & 134217728
        /* TypeViewQuery */
        && _nodeDef.flags & 536870912
        /* DynamicQuery */
        ) {
          asQueryList(view, _i12).setDirty();
        } // only visit the root nodes


        _i12 += _nodeDef.childCount;
      }
    }
}

function checkAndUpdateQuery(view, nodeDef) {
  var queryList = asQueryList(view, nodeDef.nodeIndex);

  if (!queryList.dirty) {
    return;
  }

  var directiveInstance;
  var newValues = undefined;

  if (nodeDef.flags & 67108864
  /* TypeContentQuery */
  ) {
      var _elementDef = nodeDef.parent.parent;
      newValues = calcQueryValues(view, _elementDef.nodeIndex, _elementDef.nodeIndex + _elementDef.childCount, nodeDef.query, []);
      directiveInstance = asProviderData(view, nodeDef.parent.nodeIndex).instance;
    } else if (nodeDef.flags & 134217728
  /* TypeViewQuery */
  ) {
      newValues = calcQueryValues(view, 0, view.def.nodes.length - 1, nodeDef.query, []);
      directiveInstance = view.component;
    }

  queryList.reset(newValues);
  var bindings = nodeDef.query.bindings;
  var notify = false;

  for (var i = 0; i < bindings.length; i++) {
    var binding = bindings[i];
    var boundValue = void 0;

    switch (binding.bindingType) {
      case 0
      /* First */
      :
        boundValue = queryList.first;
        break;

      case 1
      /* All */
      :
        boundValue = queryList;
        notify = true;
        break;
    }

    directiveInstance[binding.propName] = boundValue;
  }

  if (notify) {
    queryList.notifyOnChanges();
  }
}

function calcQueryValues(view, startIndex, endIndex, queryDef, values) {
  for (var i = startIndex; i <= endIndex; i++) {
    var nodeDef = view.def.nodes[i];
    var valueType = nodeDef.matchedQueries[queryDef.id];

    if (valueType != null) {
      values.push(getQueryValue(view, nodeDef, valueType));
    }

    if (nodeDef.flags & 1
    /* TypeElement */
    && nodeDef.element.template && (nodeDef.element.template.nodeMatchedQueries & queryDef.filterId) === queryDef.filterId) {
      var elementData = asElementData(view, i); // check embedded views that were attached at the place of their template,
      // but process child nodes first if some match the query (see issue #16568)

      if ((nodeDef.childMatchedQueries & queryDef.filterId) === queryDef.filterId) {
        calcQueryValues(view, i + 1, i + nodeDef.childCount, queryDef, values);
        i += nodeDef.childCount;
      }

      if (nodeDef.flags & 16777216
      /* EmbeddedViews */
      ) {
          var embeddedViews = elementData.viewContainer._embeddedViews;

          for (var k = 0; k < embeddedViews.length; k++) {
            var embeddedView = embeddedViews[k];
            var dvc = declaredViewContainer(embeddedView);

            if (dvc && dvc === elementData) {
              calcQueryValues(embeddedView, 0, embeddedView.def.nodes.length - 1, queryDef, values);
            }
          }
        }

      var projectedViews = elementData.template._projectedViews;

      if (projectedViews) {
        for (var _k = 0; _k < projectedViews.length; _k++) {
          var projectedView = projectedViews[_k];
          calcQueryValues(projectedView, 0, projectedView.def.nodes.length - 1, queryDef, values);
        }
      }
    }

    if ((nodeDef.childMatchedQueries & queryDef.filterId) !== queryDef.filterId) {
      // if no child matches the query, skip the children.
      i += nodeDef.childCount;
    }
  }

  return values;
}

function getQueryValue(view, nodeDef, queryValueType) {
  if (queryValueType != null) {
    // a match
    switch (queryValueType) {
      case 1
      /* RenderElement */
      :
        return asElementData(view, nodeDef.nodeIndex).renderElement;

      case 0
      /* ElementRef */
      :
        return new ElementRef(asElementData(view, nodeDef.nodeIndex).renderElement);

      case 2
      /* TemplateRef */
      :
        return asElementData(view, nodeDef.nodeIndex).template;

      case 3
      /* ViewContainerRef */
      :
        return asElementData(view, nodeDef.nodeIndex).viewContainer;

      case 4
      /* Provider */
      :
        return asProviderData(view, nodeDef.nodeIndex).instance;
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function ngContentDef(ngContentIndex, index) {
  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    checkIndex: -1,
    flags: 8
    /* TypeNgContent */
    ,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    matchedQueries: {},
    matchedQueryIds: 0,
    references: {},
    ngContentIndex: ngContentIndex,
    childCount: 0,
    bindings: [],
    bindingFlags: 0,
    outputs: [],
    element: null,
    provider: null,
    text: null,
    query: null,
    ngContent: {
      index: index
    }
  };
}

function appendNgContent(view, renderHost, def) {
  var parentEl = getParentRenderElement(view, renderHost, def);

  if (!parentEl) {
    // Nothing to do if there is no parent element.
    return;
  }

  var ngContentIndex = def.ngContent.index;
  visitProjectedRenderNodes(view, ngContentIndex, 1
  /* AppendChild */
  , parentEl, null, undefined);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function purePipeDef(checkIndex, argCount) {
  // argCount + 1 to include the pipe as first arg
  return _pureExpressionDef(128
  /* TypePurePipe */
  , checkIndex, newArray(argCount + 1));
}

function pureArrayDef(checkIndex, argCount) {
  return _pureExpressionDef(32
  /* TypePureArray */
  , checkIndex, newArray(argCount));
}

function pureObjectDef(checkIndex, propToIndex) {
  var keys = Object.keys(propToIndex);
  var nbKeys = keys.length;
  var propertyNames = [];

  for (var i = 0; i < nbKeys; i++) {
    var key = keys[i];
    var index = propToIndex[key];
    propertyNames.push(key);
  }

  return _pureExpressionDef(64
  /* TypePureObject */
  , checkIndex, propertyNames);
}

function _pureExpressionDef(flags, checkIndex, propertyNames) {
  var bindings = [];

  for (var i = 0; i < propertyNames.length; i++) {
    var prop = propertyNames[i];
    bindings.push({
      flags: 8
      /* TypeProperty */
      ,
      name: prop,
      ns: null,
      nonMinifiedName: prop,
      securityContext: null,
      suffix: null
    });
  }

  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    checkIndex: checkIndex,
    flags: flags,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    matchedQueries: {},
    matchedQueryIds: 0,
    references: {},
    ngContentIndex: -1,
    childCount: 0,
    bindings: bindings,
    bindingFlags: calcBindingFlags(bindings),
    outputs: [],
    element: null,
    provider: null,
    text: null,
    query: null,
    ngContent: null
  };
}

function createPureExpression(view, def) {
  return {
    value: undefined
  };
}

function checkAndUpdatePureExpressionInline(view, def, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var bindings = def.bindings;
  var changed = false;
  var bindLen = bindings.length;
  if (bindLen > 0 && checkAndUpdateBinding(view, def, 0, v0)) changed = true;
  if (bindLen > 1 && checkAndUpdateBinding(view, def, 1, v1)) changed = true;
  if (bindLen > 2 && checkAndUpdateBinding(view, def, 2, v2)) changed = true;
  if (bindLen > 3 && checkAndUpdateBinding(view, def, 3, v3)) changed = true;
  if (bindLen > 4 && checkAndUpdateBinding(view, def, 4, v4)) changed = true;
  if (bindLen > 5 && checkAndUpdateBinding(view, def, 5, v5)) changed = true;
  if (bindLen > 6 && checkAndUpdateBinding(view, def, 6, v6)) changed = true;
  if (bindLen > 7 && checkAndUpdateBinding(view, def, 7, v7)) changed = true;
  if (bindLen > 8 && checkAndUpdateBinding(view, def, 8, v8)) changed = true;
  if (bindLen > 9 && checkAndUpdateBinding(view, def, 9, v9)) changed = true;

  if (changed) {
    var data = asPureExpressionData(view, def.nodeIndex);
    var value;

    switch (def.flags & 201347067
    /* Types */
    ) {
      case 32
      /* TypePureArray */
      :
        value = [];
        if (bindLen > 0) value.push(v0);
        if (bindLen > 1) value.push(v1);
        if (bindLen > 2) value.push(v2);
        if (bindLen > 3) value.push(v3);
        if (bindLen > 4) value.push(v4);
        if (bindLen > 5) value.push(v5);
        if (bindLen > 6) value.push(v6);
        if (bindLen > 7) value.push(v7);
        if (bindLen > 8) value.push(v8);
        if (bindLen > 9) value.push(v9);
        break;

      case 64
      /* TypePureObject */
      :
        value = {};
        if (bindLen > 0) value[bindings[0].name] = v0;
        if (bindLen > 1) value[bindings[1].name] = v1;
        if (bindLen > 2) value[bindings[2].name] = v2;
        if (bindLen > 3) value[bindings[3].name] = v3;
        if (bindLen > 4) value[bindings[4].name] = v4;
        if (bindLen > 5) value[bindings[5].name] = v5;
        if (bindLen > 6) value[bindings[6].name] = v6;
        if (bindLen > 7) value[bindings[7].name] = v7;
        if (bindLen > 8) value[bindings[8].name] = v8;
        if (bindLen > 9) value[bindings[9].name] = v9;
        break;

      case 128
      /* TypePurePipe */
      :
        var pipe = v0;

        switch (bindLen) {
          case 1:
            value = pipe.transform(v0);
            break;

          case 2:
            value = pipe.transform(v1);
            break;

          case 3:
            value = pipe.transform(v1, v2);
            break;

          case 4:
            value = pipe.transform(v1, v2, v3);
            break;

          case 5:
            value = pipe.transform(v1, v2, v3, v4);
            break;

          case 6:
            value = pipe.transform(v1, v2, v3, v4, v5);
            break;

          case 7:
            value = pipe.transform(v1, v2, v3, v4, v5, v6);
            break;

          case 8:
            value = pipe.transform(v1, v2, v3, v4, v5, v6, v7);
            break;

          case 9:
            value = pipe.transform(v1, v2, v3, v4, v5, v6, v7, v8);
            break;

          case 10:
            value = pipe.transform(v1, v2, v3, v4, v5, v6, v7, v8, v9);
            break;
        }

        break;
    }

    data.value = value;
  }

  return changed;
}

function checkAndUpdatePureExpressionDynamic(view, def, values) {
  var bindings = def.bindings;
  var changed = false;

  for (var i = 0; i < values.length; i++) {
    // Note: We need to loop over all values, so that
    // the old values are updates as well!
    if (checkAndUpdateBinding(view, def, i, values[i])) {
      changed = true;
    }
  }

  if (changed) {
    var data = asPureExpressionData(view, def.nodeIndex);
    var value;

    switch (def.flags & 201347067
    /* Types */
    ) {
      case 32
      /* TypePureArray */
      :
        value = values;
        break;

      case 64
      /* TypePureObject */
      :
        value = {};

        for (var _i13 = 0; _i13 < values.length; _i13++) {
          value[bindings[_i13].name] = values[_i13];
        }

        break;

      case 128
      /* TypePurePipe */
      :
        var pipe = values[0];
        var params = values.slice(1);
        value = pipe.transform.apply(pipe, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(params));
        break;
    }

    data.value = value;
  }

  return changed;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function textDef(checkIndex, ngContentIndex, staticText) {
  var bindings = [];

  for (var i = 1; i < staticText.length; i++) {
    bindings[i - 1] = {
      flags: 8
      /* TypeProperty */
      ,
      name: null,
      ns: null,
      nonMinifiedName: null,
      securityContext: null,
      suffix: staticText[i]
    };
  }

  return {
    // will bet set by the view definition
    nodeIndex: -1,
    parent: null,
    renderParent: null,
    bindingIndex: -1,
    outputIndex: -1,
    // regular values
    checkIndex: checkIndex,
    flags: 2
    /* TypeText */
    ,
    childFlags: 0,
    directChildFlags: 0,
    childMatchedQueries: 0,
    matchedQueries: {},
    matchedQueryIds: 0,
    references: {},
    ngContentIndex: ngContentIndex,
    childCount: 0,
    bindings: bindings,
    bindingFlags: 8
    /* TypeProperty */
    ,
    outputs: [],
    element: null,
    provider: null,
    text: {
      prefix: staticText[0]
    },
    query: null,
    ngContent: null
  };
}

function createText(view, renderHost, def) {
  var renderNode;
  var renderer = view.renderer;
  renderNode = renderer.createText(def.text.prefix);
  var parentEl = getParentRenderElement(view, renderHost, def);

  if (parentEl) {
    renderer.appendChild(parentEl, renderNode);
  }

  return {
    renderText: renderNode
  };
}

function checkAndUpdateTextInline(view, def, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var changed = false;
  var bindings = def.bindings;
  var bindLen = bindings.length;
  if (bindLen > 0 && checkAndUpdateBinding(view, def, 0, v0)) changed = true;
  if (bindLen > 1 && checkAndUpdateBinding(view, def, 1, v1)) changed = true;
  if (bindLen > 2 && checkAndUpdateBinding(view, def, 2, v2)) changed = true;
  if (bindLen > 3 && checkAndUpdateBinding(view, def, 3, v3)) changed = true;
  if (bindLen > 4 && checkAndUpdateBinding(view, def, 4, v4)) changed = true;
  if (bindLen > 5 && checkAndUpdateBinding(view, def, 5, v5)) changed = true;
  if (bindLen > 6 && checkAndUpdateBinding(view, def, 6, v6)) changed = true;
  if (bindLen > 7 && checkAndUpdateBinding(view, def, 7, v7)) changed = true;
  if (bindLen > 8 && checkAndUpdateBinding(view, def, 8, v8)) changed = true;
  if (bindLen > 9 && checkAndUpdateBinding(view, def, 9, v9)) changed = true;

  if (changed) {
    var value = def.text.prefix;
    if (bindLen > 0) value += _addInterpolationPart(v0, bindings[0]);
    if (bindLen > 1) value += _addInterpolationPart(v1, bindings[1]);
    if (bindLen > 2) value += _addInterpolationPart(v2, bindings[2]);
    if (bindLen > 3) value += _addInterpolationPart(v3, bindings[3]);
    if (bindLen > 4) value += _addInterpolationPart(v4, bindings[4]);
    if (bindLen > 5) value += _addInterpolationPart(v5, bindings[5]);
    if (bindLen > 6) value += _addInterpolationPart(v6, bindings[6]);
    if (bindLen > 7) value += _addInterpolationPart(v7, bindings[7]);
    if (bindLen > 8) value += _addInterpolationPart(v8, bindings[8]);
    if (bindLen > 9) value += _addInterpolationPart(v9, bindings[9]);
    var _renderNode = asTextData(view, def.nodeIndex).renderText;
    view.renderer.setValue(_renderNode, value);
  }

  return changed;
}

function checkAndUpdateTextDynamic(view, def, values) {
  var bindings = def.bindings;
  var changed = false;

  for (var i = 0; i < values.length; i++) {
    // Note: We need to loop over all values, so that
    // the old values are updates as well!
    if (checkAndUpdateBinding(view, def, i, values[i])) {
      changed = true;
    }
  }

  if (changed) {
    var value = '';

    for (var _i14 = 0; _i14 < values.length; _i14++) {
      value = value + _addInterpolationPart(values[_i14], bindings[_i14]);
    }

    value = def.text.prefix + value;
    var _renderNode2 = asTextData(view, def.nodeIndex).renderText;
    view.renderer.setValue(_renderNode2, value);
  }

  return changed;
}

function _addInterpolationPart(value, binding) {
  var valueStr = value != null ? value.toString() : '';
  return valueStr + binding.suffix;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function viewDef(flags, nodes, updateDirectives, updateRenderer) {
  // clone nodes and set auto calculated values
  var viewBindingCount = 0;
  var viewDisposableCount = 0;
  var viewNodeFlags = 0;
  var viewRootNodeFlags = 0;
  var viewMatchedQueries = 0;
  var currentParent = null;
  var currentRenderParent = null;
  var currentElementHasPublicProviders = false;
  var currentElementHasPrivateProviders = false;
  var lastRenderRootNode = null;

  for (var i = 0; i < nodes.length; i++) {
    var node = nodes[i];
    node.nodeIndex = i;
    node.parent = currentParent;
    node.bindingIndex = viewBindingCount;
    node.outputIndex = viewDisposableCount;
    node.renderParent = currentRenderParent;
    viewNodeFlags |= node.flags;
    viewMatchedQueries |= node.matchedQueryIds;

    if (node.element) {
      var elDef = node.element;
      elDef.publicProviders = currentParent ? currentParent.element.publicProviders : Object.create(null);
      elDef.allProviders = elDef.publicProviders; // Note: We assume that all providers of an element are before any child element!

      currentElementHasPublicProviders = false;
      currentElementHasPrivateProviders = false;

      if (node.element.template) {
        viewMatchedQueries |= node.element.template.nodeMatchedQueries;
      }
    }

    validateNode(currentParent, node, nodes.length);
    viewBindingCount += node.bindings.length;
    viewDisposableCount += node.outputs.length;

    if (!currentRenderParent && node.flags & 3
    /* CatRenderNode */
    ) {
      lastRenderRootNode = node;
    }

    if (node.flags & 20224
    /* CatProvider */
    ) {
        if (!currentElementHasPublicProviders) {
          currentElementHasPublicProviders = true; // Use prototypical inheritance to not get O(n^2) complexity...

          currentParent.element.publicProviders = Object.create(currentParent.element.publicProviders);
          currentParent.element.allProviders = currentParent.element.publicProviders;
        }

        var isPrivateService = (node.flags & 8192
        /* PrivateProvider */
        ) !== 0;
        var isComponent = (node.flags & 32768
        /* Component */
        ) !== 0;

        if (!isPrivateService || isComponent) {
          currentParent.element.publicProviders[tokenKey(node.provider.token)] = node;
        } else {
          if (!currentElementHasPrivateProviders) {
            currentElementHasPrivateProviders = true; // Use prototypical inheritance to not get O(n^2) complexity...

            currentParent.element.allProviders = Object.create(currentParent.element.publicProviders);
          }

          currentParent.element.allProviders[tokenKey(node.provider.token)] = node;
        }

        if (isComponent) {
          currentParent.element.componentProvider = node;
        }
      }

    if (currentParent) {
      currentParent.childFlags |= node.flags;
      currentParent.directChildFlags |= node.flags;
      currentParent.childMatchedQueries |= node.matchedQueryIds;

      if (node.element && node.element.template) {
        currentParent.childMatchedQueries |= node.element.template.nodeMatchedQueries;
      }
    } else {
      viewRootNodeFlags |= node.flags;
    }

    if (node.childCount > 0) {
      currentParent = node;

      if (!isNgContainer(node)) {
        currentRenderParent = node;
      }
    } else {
      // When the current node has no children, check if it is the last children of its parent.
      // When it is, propagate the flags up.
      // The loop is required because an element could be the last transitive children of several
      // elements. We loop to either the root or the highest opened element (= with remaining
      // children)
      while (currentParent && i === currentParent.nodeIndex + currentParent.childCount) {
        var newParent = currentParent.parent;

        if (newParent) {
          newParent.childFlags |= currentParent.childFlags;
          newParent.childMatchedQueries |= currentParent.childMatchedQueries;
        }

        currentParent = newParent; // We also need to update the render parent & account for ng-container

        if (currentParent && isNgContainer(currentParent)) {
          currentRenderParent = currentParent.renderParent;
        } else {
          currentRenderParent = currentParent;
        }
      }
    }
  }

  var handleEvent = function handleEvent(view, nodeIndex, eventName, event) {
    return nodes[nodeIndex].element.handleEvent(view, eventName, event);
  };

  return {
    // Will be filled later...
    factory: null,
    nodeFlags: viewNodeFlags,
    rootNodeFlags: viewRootNodeFlags,
    nodeMatchedQueries: viewMatchedQueries,
    flags: flags,
    nodes: nodes,
    updateDirectives: updateDirectives || NOOP,
    updateRenderer: updateRenderer || NOOP,
    handleEvent: handleEvent,
    bindingCount: viewBindingCount,
    outputCount: viewDisposableCount,
    lastRenderRootNode: lastRenderRootNode
  };
}

function isNgContainer(node) {
  return (node.flags & 1
  /* TypeElement */
  ) !== 0 && node.element.name === null;
}

function validateNode(parent, node, nodeCount) {
  var template = node.element && node.element.template;

  if (template) {
    if (!template.lastRenderRootNode) {
      throw new Error("Illegal State: Embedded templates without nodes are not allowed!");
    }

    if (template.lastRenderRootNode && template.lastRenderRootNode.flags & 16777216
    /* EmbeddedViews */
    ) {
        throw new Error("Illegal State: Last root node of a template can't have embedded views, at index ".concat(node.nodeIndex, "!"));
      }
  }

  if (node.flags & 20224
  /* CatProvider */
  ) {
      var parentFlags = parent ? parent.flags : 0;

      if ((parentFlags & 1
      /* TypeElement */
      ) === 0) {
        throw new Error("Illegal State: StaticProvider/Directive nodes need to be children of elements or anchors, at index ".concat(node.nodeIndex, "!"));
      }
    }

  if (node.query) {
    if (node.flags & 67108864
    /* TypeContentQuery */
    && (!parent || (parent.flags & 16384
    /* TypeDirective */
    ) === 0)) {
      throw new Error("Illegal State: Content Query nodes need to be children of directives, at index ".concat(node.nodeIndex, "!"));
    }

    if (node.flags & 134217728
    /* TypeViewQuery */
    && parent) {
      throw new Error("Illegal State: View Query nodes have to be top level nodes, at index ".concat(node.nodeIndex, "!"));
    }
  }

  if (node.childCount) {
    var parentEnd = parent ? parent.nodeIndex + parent.childCount : nodeCount - 1;

    if (node.nodeIndex <= parentEnd && node.nodeIndex + node.childCount > parentEnd) {
      throw new Error("Illegal State: childCount of node leads outside of parent, at index ".concat(node.nodeIndex, "!"));
    }
  }
}

function createEmbeddedView(parent, anchorDef, viewDef, context) {
  // embedded views are seen as siblings to the anchor, so we need
  // to get the parent of the anchor and use it as parentIndex.
  var view = createView(parent.root, parent.renderer, parent, anchorDef, viewDef);
  initView(view, parent.component, context);
  createViewNodes(view);
  return view;
}

function createRootView(root, def, context) {
  var view = createView(root, root.renderer, null, null, def);
  initView(view, context, context);
  createViewNodes(view);
  return view;
}

function createComponentView(parentView, nodeDef, viewDef, hostElement) {
  var rendererType = nodeDef.element.componentRendererType;
  var compRenderer;

  if (!rendererType) {
    compRenderer = parentView.root.renderer;
  } else {
    compRenderer = parentView.root.rendererFactory.createRenderer(hostElement, rendererType);
  }

  return createView(parentView.root, compRenderer, parentView, nodeDef.element.componentProvider, viewDef);
}

function createView(root, renderer, parent, parentNodeDef, def) {
  var nodes = new Array(def.nodes.length);
  var disposables = def.outputCount ? new Array(def.outputCount) : null;
  var view = {
    def: def,
    parent: parent,
    viewContainerParent: null,
    parentNodeDef: parentNodeDef,
    context: null,
    component: null,
    nodes: nodes,
    state: 13
    /* CatInit */
    ,
    root: root,
    renderer: renderer,
    oldValues: new Array(def.bindingCount),
    disposables: disposables,
    initIndex: -1
  };
  return view;
}

function initView(view, component, context) {
  view.component = component;
  view.context = context;
}

function createViewNodes(view) {
  var renderHost;

  if (isComponentView(view)) {
    var hostDef = view.parentNodeDef;
    renderHost = asElementData(view.parent, hostDef.parent.nodeIndex).renderElement;
  }

  var def = view.def;
  var nodes = view.nodes;

  for (var i = 0; i < def.nodes.length; i++) {
    var nodeDef = def.nodes[i];
    Services.setCurrentNode(view, i);
    var nodeData = void 0;

    switch (nodeDef.flags & 201347067
    /* Types */
    ) {
      case 1
      /* TypeElement */
      :
        var el = createElement(view, renderHost, nodeDef);
        var componentView = undefined;

        if (nodeDef.flags & 33554432
        /* ComponentView */
        ) {
            var compViewDef = resolveDefinition(nodeDef.element.componentView);
            componentView = Services.createComponentView(view, nodeDef, compViewDef, el);
          }

        listenToElementOutputs(view, componentView, nodeDef, el);
        nodeData = {
          renderElement: el,
          componentView: componentView,
          viewContainer: null,
          template: nodeDef.element.template ? createTemplateData(view, nodeDef) : undefined
        };

        if (nodeDef.flags & 16777216
        /* EmbeddedViews */
        ) {
            nodeData.viewContainer = createViewContainerData(view, nodeDef, nodeData);
          }

        break;

      case 2
      /* TypeText */
      :
        nodeData = createText(view, renderHost, nodeDef);
        break;

      case 512
      /* TypeClassProvider */
      :
      case 1024
      /* TypeFactoryProvider */
      :
      case 2048
      /* TypeUseExistingProvider */
      :
      case 256
      /* TypeValueProvider */
      :
        {
          nodeData = nodes[i];

          if (!nodeData && !(nodeDef.flags & 4096
          /* LazyProvider */
          )) {
            var instance = createProviderInstance(view, nodeDef);
            nodeData = {
              instance: instance
            };
          }

          break;
        }

      case 16
      /* TypePipe */
      :
        {
          var _instance = createPipeInstance(view, nodeDef);

          nodeData = {
            instance: _instance
          };
          break;
        }

      case 16384
      /* TypeDirective */
      :
        {
          nodeData = nodes[i];

          if (!nodeData) {
            var _instance2 = createDirectiveInstance(view, nodeDef);

            nodeData = {
              instance: _instance2
            };
          }

          if (nodeDef.flags & 32768
          /* Component */
          ) {
              var compView = asElementData(view, nodeDef.parent.nodeIndex).componentView;
              initView(compView, nodeData.instance, nodeData.instance);
            }

          break;
        }

      case 32
      /* TypePureArray */
      :
      case 64
      /* TypePureObject */
      :
      case 128
      /* TypePurePipe */
      :
        nodeData = createPureExpression(view, nodeDef);
        break;

      case 67108864
      /* TypeContentQuery */
      :
      case 134217728
      /* TypeViewQuery */
      :
        nodeData = createQuery();
        break;

      case 8
      /* TypeNgContent */
      :
        appendNgContent(view, renderHost, nodeDef); // no runtime data needed for NgContent...

        nodeData = undefined;
        break;
    }

    nodes[i] = nodeData;
  } // Create the ViewData.nodes of component views after we created everything else,
  // so that e.g. ng-content works


  execComponentViewsAction(view, ViewAction.CreateViewNodes); // fill static content and view queries

  execQueriesAction(view, 67108864
  /* TypeContentQuery */
  | 134217728
  /* TypeViewQuery */
  , 268435456
  /* StaticQuery */
  , 0
  /* CheckAndUpdate */
  );
}

function checkNoChangesView(view) {
  markProjectedViewsForCheck(view);
  Services.updateDirectives(view, 1
  /* CheckNoChanges */
  );
  execEmbeddedViewsAction(view, ViewAction.CheckNoChanges);
  Services.updateRenderer(view, 1
  /* CheckNoChanges */
  );
  execComponentViewsAction(view, ViewAction.CheckNoChanges); // Note: We don't check queries for changes as we didn't do this in v2.x.
  // TODO(tbosch): investigate if we can enable the check again in v5.x with a nicer error message.

  view.state &= ~(64
  /* CheckProjectedViews */
  | 32
  /* CheckProjectedView */
  );
}

function checkAndUpdateView(view) {
  if (view.state & 1
  /* BeforeFirstCheck */
  ) {
      view.state &= ~1
      /* BeforeFirstCheck */
      ;
      view.state |= 2
      /* FirstCheck */
      ;
    } else {
    view.state &= ~2
    /* FirstCheck */
    ;
  }

  shiftInitState(view, 0
  /* InitState_BeforeInit */
  , 256
  /* InitState_CallingOnInit */
  );
  markProjectedViewsForCheck(view);
  Services.updateDirectives(view, 0
  /* CheckAndUpdate */
  );
  execEmbeddedViewsAction(view, ViewAction.CheckAndUpdate);
  execQueriesAction(view, 67108864
  /* TypeContentQuery */
  , 536870912
  /* DynamicQuery */
  , 0
  /* CheckAndUpdate */
  );
  var callInit = shiftInitState(view, 256
  /* InitState_CallingOnInit */
  , 512
  /* InitState_CallingAfterContentInit */
  );
  callLifecycleHooksChildrenFirst(view, 2097152
  /* AfterContentChecked */
  | (callInit ? 1048576
  /* AfterContentInit */
  : 0));
  Services.updateRenderer(view, 0
  /* CheckAndUpdate */
  );
  execComponentViewsAction(view, ViewAction.CheckAndUpdate);
  execQueriesAction(view, 134217728
  /* TypeViewQuery */
  , 536870912
  /* DynamicQuery */
  , 0
  /* CheckAndUpdate */
  );
  callInit = shiftInitState(view, 512
  /* InitState_CallingAfterContentInit */
  , 768
  /* InitState_CallingAfterViewInit */
  );
  callLifecycleHooksChildrenFirst(view, 8388608
  /* AfterViewChecked */
  | (callInit ? 4194304
  /* AfterViewInit */
  : 0));

  if (view.def.flags & 2
  /* OnPush */
  ) {
      view.state &= ~8
      /* ChecksEnabled */
      ;
    }

  view.state &= ~(64
  /* CheckProjectedViews */
  | 32
  /* CheckProjectedView */
  );
  shiftInitState(view, 768
  /* InitState_CallingAfterViewInit */
  , 1024
  /* InitState_AfterInit */
  );
}

function checkAndUpdateNode(view, nodeDef, argStyle, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  if (argStyle === 0
  /* Inline */
  ) {
      return checkAndUpdateNodeInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);
    } else {
    return checkAndUpdateNodeDynamic(view, nodeDef, v0);
  }
}

function markProjectedViewsForCheck(view) {
  var def = view.def;

  if (!(def.nodeFlags & 4
  /* ProjectedTemplate */
  )) {
    return;
  }

  for (var i = 0; i < def.nodes.length; i++) {
    var nodeDef = def.nodes[i];

    if (nodeDef.flags & 4
    /* ProjectedTemplate */
    ) {
        var projectedViews = asElementData(view, i).template._projectedViews;

        if (projectedViews) {
          for (var _i15 = 0; _i15 < projectedViews.length; _i15++) {
            var projectedView = projectedViews[_i15];
            projectedView.state |= 32
            /* CheckProjectedView */
            ;
            markParentViewsForCheckProjectedViews(projectedView, view);
          }
        }
      } else if ((nodeDef.childFlags & 4
    /* ProjectedTemplate */
    ) === 0) {
      // a parent with leafs
      // no child is a component,
      // then skip the children
      i += nodeDef.childCount;
    }
  }
}

function checkAndUpdateNodeInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  switch (nodeDef.flags & 201347067
  /* Types */
  ) {
    case 1
    /* TypeElement */
    :
      return checkAndUpdateElementInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);

    case 2
    /* TypeText */
    :
      return checkAndUpdateTextInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);

    case 16384
    /* TypeDirective */
    :
      return checkAndUpdateDirectiveInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);

    case 32
    /* TypePureArray */
    :
    case 64
    /* TypePureObject */
    :
    case 128
    /* TypePurePipe */
    :
      return checkAndUpdatePureExpressionInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);

    default:
      throw 'unreachable';
  }
}

function checkAndUpdateNodeDynamic(view, nodeDef, values) {
  switch (nodeDef.flags & 201347067
  /* Types */
  ) {
    case 1
    /* TypeElement */
    :
      return checkAndUpdateElementDynamic(view, nodeDef, values);

    case 2
    /* TypeText */
    :
      return checkAndUpdateTextDynamic(view, nodeDef, values);

    case 16384
    /* TypeDirective */
    :
      return checkAndUpdateDirectiveDynamic(view, nodeDef, values);

    case 32
    /* TypePureArray */
    :
    case 64
    /* TypePureObject */
    :
    case 128
    /* TypePurePipe */
    :
      return checkAndUpdatePureExpressionDynamic(view, nodeDef, values);

    default:
      throw 'unreachable';
  }
}

function checkNoChangesNode(view, nodeDef, argStyle, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  if (argStyle === 0
  /* Inline */
  ) {
      checkNoChangesNodeInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);
    } else {
    checkNoChangesNodeDynamic(view, nodeDef, v0);
  } // Returning false is ok here as we would have thrown in case of a change.


  return false;
}

function checkNoChangesNodeInline(view, nodeDef, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var bindLen = nodeDef.bindings.length;
  if (bindLen > 0) checkBindingNoChanges(view, nodeDef, 0, v0);
  if (bindLen > 1) checkBindingNoChanges(view, nodeDef, 1, v1);
  if (bindLen > 2) checkBindingNoChanges(view, nodeDef, 2, v2);
  if (bindLen > 3) checkBindingNoChanges(view, nodeDef, 3, v3);
  if (bindLen > 4) checkBindingNoChanges(view, nodeDef, 4, v4);
  if (bindLen > 5) checkBindingNoChanges(view, nodeDef, 5, v5);
  if (bindLen > 6) checkBindingNoChanges(view, nodeDef, 6, v6);
  if (bindLen > 7) checkBindingNoChanges(view, nodeDef, 7, v7);
  if (bindLen > 8) checkBindingNoChanges(view, nodeDef, 8, v8);
  if (bindLen > 9) checkBindingNoChanges(view, nodeDef, 9, v9);
}

function checkNoChangesNodeDynamic(view, nodeDef, values) {
  for (var i = 0; i < values.length; i++) {
    checkBindingNoChanges(view, nodeDef, i, values[i]);
  }
}
/**
 * Workaround https://github.com/angular/tsickle/issues/497
 * @suppress {misplacedTypeAnnotation}
 */


function checkNoChangesQuery(view, nodeDef) {
  var queryList = asQueryList(view, nodeDef.nodeIndex);

  if (queryList.dirty) {
    throw expressionChangedAfterItHasBeenCheckedError(Services.createDebugContext(view, nodeDef.nodeIndex), "Query ".concat(nodeDef.query.id, " not dirty"), "Query ".concat(nodeDef.query.id, " dirty"), (view.state & 1
    /* BeforeFirstCheck */
    ) !== 0);
  }
}

function destroyView(view) {
  if (view.state & 128
  /* Destroyed */
  ) {
      return;
    }

  execEmbeddedViewsAction(view, ViewAction.Destroy);
  execComponentViewsAction(view, ViewAction.Destroy);
  callLifecycleHooksChildrenFirst(view, 131072
  /* OnDestroy */
  );

  if (view.disposables) {
    for (var i = 0; i < view.disposables.length; i++) {
      view.disposables[i]();
    }
  }

  detachProjectedView(view);

  if (view.renderer.destroyNode) {
    destroyViewNodes(view);
  }

  if (isComponentView(view)) {
    view.renderer.destroy();
  }

  view.state |= 128
  /* Destroyed */
  ;
}

function destroyViewNodes(view) {
  var len = view.def.nodes.length;

  for (var i = 0; i < len; i++) {
    var def = view.def.nodes[i];

    if (def.flags & 1
    /* TypeElement */
    ) {
        view.renderer.destroyNode(asElementData(view, i).renderElement);
      } else if (def.flags & 2
    /* TypeText */
    ) {
        view.renderer.destroyNode(asTextData(view, i).renderText);
      } else if (def.flags & 67108864
    /* TypeContentQuery */
    || def.flags & 134217728
    /* TypeViewQuery */
    ) {
        asQueryList(view, i).destroy();
      }
  }
}

var ViewAction;

(function (ViewAction) {
  ViewAction[ViewAction["CreateViewNodes"] = 0] = "CreateViewNodes";
  ViewAction[ViewAction["CheckNoChanges"] = 1] = "CheckNoChanges";
  ViewAction[ViewAction["CheckNoChangesProjectedViews"] = 2] = "CheckNoChangesProjectedViews";
  ViewAction[ViewAction["CheckAndUpdate"] = 3] = "CheckAndUpdate";
  ViewAction[ViewAction["CheckAndUpdateProjectedViews"] = 4] = "CheckAndUpdateProjectedViews";
  ViewAction[ViewAction["Destroy"] = 5] = "Destroy";
})(ViewAction || (ViewAction = {}));

function execComponentViewsAction(view, action) {
  var def = view.def;

  if (!(def.nodeFlags & 33554432
  /* ComponentView */
  )) {
    return;
  }

  for (var i = 0; i < def.nodes.length; i++) {
    var nodeDef = def.nodes[i];

    if (nodeDef.flags & 33554432
    /* ComponentView */
    ) {
        // a leaf
        callViewAction(asElementData(view, i).componentView, action);
      } else if ((nodeDef.childFlags & 33554432
    /* ComponentView */
    ) === 0) {
      // a parent with leafs
      // no child is a component,
      // then skip the children
      i += nodeDef.childCount;
    }
  }
}

function execEmbeddedViewsAction(view, action) {
  var def = view.def;

  if (!(def.nodeFlags & 16777216
  /* EmbeddedViews */
  )) {
    return;
  }

  for (var i = 0; i < def.nodes.length; i++) {
    var nodeDef = def.nodes[i];

    if (nodeDef.flags & 16777216
    /* EmbeddedViews */
    ) {
        // a leaf
        var embeddedViews = asElementData(view, i).viewContainer._embeddedViews;

        for (var k = 0; k < embeddedViews.length; k++) {
          callViewAction(embeddedViews[k], action);
        }
      } else if ((nodeDef.childFlags & 16777216
    /* EmbeddedViews */
    ) === 0) {
      // a parent with leafs
      // no child is a component,
      // then skip the children
      i += nodeDef.childCount;
    }
  }
}

function callViewAction(view, action) {
  var viewState = view.state;

  switch (action) {
    case ViewAction.CheckNoChanges:
      if ((viewState & 128
      /* Destroyed */
      ) === 0) {
        if ((viewState & 12
        /* CatDetectChanges */
        ) === 12
        /* CatDetectChanges */
        ) {
            checkNoChangesView(view);
          } else if (viewState & 64
        /* CheckProjectedViews */
        ) {
            execProjectedViewsAction(view, ViewAction.CheckNoChangesProjectedViews);
          }
      }

      break;

    case ViewAction.CheckNoChangesProjectedViews:
      if ((viewState & 128
      /* Destroyed */
      ) === 0) {
        if (viewState & 32
        /* CheckProjectedView */
        ) {
            checkNoChangesView(view);
          } else if (viewState & 64
        /* CheckProjectedViews */
        ) {
            execProjectedViewsAction(view, action);
          }
      }

      break;

    case ViewAction.CheckAndUpdate:
      if ((viewState & 128
      /* Destroyed */
      ) === 0) {
        if ((viewState & 12
        /* CatDetectChanges */
        ) === 12
        /* CatDetectChanges */
        ) {
            checkAndUpdateView(view);
          } else if (viewState & 64
        /* CheckProjectedViews */
        ) {
            execProjectedViewsAction(view, ViewAction.CheckAndUpdateProjectedViews);
          }
      }

      break;

    case ViewAction.CheckAndUpdateProjectedViews:
      if ((viewState & 128
      /* Destroyed */
      ) === 0) {
        if (viewState & 32
        /* CheckProjectedView */
        ) {
            checkAndUpdateView(view);
          } else if (viewState & 64
        /* CheckProjectedViews */
        ) {
            execProjectedViewsAction(view, action);
          }
      }

      break;

    case ViewAction.Destroy:
      // Note: destroyView recurses over all views,
      // so we don't need to special case projected views here.
      destroyView(view);
      break;

    case ViewAction.CreateViewNodes:
      createViewNodes(view);
      break;
  }
}

function execProjectedViewsAction(view, action) {
  execEmbeddedViewsAction(view, action);
  execComponentViewsAction(view, action);
}

function execQueriesAction(view, queryFlags, staticDynamicQueryFlag, checkType) {
  if (!(view.def.nodeFlags & queryFlags) || !(view.def.nodeFlags & staticDynamicQueryFlag)) {
    return;
  }

  var nodeCount = view.def.nodes.length;

  for (var i = 0; i < nodeCount; i++) {
    var nodeDef = view.def.nodes[i];

    if (nodeDef.flags & queryFlags && nodeDef.flags & staticDynamicQueryFlag) {
      Services.setCurrentNode(view, nodeDef.nodeIndex);

      switch (checkType) {
        case 0
        /* CheckAndUpdate */
        :
          checkAndUpdateQuery(view, nodeDef);
          break;

        case 1
        /* CheckNoChanges */
        :
          checkNoChangesQuery(view, nodeDef);
          break;
      }
    }

    if (!(nodeDef.childFlags & queryFlags) || !(nodeDef.childFlags & staticDynamicQueryFlag)) {
      // no child has a matching query
      // then skip the children
      i += nodeDef.childCount;
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var initialized = false;

function initServicesIfNeeded() {
  if (initialized) {
    return;
  }

  initialized = true;
  var services = isDevMode() ? createDebugServices() : createProdServices();
  Services.setCurrentNode = services.setCurrentNode;
  Services.createRootView = services.createRootView;
  Services.createEmbeddedView = services.createEmbeddedView;
  Services.createComponentView = services.createComponentView;
  Services.createNgModuleRef = services.createNgModuleRef;
  Services.overrideProvider = services.overrideProvider;
  Services.overrideComponentView = services.overrideComponentView;
  Services.clearOverrides = services.clearOverrides;
  Services.checkAndUpdateView = services.checkAndUpdateView;
  Services.checkNoChangesView = services.checkNoChangesView;
  Services.destroyView = services.destroyView;
  Services.resolveDep = resolveDep;
  Services.createDebugContext = services.createDebugContext;
  Services.handleEvent = services.handleEvent;
  Services.updateDirectives = services.updateDirectives;
  Services.updateRenderer = services.updateRenderer;
  Services.dirtyParentQueries = dirtyParentQueries;
}

function createProdServices() {
  return {
    setCurrentNode: function setCurrentNode() {},
    createRootView: createProdRootView,
    createEmbeddedView: createEmbeddedView,
    createComponentView: createComponentView,
    createNgModuleRef: createNgModuleRef,
    overrideProvider: NOOP,
    overrideComponentView: NOOP,
    clearOverrides: NOOP,
    checkAndUpdateView: checkAndUpdateView,
    checkNoChangesView: checkNoChangesView,
    destroyView: destroyView,
    createDebugContext: function createDebugContext(view, nodeIndex) {
      return new DebugContext_(view, nodeIndex);
    },
    handleEvent: function handleEvent(view, nodeIndex, eventName, event) {
      return view.def.handleEvent(view, nodeIndex, eventName, event);
    },
    updateDirectives: function updateDirectives(view, checkType) {
      return view.def.updateDirectives(checkType === 0
      /* CheckAndUpdate */
      ? prodCheckAndUpdateNode : prodCheckNoChangesNode, view);
    },
    updateRenderer: function updateRenderer(view, checkType) {
      return view.def.updateRenderer(checkType === 0
      /* CheckAndUpdate */
      ? prodCheckAndUpdateNode : prodCheckNoChangesNode, view);
    }
  };
}

function createDebugServices() {
  return {
    setCurrentNode: debugSetCurrentNode,
    createRootView: debugCreateRootView,
    createEmbeddedView: debugCreateEmbeddedView,
    createComponentView: debugCreateComponentView,
    createNgModuleRef: debugCreateNgModuleRef,
    overrideProvider: debugOverrideProvider,
    overrideComponentView: debugOverrideComponentView,
    clearOverrides: debugClearOverrides,
    checkAndUpdateView: debugCheckAndUpdateView,
    checkNoChangesView: debugCheckNoChangesView,
    destroyView: debugDestroyView,
    createDebugContext: function createDebugContext(view, nodeIndex) {
      return new DebugContext_(view, nodeIndex);
    },
    handleEvent: debugHandleEvent,
    updateDirectives: debugUpdateDirectives,
    updateRenderer: debugUpdateRenderer
  };
}

function createProdRootView(elInjector, projectableNodes, rootSelectorOrNode, def, ngModule, context) {
  var rendererFactory = ngModule.injector.get(RendererFactory2);
  return createRootView(createRootData(elInjector, ngModule, rendererFactory, projectableNodes, rootSelectorOrNode), def, context);
}

function debugCreateRootView(elInjector, projectableNodes, rootSelectorOrNode, def, ngModule, context) {
  var rendererFactory = ngModule.injector.get(RendererFactory2);
  var root = createRootData(elInjector, ngModule, new DebugRendererFactory2(rendererFactory), projectableNodes, rootSelectorOrNode);
  var defWithOverride = applyProviderOverridesToView(def);
  return callWithDebugContext(DebugAction.create, createRootView, null, [root, defWithOverride, context]);
}

function createRootData(elInjector, ngModule, rendererFactory, projectableNodes, rootSelectorOrNode) {
  var sanitizer = ngModule.injector.get(Sanitizer);
  var errorHandler = ngModule.injector.get(ErrorHandler);
  var renderer = rendererFactory.createRenderer(null, null);
  return {
    ngModule: ngModule,
    injector: elInjector,
    projectableNodes: projectableNodes,
    selectorOrNode: rootSelectorOrNode,
    sanitizer: sanitizer,
    rendererFactory: rendererFactory,
    renderer: renderer,
    errorHandler: errorHandler
  };
}

function debugCreateEmbeddedView(parentView, anchorDef, viewDef, context) {
  var defWithOverride = applyProviderOverridesToView(viewDef);
  return callWithDebugContext(DebugAction.create, createEmbeddedView, null, [parentView, anchorDef, defWithOverride, context]);
}

function debugCreateComponentView(parentView, nodeDef, viewDef, hostElement) {
  var overrideComponentView = viewDefOverrides.get(nodeDef.element.componentProvider.provider.token);

  if (overrideComponentView) {
    viewDef = overrideComponentView;
  } else {
    viewDef = applyProviderOverridesToView(viewDef);
  }

  return callWithDebugContext(DebugAction.create, createComponentView, null, [parentView, nodeDef, viewDef, hostElement]);
}

function debugCreateNgModuleRef(moduleType, parentInjector, bootstrapComponents, def) {
  var defWithOverride = applyProviderOverridesToNgModule(def);
  return createNgModuleRef(moduleType, parentInjector, bootstrapComponents, defWithOverride);
}

var providerOverrides = new Map();
var providerOverridesWithScope = new Map();
var viewDefOverrides = new Map();

function debugOverrideProvider(override) {
  providerOverrides.set(override.token, override);
  var injectableDef;

  if (typeof override.token === 'function' && (injectableDef = getInjectableDef(override.token)) && typeof injectableDef.providedIn === 'function') {
    providerOverridesWithScope.set(override.token, override);
  }
}

function debugOverrideComponentView(comp, compFactory) {
  var hostViewDef = resolveDefinition(getComponentViewDefinitionFactory(compFactory));
  var compViewDef = resolveDefinition(hostViewDef.nodes[0].element.componentView);
  viewDefOverrides.set(comp, compViewDef);
}

function debugClearOverrides() {
  providerOverrides.clear();
  providerOverridesWithScope.clear();
  viewDefOverrides.clear();
} // Notes about the algorithm:
// 1) Locate the providers of an element and check if one of them was overwritten
// 2) Change the providers of that element
//
// We only create new datastructures if we need to, to keep perf impact
// reasonable.


function applyProviderOverridesToView(def) {
  if (providerOverrides.size === 0) {
    return def;
  }

  var elementIndicesWithOverwrittenProviders = findElementIndicesWithOverwrittenProviders(def);

  if (elementIndicesWithOverwrittenProviders.length === 0) {
    return def;
  } // clone the whole view definition,
  // as it maintains references between the nodes that are hard to update.


  def = def.factory(function () {
    return NOOP;
  });

  for (var i = 0; i < elementIndicesWithOverwrittenProviders.length; i++) {
    applyProviderOverridesToElement(def, elementIndicesWithOverwrittenProviders[i]);
  }

  return def;

  function findElementIndicesWithOverwrittenProviders(def) {
    var elIndicesWithOverwrittenProviders = [];
    var lastElementDef = null;

    for (var _i16 = 0; _i16 < def.nodes.length; _i16++) {
      var nodeDef = def.nodes[_i16];

      if (nodeDef.flags & 1
      /* TypeElement */
      ) {
          lastElementDef = nodeDef;
        }

      if (lastElementDef && nodeDef.flags & 3840
      /* CatProviderNoDirective */
      && providerOverrides.has(nodeDef.provider.token)) {
        elIndicesWithOverwrittenProviders.push(lastElementDef.nodeIndex);
        lastElementDef = null;
      }
    }

    return elIndicesWithOverwrittenProviders;
  }

  function applyProviderOverridesToElement(viewDef, elIndex) {
    for (var _i17 = elIndex + 1; _i17 < viewDef.nodes.length; _i17++) {
      var nodeDef = viewDef.nodes[_i17];

      if (nodeDef.flags & 1
      /* TypeElement */
      ) {
          // stop at the next element
          return;
        }

      if (nodeDef.flags & 3840
      /* CatProviderNoDirective */
      ) {
          var provider = nodeDef.provider;
          var override = providerOverrides.get(provider.token);

          if (override) {
            nodeDef.flags = nodeDef.flags & ~3840
            /* CatProviderNoDirective */
            | override.flags;
            provider.deps = splitDepsDsl(override.deps);
            provider.value = override.value;
          }
        }
    }
  }
} // Notes about the algorithm:
// We only create new datastructures if we need to, to keep perf impact
// reasonable.


function applyProviderOverridesToNgModule(def) {
  var _calcHasOverrides = calcHasOverrides(def),
      hasOverrides = _calcHasOverrides.hasOverrides,
      hasDeprecatedOverrides = _calcHasOverrides.hasDeprecatedOverrides;

  if (!hasOverrides) {
    return def;
  } // clone the whole view definition,
  // as it maintains references between the nodes that are hard to update.


  def = def.factory(function () {
    return NOOP;
  });
  applyProviderOverrides(def);
  return def;

  function calcHasOverrides(def) {
    var hasOverrides = false;
    var hasDeprecatedOverrides = false;

    if (providerOverrides.size === 0) {
      return {
        hasOverrides: hasOverrides,
        hasDeprecatedOverrides: hasDeprecatedOverrides
      };
    }

    def.providers.forEach(function (node) {
      var override = providerOverrides.get(node.token);

      if (node.flags & 3840
      /* CatProviderNoDirective */
      && override) {
        hasOverrides = true;
        hasDeprecatedOverrides = hasDeprecatedOverrides || override.deprecatedBehavior;
      }
    });
    def.modules.forEach(function (module) {
      providerOverridesWithScope.forEach(function (override, token) {
        if (getInjectableDef(token).providedIn === module) {
          hasOverrides = true;
          hasDeprecatedOverrides = hasDeprecatedOverrides || override.deprecatedBehavior;
        }
      });
    });
    return {
      hasOverrides: hasOverrides,
      hasDeprecatedOverrides: hasDeprecatedOverrides
    };
  }

  function applyProviderOverrides(def) {
    for (var i = 0; i < def.providers.length; i++) {
      var provider = def.providers[i];

      if (hasDeprecatedOverrides) {
        // We had a bug where me made
        // all providers lazy. Keep this logic behind a flag
        // for migrating existing users.
        provider.flags |= 4096
        /* LazyProvider */
        ;
      }

      var override = providerOverrides.get(provider.token);

      if (override) {
        provider.flags = provider.flags & ~3840
        /* CatProviderNoDirective */
        | override.flags;
        provider.deps = splitDepsDsl(override.deps);
        provider.value = override.value;
      }
    }

    if (providerOverridesWithScope.size > 0) {
      var moduleSet = new Set(def.modules);
      providerOverridesWithScope.forEach(function (override, token) {
        if (moduleSet.has(getInjectableDef(token).providedIn)) {
          var _provider = {
            token: token,
            flags: override.flags | (hasDeprecatedOverrides ? 4096
            /* LazyProvider */
            : 0
            /* None */
            ),
            deps: splitDepsDsl(override.deps),
            value: override.value,
            index: def.providers.length
          };
          def.providers.push(_provider);
          def.providersByKey[tokenKey(token)] = _provider;
        }
      });
    }
  }
}

function prodCheckAndUpdateNode(view, checkIndex, argStyle, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var nodeDef = view.def.nodes[checkIndex];
  checkAndUpdateNode(view, nodeDef, argStyle, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);
  return nodeDef.flags & 224
  /* CatPureExpression */
  ? asPureExpressionData(view, checkIndex).value : undefined;
}

function prodCheckNoChangesNode(view, checkIndex, argStyle, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9) {
  var nodeDef = view.def.nodes[checkIndex];
  checkNoChangesNode(view, nodeDef, argStyle, v0, v1, v2, v3, v4, v5, v6, v7, v8, v9);
  return nodeDef.flags & 224
  /* CatPureExpression */
  ? asPureExpressionData(view, checkIndex).value : undefined;
}

function debugCheckAndUpdateView(view) {
  return callWithDebugContext(DebugAction.detectChanges, checkAndUpdateView, null, [view]);
}

function debugCheckNoChangesView(view) {
  return callWithDebugContext(DebugAction.checkNoChanges, checkNoChangesView, null, [view]);
}

function debugDestroyView(view) {
  return callWithDebugContext(DebugAction.destroy, destroyView, null, [view]);
}

var DebugAction;

(function (DebugAction) {
  DebugAction[DebugAction["create"] = 0] = "create";
  DebugAction[DebugAction["detectChanges"] = 1] = "detectChanges";
  DebugAction[DebugAction["checkNoChanges"] = 2] = "checkNoChanges";
  DebugAction[DebugAction["destroy"] = 3] = "destroy";
  DebugAction[DebugAction["handleEvent"] = 4] = "handleEvent";
})(DebugAction || (DebugAction = {}));

var _currentAction;

var _currentView;

var _currentNodeIndex;

function debugSetCurrentNode(view, nodeIndex) {
  _currentView = view;
  _currentNodeIndex = nodeIndex;
}

function debugHandleEvent(view, nodeIndex, eventName, event) {
  debugSetCurrentNode(view, nodeIndex);
  return callWithDebugContext(DebugAction.handleEvent, view.def.handleEvent, null, [view, nodeIndex, eventName, event]);
}

function debugUpdateDirectives(view, checkType) {
  if (view.state & 128
  /* Destroyed */
  ) {
      throw viewDestroyedError(DebugAction[_currentAction]);
    }

  debugSetCurrentNode(view, nextDirectiveWithBinding(view, 0));
  return view.def.updateDirectives(debugCheckDirectivesFn, view);

  function debugCheckDirectivesFn(view, nodeIndex, argStyle) {
    var nodeDef = view.def.nodes[nodeIndex];

    for (var _len9 = arguments.length, values = new Array(_len9 > 3 ? _len9 - 3 : 0), _key9 = 3; _key9 < _len9; _key9++) {
      values[_key9 - 3] = arguments[_key9];
    }

    if (checkType === 0
    /* CheckAndUpdate */
    ) {
        debugCheckAndUpdateNode(view, nodeDef, argStyle, values);
      } else {
      debugCheckNoChangesNode(view, nodeDef, argStyle, values);
    }

    if (nodeDef.flags & 16384
    /* TypeDirective */
    ) {
        debugSetCurrentNode(view, nextDirectiveWithBinding(view, nodeIndex));
      }

    return nodeDef.flags & 224
    /* CatPureExpression */
    ? asPureExpressionData(view, nodeDef.nodeIndex).value : undefined;
  }
}

function debugUpdateRenderer(view, checkType) {
  if (view.state & 128
  /* Destroyed */
  ) {
      throw viewDestroyedError(DebugAction[_currentAction]);
    }

  debugSetCurrentNode(view, nextRenderNodeWithBinding(view, 0));
  return view.def.updateRenderer(debugCheckRenderNodeFn, view);

  function debugCheckRenderNodeFn(view, nodeIndex, argStyle) {
    var nodeDef = view.def.nodes[nodeIndex];

    for (var _len10 = arguments.length, values = new Array(_len10 > 3 ? _len10 - 3 : 0), _key10 = 3; _key10 < _len10; _key10++) {
      values[_key10 - 3] = arguments[_key10];
    }

    if (checkType === 0
    /* CheckAndUpdate */
    ) {
        debugCheckAndUpdateNode(view, nodeDef, argStyle, values);
      } else {
      debugCheckNoChangesNode(view, nodeDef, argStyle, values);
    }

    if (nodeDef.flags & 3
    /* CatRenderNode */
    ) {
        debugSetCurrentNode(view, nextRenderNodeWithBinding(view, nodeIndex));
      }

    return nodeDef.flags & 224
    /* CatPureExpression */
    ? asPureExpressionData(view, nodeDef.nodeIndex).value : undefined;
  }
}

function debugCheckAndUpdateNode(view, nodeDef, argStyle, givenValues) {
  var changed = checkAndUpdateNode.apply(void 0, [view, nodeDef, argStyle].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(givenValues)));

  if (changed) {
    var values = argStyle === 1
    /* Dynamic */
    ? givenValues[0] : givenValues;

    if (nodeDef.flags & 16384
    /* TypeDirective */
    ) {
        var bindingValues = {};

        for (var i = 0; i < nodeDef.bindings.length; i++) {
          var binding = nodeDef.bindings[i];
          var value = values[i];

          if (binding.flags & 8
          /* TypeProperty */
          ) {
              bindingValues[normalizeDebugBindingName(binding.nonMinifiedName)] = normalizeDebugBindingValue(value);
            }
        }

        var elDef = nodeDef.parent;
        var el = asElementData(view, elDef.nodeIndex).renderElement;

        if (!elDef.element.name) {
          // a comment.
          view.renderer.setValue(el, "bindings=".concat(JSON.stringify(bindingValues, null, 2)));
        } else {
          // a regular element.
          for (var attr in bindingValues) {
            var _value3 = bindingValues[attr];

            if (_value3 != null) {
              view.renderer.setAttribute(el, attr, _value3);
            } else {
              view.renderer.removeAttribute(el, attr);
            }
          }
        }
      }
  }
}

function debugCheckNoChangesNode(view, nodeDef, argStyle, values) {
  checkNoChangesNode.apply(void 0, [view, nodeDef, argStyle].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_4__["default"])(values)));
}

function nextDirectiveWithBinding(view, nodeIndex) {
  for (var i = nodeIndex; i < view.def.nodes.length; i++) {
    var nodeDef = view.def.nodes[i];

    if (nodeDef.flags & 16384
    /* TypeDirective */
    && nodeDef.bindings && nodeDef.bindings.length) {
      return i;
    }
  }

  return null;
}

function nextRenderNodeWithBinding(view, nodeIndex) {
  for (var i = nodeIndex; i < view.def.nodes.length; i++) {
    var nodeDef = view.def.nodes[i];

    if (nodeDef.flags & 3
    /* CatRenderNode */
    && nodeDef.bindings && nodeDef.bindings.length) {
      return i;
    }
  }

  return null;
}

var DebugContext_ = /*#__PURE__*/function () {
  function DebugContext_(view, nodeIndex) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugContext_);

    this.view = view;
    this.nodeIndex = nodeIndex;

    if (nodeIndex == null) {
      this.nodeIndex = nodeIndex = 0;
    }

    this.nodeDef = view.def.nodes[nodeIndex];
    var elDef = this.nodeDef;
    var elView = view;

    while (elDef && (elDef.flags & 1
    /* TypeElement */
    ) === 0) {
      elDef = elDef.parent;
    }

    if (!elDef) {
      while (!elDef && elView) {
        elDef = viewParentEl(elView);
        elView = elView.parent;
      }
    }

    this.elDef = elDef;
    this.elView = elView;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugContext_, [{
    key: "logError",
    value: function logError(console) {
      for (var _len11 = arguments.length, values = new Array(_len11 > 1 ? _len11 - 1 : 0), _key11 = 1; _key11 < _len11; _key11++) {
        values[_key11 - 1] = arguments[_key11];
      }

      var logViewDef;
      var logNodeIndex;

      if (this.nodeDef.flags & 2
      /* TypeText */
      ) {
          logViewDef = this.view.def;
          logNodeIndex = this.nodeDef.nodeIndex;
        } else {
        logViewDef = this.elView.def;
        logNodeIndex = this.elDef.nodeIndex;
      } // Note: we only generate a log function for text and element nodes
      // to make the generated code as small as possible.


      var renderNodeIndex = getRenderNodeIndex(logViewDef, logNodeIndex);
      var currRenderNodeIndex = -1;

      var nodeLogger = function nodeLogger() {
        currRenderNodeIndex++;

        if (currRenderNodeIndex === renderNodeIndex) {
          var _console$error;

          return (_console$error = console.error).bind.apply(_console$error, [console].concat(values));
        } else {
          return NOOP;
        }
      };

      logViewDef.factory(nodeLogger);

      if (currRenderNodeIndex < renderNodeIndex) {
        console.error('Illegal state: the ViewDefinitionFactory did not call the logger!');
        console.error.apply(console, values);
      }
    }
  }, {
    key: "elOrCompView",
    get: function get() {
      // Has to be done lazily as we use the DebugContext also during creation of elements...
      return asElementData(this.elView, this.elDef.nodeIndex).componentView || this.view;
    }
  }, {
    key: "injector",
    get: function get() {
      return createInjector$1(this.elView, this.elDef);
    }
  }, {
    key: "component",
    get: function get() {
      return this.elOrCompView.component;
    }
  }, {
    key: "context",
    get: function get() {
      return this.elOrCompView.context;
    }
  }, {
    key: "providerTokens",
    get: function get() {
      var tokens = [];

      if (this.elDef) {
        for (var i = this.elDef.nodeIndex + 1; i <= this.elDef.nodeIndex + this.elDef.childCount; i++) {
          var childDef = this.elView.def.nodes[i];

          if (childDef.flags & 20224
          /* CatProvider */
          ) {
              tokens.push(childDef.provider.token);
            }

          i += childDef.childCount;
        }
      }

      return tokens;
    }
  }, {
    key: "references",
    get: function get() {
      var references = {};

      if (this.elDef) {
        collectReferences(this.elView, this.elDef, references);

        for (var i = this.elDef.nodeIndex + 1; i <= this.elDef.nodeIndex + this.elDef.childCount; i++) {
          var childDef = this.elView.def.nodes[i];

          if (childDef.flags & 20224
          /* CatProvider */
          ) {
              collectReferences(this.elView, childDef, references);
            }

          i += childDef.childCount;
        }
      }

      return references;
    }
  }, {
    key: "componentRenderElement",
    get: function get() {
      var elData = findHostElement(this.elOrCompView);
      return elData ? elData.renderElement : undefined;
    }
  }, {
    key: "renderNode",
    get: function get() {
      return this.nodeDef.flags & 2
      /* TypeText */
      ? renderNode(this.view, this.nodeDef) : renderNode(this.elView, this.elDef);
    }
  }]);

  return DebugContext_;
}();

function getRenderNodeIndex(viewDef, nodeIndex) {
  var renderNodeIndex = -1;

  for (var i = 0; i <= nodeIndex; i++) {
    var nodeDef = viewDef.nodes[i];

    if (nodeDef.flags & 3
    /* CatRenderNode */
    ) {
        renderNodeIndex++;
      }
  }

  return renderNodeIndex;
}

function findHostElement(view) {
  while (view && !isComponentView(view)) {
    view = view.parent;
  }

  if (view.parent) {
    return asElementData(view.parent, viewParentEl(view).nodeIndex);
  }

  return null;
}

function collectReferences(view, nodeDef, references) {
  for (var refName in nodeDef.references) {
    references[refName] = getQueryValue(view, nodeDef, nodeDef.references[refName]);
  }
}

function callWithDebugContext(action, fn, self, args) {
  var oldAction = _currentAction;
  var oldView = _currentView;
  var oldNodeIndex = _currentNodeIndex;

  try {
    _currentAction = action;
    var result = fn.apply(self, args);
    _currentView = oldView;
    _currentNodeIndex = oldNodeIndex;
    _currentAction = oldAction;
    return result;
  } catch (e) {
    if (isViewDebugError(e) || !_currentView) {
      throw e;
    }

    throw viewWrappedDebugError(e, getCurrentDebugContext());
  }
}

function getCurrentDebugContext() {
  return _currentView ? new DebugContext_(_currentView, _currentNodeIndex) : null;
}

var DebugRendererFactory2 = /*#__PURE__*/function () {
  function DebugRendererFactory2(delegate) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugRendererFactory2);

    this.delegate = delegate;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugRendererFactory2, [{
    key: "createRenderer",
    value: function createRenderer(element, renderData) {
      return new DebugRenderer2(this.delegate.createRenderer(element, renderData));
    }
  }, {
    key: "begin",
    value: function begin() {
      if (this.delegate.begin) {
        this.delegate.begin();
      }
    }
  }, {
    key: "end",
    value: function end() {
      if (this.delegate.end) {
        this.delegate.end();
      }
    }
  }, {
    key: "whenRenderingDone",
    value: function whenRenderingDone() {
      if (this.delegate.whenRenderingDone) {
        return this.delegate.whenRenderingDone();
      }

      return Promise.resolve(null);
    }
  }]);

  return DebugRendererFactory2;
}();

var DebugRenderer2 = /*#__PURE__*/function () {
  function DebugRenderer2(delegate) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, DebugRenderer2);

    this.delegate = delegate;
    /**
     * Factory function used to create a `DebugContext` when a node is created.
     *
     * The `DebugContext` allows to retrieve information about the nodes that are useful in tests.
     *
     * The factory is configurable so that the `DebugRenderer2` could instantiate either a View Engine
     * or a Render context.
     */

    this.debugContextFactory = getCurrentDebugContext;
    this.data = this.delegate.data;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(DebugRenderer2, [{
    key: "createDebugContext",
    value: function createDebugContext(nativeElement) {
      return this.debugContextFactory(nativeElement);
    }
  }, {
    key: "destroyNode",
    value: function destroyNode(node) {
      var debugNode = getDebugNode$1(node);
      removeDebugNodeFromIndex(debugNode);

      if (debugNode instanceof DebugNode__PRE_R3__) {
        debugNode.listeners.length = 0;
      }

      if (this.delegate.destroyNode) {
        this.delegate.destroyNode(node);
      }
    }
  }, {
    key: "destroy",
    value: function destroy() {
      this.delegate.destroy();
    }
  }, {
    key: "createElement",
    value: function createElement(name, namespace) {
      var el = this.delegate.createElement(name, namespace);
      var debugCtx = this.createDebugContext(el);

      if (debugCtx) {
        var debugEl = new DebugElement__PRE_R3__(el, null, debugCtx);
        debugEl.name = name;
        indexDebugNode(debugEl);
      }

      return el;
    }
  }, {
    key: "createComment",
    value: function createComment(value) {
      var comment = this.delegate.createComment(value);
      var debugCtx = this.createDebugContext(comment);

      if (debugCtx) {
        indexDebugNode(new DebugNode__PRE_R3__(comment, null, debugCtx));
      }

      return comment;
    }
  }, {
    key: "createText",
    value: function createText(value) {
      var text = this.delegate.createText(value);
      var debugCtx = this.createDebugContext(text);

      if (debugCtx) {
        indexDebugNode(new DebugNode__PRE_R3__(text, null, debugCtx));
      }

      return text;
    }
  }, {
    key: "appendChild",
    value: function appendChild(parent, newChild) {
      var debugEl = getDebugNode$1(parent);
      var debugChildEl = getDebugNode$1(newChild);

      if (debugEl && debugChildEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.addChild(debugChildEl);
      }

      this.delegate.appendChild(parent, newChild);
    }
  }, {
    key: "insertBefore",
    value: function insertBefore(parent, newChild, refChild) {
      var debugEl = getDebugNode$1(parent);
      var debugChildEl = getDebugNode$1(newChild);
      var debugRefEl = getDebugNode$1(refChild);

      if (debugEl && debugChildEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.insertBefore(debugRefEl, debugChildEl);
      }

      this.delegate.insertBefore(parent, newChild, refChild);
    }
  }, {
    key: "removeChild",
    value: function removeChild(parent, oldChild) {
      var debugEl = getDebugNode$1(parent);
      var debugChildEl = getDebugNode$1(oldChild);

      if (debugEl && debugChildEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.removeChild(debugChildEl);
      }

      this.delegate.removeChild(parent, oldChild);
    }
  }, {
    key: "selectRootElement",
    value: function selectRootElement(selectorOrNode, preserveContent) {
      var el = this.delegate.selectRootElement(selectorOrNode, preserveContent);
      var debugCtx = getCurrentDebugContext();

      if (debugCtx) {
        indexDebugNode(new DebugElement__PRE_R3__(el, null, debugCtx));
      }

      return el;
    }
  }, {
    key: "setAttribute",
    value: function setAttribute(el, name, value, namespace) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        var fullName = namespace ? namespace + ':' + name : name;
        debugEl.attributes[fullName] = value;
      }

      this.delegate.setAttribute(el, name, value, namespace);
    }
  }, {
    key: "removeAttribute",
    value: function removeAttribute(el, name, namespace) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        var fullName = namespace ? namespace + ':' + name : name;
        debugEl.attributes[fullName] = null;
      }

      this.delegate.removeAttribute(el, name, namespace);
    }
  }, {
    key: "addClass",
    value: function addClass(el, name) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.classes[name] = true;
      }

      this.delegate.addClass(el, name);
    }
  }, {
    key: "removeClass",
    value: function removeClass(el, name) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.classes[name] = false;
      }

      this.delegate.removeClass(el, name);
    }
  }, {
    key: "setStyle",
    value: function setStyle(el, style, value, flags) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.styles[style] = value;
      }

      this.delegate.setStyle(el, style, value, flags);
    }
  }, {
    key: "removeStyle",
    value: function removeStyle(el, style, flags) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.styles[style] = null;
      }

      this.delegate.removeStyle(el, style, flags);
    }
  }, {
    key: "setProperty",
    value: function setProperty(el, name, value) {
      var debugEl = getDebugNode$1(el);

      if (debugEl && debugEl instanceof DebugElement__PRE_R3__) {
        debugEl.properties[name] = value;
      }

      this.delegate.setProperty(el, name, value);
    }
  }, {
    key: "listen",
    value: function listen(target, eventName, callback) {
      if (typeof target !== 'string') {
        var debugEl = getDebugNode$1(target);

        if (debugEl) {
          debugEl.listeners.push(new DebugEventListener(eventName, callback));
        }
      }

      return this.delegate.listen(target, eventName, callback);
    }
  }, {
    key: "parentNode",
    value: function parentNode(node) {
      return this.delegate.parentNode(node);
    }
  }, {
    key: "nextSibling",
    value: function nextSibling(node) {
      return this.delegate.nextSibling(node);
    }
  }, {
    key: "setValue",
    value: function setValue(node, value) {
      return this.delegate.setValue(node, value);
    }
  }]);

  return DebugRenderer2;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function overrideProvider(override) {
  initServicesIfNeeded();
  return Services.overrideProvider(override);
}

function overrideComponentView(comp, componentFactory) {
  initServicesIfNeeded();
  return Services.overrideComponentView(comp, componentFactory);
}

function clearOverrides() {
  initServicesIfNeeded();
  return Services.clearOverrides();
} // Attention: this function is called as top level function.
// Putting any logic in here will destroy closure tree shaking!


function createNgModuleFactory(ngModuleType, bootstrapComponents, defFactory) {
  return new NgModuleFactory_(ngModuleType, bootstrapComponents, defFactory);
}

function cloneNgModuleDefinition(def) {
  var providers = Array.from(def.providers);
  var modules = Array.from(def.modules);
  var providersByKey = {};

  for (var key in def.providersByKey) {
    providersByKey[key] = def.providersByKey[key];
  }

  return {
    factory: def.factory,
    scope: def.scope,
    providers: providers,
    modules: modules,
    providersByKey: providersByKey
  };
}

var NgModuleFactory_ = /*#__PURE__*/function (_NgModuleFactory2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_8__["default"])(NgModuleFactory_, _NgModuleFactory2);

  var _super24 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_9__["default"])(NgModuleFactory_);

  function NgModuleFactory_(moduleType, _bootstrapComponents, _ngModuleDefFactory) {
    var _this34;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_10__["default"])(this, NgModuleFactory_);

    // Attention: this ctor is called as top level function.
    // Putting any logic in here will destroy closure tree shaking!
    _this34 = _super24.call(this);
    _this34.moduleType = moduleType;
    _this34._bootstrapComponents = _bootstrapComponents;
    _this34._ngModuleDefFactory = _ngModuleDefFactory;
    return _this34;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_11__["default"])(NgModuleFactory_, [{
    key: "create",
    value: function create(parentInjector) {
      initServicesIfNeeded(); // Clone the NgModuleDefinition so that any tree shakeable provider definition
      // added to this instance of the NgModuleRef doesn't affect the cached copy.
      // See https://github.com/angular/angular/issues/25018.

      var def = cloneNgModuleDefinition(resolveDefinition(this._ngModuleDefFactory));
      return Services.createNgModuleRef(this.moduleType, parentInjector || Injector.NULL, this._bootstrapComponents, def);
    }
  }]);

  return NgModuleFactory_;
}(NgModuleFactory);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// clang-format on

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


if (ngDevMode) {
  // This helper is to give a reasonable error message to people upgrading to v9 that have not yet
  // installed `@angular/localize` in their app.
  // tslint:disable-next-line: no-toplevel-property-access
  _global.$localize = _global.$localize || function () {
    throw new Error('It looks like your application or one of its dependencies is using i18n.\n' + 'Angular 9 introduced a global `$localize()` function that needs to be loaded.\n' + 'Please run `ng add @angular/localize` from the Angular CLI.\n' + '(For non-CLI projects, add `import \'@angular/localize/init\';` to your `polyfills.ts` file.\n' + 'For server-side rendering applications add the import to your `main.server.ts` file.)');
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */




/***/ }),

/***/ "foSv":
/*!*******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf.js ***!
  \*******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _getPrototypeOf; });
function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

/***/ }),

/***/ "fzPg":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/yo.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Yoruba Nigeria [yo]
//! author : Atolagbe Abisoye : https://github.com/andela-batolagbe
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var yo = moment.defineLocale('yo', {
    months: 'Sẹ́rẹ́_Èrèlè_Ẹrẹ̀nà_Ìgbé_Èbibi_Òkùdu_Agẹmo_Ògún_Owewe_Ọ̀wàrà_Bélú_Ọ̀pẹ̀̀'.split('_'),
    monthsShort: 'Sẹ́r_Èrl_Ẹrn_Ìgb_Èbi_Òkù_Agẹ_Ògú_Owe_Ọ̀wà_Bél_Ọ̀pẹ̀̀'.split('_'),
    weekdays: 'Àìkú_Ajé_Ìsẹ́gun_Ọjọ́rú_Ọjọ́bọ_Ẹtì_Àbámẹ́ta'.split('_'),
    weekdaysShort: 'Àìk_Ajé_Ìsẹ́_Ọjr_Ọjb_Ẹtì_Àbá'.split('_'),
    weekdaysMin: 'Àì_Aj_Ìs_Ọr_Ọb_Ẹt_Àb'.split('_'),
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY h:mm A',
      LLLL: 'dddd, D MMMM YYYY h:mm A'
    },
    calendar: {
      sameDay: '[Ònì ni] LT',
      nextDay: '[Ọ̀la ni] LT',
      nextWeek: "dddd [Ọsẹ̀ tón'bọ] [ni] LT",
      lastDay: '[Àna ni] LT',
      lastWeek: 'dddd [Ọsẹ̀ tólọ́] [ni] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'ní %s',
      past: '%s kọjá',
      s: 'ìsẹjú aayá die',
      ss: 'aayá %d',
      m: 'ìsẹjú kan',
      mm: 'ìsẹjú %d',
      h: 'wákati kan',
      hh: 'wákati %d',
      d: 'ọjọ́ kan',
      dd: 'ọjọ́ %d',
      M: 'osù kan',
      MM: 'osù %d',
      y: 'ọdún kan',
      yy: 'ọdún %d'
    },
    dayOfMonthOrdinalParse: /ọjọ́\s\d{1,2}/,
    ordinal: 'ọjọ́ %d',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return yo;
});

/***/ }),

/***/ "gRHU":
/*!*********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Observer.js ***!
  \*********************************************************/
/*! exports provided: empty */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "empty", function() { return empty; });
/* harmony import */ var _config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./config */ "2fFW");
/* harmony import */ var _util_hostReportError__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./util/hostReportError */ "NJ4a");


var empty = {
  closed: true,
  next: function next(value) {},
  error: function error(err) {
    if (_config__WEBPACK_IMPORTED_MODULE_0__["config"].useDeprecatedSynchronousErrorHandling) {
      throw err;
    } else {
      Object(_util_hostReportError__WEBPACK_IMPORTED_MODULE_1__["hostReportError"])(err);
    }
  },
  complete: function complete() {}
};

/***/ }),

/***/ "gVVK":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sl.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Slovenian [sl]
//! author : Robert Sedovšek : https://github.com/sedovsek
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var result = number + ' ';

    switch (key) {
      case 's':
        return withoutSuffix || isFuture ? 'nekaj sekund' : 'nekaj sekundami';

      case 'ss':
        if (number === 1) {
          result += withoutSuffix ? 'sekundo' : 'sekundi';
        } else if (number === 2) {
          result += withoutSuffix || isFuture ? 'sekundi' : 'sekundah';
        } else if (number < 5) {
          result += withoutSuffix || isFuture ? 'sekunde' : 'sekundah';
        } else {
          result += 'sekund';
        }

        return result;

      case 'm':
        return withoutSuffix ? 'ena minuta' : 'eno minuto';

      case 'mm':
        if (number === 1) {
          result += withoutSuffix ? 'minuta' : 'minuto';
        } else if (number === 2) {
          result += withoutSuffix || isFuture ? 'minuti' : 'minutama';
        } else if (number < 5) {
          result += withoutSuffix || isFuture ? 'minute' : 'minutami';
        } else {
          result += withoutSuffix || isFuture ? 'minut' : 'minutami';
        }

        return result;

      case 'h':
        return withoutSuffix ? 'ena ura' : 'eno uro';

      case 'hh':
        if (number === 1) {
          result += withoutSuffix ? 'ura' : 'uro';
        } else if (number === 2) {
          result += withoutSuffix || isFuture ? 'uri' : 'urama';
        } else if (number < 5) {
          result += withoutSuffix || isFuture ? 'ure' : 'urami';
        } else {
          result += withoutSuffix || isFuture ? 'ur' : 'urami';
        }

        return result;

      case 'd':
        return withoutSuffix || isFuture ? 'en dan' : 'enim dnem';

      case 'dd':
        if (number === 1) {
          result += withoutSuffix || isFuture ? 'dan' : 'dnem';
        } else if (number === 2) {
          result += withoutSuffix || isFuture ? 'dni' : 'dnevoma';
        } else {
          result += withoutSuffix || isFuture ? 'dni' : 'dnevi';
        }

        return result;

      case 'M':
        return withoutSuffix || isFuture ? 'en mesec' : 'enim mesecem';

      case 'MM':
        if (number === 1) {
          result += withoutSuffix || isFuture ? 'mesec' : 'mesecem';
        } else if (number === 2) {
          result += withoutSuffix || isFuture ? 'meseca' : 'mesecema';
        } else if (number < 5) {
          result += withoutSuffix || isFuture ? 'mesece' : 'meseci';
        } else {
          result += withoutSuffix || isFuture ? 'mesecev' : 'meseci';
        }

        return result;

      case 'y':
        return withoutSuffix || isFuture ? 'eno leto' : 'enim letom';

      case 'yy':
        if (number === 1) {
          result += withoutSuffix || isFuture ? 'leto' : 'letom';
        } else if (number === 2) {
          result += withoutSuffix || isFuture ? 'leti' : 'letoma';
        } else if (number < 5) {
          result += withoutSuffix || isFuture ? 'leta' : 'leti';
        } else {
          result += withoutSuffix || isFuture ? 'let' : 'leti';
        }

        return result;
    }
  }

  var sl = moment.defineLocale('sl', {
    months: 'januar_februar_marec_april_maj_junij_julij_avgust_september_oktober_november_december'.split('_'),
    monthsShort: 'jan._feb._mar._apr._maj._jun._jul._avg._sep._okt._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'nedelja_ponedeljek_torek_sreda_četrtek_petek_sobota'.split('_'),
    weekdaysShort: 'ned._pon._tor._sre._čet._pet._sob.'.split('_'),
    weekdaysMin: 'ne_po_to_sr_če_pe_so'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD. MM. YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY H:mm',
      LLLL: 'dddd, D. MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[danes ob] LT',
      nextDay: '[jutri ob] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[v] [nedeljo] [ob] LT';

          case 3:
            return '[v] [sredo] [ob] LT';

          case 6:
            return '[v] [soboto] [ob] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[v] dddd [ob] LT';
        }
      },
      lastDay: '[včeraj ob] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[prejšnjo] [nedeljo] [ob] LT';

          case 3:
            return '[prejšnjo] [sredo] [ob] LT';

          case 6:
            return '[prejšnjo] [soboto] [ob] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[prejšnji] dddd [ob] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'čez %s',
      past: 'pred %s',
      s: processRelativeTime,
      ss: processRelativeTime,
      m: processRelativeTime,
      mm: processRelativeTime,
      h: processRelativeTime,
      hh: processRelativeTime,
      d: processRelativeTime,
      dd: processRelativeTime,
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return sl;
});

/***/ }),

/***/ "gcYM":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/throttleTime.js ***!
  \***********************************************************************/
/*! exports provided: throttleTime */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "throttleTime", function() { return throttleTime; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _throttle__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./throttle */ "yuhW");







function throttleTime(duration) {
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_5__["async"];
  var config = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _throttle__WEBPACK_IMPORTED_MODULE_6__["defaultThrottleConfig"];
  return function (source) {
    return source.lift(new ThrottleTimeOperator(duration, scheduler, config.leading, config.trailing));
  };
}

var ThrottleTimeOperator = /*#__PURE__*/function () {
  function ThrottleTimeOperator(duration, scheduler, leading, trailing) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ThrottleTimeOperator);

    this.duration = duration;
    this.scheduler = scheduler;
    this.leading = leading;
    this.trailing = trailing;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ThrottleTimeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ThrottleTimeSubscriber(subscriber, this.duration, this.scheduler, this.leading, this.trailing));
    }
  }]);

  return ThrottleTimeOperator;
}();

var ThrottleTimeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ThrottleTimeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ThrottleTimeSubscriber);

  function ThrottleTimeSubscriber(destination, duration, scheduler, leading, trailing) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ThrottleTimeSubscriber);

    _this = _super.call(this, destination);
    _this.duration = duration;
    _this.scheduler = scheduler;
    _this.leading = leading;
    _this.trailing = trailing;
    _this._hasTrailingValue = false;
    _this._trailingValue = null;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ThrottleTimeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (this.throttled) {
        if (this.trailing) {
          this._trailingValue = value;
          this._hasTrailingValue = true;
        }
      } else {
        this.add(this.throttled = this.scheduler.schedule(dispatchNext, this.duration, {
          subscriber: this
        }));

        if (this.leading) {
          this.destination.next(value);
        } else if (this.trailing) {
          this._trailingValue = value;
          this._hasTrailingValue = true;
        }
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      if (this._hasTrailingValue) {
        this.destination.next(this._trailingValue);
        this.destination.complete();
      } else {
        this.destination.complete();
      }
    }
  }, {
    key: "clearThrottle",
    value: function clearThrottle() {
      var throttled = this.throttled;

      if (throttled) {
        if (this.trailing && this._hasTrailingValue) {
          this.destination.next(this._trailingValue);
          this._trailingValue = null;
          this._hasTrailingValue = false;
        }

        throttled.unsubscribe();
        this.remove(throttled);
        this.throttled = null;
      }
    }
  }]);

  return ThrottleTimeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

function dispatchNext(arg) {
  var subscriber = arg.subscriber;
  subscriber.clearThrottle();
}

/***/ }),

/***/ "gekB":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/fi.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Finnish [fi]
//! author : Tarmo Aidantausta : https://github.com/bleadof
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var numbersPast = 'nolla yksi kaksi kolme neljä viisi kuusi seitsemän kahdeksan yhdeksän'.split(' '),
      numbersFuture = ['nolla', 'yhden', 'kahden', 'kolmen', 'neljän', 'viiden', 'kuuden', numbersPast[7], numbersPast[8], numbersPast[9]];

  function translate(number, withoutSuffix, key, isFuture) {
    var result = '';

    switch (key) {
      case 's':
        return isFuture ? 'muutaman sekunnin' : 'muutama sekunti';

      case 'ss':
        result = isFuture ? 'sekunnin' : 'sekuntia';
        break;

      case 'm':
        return isFuture ? 'minuutin' : 'minuutti';

      case 'mm':
        result = isFuture ? 'minuutin' : 'minuuttia';
        break;

      case 'h':
        return isFuture ? 'tunnin' : 'tunti';

      case 'hh':
        result = isFuture ? 'tunnin' : 'tuntia';
        break;

      case 'd':
        return isFuture ? 'päivän' : 'päivä';

      case 'dd':
        result = isFuture ? 'päivän' : 'päivää';
        break;

      case 'M':
        return isFuture ? 'kuukauden' : 'kuukausi';

      case 'MM':
        result = isFuture ? 'kuukauden' : 'kuukautta';
        break;

      case 'y':
        return isFuture ? 'vuoden' : 'vuosi';

      case 'yy':
        result = isFuture ? 'vuoden' : 'vuotta';
        break;
    }

    result = verbalNumber(number, isFuture) + ' ' + result;
    return result;
  }

  function verbalNumber(number, isFuture) {
    return number < 10 ? isFuture ? numbersFuture[number] : numbersPast[number] : number;
  }

  var fi = moment.defineLocale('fi', {
    months: 'tammikuu_helmikuu_maaliskuu_huhtikuu_toukokuu_kesäkuu_heinäkuu_elokuu_syyskuu_lokakuu_marraskuu_joulukuu'.split('_'),
    monthsShort: 'tammi_helmi_maalis_huhti_touko_kesä_heinä_elo_syys_loka_marras_joulu'.split('_'),
    weekdays: 'sunnuntai_maanantai_tiistai_keskiviikko_torstai_perjantai_lauantai'.split('_'),
    weekdaysShort: 'su_ma_ti_ke_to_pe_la'.split('_'),
    weekdaysMin: 'su_ma_ti_ke_to_pe_la'.split('_'),
    longDateFormat: {
      LT: 'HH.mm',
      LTS: 'HH.mm.ss',
      L: 'DD.MM.YYYY',
      LL: 'Do MMMM[ta] YYYY',
      LLL: 'Do MMMM[ta] YYYY, [klo] HH.mm',
      LLLL: 'dddd, Do MMMM[ta] YYYY, [klo] HH.mm',
      l: 'D.M.YYYY',
      ll: 'Do MMM YYYY',
      lll: 'Do MMM YYYY, [klo] HH.mm',
      llll: 'ddd, Do MMM YYYY, [klo] HH.mm'
    },
    calendar: {
      sameDay: '[tänään] [klo] LT',
      nextDay: '[huomenna] [klo] LT',
      nextWeek: 'dddd [klo] LT',
      lastDay: '[eilen] [klo] LT',
      lastWeek: '[viime] dddd[na] [klo] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s päästä',
      past: '%s sitten',
      s: translate,
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: translate,
      dd: translate,
      M: translate,
      MM: translate,
      y: translate,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return fi;
});

/***/ }),

/***/ "gjCT":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ar-sa.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Arabic (Saudi Arabia) [ar-sa]
//! author : Suhail Alkowaileet : https://github.com/xsoh
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '١',
    2: '٢',
    3: '٣',
    4: '٤',
    5: '٥',
    6: '٦',
    7: '٧',
    8: '٨',
    9: '٩',
    0: '٠'
  },
      numberMap = {
    '١': '1',
    '٢': '2',
    '٣': '3',
    '٤': '4',
    '٥': '5',
    '٦': '6',
    '٧': '7',
    '٨': '8',
    '٩': '9',
    '٠': '0'
  };
  var arSa = moment.defineLocale('ar-sa', {
    months: 'يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
    monthsShort: 'يناير_فبراير_مارس_أبريل_مايو_يونيو_يوليو_أغسطس_سبتمبر_أكتوبر_نوفمبر_ديسمبر'.split('_'),
    weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    meridiemParse: /ص|م/,
    isPM: function isPM(input) {
      return 'م' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ص';
      } else {
        return 'م';
      }
    },
    calendar: {
      sameDay: '[اليوم على الساعة] LT',
      nextDay: '[غدا على الساعة] LT',
      nextWeek: 'dddd [على الساعة] LT',
      lastDay: '[أمس على الساعة] LT',
      lastWeek: 'dddd [على الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'في %s',
      past: 'منذ %s',
      s: 'ثوان',
      ss: '%d ثانية',
      m: 'دقيقة',
      mm: '%d دقائق',
      h: 'ساعة',
      hh: '%d ساعات',
      d: 'يوم',
      dd: '%d أيام',
      M: 'شهر',
      MM: '%d أشهر',
      y: 'سنة',
      yy: '%d سنوات'
    },
    preparse: function preparse(string) {
      return string.replace(/[١٢٣٤٥٦٧٨٩٠]/g, function (match) {
        return numberMap[match];
      }).replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      }).replace(/,/g, '،');
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return arSa;
});

/***/ }),

/***/ "hKrs":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/bg.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Bulgarian [bg]
//! author : Krasen Borisov : https://github.com/kraz
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var bg = moment.defineLocale('bg', {
    months: 'януари_февруари_март_април_май_юни_юли_август_септември_октомври_ноември_декември'.split('_'),
    monthsShort: 'яну_фев_мар_апр_май_юни_юли_авг_сеп_окт_ное_дек'.split('_'),
    weekdays: 'неделя_понеделник_вторник_сряда_четвъртък_петък_събота'.split('_'),
    weekdaysShort: 'нед_пон_вто_сря_чет_пет_съб'.split('_'),
    weekdaysMin: 'нд_пн_вт_ср_чт_пт_сб'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'D.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY H:mm',
      LLLL: 'dddd, D MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[Днес в] LT',
      nextDay: '[Утре в] LT',
      nextWeek: 'dddd [в] LT',
      lastDay: '[Вчера в] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
          case 3:
          case 6:
            return '[Миналата] dddd [в] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[Миналия] dddd [в] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'след %s',
      past: 'преди %s',
      s: 'няколко секунди',
      ss: '%d секунди',
      m: 'минута',
      mm: '%d минути',
      h: 'час',
      hh: '%d часа',
      d: 'ден',
      dd: '%d дена',
      w: 'седмица',
      ww: '%d седмици',
      M: 'месец',
      MM: '%d месеца',
      y: 'година',
      yy: '%d години'
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(ев|ен|ти|ви|ри|ми)/,
    ordinal: function ordinal(number) {
      var lastDigit = number % 10,
          last2Digits = number % 100;

      if (number === 0) {
        return number + '-ев';
      } else if (last2Digits === 0) {
        return number + '-ен';
      } else if (last2Digits > 10 && last2Digits < 20) {
        return number + '-ти';
      } else if (lastDigit === 1) {
        return number + '-ви';
      } else if (lastDigit === 2) {
        return number + '-ри';
      } else if (lastDigit === 7 || lastDigit === 8) {
        return number + '-ми';
      } else {
        return number + '-ти';
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return bg;
});

/***/ }),

/***/ "hKy8":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/pairs.js ***!
  \*****************************************************************/
/*! exports provided: pairs, dispatch */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "pairs", function() { return pairs; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "dispatch", function() { return dispatch; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Subscription */ "quSY");


function pairs(obj, scheduler) {
  if (!scheduler) {
    return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
      var keys = Object.keys(obj);

      for (var i = 0; i < keys.length && !subscriber.closed; i++) {
        var key = keys[i];

        if (obj.hasOwnProperty(key)) {
          subscriber.next([key, obj[key]]);
        }
      }

      subscriber.complete();
    });
  } else {
    return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
      var keys = Object.keys(obj);
      var subscription = new _Subscription__WEBPACK_IMPORTED_MODULE_1__["Subscription"]();
      subscription.add(scheduler.schedule(dispatch, 0, {
        keys: keys,
        index: 0,
        subscriber: subscriber,
        subscription: subscription,
        obj: obj
      }));
      return subscription;
    });
  }
}
function dispatch(state) {
  var keys = state.keys,
      index = state.index,
      subscriber = state.subscriber,
      subscription = state.subscription,
      obj = state.obj;

  if (!subscriber.closed) {
    if (index < keys.length) {
      var key = keys[index];
      subscriber.next([key, obj[key]]);
      subscription.add(this.schedule({
        keys: keys,
        index: index + 1,
        subscriber: subscriber,
        subscription: subscription,
        obj: obj
      }));
    } else {
      subscriber.complete();
    }
  }
}

/***/ }),

/***/ "honF":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/my.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Burmese [my]
//! author : Squar team, mysquar.com
//! author : David Rossellat : https://github.com/gholadr
//! author : Tin Aung Lin : https://github.com/thanyawzinmin
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '၁',
    2: '၂',
    3: '၃',
    4: '၄',
    5: '၅',
    6: '၆',
    7: '၇',
    8: '၈',
    9: '၉',
    0: '၀'
  },
      numberMap = {
    '၁': '1',
    '၂': '2',
    '၃': '3',
    '၄': '4',
    '၅': '5',
    '၆': '6',
    '၇': '7',
    '၈': '8',
    '၉': '9',
    '၀': '0'
  };
  var my = moment.defineLocale('my', {
    months: 'ဇန်နဝါရီ_ဖေဖော်ဝါရီ_မတ်_ဧပြီ_မေ_ဇွန်_ဇူလိုင်_သြဂုတ်_စက်တင်ဘာ_အောက်တိုဘာ_နိုဝင်ဘာ_ဒီဇင်ဘာ'.split('_'),
    monthsShort: 'ဇန်_ဖေ_မတ်_ပြီ_မေ_ဇွန်_လိုင်_သြ_စက်_အောက်_နို_ဒီ'.split('_'),
    weekdays: 'တနင်္ဂနွေ_တနင်္လာ_အင်္ဂါ_ဗုဒ္ဓဟူး_ကြာသပတေး_သောကြာ_စနေ'.split('_'),
    weekdaysShort: 'နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ'.split('_'),
    weekdaysMin: 'နွေ_လာ_ဂါ_ဟူး_ကြာ_သော_နေ'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[ယနေ.] LT [မှာ]',
      nextDay: '[မနက်ဖြန်] LT [မှာ]',
      nextWeek: 'dddd LT [မှာ]',
      lastDay: '[မနေ.က] LT [မှာ]',
      lastWeek: '[ပြီးခဲ့သော] dddd LT [မှာ]',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'လာမည့် %s မှာ',
      past: 'လွန်ခဲ့သော %s က',
      s: 'စက္ကန်.အနည်းငယ်',
      ss: '%d စက္ကန့်',
      m: 'တစ်မိနစ်',
      mm: '%d မိနစ်',
      h: 'တစ်နာရီ',
      hh: '%d နာရီ',
      d: 'တစ်ရက်',
      dd: '%d ရက်',
      M: 'တစ်လ',
      MM: '%d လ',
      y: 'တစ်နှစ်',
      yy: '%d နှစ်'
    },
    preparse: function preparse(string) {
      return string.replace(/[၁၂၃၄၅၆၇၈၉၀]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return my;
});

/***/ }),

/***/ "iEDd":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/gl.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Galician [gl]
//! author : Juan G. Hurtado : https://github.com/juanghurtado
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var gl = moment.defineLocale('gl', {
    months: 'xaneiro_febreiro_marzo_abril_maio_xuño_xullo_agosto_setembro_outubro_novembro_decembro'.split('_'),
    monthsShort: 'xan._feb._mar._abr._mai._xuñ._xul._ago._set._out._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'domingo_luns_martes_mércores_xoves_venres_sábado'.split('_'),
    weekdaysShort: 'dom._lun._mar._mér._xov._ven._sáb.'.split('_'),
    weekdaysMin: 'do_lu_ma_mé_xo_ve_sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY H:mm',
      LLLL: 'dddd, D [de] MMMM [de] YYYY H:mm'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[hoxe ' + (this.hours() !== 1 ? 'ás' : 'á') + '] LT';
      },
      nextDay: function nextDay() {
        return '[mañá ' + (this.hours() !== 1 ? 'ás' : 'á') + '] LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [' + (this.hours() !== 1 ? 'ás' : 'a') + '] LT';
      },
      lastDay: function lastDay() {
        return '[onte ' + (this.hours() !== 1 ? 'á' : 'a') + '] LT';
      },
      lastWeek: function lastWeek() {
        return '[o] dddd [pasado ' + (this.hours() !== 1 ? 'ás' : 'a') + '] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: function future(str) {
        if (str.indexOf('un') === 0) {
          return 'n' + str;
        }

        return 'en ' + str;
      },
      past: 'hai %s',
      s: 'uns segundos',
      ss: '%d segundos',
      m: 'un minuto',
      mm: '%d minutos',
      h: 'unha hora',
      hh: '%d horas',
      d: 'un día',
      dd: '%d días',
      M: 'un mes',
      MM: '%d meses',
      y: 'un ano',
      yy: '%d anos'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return gl;
});

/***/ }),

/***/ "iKkX":
/*!*******************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/VirtualTimeScheduler.js ***!
  \*******************************************************************************/
/*! exports provided: VirtualTimeScheduler, VirtualAction */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VirtualTimeScheduler", function() { return VirtualTimeScheduler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VirtualAction", function() { return VirtualAction; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _AsyncAction__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./AsyncAction */ "3N8a");
/* harmony import */ var _AsyncScheduler__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./AsyncScheduler */ "IjjT");








var VirtualTimeScheduler = /*#__PURE__*/function (_AsyncScheduler) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(VirtualTimeScheduler, _AsyncScheduler);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(VirtualTimeScheduler);

  function VirtualTimeScheduler() {
    var _this;

    var SchedulerAction = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : VirtualAction;
    var maxFrames = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Number.POSITIVE_INFINITY;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, VirtualTimeScheduler);

    _this = _super.call(this, SchedulerAction, function () {
      return _this.frame;
    });
    _this.maxFrames = maxFrames;
    _this.frame = 0;
    _this.index = -1;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(VirtualTimeScheduler, [{
    key: "flush",
    value: function flush() {
      var actions = this.actions,
          maxFrames = this.maxFrames;
      var error, action;

      while ((action = actions[0]) && action.delay <= maxFrames) {
        actions.shift();
        this.frame = action.delay;

        if (error = action.execute(action.state, action.delay)) {
          break;
        }
      }

      if (error) {
        while (action = actions.shift()) {
          action.unsubscribe();
        }

        throw error;
      }
    }
  }]);

  return VirtualTimeScheduler;
}(_AsyncScheduler__WEBPACK_IMPORTED_MODULE_7__["AsyncScheduler"]);
VirtualTimeScheduler.frameTimeFactor = 10;
var VirtualAction = /*#__PURE__*/function (_AsyncAction) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(VirtualAction, _AsyncAction);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(VirtualAction);

  function VirtualAction(scheduler, work) {
    var _this2;

    var index = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : scheduler.index += 1;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, VirtualAction);

    _this2 = _super2.call(this, scheduler, work);
    _this2.scheduler = scheduler;
    _this2.work = work;
    _this2.index = index;
    _this2.active = true;
    _this2.index = scheduler.index = index;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(VirtualAction, [{
    key: "schedule",
    value: function schedule(state) {
      var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

      if (!this.id) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(VirtualAction.prototype), "schedule", this).call(this, state, delay);
      }

      this.active = false;
      var action = new VirtualAction(this.scheduler, this.work);
      this.add(action);
      return action.schedule(state, delay);
    }
  }, {
    key: "requestAsyncId",
    value: function requestAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
      this.delay = scheduler.frame + delay;
      var actions = scheduler.actions;
      actions.push(this);
      actions.sort(VirtualAction.sortActions);
      return true;
    }
  }, {
    key: "recycleAsyncId",
    value: function recycleAsyncId(scheduler, id) {
      var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
      return undefined;
    }
  }, {
    key: "_execute",
    value: function _execute(state, delay) {
      if (this.active === true) {
        return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(VirtualAction.prototype), "_execute", this).call(this, state, delay);
      }
    }
  }], [{
    key: "sortActions",
    value: function sortActions(a, b) {
      if (a.delay === b.delay) {
        if (a.index === b.index) {
          return 0;
        } else if (a.index > b.index) {
          return 1;
        } else {
          return -1;
        }
      } else if (a.delay > b.delay) {
        return 1;
      } else {
        return -1;
      }
    }
  }]);

  return VirtualAction;
}(_AsyncAction__WEBPACK_IMPORTED_MODULE_6__["AsyncAction"]);

/***/ }),

/***/ "iYuL":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/es.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Spanish [es]
//! author : Julio Napurí : https://github.com/julionc
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortDot = 'ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.'.split('_'),
      _monthsShort = 'ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic'.split('_'),
      monthsParse = [/^ene/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i],
      monthsRegex = /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;

  var es = moment.defineLocale('es', {
    months: 'enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortDot;
      } else if (/-MMM-/.test(format)) {
        return _monthsShort[m.month()];
      } else {
        return monthsShortDot[m.month()];
      }
    },
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,
    monthsShortStrictRegex: /^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'domingo_lunes_martes_miércoles_jueves_viernes_sábado'.split('_'),
    weekdaysShort: 'dom._lun._mar._mié._jue._vie._sáb.'.split('_'),
    weekdaysMin: 'do_lu_ma_mi_ju_vi_sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY H:mm',
      LLLL: 'dddd, D [de] MMMM [de] YYYY H:mm'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[hoy a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextDay: function nextDay() {
        return '[mañana a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastDay: function lastDay() {
        return '[ayer a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastWeek: function lastWeek() {
        return '[el] dddd [pasado a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'en %s',
      past: 'hace %s',
      s: 'unos segundos',
      ss: '%d segundos',
      m: 'un minuto',
      mm: '%d minutos',
      h: 'una hora',
      hh: '%d horas',
      d: 'un día',
      dd: '%d días',
      w: 'una semana',
      ww: '%d semanas',
      M: 'un mes',
      MM: '%d meses',
      y: 'un año',
      yy: '%d años'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    },
    invalidDate: 'Fecha inválida'
  });
  return es;
});

/***/ }),

/***/ "itXk":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/combineLatest.js ***!
  \*************************************************************************/
/*! exports provided: combineLatest, CombineLatestOperator, CombineLatestSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "combineLatest", function() { return combineLatest; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CombineLatestOperator", function() { return CombineLatestOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CombineLatestSubscriber", function() { return CombineLatestSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _util_isScheduler__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/isScheduler */ "z+Ro");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");
/* harmony import */ var _fromArray__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./fromArray */ "yCtX");









var NONE = {};
function combineLatest() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  var resultSelector = undefined;
  var scheduler = undefined;

  if (Object(_util_isScheduler__WEBPACK_IMPORTED_MODULE_4__["isScheduler"])(observables[observables.length - 1])) {
    scheduler = observables.pop();
  }

  if (typeof observables[observables.length - 1] === 'function') {
    resultSelector = observables.pop();
  }

  if (observables.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_5__["isArray"])(observables[0])) {
    observables = observables[0];
  }

  return Object(_fromArray__WEBPACK_IMPORTED_MODULE_8__["fromArray"])(observables, scheduler).lift(new CombineLatestOperator(resultSelector));
}
var CombineLatestOperator = /*#__PURE__*/function () {
  function CombineLatestOperator(resultSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, CombineLatestOperator);

    this.resultSelector = resultSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(CombineLatestOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new CombineLatestSubscriber(subscriber, this.resultSelector));
    }
  }]);

  return CombineLatestOperator;
}();
var CombineLatestSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(CombineLatestSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(CombineLatestSubscriber);

  function CombineLatestSubscriber(destination, resultSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, CombineLatestSubscriber);

    _this = _super.call(this, destination);
    _this.resultSelector = resultSelector;
    _this.active = 0;
    _this.values = [];
    _this.observables = [];
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(CombineLatestSubscriber, [{
    key: "_next",
    value: function _next(observable) {
      this.values.push(NONE);
      this.observables.push(observable);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var observables = this.observables;
      var len = observables.length;

      if (len === 0) {
        this.destination.complete();
      } else {
        this.active = len;
        this.toRespond = len;

        for (var i = 0; i < len; i++) {
          var observable = observables[i];
          this.add(Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__["subscribeToResult"])(this, observable, undefined, i));
        }
      }
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(unused) {
      if ((this.active -= 1) === 0) {
        this.destination.complete();
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(_outerValue, innerValue, outerIndex) {
      var values = this.values;
      var oldVal = values[outerIndex];
      var toRespond = !this.toRespond ? 0 : oldVal === NONE ? --this.toRespond : this.toRespond;
      values[outerIndex] = innerValue;

      if (toRespond === 0) {
        if (this.resultSelector) {
          this._tryResultSelector(values);
        } else {
          this.destination.next(values.slice());
        }
      }
    }
  }, {
    key: "_tryResultSelector",
    value: function _tryResultSelector(values) {
      var result;

      try {
        result = this.resultSelector.apply(this, values);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.destination.next(result);
    }
  }]);

  return CombineLatestSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__["OuterSubscriber"]);

/***/ }),

/***/ "jUeY":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/el.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Greek [el]
//! author : Aggelos Karalias : https://github.com/mehiel
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function isFunction(input) {
    return typeof Function !== 'undefined' && input instanceof Function || Object.prototype.toString.call(input) === '[object Function]';
  }

  var el = moment.defineLocale('el', {
    monthsNominativeEl: 'Ιανουάριος_Φεβρουάριος_Μάρτιος_Απρίλιος_Μάιος_Ιούνιος_Ιούλιος_Αύγουστος_Σεπτέμβριος_Οκτώβριος_Νοέμβριος_Δεκέμβριος'.split('_'),
    monthsGenitiveEl: 'Ιανουαρίου_Φεβρουαρίου_Μαρτίου_Απριλίου_Μαΐου_Ιουνίου_Ιουλίου_Αυγούστου_Σεπτεμβρίου_Οκτωβρίου_Νοεμβρίου_Δεκεμβρίου'.split('_'),
    months: function months(momentToFormat, format) {
      if (!momentToFormat) {
        return this._monthsNominativeEl;
      } else if (typeof format === 'string' && /D/.test(format.substring(0, format.indexOf('MMMM')))) {
        // if there is a day number before 'MMMM'
        return this._monthsGenitiveEl[momentToFormat.month()];
      } else {
        return this._monthsNominativeEl[momentToFormat.month()];
      }
    },
    monthsShort: 'Ιαν_Φεβ_Μαρ_Απρ_Μαϊ_Ιουν_Ιουλ_Αυγ_Σεπ_Οκτ_Νοε_Δεκ'.split('_'),
    weekdays: 'Κυριακή_Δευτέρα_Τρίτη_Τετάρτη_Πέμπτη_Παρασκευή_Σάββατο'.split('_'),
    weekdaysShort: 'Κυρ_Δευ_Τρι_Τετ_Πεμ_Παρ_Σαβ'.split('_'),
    weekdaysMin: 'Κυ_Δε_Τρ_Τε_Πε_Πα_Σα'.split('_'),
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours > 11) {
        return isLower ? 'μμ' : 'ΜΜ';
      } else {
        return isLower ? 'πμ' : 'ΠΜ';
      }
    },
    isPM: function isPM(input) {
      return (input + '').toLowerCase()[0] === 'μ';
    },
    meridiemParse: /[ΠΜ]\.?Μ?\.?/i,
    longDateFormat: {
      LT: 'h:mm A',
      LTS: 'h:mm:ss A',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY h:mm A',
      LLLL: 'dddd, D MMMM YYYY h:mm A'
    },
    calendarEl: {
      sameDay: '[Σήμερα {}] LT',
      nextDay: '[Αύριο {}] LT',
      nextWeek: 'dddd [{}] LT',
      lastDay: '[Χθες {}] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 6:
            return '[το προηγούμενο] dddd [{}] LT';

          default:
            return '[την προηγούμενη] dddd [{}] LT';
        }
      },
      sameElse: 'L'
    },
    calendar: function calendar(key, mom) {
      var output = this._calendarEl[key],
          hours = mom && mom.hours();

      if (isFunction(output)) {
        output = output.apply(mom);
      }

      return output.replace('{}', hours % 12 === 1 ? 'στη' : 'στις');
    },
    relativeTime: {
      future: 'σε %s',
      past: '%s πριν',
      s: 'λίγα δευτερόλεπτα',
      ss: '%d δευτερόλεπτα',
      m: 'ένα λεπτό',
      mm: '%d λεπτά',
      h: 'μία ώρα',
      hh: '%d ώρες',
      d: 'μία μέρα',
      dd: '%d μέρες',
      M: 'ένας μήνας',
      MM: '%d μήνες',
      y: 'ένας χρόνος',
      yy: '%d χρόνια'
    },
    dayOfMonthOrdinalParse: /\d{1,2}η/,
    ordinal: '%dη',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4st is the first week of the year.

    }
  });
  return el;
});

/***/ }),

/***/ "jVdC":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/pl.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Polish [pl]
//! author : Rafal Hirsz : https://github.com/evoL
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsNominative = 'styczeń_luty_marzec_kwiecień_maj_czerwiec_lipiec_sierpień_wrzesień_październik_listopad_grudzień'.split('_'),
      monthsSubjective = 'stycznia_lutego_marca_kwietnia_maja_czerwca_lipca_sierpnia_września_października_listopada_grudnia'.split('_'),
      monthsParse = [/^sty/i, /^lut/i, /^mar/i, /^kwi/i, /^maj/i, /^cze/i, /^lip/i, /^sie/i, /^wrz/i, /^paź/i, /^lis/i, /^gru/i];

  function plural(n) {
    return n % 10 < 5 && n % 10 > 1 && ~~(n / 10) % 10 !== 1;
  }

  function translate(number, withoutSuffix, key) {
    var result = number + ' ';

    switch (key) {
      case 'ss':
        return result + (plural(number) ? 'sekundy' : 'sekund');

      case 'm':
        return withoutSuffix ? 'minuta' : 'minutę';

      case 'mm':
        return result + (plural(number) ? 'minuty' : 'minut');

      case 'h':
        return withoutSuffix ? 'godzina' : 'godzinę';

      case 'hh':
        return result + (plural(number) ? 'godziny' : 'godzin');

      case 'ww':
        return result + (plural(number) ? 'tygodnie' : 'tygodni');

      case 'MM':
        return result + (plural(number) ? 'miesiące' : 'miesięcy');

      case 'yy':
        return result + (plural(number) ? 'lata' : 'lat');
    }
  }

  var pl = moment.defineLocale('pl', {
    months: function months(momentToFormat, format) {
      if (!momentToFormat) {
        return monthsNominative;
      } else if (/D MMMM/.test(format)) {
        return monthsSubjective[momentToFormat.month()];
      } else {
        return monthsNominative[momentToFormat.month()];
      }
    },
    monthsShort: 'sty_lut_mar_kwi_maj_cze_lip_sie_wrz_paź_lis_gru'.split('_'),
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'niedziela_poniedziałek_wtorek_środa_czwartek_piątek_sobota'.split('_'),
    weekdaysShort: 'ndz_pon_wt_śr_czw_pt_sob'.split('_'),
    weekdaysMin: 'Nd_Pn_Wt_Śr_Cz_Pt_So'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Dziś o] LT',
      nextDay: '[Jutro o] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[W niedzielę o] LT';

          case 2:
            return '[We wtorek o] LT';

          case 3:
            return '[W środę o] LT';

          case 6:
            return '[W sobotę o] LT';

          default:
            return '[W] dddd [o] LT';
        }
      },
      lastDay: '[Wczoraj o] LT',
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
            return '[W zeszłą niedzielę o] LT';

          case 3:
            return '[W zeszłą środę o] LT';

          case 6:
            return '[W zeszłą sobotę o] LT';

          default:
            return '[W zeszły] dddd [o] LT';
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: '%s temu',
      s: 'kilka sekund',
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: '1 dzień',
      dd: '%d dni',
      w: 'tydzień',
      ww: translate,
      M: 'miesiąc',
      MM: translate,
      y: 'rok',
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return pl;
});

/***/ }),

/***/ "jZKg":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduled/scheduleArray.js ***!
  \************************************************************************/
/*! exports provided: scheduleArray */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "scheduleArray", function() { return scheduleArray; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Subscription */ "quSY");


function scheduleArray(input, scheduler) {
  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    var sub = new _Subscription__WEBPACK_IMPORTED_MODULE_1__["Subscription"]();
    var i = 0;
    sub.add(scheduler.schedule(function () {
      if (i === input.length) {
        subscriber.complete();
        return;
      }

      subscriber.next(input[i++]);

      if (!subscriber.closed) {
        sub.add(this.schedule());
      }
    }));
    return sub;
  });
}

/***/ }),

/***/ "jfSC":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/fa.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Persian [fa]
//! author : Ebrahim Byagowi : https://github.com/ebraminio
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '۱',
    2: '۲',
    3: '۳',
    4: '۴',
    5: '۵',
    6: '۶',
    7: '۷',
    8: '۸',
    9: '۹',
    0: '۰'
  },
      numberMap = {
    '۱': '1',
    '۲': '2',
    '۳': '3',
    '۴': '4',
    '۵': '5',
    '۶': '6',
    '۷': '7',
    '۸': '8',
    '۹': '9',
    '۰': '0'
  };
  var fa = moment.defineLocale('fa', {
    months: 'ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر'.split('_'),
    monthsShort: 'ژانویه_فوریه_مارس_آوریل_مه_ژوئن_ژوئیه_اوت_سپتامبر_اکتبر_نوامبر_دسامبر'.split('_'),
    weekdays: "\u06CC\u06A9\u200C\u0634\u0646\u0628\u0647_\u062F\u0648\u0634\u0646\u0628\u0647_\u0633\u0647\u200C\u0634\u0646\u0628\u0647_\u0686\u0647\u0627\u0631\u0634\u0646\u0628\u0647_\u067E\u0646\u062C\u200C\u0634\u0646\u0628\u0647_\u062C\u0645\u0639\u0647_\u0634\u0646\u0628\u0647".split('_'),
    weekdaysShort: "\u06CC\u06A9\u200C\u0634\u0646\u0628\u0647_\u062F\u0648\u0634\u0646\u0628\u0647_\u0633\u0647\u200C\u0634\u0646\u0628\u0647_\u0686\u0647\u0627\u0631\u0634\u0646\u0628\u0647_\u067E\u0646\u062C\u200C\u0634\u0646\u0628\u0647_\u062C\u0645\u0639\u0647_\u0634\u0646\u0628\u0647".split('_'),
    weekdaysMin: 'ی_د_س_چ_پ_ج_ش'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    meridiemParse: /قبل از ظهر|بعد از ظهر/,
    isPM: function isPM(input) {
      return /بعد از ظهر/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'قبل از ظهر';
      } else {
        return 'بعد از ظهر';
      }
    },
    calendar: {
      sameDay: '[امروز ساعت] LT',
      nextDay: '[فردا ساعت] LT',
      nextWeek: 'dddd [ساعت] LT',
      lastDay: '[دیروز ساعت] LT',
      lastWeek: 'dddd [پیش] [ساعت] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'در %s',
      past: '%s پیش',
      s: 'چند ثانیه',
      ss: '%d ثانیه',
      m: 'یک دقیقه',
      mm: '%d دقیقه',
      h: 'یک ساعت',
      hh: '%d ساعت',
      d: 'یک روز',
      dd: '%d روز',
      M: 'یک ماه',
      MM: '%d ماه',
      y: 'یک سال',
      yy: '%d سال'
    },
    preparse: function preparse(string) {
      return string.replace(/[۰-۹]/g, function (match) {
        return numberMap[match];
      }).replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      }).replace(/,/g, '،');
    },
    dayOfMonthOrdinalParse: /\d{1,2}م/,
    ordinal: '%dم',
    week: {
      dow: 6,
      // Saturday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return fa;
});

/***/ }),

/***/ "jhN1":
/*!******************************************************************************************!*\
  !*** ./node_modules/@angular/platform-browser/__ivy_ngcc__/fesm2015/platform-browser.js ***!
  \******************************************************************************************/
/*! exports provided: ɵgetDOM, BrowserModule, BrowserTransferStateModule, By, DomSanitizer, EVENT_MANAGER_PLUGINS, EventManager, HAMMER_GESTURE_CONFIG, HAMMER_LOADER, HammerGestureConfig, HammerModule, Meta, Title, TransferState, VERSION, disableDebugTools, enableDebugTools, makeStateKey, platformBrowser, ɵBROWSER_SANITIZATION_PROVIDERS, ɵBROWSER_SANITIZATION_PROVIDERS__POST_R3__, ɵBrowserDomAdapter, ɵBrowserGetTestability, ɵDomEventsPlugin, ɵDomRendererFactory2, ɵDomSanitizerImpl, ɵDomSharedStylesHost, ɵELEMENT_PROBE_PROVIDERS, ɵELEMENT_PROBE_PROVIDERS__POST_R3__, ɵHAMMER_PROVIDERS__POST_R3__, ɵHammerGesturesPlugin, ɵINTERNAL_BROWSER_PLATFORM_PROVIDERS, ɵKeyEventsPlugin, ɵNAMESPACE_URIS, ɵSharedStylesHost, ɵTRANSITION_ID, ɵangular_packages_platform_browser_platform_browser_a, ɵangular_packages_platform_browser_platform_browser_b, ɵangular_packages_platform_browser_platform_browser_c, ɵangular_packages_platform_browser_platform_browser_d, ɵangular_packages_platform_browser_platform_browser_e, ɵangular_packages_platform_browser_platform_browser_f, ɵangular_packages_platform_browser_platform_browser_g, ɵangular_packages_platform_browser_platform_browser_h, ɵangular_packages_platform_browser_platform_browser_i, ɵangular_packages_platform_browser_platform_browser_j, ɵangular_packages_platform_browser_platform_browser_k, ɵangular_packages_platform_browser_platform_browser_l, ɵangular_packages_platform_browser_platform_browser_m, ɵangular_packages_platform_browser_platform_browser_n, ɵangular_packages_platform_browser_platform_browser_o, ɵescapeHtml, ɵflattenStyles, ɵinitDomAdapter, ɵshimContentAttribute, ɵshimHostAttribute */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BrowserModule", function() { return BrowserModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BrowserTransferStateModule", function() { return BrowserTransferStateModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "By", function() { return By; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DomSanitizer", function() { return DomSanitizer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EVENT_MANAGER_PLUGINS", function() { return EVENT_MANAGER_PLUGINS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EventManager", function() { return EventManager; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HAMMER_GESTURE_CONFIG", function() { return HAMMER_GESTURE_CONFIG; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HAMMER_LOADER", function() { return HAMMER_LOADER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HammerGestureConfig", function() { return HammerGestureConfig; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HammerModule", function() { return HammerModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Meta", function() { return Meta; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Title", function() { return Title; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TransferState", function() { return TransferState; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "disableDebugTools", function() { return disableDebugTools; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "enableDebugTools", function() { return enableDebugTools; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "makeStateKey", function() { return makeStateKey; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "platformBrowser", function() { return platformBrowser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵBROWSER_SANITIZATION_PROVIDERS", function() { return BROWSER_SANITIZATION_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵBROWSER_SANITIZATION_PROVIDERS__POST_R3__", function() { return BROWSER_SANITIZATION_PROVIDERS__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵBrowserDomAdapter", function() { return BrowserDomAdapter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵBrowserGetTestability", function() { return BrowserGetTestability; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵDomEventsPlugin", function() { return DomEventsPlugin; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵDomRendererFactory2", function() { return DomRendererFactory2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵDomSanitizerImpl", function() { return DomSanitizerImpl; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵDomSharedStylesHost", function() { return DomSharedStylesHost; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵELEMENT_PROBE_PROVIDERS", function() { return ELEMENT_PROBE_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵELEMENT_PROBE_PROVIDERS__POST_R3__", function() { return ELEMENT_PROBE_PROVIDERS__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵHAMMER_PROVIDERS__POST_R3__", function() { return HAMMER_PROVIDERS__POST_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵHammerGesturesPlugin", function() { return HammerGesturesPlugin; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵINTERNAL_BROWSER_PLATFORM_PROVIDERS", function() { return INTERNAL_BROWSER_PLATFORM_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵKeyEventsPlugin", function() { return KeyEventsPlugin; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNAMESPACE_URIS", function() { return NAMESPACE_URIS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵSharedStylesHost", function() { return SharedStylesHost; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵTRANSITION_ID", function() { return TRANSITION_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_a", function() { return errorHandler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_b", function() { return _document; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_c", function() { return BROWSER_MODULE_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_d", function() { return createMeta; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_e", function() { return createTitle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_f", function() { return initTransferState; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_g", function() { return EventManagerPlugin; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_h", function() { return HAMMER_PROVIDERS__PRE_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_i", function() { return HAMMER_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_j", function() { return domSanitizerImplFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_k", function() { return appInitializerFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_l", function() { return SERVER_TRANSITION_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_m", function() { return _createNgProbeR2; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_n", function() { return ELEMENT_PROBE_PROVIDERS__PRE_R3__; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_platform_browser_platform_browser_o", function() { return GenericBrowserDomAdapter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵescapeHtml", function() { return escapeHtml; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵflattenStyles", function() { return flattenStyles; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵinitDomAdapter", function() { return initDomAdapter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵshimContentAttribute", function() { return shimContentAttribute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵshimHostAttribute", function() { return shimHostAttribute; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _angular_common__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @angular/common */ "ofXK");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @angular/core */ "fXoL");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ɵgetDOM", function() { return _angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"]; });








/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */




/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Provides DOM operations in any browser environment.
 *
 * @security Tread carefully! Interacting with the DOM directly is dangerous and
 * can introduce XSS risks.
 */

var GenericBrowserDomAdapter = /*#__PURE__*/function (_DomAdapter) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(GenericBrowserDomAdapter, _DomAdapter);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(GenericBrowserDomAdapter);

  function GenericBrowserDomAdapter() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, GenericBrowserDomAdapter);

    return _super.call(this);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(GenericBrowserDomAdapter, [{
    key: "supportsDOMEvents",
    value: function supportsDOMEvents() {
      return true;
    }
  }]);

  return GenericBrowserDomAdapter;
}(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵDomAdapter"]);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0 = function ɵ0() {
  if (_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['Node']) {
    return _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['Node'].prototype.contains || function (node) {
      return !!(this.compareDocumentPosition(node) & 16);
    };
  }

  return undefined;
};

var nodeContains = ɵ0();
/**
 * A `DomAdapter` powered by full browser DOM APIs.
 *
 * @security Tread carefully! Interacting with the DOM directly is dangerous and
 * can introduce XSS risks.
 */

/* tslint:disable:requireParameterType no-console */

var BrowserDomAdapter = /*#__PURE__*/function (_GenericBrowserDomAda) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(BrowserDomAdapter, _GenericBrowserDomAda);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(BrowserDomAdapter);

  function BrowserDomAdapter() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, BrowserDomAdapter);

    return _super2.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(BrowserDomAdapter, [{
    key: "getProperty",
    value: function getProperty(el, name) {
      return el[name];
    }
  }, {
    key: "log",
    value: function log(error) {
      if (window.console) {
        window.console.log && window.console.log(error);
      }
    }
  }, {
    key: "logGroup",
    value: function logGroup(error) {
      if (window.console) {
        window.console.group && window.console.group(error);
      }
    }
  }, {
    key: "logGroupEnd",
    value: function logGroupEnd() {
      if (window.console) {
        window.console.groupEnd && window.console.groupEnd();
      }
    }
  }, {
    key: "onAndCancel",
    value: function onAndCancel(el, evt, listener) {
      el.addEventListener(evt, listener, false); // Needed to follow Dart's subscription semantic, until fix of
      // https://code.google.com/p/dart/issues/detail?id=17406

      return function () {
        el.removeEventListener(evt, listener, false);
      };
    }
  }, {
    key: "dispatchEvent",
    value: function dispatchEvent(el, evt) {
      el.dispatchEvent(evt);
    }
  }, {
    key: "remove",
    value: function remove(node) {
      if (node.parentNode) {
        node.parentNode.removeChild(node);
      }

      return node;
    }
  }, {
    key: "getValue",
    value: function getValue(el) {
      return el.value;
    }
  }, {
    key: "createElement",
    value: function createElement(tagName, doc) {
      doc = doc || this.getDefaultDocument();
      return doc.createElement(tagName);
    }
  }, {
    key: "createHtmlDocument",
    value: function createHtmlDocument() {
      return document.implementation.createHTMLDocument('fakeTitle');
    }
  }, {
    key: "getDefaultDocument",
    value: function getDefaultDocument() {
      return document;
    }
  }, {
    key: "isElementNode",
    value: function isElementNode(node) {
      return node.nodeType === Node.ELEMENT_NODE;
    }
  }, {
    key: "isShadowRoot",
    value: function isShadowRoot(node) {
      return node instanceof DocumentFragment;
    }
  }, {
    key: "getGlobalEventTarget",
    value: function getGlobalEventTarget(doc, target) {
      if (target === 'window') {
        return window;
      }

      if (target === 'document') {
        return doc;
      }

      if (target === 'body') {
        return doc.body;
      }

      return null;
    }
  }, {
    key: "getHistory",
    value: function getHistory() {
      return window.history;
    }
  }, {
    key: "getLocation",
    value: function getLocation() {
      return window.location;
    }
  }, {
    key: "getBaseHref",
    value: function getBaseHref(doc) {
      var href = getBaseElementHref();
      return href == null ? null : relativePath(href);
    }
  }, {
    key: "resetBaseElement",
    value: function resetBaseElement() {
      baseElement = null;
    }
  }, {
    key: "getUserAgent",
    value: function getUserAgent() {
      return window.navigator.userAgent;
    }
  }, {
    key: "performanceNow",
    value: function performanceNow() {
      // performance.now() is not available in all browsers, see
      // http://caniuse.com/#search=performance.now
      return window.performance && window.performance.now ? window.performance.now() : new Date().getTime();
    }
  }, {
    key: "supportsCookies",
    value: function supportsCookies() {
      return true;
    }
  }, {
    key: "getCookie",
    value: function getCookie(name) {
      return Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵparseCookieValue"])(document.cookie, name);
    }
  }], [{
    key: "makeCurrent",
    value: function makeCurrent() {
      Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵsetRootDomAdapter"])(new BrowserDomAdapter());
    }
  }]);

  return BrowserDomAdapter;
}(GenericBrowserDomAdapter);

var baseElement = null;

function getBaseElementHref() {
  if (!baseElement) {
    baseElement = document.querySelector('base');

    if (!baseElement) {
      return null;
    }
  }

  return baseElement.getAttribute('href');
} // based on urlUtils.js in AngularJS 1


var urlParsingNode;

function relativePath(url) {
  if (!urlParsingNode) {
    urlParsingNode = document.createElement('a');
  }

  urlParsingNode.setAttribute('href', url);
  return urlParsingNode.pathname.charAt(0) === '/' ? urlParsingNode.pathname : '/' + urlParsingNode.pathname;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An id that identifies a particular application being bootstrapped, that should
 * match across the client/server boundary.
 */


var TRANSITION_ID = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('TRANSITION_ID');

function appInitializerFactory(transitionId, document, injector) {
  return function () {
    // Wait for all application initializers to be completed before removing the styles set by
    // the server.
    injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ApplicationInitStatus"]).donePromise.then(function () {
      var dom = Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])();
      var styles = Array.prototype.slice.apply(document.querySelectorAll("style[ng-transition]"));
      styles.filter(function (el) {
        return el.getAttribute('ng-transition') === transitionId;
      }).forEach(function (el) {
        return dom.remove(el);
      });
    });
  };
}

var SERVER_TRANSITION_PROVIDERS = [{
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_INITIALIZER"],
  useFactory: appInitializerFactory,
  deps: [TRANSITION_ID, _angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injector"]],
  multi: true
}];
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var BrowserGetTestability = /*#__PURE__*/function () {
  function BrowserGetTestability() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, BrowserGetTestability);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(BrowserGetTestability, [{
    key: "addToWindow",
    value: function addToWindow(registry) {
      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['getAngularTestability'] = function (elem) {
        var findInAncestors = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
        var testability = registry.findTestabilityInTree(elem, findInAncestors);

        if (testability == null) {
          throw new Error('Could not find testability for element.');
        }

        return testability;
      };

      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['getAllAngularTestabilities'] = function () {
        return registry.getAllTestabilities();
      };

      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['getAllAngularRootElements'] = function () {
        return registry.getAllRootElements();
      };

      var whenAllStable = function whenAllStable(callback
      /** TODO #9100 */
      ) {
        var testabilities = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['getAllAngularTestabilities']();
        var count = testabilities.length;
        var didWork = false;

        var decrement = function decrement(didWork_
        /** TODO #9100 */
        ) {
          didWork = didWork || didWork_;
          count--;

          if (count == 0) {
            callback(didWork);
          }
        };

        testabilities.forEach(function (testability
        /** TODO #9100 */
        ) {
          testability.whenStable(decrement);
        });
      };

      if (!_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['frameworkStabilizers']) {
        _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['frameworkStabilizers'] = [];
      }

      _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['frameworkStabilizers'].push(whenAllStable);
    }
  }, {
    key: "findTestabilityInTree",
    value: function findTestabilityInTree(registry, elem, findInAncestors) {
      if (elem == null) {
        return null;
      }

      var t = registry.getTestability(elem);

      if (t != null) {
        return t;
      } else if (!findInAncestors) {
        return null;
      }

      if (Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().isShadowRoot(elem)) {
        return this.findTestabilityInTree(registry, elem.host, true);
      }

      return this.findTestabilityInTree(registry, elem.parentElement, true);
    }
  }], [{
    key: "init",
    value: function init() {
      Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["setTestabilityGetter"])(new BrowserGetTestability());
    }
  }]);

  return BrowserGetTestability;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CAMEL_CASE_REGEXP = /([A-Z])/g;
var DASH_CASE_REGEXP = /-([a-z])/g;

function camelCaseToDashCase(input) {
  return input.replace(CAMEL_CASE_REGEXP, function () {
    for (var _len = arguments.length, m = new Array(_len), _key = 0; _key < _len; _key++) {
      m[_key] = arguments[_key];
    }

    return '-' + m[1].toLowerCase();
  });
}

function dashCaseToCamelCase(input) {
  return input.replace(DASH_CASE_REGEXP, function () {
    for (var _len2 = arguments.length, m = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      m[_key2] = arguments[_key2];
    }

    return m[1].toUpperCase();
  });
}
/**
 * Exports the value under a given `name` in the global property `ng`. For example `ng.probe` if
 * `name` is `'probe'`.
 * @param name Name under which it will be exported. Keep in mind this will be a property of the
 * global `ng` object.
 * @param value The value to export.
 */


function exportNgVar(name, value) {
  if (typeof COMPILED === 'undefined' || !COMPILED) {
    // Note: we can't export `ng` when using closure enhanced optimization as:
    // - closure declares globals itself for minified names, which sometimes clobber our `ng` global
    // - we can't declare a closure extern as the namespace `ng` is already used within Google
    //   for typings for angularJS (via `goog.provide('ng....')`).
    var ng = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['ng'] = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵglobal"]['ng'] || {};
    ng[name] = value;
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ɵ0$1 = function ɵ0$1() {
  return {
    'ApplicationRef': _angular_core__WEBPACK_IMPORTED_MODULE_7__["ApplicationRef"],
    'NgZone': _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"]
  };
};

var CORE_TOKENS = ɵ0$1();
var INSPECT_GLOBAL_NAME = 'probe';
var CORE_TOKENS_GLOBAL_NAME = 'coreTokens';
/**
 * Returns a {@link DebugElement} for the given native DOM element, or
 * null if the given native element does not have an Angular view associated
 * with it.
 */

function inspectNativeElementR2(element) {
  return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵgetDebugNodeR2"])(element);
}

function _createNgProbeR2(coreTokens) {
  exportNgVar(INSPECT_GLOBAL_NAME, inspectNativeElementR2);
  exportNgVar(CORE_TOKENS_GLOBAL_NAME, Object.assign(Object.assign({}, CORE_TOKENS), _ngProbeTokensToMap(coreTokens || [])));
  return function () {
    return inspectNativeElementR2;
  };
}

function _ngProbeTokensToMap(tokens) {
  return tokens.reduce(function (prev, t) {
    return prev[t.name] = t.token, prev;
  }, {});
}
/**
 * In Ivy, we don't support NgProbe because we have our own set of testing utilities
 * with more robust functionality.
 *
 * We shouldn't bring in NgProbe because it prevents DebugNode and friends from
 * tree-shaking properly.
 */


var ELEMENT_PROBE_PROVIDERS__POST_R3__ = [];
/**
 * Providers which support debugging Angular applications (e.g. via `ng.probe`).
 */

var ELEMENT_PROBE_PROVIDERS__PRE_R3__ = [{
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_INITIALIZER"],
  useFactory: _createNgProbeR2,
  deps: [[_angular_core__WEBPACK_IMPORTED_MODULE_7__["NgProbeToken"], new _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]()]],
  multi: true
}];
var ELEMENT_PROBE_PROVIDERS = ELEMENT_PROBE_PROVIDERS__POST_R3__;
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The injection token for the event-manager plug-in service.
 *
 * @publicApi
 */

var EVENT_MANAGER_PLUGINS = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('EventManagerPlugins');
/**
 * An injectable service that provides event management for Angular
 * through a browser plug-in.
 *
 * @publicApi
 */

var EventManager = /*#__PURE__*/function () {
  /**
   * Initializes an instance of the event-manager service.
   */
  function EventManager(plugins, _zone) {
    var _this = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, EventManager);

    this._zone = _zone;
    this._eventNameToPlugin = new Map();
    plugins.forEach(function (p) {
      return p.manager = _this;
    });
    this._plugins = plugins.slice().reverse();
  }
  /**
   * Registers a handler for a specific element and event.
   *
   * @param element The HTML element to receive event notifications.
   * @param eventName The name of the event to listen for.
   * @param handler A function to call when the notification occurs. Receives the
   * event object as an argument.
   * @returns  A callback function that can be used to remove the handler.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(EventManager, [{
    key: "addEventListener",
    value: function addEventListener(element, eventName, handler) {
      var plugin = this._findPluginFor(eventName);

      return plugin.addEventListener(element, eventName, handler);
    }
    /**
     * Registers a global handler for an event in a target view.
     *
     * @param target A target for global event notifications. One of "window", "document", or "body".
     * @param eventName The name of the event to listen for.
     * @param handler A function to call when the notification occurs. Receives the
     * event object as an argument.
     * @returns A callback function that can be used to remove the handler.
     */

  }, {
    key: "addGlobalEventListener",
    value: function addGlobalEventListener(target, eventName, handler) {
      var plugin = this._findPluginFor(eventName);

      return plugin.addGlobalEventListener(target, eventName, handler);
    }
    /**
     * Retrieves the compilation zone in which event listeners are registered.
     */

  }, {
    key: "getZone",
    value: function getZone() {
      return this._zone;
    }
    /** @internal */

  }, {
    key: "_findPluginFor",
    value: function _findPluginFor(eventName) {
      var plugin = this._eventNameToPlugin.get(eventName);

      if (plugin) {
        return plugin;
      }

      var plugins = this._plugins;

      for (var i = 0; i < plugins.length; i++) {
        var _plugin = plugins[i];

        if (_plugin.supports(eventName)) {
          this._eventNameToPlugin.set(eventName, _plugin);

          return _plugin;
        }
      }

      throw new Error("No event manager plugin found for event ".concat(eventName));
    }
  }]);

  return EventManager;
}();

EventManager.ɵfac = function EventManager_Factory(t) {
  return new (t || EventManager)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](EVENT_MANAGER_PLUGINS), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"]));
};

EventManager.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: EventManager,
  factory: EventManager.ɵfac
});

EventManager.ctorParameters = function () {
  return [{
    type: Array,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [EVENT_MANAGER_PLUGINS]
    }]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](EventManager, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [{
      type: Array,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [EVENT_MANAGER_PLUGINS]
      }]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"]
    }];
  }, null);
})();

var EventManagerPlugin = /*#__PURE__*/function () {
  function EventManagerPlugin(_doc) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, EventManagerPlugin);

    this._doc = _doc;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(EventManagerPlugin, [{
    key: "addGlobalEventListener",
    value: function addGlobalEventListener(element, eventName, handler) {
      var target = Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().getGlobalEventTarget(this._doc, element);

      if (!target) {
        throw new Error("Unsupported event target ".concat(target, " for event ").concat(eventName));
      }

      return this.addEventListener(target, eventName, handler);
    }
  }]);

  return EventManagerPlugin;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SharedStylesHost = /*#__PURE__*/function () {
  function SharedStylesHost() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SharedStylesHost);

    /** @internal */
    this._stylesSet = new Set();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SharedStylesHost, [{
    key: "addStyles",
    value: function addStyles(styles) {
      var _this2 = this;

      var additions = new Set();
      styles.forEach(function (style) {
        if (!_this2._stylesSet.has(style)) {
          _this2._stylesSet.add(style);

          additions.add(style);
        }
      });
      this.onStylesAdded(additions);
    }
  }, {
    key: "onStylesAdded",
    value: function onStylesAdded(additions) {}
  }, {
    key: "getAllStyles",
    value: function getAllStyles() {
      return Array.from(this._stylesSet);
    }
  }]);

  return SharedStylesHost;
}();

SharedStylesHost.ɵfac = function SharedStylesHost_Factory(t) {
  return new (t || SharedStylesHost)();
};

SharedStylesHost.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: SharedStylesHost,
  factory: SharedStylesHost.ɵfac
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](SharedStylesHost, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [];
  }, null);
})();

var DomSharedStylesHost = /*#__PURE__*/function (_SharedStylesHost) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(DomSharedStylesHost, _SharedStylesHost);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(DomSharedStylesHost);

  function DomSharedStylesHost(_doc) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DomSharedStylesHost);

    _this3 = _super3.call(this);
    _this3._doc = _doc;
    _this3._hostNodes = new Set();
    _this3._styleNodes = new Set();

    _this3._hostNodes.add(_doc.head);

    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DomSharedStylesHost, [{
    key: "_addStylesToHost",
    value: function _addStylesToHost(styles, host) {
      var _this4 = this;

      styles.forEach(function (style) {
        var styleEl = _this4._doc.createElement('style');

        styleEl.textContent = style;

        _this4._styleNodes.add(host.appendChild(styleEl));
      });
    }
  }, {
    key: "addHost",
    value: function addHost(hostNode) {
      this._addStylesToHost(this._stylesSet, hostNode);

      this._hostNodes.add(hostNode);
    }
  }, {
    key: "removeHost",
    value: function removeHost(hostNode) {
      this._hostNodes.delete(hostNode);
    }
  }, {
    key: "onStylesAdded",
    value: function onStylesAdded(additions) {
      var _this5 = this;

      this._hostNodes.forEach(function (hostNode) {
        return _this5._addStylesToHost(additions, hostNode);
      });
    }
  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      this._styleNodes.forEach(function (styleNode) {
        return Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().remove(styleNode);
      });
    }
  }]);

  return DomSharedStylesHost;
}(SharedStylesHost);

DomSharedStylesHost.ɵfac = function DomSharedStylesHost_Factory(t) {
  return new (t || DomSharedStylesHost)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
};

DomSharedStylesHost.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: DomSharedStylesHost,
  factory: DomSharedStylesHost.ɵfac
});

DomSharedStylesHost.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](DomSharedStylesHost, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NAMESPACE_URIS = {
  'svg': 'http://www.w3.org/2000/svg',
  'xhtml': 'http://www.w3.org/1999/xhtml',
  'xlink': 'http://www.w3.org/1999/xlink',
  'xml': 'http://www.w3.org/XML/1998/namespace',
  'xmlns': 'http://www.w3.org/2000/xmlns/'
};
var COMPONENT_REGEX = /%COMP%/g;
var NG_DEV_MODE = typeof ngDevMode === 'undefined' || !!ngDevMode;
var COMPONENT_VARIABLE = '%COMP%';
var HOST_ATTR = "_nghost-".concat(COMPONENT_VARIABLE);
var CONTENT_ATTR = "_ngcontent-".concat(COMPONENT_VARIABLE);

function shimContentAttribute(componentShortId) {
  return CONTENT_ATTR.replace(COMPONENT_REGEX, componentShortId);
}

function shimHostAttribute(componentShortId) {
  return HOST_ATTR.replace(COMPONENT_REGEX, componentShortId);
}

function flattenStyles(compId, styles, target) {
  for (var i = 0; i < styles.length; i++) {
    var style = styles[i];

    if (Array.isArray(style)) {
      flattenStyles(compId, style, target);
    } else {
      style = style.replace(COMPONENT_REGEX, compId);
      target.push(style);
    }
  }

  return target;
}

function decoratePreventDefault(eventHandler) {
  // `DebugNode.triggerEventHandler` needs to know if the listener was created with
  // decoratePreventDefault or is a listener added outside the Angular context so it can handle the
  // two differently. In the first case, the special '__ngUnwrap__' token is passed to the unwrap
  // the listener (see below).
  return function (event) {
    // Ivy uses '__ngUnwrap__' as a special token that allows us to unwrap the function
    // so that it can be invoked programmatically by `DebugNode.triggerEventHandler`. The debug_node
    // can inspect the listener toString contents for the existence of this special token. Because
    // the token is a string literal, it is ensured to not be modified by compiled code.
    if (event === '__ngUnwrap__') {
      return eventHandler;
    }

    var allowDefaultBehavior = eventHandler(event);

    if (allowDefaultBehavior === false) {
      // TODO(tbosch): move preventDefault into event plugins...
      event.preventDefault();
      event.returnValue = false;
    }

    return undefined;
  };
}

var DomRendererFactory2 = /*#__PURE__*/function () {
  function DomRendererFactory2(eventManager, sharedStylesHost, appId) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DomRendererFactory2);

    this.eventManager = eventManager;
    this.sharedStylesHost = sharedStylesHost;
    this.appId = appId;
    this.rendererByCompId = new Map();
    this.defaultRenderer = new DefaultDomRenderer2(eventManager);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DomRendererFactory2, [{
    key: "createRenderer",
    value: function createRenderer(element, type) {
      if (!element || !type) {
        return this.defaultRenderer;
      }

      switch (type.encapsulation) {
        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["ViewEncapsulation"].Emulated:
          {
            var renderer = this.rendererByCompId.get(type.id);

            if (!renderer) {
              renderer = new EmulatedEncapsulationDomRenderer2(this.eventManager, this.sharedStylesHost, type, this.appId);
              this.rendererByCompId.set(type.id, renderer);
            }

            renderer.applyToHost(element);
            return renderer;
          }

        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["ViewEncapsulation"].Native:
        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["ViewEncapsulation"].ShadowDom:
          return new ShadowDomRenderer(this.eventManager, this.sharedStylesHost, element, type);

        default:
          {
            if (!this.rendererByCompId.has(type.id)) {
              var styles = flattenStyles(type.id, type.styles, []);
              this.sharedStylesHost.addStyles(styles);
              this.rendererByCompId.set(type.id, this.defaultRenderer);
            }

            return this.defaultRenderer;
          }
      }
    }
  }, {
    key: "begin",
    value: function begin() {}
  }, {
    key: "end",
    value: function end() {}
  }]);

  return DomRendererFactory2;
}();

DomRendererFactory2.ɵfac = function DomRendererFactory2_Factory(t) {
  return new (t || DomRendererFactory2)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](EventManager), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](DomSharedStylesHost), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]));
};

DomRendererFactory2.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: DomRendererFactory2,
  factory: DomRendererFactory2.ɵfac
});

DomRendererFactory2.ctorParameters = function () {
  return [{
    type: EventManager
  }, {
    type: DomSharedStylesHost
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](DomRendererFactory2, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [{
      type: EventManager
    }, {
      type: DomSharedStylesHost
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]]
      }]
    }];
  }, null);
})();

var DefaultDomRenderer2 = /*#__PURE__*/function () {
  function DefaultDomRenderer2(eventManager) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DefaultDomRenderer2);

    this.eventManager = eventManager;
    this.data = Object.create(null);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DefaultDomRenderer2, [{
    key: "destroy",
    value: function destroy() {}
  }, {
    key: "createElement",
    value: function createElement(name, namespace) {
      if (namespace) {
        // In cases where Ivy (not ViewEngine) is giving us the actual namespace, the look up by key
        // will result in undefined, so we just return the namespace here.
        return document.createElementNS(NAMESPACE_URIS[namespace] || namespace, name);
      }

      return document.createElement(name);
    }
  }, {
    key: "createComment",
    value: function createComment(value) {
      return document.createComment(value);
    }
  }, {
    key: "createText",
    value: function createText(value) {
      return document.createTextNode(value);
    }
  }, {
    key: "appendChild",
    value: function appendChild(parent, newChild) {
      parent.appendChild(newChild);
    }
  }, {
    key: "insertBefore",
    value: function insertBefore(parent, newChild, refChild) {
      if (parent) {
        parent.insertBefore(newChild, refChild);
      }
    }
  }, {
    key: "removeChild",
    value: function removeChild(parent, oldChild) {
      if (parent) {
        parent.removeChild(oldChild);
      }
    }
  }, {
    key: "selectRootElement",
    value: function selectRootElement(selectorOrNode, preserveContent) {
      var el = typeof selectorOrNode === 'string' ? document.querySelector(selectorOrNode) : selectorOrNode;

      if (!el) {
        throw new Error("The selector \"".concat(selectorOrNode, "\" did not match any elements"));
      }

      if (!preserveContent) {
        el.textContent = '';
      }

      return el;
    }
  }, {
    key: "parentNode",
    value: function parentNode(node) {
      return node.parentNode;
    }
  }, {
    key: "nextSibling",
    value: function nextSibling(node) {
      return node.nextSibling;
    }
  }, {
    key: "setAttribute",
    value: function setAttribute(el, name, value, namespace) {
      if (namespace) {
        name = namespace + ':' + name; // TODO(FW-811): Ivy may cause issues here because it's passing around
        // full URIs for namespaces, therefore this lookup will fail.

        var namespaceUri = NAMESPACE_URIS[namespace];

        if (namespaceUri) {
          el.setAttributeNS(namespaceUri, name, value);
        } else {
          el.setAttribute(name, value);
        }
      } else {
        el.setAttribute(name, value);
      }
    }
  }, {
    key: "removeAttribute",
    value: function removeAttribute(el, name, namespace) {
      if (namespace) {
        // TODO(FW-811): Ivy may cause issues here because it's passing around
        // full URIs for namespaces, therefore this lookup will fail.
        var namespaceUri = NAMESPACE_URIS[namespace];

        if (namespaceUri) {
          el.removeAttributeNS(namespaceUri, name);
        } else {
          // TODO(FW-811): Since ivy is passing around full URIs for namespaces
          // this could result in properties like `http://www.w3.org/2000/svg:cx="123"`,
          // which is wrong.
          el.removeAttribute("".concat(namespace, ":").concat(name));
        }
      } else {
        el.removeAttribute(name);
      }
    }
  }, {
    key: "addClass",
    value: function addClass(el, name) {
      el.classList.add(name);
    }
  }, {
    key: "removeClass",
    value: function removeClass(el, name) {
      el.classList.remove(name);
    }
  }, {
    key: "setStyle",
    value: function setStyle(el, style, value, flags) {
      if (flags & _angular_core__WEBPACK_IMPORTED_MODULE_7__["RendererStyleFlags2"].DashCase) {
        el.style.setProperty(style, value, !!(flags & _angular_core__WEBPACK_IMPORTED_MODULE_7__["RendererStyleFlags2"].Important) ? 'important' : '');
      } else {
        el.style[style] = value;
      }
    }
  }, {
    key: "removeStyle",
    value: function removeStyle(el, style, flags) {
      if (flags & _angular_core__WEBPACK_IMPORTED_MODULE_7__["RendererStyleFlags2"].DashCase) {
        el.style.removeProperty(style);
      } else {
        // IE requires '' instead of null
        // see https://github.com/angular/angular/issues/7916
        el.style[style] = '';
      }
    }
  }, {
    key: "setProperty",
    value: function setProperty(el, name, value) {
      NG_DEV_MODE && checkNoSyntheticProp(name, 'property');
      el[name] = value;
    }
  }, {
    key: "setValue",
    value: function setValue(node, value) {
      node.nodeValue = value;
    }
  }, {
    key: "listen",
    value: function listen(target, event, callback) {
      NG_DEV_MODE && checkNoSyntheticProp(event, 'listener');

      if (typeof target === 'string') {
        return this.eventManager.addGlobalEventListener(target, event, decoratePreventDefault(callback));
      }

      return this.eventManager.addEventListener(target, event, decoratePreventDefault(callback));
    }
  }]);

  return DefaultDomRenderer2;
}();

var ɵ0$2 = function ɵ0$2() {
  return '@'.charCodeAt(0);
};

var AT_CHARCODE = ɵ0$2();

function checkNoSyntheticProp(name, nameKind) {
  if (name.charCodeAt(0) === AT_CHARCODE) {
    throw new Error("Found the synthetic ".concat(nameKind, " ").concat(name, ". Please include either \"BrowserAnimationsModule\" or \"NoopAnimationsModule\" in your application."));
  }
}

var EmulatedEncapsulationDomRenderer2 = /*#__PURE__*/function (_DefaultDomRenderer) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(EmulatedEncapsulationDomRenderer2, _DefaultDomRenderer);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(EmulatedEncapsulationDomRenderer2);

  function EmulatedEncapsulationDomRenderer2(eventManager, sharedStylesHost, component, appId) {
    var _this6;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, EmulatedEncapsulationDomRenderer2);

    _this6 = _super4.call(this, eventManager);
    _this6.component = component;
    var styles = flattenStyles(appId + '-' + component.id, component.styles, []);
    sharedStylesHost.addStyles(styles);
    _this6.contentAttr = shimContentAttribute(appId + '-' + component.id);
    _this6.hostAttr = shimHostAttribute(appId + '-' + component.id);
    return _this6;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(EmulatedEncapsulationDomRenderer2, [{
    key: "applyToHost",
    value: function applyToHost(element) {
      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(EmulatedEncapsulationDomRenderer2.prototype), "setAttribute", this).call(this, element, this.hostAttr, '');
    }
  }, {
    key: "createElement",
    value: function createElement(parent, name) {
      var el = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(EmulatedEncapsulationDomRenderer2.prototype), "createElement", this).call(this, parent, name);

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(EmulatedEncapsulationDomRenderer2.prototype), "setAttribute", this).call(this, el, this.contentAttr, '');

      return el;
    }
  }]);

  return EmulatedEncapsulationDomRenderer2;
}(DefaultDomRenderer2);

var ShadowDomRenderer = /*#__PURE__*/function (_DefaultDomRenderer2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(ShadowDomRenderer, _DefaultDomRenderer2);

  var _super5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(ShadowDomRenderer);

  function ShadowDomRenderer(eventManager, sharedStylesHost, hostEl, component) {
    var _this7;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ShadowDomRenderer);

    _this7 = _super5.call(this, eventManager);
    _this7.sharedStylesHost = sharedStylesHost;
    _this7.hostEl = hostEl;
    _this7.component = component;

    if (component.encapsulation === _angular_core__WEBPACK_IMPORTED_MODULE_7__["ViewEncapsulation"].ShadowDom) {
      _this7.shadowRoot = hostEl.attachShadow({
        mode: 'open'
      });
    } else {
      _this7.shadowRoot = hostEl.createShadowRoot();
    }

    _this7.sharedStylesHost.addHost(_this7.shadowRoot);

    var styles = flattenStyles(component.id, component.styles, []);

    for (var i = 0; i < styles.length; i++) {
      var styleEl = document.createElement('style');
      styleEl.textContent = styles[i];

      _this7.shadowRoot.appendChild(styleEl);
    }

    return _this7;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ShadowDomRenderer, [{
    key: "nodeOrShadowRoot",
    value: function nodeOrShadowRoot(node) {
      return node === this.hostEl ? this.shadowRoot : node;
    }
  }, {
    key: "destroy",
    value: function destroy() {
      this.sharedStylesHost.removeHost(this.shadowRoot);
    }
  }, {
    key: "appendChild",
    value: function appendChild(parent, newChild) {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(ShadowDomRenderer.prototype), "appendChild", this).call(this, this.nodeOrShadowRoot(parent), newChild);
    }
  }, {
    key: "insertBefore",
    value: function insertBefore(parent, newChild, refChild) {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(ShadowDomRenderer.prototype), "insertBefore", this).call(this, this.nodeOrShadowRoot(parent), newChild, refChild);
    }
  }, {
    key: "removeChild",
    value: function removeChild(parent, oldChild) {
      return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(ShadowDomRenderer.prototype), "removeChild", this).call(this, this.nodeOrShadowRoot(parent), oldChild);
    }
  }, {
    key: "parentNode",
    value: function parentNode(node) {
      return this.nodeOrShadowRoot(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(ShadowDomRenderer.prototype), "parentNode", this).call(this, this.nodeOrShadowRoot(node)));
    }
  }]);

  return ShadowDomRenderer;
}(DefaultDomRenderer2);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var DomEventsPlugin = /*#__PURE__*/function (_EventManagerPlugin) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(DomEventsPlugin, _EventManagerPlugin);

  var _super6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(DomEventsPlugin);

  function DomEventsPlugin(doc) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DomEventsPlugin);

    return _super6.call(this, doc);
  } // This plugin should come last in the list of plugins, because it accepts all
  // events.


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DomEventsPlugin, [{
    key: "supports",
    value: function supports(eventName) {
      return true;
    }
  }, {
    key: "addEventListener",
    value: function addEventListener(element, eventName, handler) {
      var _this8 = this;

      element.addEventListener(eventName, handler, false);
      return function () {
        return _this8.removeEventListener(element, eventName, handler);
      };
    }
  }, {
    key: "removeEventListener",
    value: function removeEventListener(target, eventName, callback) {
      return target.removeEventListener(eventName, callback);
    }
  }]);

  return DomEventsPlugin;
}(EventManagerPlugin);

DomEventsPlugin.ɵfac = function DomEventsPlugin_Factory(t) {
  return new (t || DomEventsPlugin)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
};

DomEventsPlugin.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: DomEventsPlugin,
  factory: DomEventsPlugin.ɵfac
});

DomEventsPlugin.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](DomEventsPlugin, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Supported HammerJS recognizer event names.
 */


var EVENT_NAMES = {
  // pan
  'pan': true,
  'panstart': true,
  'panmove': true,
  'panend': true,
  'pancancel': true,
  'panleft': true,
  'panright': true,
  'panup': true,
  'pandown': true,
  // pinch
  'pinch': true,
  'pinchstart': true,
  'pinchmove': true,
  'pinchend': true,
  'pinchcancel': true,
  'pinchin': true,
  'pinchout': true,
  // press
  'press': true,
  'pressup': true,
  // rotate
  'rotate': true,
  'rotatestart': true,
  'rotatemove': true,
  'rotateend': true,
  'rotatecancel': true,
  // swipe
  'swipe': true,
  'swipeleft': true,
  'swiperight': true,
  'swipeup': true,
  'swipedown': true,
  // tap
  'tap': true
};
/**
 * DI token for providing [HammerJS](http://hammerjs.github.io/) support to Angular.
 * @see `HammerGestureConfig`
 *
 * @ngModule HammerModule
 * @publicApi
 */

var HAMMER_GESTURE_CONFIG = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('HammerGestureConfig');
/**
 * Injection token used to provide a {@link HammerLoader} to Angular.
 *
 * @publicApi
 */

var HAMMER_LOADER = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["InjectionToken"]('HammerLoader');
/**
 * An injectable [HammerJS Manager](http://hammerjs.github.io/api/#hammer.manager)
 * for gesture recognition. Configures specific event recognition.
 * @publicApi
 */

var HammerGestureConfig = /*#__PURE__*/function () {
  function HammerGestureConfig() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, HammerGestureConfig);

    /**
     * A set of supported event names for gestures to be used in Angular.
     * Angular supports all built-in recognizers, as listed in
     * [HammerJS documentation](http://hammerjs.github.io/).
     */
    this.events = [];
    /**
     * Maps gesture event names to a set of configuration options
     * that specify overrides to the default values for specific properties.
     *
     * The key is a supported event name to be configured,
     * and the options object contains a set of properties, with override values
     * to be applied to the named recognizer event.
     * For example, to disable recognition of the rotate event, specify
     *  `{"rotate": {"enable": false}}`.
     *
     * Properties that are not present take the HammerJS default values.
     * For information about which properties are supported for which events,
     * and their allowed and default values, see
     * [HammerJS documentation](http://hammerjs.github.io/).
     *
     */

    this.overrides = {};
  }
  /**
   * Creates a [HammerJS Manager](http://hammerjs.github.io/api/#hammer.manager)
   * and attaches it to a given HTML element.
   * @param element The element that will recognize gestures.
   * @returns A HammerJS event-manager object.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(HammerGestureConfig, [{
    key: "buildHammer",
    value: function buildHammer(element) {
      var mc = new Hammer(element, this.options);
      mc.get('pinch').set({
        enable: true
      });
      mc.get('rotate').set({
        enable: true
      });

      for (var eventName in this.overrides) {
        mc.get(eventName).set(this.overrides[eventName]);
      }

      return mc;
    }
  }]);

  return HammerGestureConfig;
}();

HammerGestureConfig.ɵfac = function HammerGestureConfig_Factory(t) {
  return new (t || HammerGestureConfig)();
};

HammerGestureConfig.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: HammerGestureConfig,
  factory: HammerGestureConfig.ɵfac
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](HammerGestureConfig, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [];
  }, null);
})();
/**
 * Event plugin that adds Hammer support to an application.
 *
 * @ngModule HammerModule
 */


var HammerGesturesPlugin = /*#__PURE__*/function (_EventManagerPlugin2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(HammerGesturesPlugin, _EventManagerPlugin2);

  var _super7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(HammerGesturesPlugin);

  function HammerGesturesPlugin(doc, _config, console, loader) {
    var _this9;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, HammerGesturesPlugin);

    _this9 = _super7.call(this, doc);
    _this9._config = _config;
    _this9.console = console;
    _this9.loader = loader;
    return _this9;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(HammerGesturesPlugin, [{
    key: "supports",
    value: function supports(eventName) {
      if (!EVENT_NAMES.hasOwnProperty(eventName.toLowerCase()) && !this.isCustomEvent(eventName)) {
        return false;
      }

      if (!window.Hammer && !this.loader) {
        this.console.warn("The \"".concat(eventName, "\" event cannot be bound because Hammer.JS is not ") + "loaded and no custom loader has been specified.");
        return false;
      }

      return true;
    }
  }, {
    key: "addEventListener",
    value: function addEventListener(element, eventName, handler) {
      var _this10 = this;

      var zone = this.manager.getZone();
      eventName = eventName.toLowerCase(); // If Hammer is not present but a loader is specified, we defer adding the event listener
      // until Hammer is loaded.

      if (!window.Hammer && this.loader) {
        // This `addEventListener` method returns a function to remove the added listener.
        // Until Hammer is loaded, the returned function needs to *cancel* the registration rather
        // than remove anything.
        var cancelRegistration = false;

        var deregister = function deregister() {
          cancelRegistration = true;
        };

        this.loader().then(function () {
          // If Hammer isn't actually loaded when the custom loader resolves, give up.
          if (!window.Hammer) {
            _this10.console.warn("The custom HAMMER_LOADER completed, but Hammer.JS is not present.");

            deregister = function deregister() {};

            return;
          }

          if (!cancelRegistration) {
            // Now that Hammer is loaded and the listener is being loaded for real,
            // the deregistration function changes from canceling registration to removal.
            deregister = _this10.addEventListener(element, eventName, handler);
          }
        }).catch(function () {
          _this10.console.warn("The \"".concat(eventName, "\" event cannot be bound because the custom ") + "Hammer.JS loader failed.");

          deregister = function deregister() {};
        }); // Return a function that *executes* `deregister` (and not `deregister` itself) so that we
        // can change the behavior of `deregister` once the listener is added. Using a closure in
        // this way allows us to avoid any additional data structures to track listener removal.

        return function () {
          deregister();
        };
      }

      return zone.runOutsideAngular(function () {
        // Creating the manager bind events, must be done outside of angular
        var mc = _this10._config.buildHammer(element);

        var callback = function callback(eventObj) {
          zone.runGuarded(function () {
            handler(eventObj);
          });
        };

        mc.on(eventName, callback);
        return function () {
          mc.off(eventName, callback); // destroy mc to prevent memory leak

          if (typeof mc.destroy === 'function') {
            mc.destroy();
          }
        };
      });
    }
  }, {
    key: "isCustomEvent",
    value: function isCustomEvent(eventName) {
      return this._config.events.indexOf(eventName) > -1;
    }
  }]);

  return HammerGesturesPlugin;
}(EventManagerPlugin);

HammerGesturesPlugin.ɵfac = function HammerGesturesPlugin_Factory(t) {
  return new (t || HammerGesturesPlugin)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](HAMMER_GESTURE_CONFIG), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵConsole"]), _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](HAMMER_LOADER, 8));
};

HammerGesturesPlugin.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: HammerGesturesPlugin,
  factory: HammerGesturesPlugin.ɵfac
});

HammerGesturesPlugin.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }, {
    type: HammerGestureConfig,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [HAMMER_GESTURE_CONFIG]
    }]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵConsole"]
  }, {
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [HAMMER_LOADER]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](HammerGesturesPlugin, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }, {
      type: HammerGestureConfig,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [HAMMER_GESTURE_CONFIG]
      }]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵConsole"]
    }, {
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [HAMMER_LOADER]
      }]
    }];
  }, null);
})();
/**
 * In Ivy, support for Hammer gestures is optional, so applications must
 * import the `HammerModule` at root to turn on support. This means that
 * Hammer-specific code can be tree-shaken away if not needed.
 */


var HAMMER_PROVIDERS__POST_R3__ = [];
/**
 * In View Engine, support for Hammer gestures is built-in by default.
 */

var HAMMER_PROVIDERS__PRE_R3__ = [{
  provide: EVENT_MANAGER_PLUGINS,
  useClass: HammerGesturesPlugin,
  multi: true,
  deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"], HAMMER_GESTURE_CONFIG, _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵConsole"], [new _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"](), HAMMER_LOADER]]
}, {
  provide: HAMMER_GESTURE_CONFIG,
  useClass: HammerGestureConfig,
  deps: []
}];
var HAMMER_PROVIDERS = HAMMER_PROVIDERS__POST_R3__;
/**
 * Adds support for HammerJS.
 *
 * Import this module at the root of your application so that Angular can work with
 * HammerJS to detect gesture events.
 *
 * Note that applications still need to include the HammerJS script itself. This module
 * simply sets up the coordination layer between HammerJS and Angular's EventManager.
 *
 * @publicApi
 */

var HammerModule = function HammerModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, HammerModule);
};

HammerModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineNgModule"]({
  type: HammerModule
});
HammerModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjector"]({
  factory: function HammerModule_Factory(t) {
    return new (t || HammerModule)();
  },
  providers: HAMMER_PROVIDERS__PRE_R3__
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](HammerModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgModule"],
    args: [{
      providers: HAMMER_PROVIDERS__PRE_R3__
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Defines supported modifiers for key events.
 */


var MODIFIER_KEYS = ['alt', 'control', 'meta', 'shift'];
var DOM_KEY_LOCATION_NUMPAD = 3; // Map to convert some key or keyIdentifier values to what will be returned by getEventKey

var _keyMap = {
  // The following values are here for cross-browser compatibility and to match the W3C standard
  // cf http://www.w3.org/TR/DOM-Level-3-Events-key/
  '\b': 'Backspace',
  '\t': 'Tab',
  '\x7F': 'Delete',
  '\x1B': 'Escape',
  'Del': 'Delete',
  'Esc': 'Escape',
  'Left': 'ArrowLeft',
  'Right': 'ArrowRight',
  'Up': 'ArrowUp',
  'Down': 'ArrowDown',
  'Menu': 'ContextMenu',
  'Scroll': 'ScrollLock',
  'Win': 'OS'
}; // There is a bug in Chrome for numeric keypad keys:
// https://code.google.com/p/chromium/issues/detail?id=155654
// 1, 2, 3 ... are reported as A, B, C ...

var _chromeNumKeyPadMap = {
  'A': '1',
  'B': '2',
  'C': '3',
  'D': '4',
  'E': '5',
  'F': '6',
  'G': '7',
  'H': '8',
  'I': '9',
  'J': '*',
  'K': '+',
  'M': '-',
  'N': '.',
  'O': '/',
  '\x60': '0',
  '\x90': 'NumLock'
};

var ɵ0$3 = function ɵ0$3(event) {
  return event.altKey;
},
    ɵ1 = function ɵ1(event) {
  return event.ctrlKey;
},
    ɵ2 = function ɵ2(event) {
  return event.metaKey;
},
    ɵ3 = function ɵ3(event) {
  return event.shiftKey;
};
/**
 * Retrieves modifiers from key-event objects.
 */


var MODIFIER_KEY_GETTERS = {
  'alt': ɵ0$3,
  'control': ɵ1,
  'meta': ɵ2,
  'shift': ɵ3
};
/**
 * @publicApi
 * A browser plug-in that provides support for handling of key events in Angular.
 */

var KeyEventsPlugin = /*#__PURE__*/function (_EventManagerPlugin3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(KeyEventsPlugin, _EventManagerPlugin3);

  var _super8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(KeyEventsPlugin);

  /**
   * Initializes an instance of the browser plug-in.
   * @param doc The document in which key events will be detected.
   */
  function KeyEventsPlugin(doc) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, KeyEventsPlugin);

    return _super8.call(this, doc);
  }
  /**
   * Reports whether a named key event is supported.
   * @param eventName The event name to query.
   * @return True if the named key event is supported.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(KeyEventsPlugin, [{
    key: "supports",
    value: function supports(eventName) {
      return KeyEventsPlugin.parseEventName(eventName) != null;
    }
    /**
     * Registers a handler for a specific element and key event.
     * @param element The HTML element to receive event notifications.
     * @param eventName The name of the key event to listen for.
     * @param handler A function to call when the notification occurs. Receives the
     * event object as an argument.
     * @returns The key event that was registered.
     */

  }, {
    key: "addEventListener",
    value: function addEventListener(element, eventName, handler) {
      var parsedEvent = KeyEventsPlugin.parseEventName(eventName);
      var outsideHandler = KeyEventsPlugin.eventCallback(parsedEvent['fullKey'], handler, this.manager.getZone());
      return this.manager.getZone().runOutsideAngular(function () {
        return Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().onAndCancel(element, parsedEvent['domEventName'], outsideHandler);
      });
    }
  }], [{
    key: "parseEventName",
    value: function parseEventName(eventName) {
      var parts = eventName.toLowerCase().split('.');
      var domEventName = parts.shift();

      if (parts.length === 0 || !(domEventName === 'keydown' || domEventName === 'keyup')) {
        return null;
      }

      var key = KeyEventsPlugin._normalizeKey(parts.pop());

      var fullKey = '';
      MODIFIER_KEYS.forEach(function (modifierName) {
        var index = parts.indexOf(modifierName);

        if (index > -1) {
          parts.splice(index, 1);
          fullKey += modifierName + '.';
        }
      });
      fullKey += key;

      if (parts.length != 0 || key.length === 0) {
        // returning null instead of throwing to let another plugin process the event
        return null;
      } // NOTE: Please don't rewrite this as so, as it will break JSCompiler property renaming.
      //       The code must remain in the `result['domEventName']` form.
      // return {domEventName, fullKey};


      var result = {};
      result['domEventName'] = domEventName;
      result['fullKey'] = fullKey;
      return result;
    }
  }, {
    key: "getEventFullKey",
    value: function getEventFullKey(event) {
      var fullKey = '';
      var key = getEventKey(event);
      key = key.toLowerCase();

      if (key === ' ') {
        key = 'space'; // for readability
      } else if (key === '.') {
        key = 'dot'; // because '.' is used as a separator in event names
      }

      MODIFIER_KEYS.forEach(function (modifierName) {
        if (modifierName != key) {
          var modifierGetter = MODIFIER_KEY_GETTERS[modifierName];

          if (modifierGetter(event)) {
            fullKey += modifierName + '.';
          }
        }
      });
      fullKey += key;
      return fullKey;
    }
    /**
     * Configures a handler callback for a key event.
     * @param fullKey The event name that combines all simultaneous keystrokes.
     * @param handler The function that responds to the key event.
     * @param zone The zone in which the event occurred.
     * @returns A callback function.
     */

  }, {
    key: "eventCallback",
    value: function eventCallback(fullKey, handler, zone) {
      return function (event
      /** TODO #9100 */
      ) {
        if (KeyEventsPlugin.getEventFullKey(event) === fullKey) {
          zone.runGuarded(function () {
            return handler(event);
          });
        }
      };
    }
    /** @internal */

  }, {
    key: "_normalizeKey",
    value: function _normalizeKey(keyName) {
      // TODO: switch to a Map if the mapping grows too much
      switch (keyName) {
        case 'esc':
          return 'escape';

        default:
          return keyName;
      }
    }
  }]);

  return KeyEventsPlugin;
}(EventManagerPlugin);

KeyEventsPlugin.ɵfac = function KeyEventsPlugin_Factory(t) {
  return new (t || KeyEventsPlugin)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
};

KeyEventsPlugin.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: KeyEventsPlugin,
  factory: KeyEventsPlugin.ɵfac
});

KeyEventsPlugin.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](KeyEventsPlugin, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }];
  }, null);
})();

function getEventKey(event) {
  var key = event.key;

  if (key == null) {
    key = event.keyIdentifier; // keyIdentifier is defined in the old draft of DOM Level 3 Events implemented by Chrome and
    // Safari cf
    // http://www.w3.org/TR/2007/WD-DOM-Level-3-Events-20071221/events.html#Events-KeyboardEvents-Interfaces

    if (key == null) {
      return 'Unidentified';
    }

    if (key.startsWith('U+')) {
      key = String.fromCharCode(parseInt(key.substring(2), 16));

      if (event.location === DOM_KEY_LOCATION_NUMPAD && _chromeNumKeyPadMap.hasOwnProperty(key)) {
        // There is a bug in Chrome for numeric keypad keys:
        // https://code.google.com/p/chromium/issues/detail?id=155654
        // 1, 2, 3 ... are reported as A, B, C ...
        key = _chromeNumKeyPadMap[key];
      }
    }
  }

  return _keyMap[key] || key;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * DomSanitizer helps preventing Cross Site Scripting Security bugs (XSS) by sanitizing
 * values to be safe to use in the different DOM contexts.
 *
 * For example, when binding a URL in an `<a [href]="someValue">` hyperlink, `someValue` will be
 * sanitized so that an attacker cannot inject e.g. a `javascript:` URL that would execute code on
 * the website.
 *
 * In specific situations, it might be necessary to disable sanitization, for example if the
 * application genuinely needs to produce a `javascript:` style link with a dynamic value in it.
 * Users can bypass security by constructing a value with one of the `bypassSecurityTrust...`
 * methods, and then binding to that value from the template.
 *
 * These situations should be very rare, and extraordinary care must be taken to avoid creating a
 * Cross Site Scripting (XSS) security bug!
 *
 * When using `bypassSecurityTrust...`, make sure to call the method as early as possible and as
 * close as possible to the source of the value, to make it easy to verify no security bug is
 * created by its use.
 *
 * It is not required (and not recommended) to bypass security if the value is safe, e.g. a URL that
 * does not start with a suspicious protocol, or an HTML snippet that does not contain dangerous
 * code. The sanitizer leaves safe values intact.
 *
 * @security Calling any of the `bypassSecurityTrust...` APIs disables Angular's built-in
 * sanitization for the value passed in. Carefully check and audit all values and code paths going
 * into this call. Make sure any user data is appropriately escaped for this security context.
 * For more detail, see the [Security Guide](http://g.co/ng/security).
 *
 * @publicApi
 */


var DomSanitizer = function DomSanitizer() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DomSanitizer);
};

DomSanitizer.ɵfac = function DomSanitizer_Factory(t) {
  return new (t || DomSanitizer)();
};

DomSanitizer.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"])({
  factory: function DomSanitizer_Factory() {
    return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"])(DomSanitizerImpl);
  },
  token: DomSanitizer,
  providedIn: "root"
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](DomSanitizer, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"],
    args: [{
      providedIn: 'root',
      useExisting: Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["forwardRef"])(function () {
        return DomSanitizerImpl;
      })
    }]
  }], null, null);
})();

function domSanitizerImplFactory(injector) {
  return new DomSanitizerImpl(injector.get(_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
}

var DomSanitizerImpl = /*#__PURE__*/function (_DomSanitizer) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(DomSanitizerImpl, _DomSanitizer);

  var _super9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(DomSanitizerImpl);

  function DomSanitizerImpl(_doc) {
    var _this11;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DomSanitizerImpl);

    _this11 = _super9.call(this);
    _this11._doc = _doc;
    return _this11;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DomSanitizerImpl, [{
    key: "sanitize",
    value: function sanitize(ctx, value) {
      if (value == null) return null;

      switch (ctx) {
        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["SecurityContext"].NONE:
          return value;

        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["SecurityContext"].HTML:
          if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵallowSanitizationBypassAndThrow"])(value, "HTML"
          /* Html */
          )) {
            return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵunwrapSafeValue"])(value);
          }

          return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵ_sanitizeHtml"])(this._doc, String(value));

        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["SecurityContext"].STYLE:
          if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵallowSanitizationBypassAndThrow"])(value, "Style"
          /* Style */
          )) {
            return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵunwrapSafeValue"])(value);
          }

          return value;

        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["SecurityContext"].SCRIPT:
          if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵallowSanitizationBypassAndThrow"])(value, "Script"
          /* Script */
          )) {
            return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵunwrapSafeValue"])(value);
          }

          throw new Error('unsafe value used in a script context');

        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["SecurityContext"].URL:
          var type = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵgetSanitizationBypassType"])(value);

          if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵallowSanitizationBypassAndThrow"])(value, "URL"
          /* Url */
          )) {
            return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵunwrapSafeValue"])(value);
          }

          return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵ_sanitizeUrl"])(String(value));

        case _angular_core__WEBPACK_IMPORTED_MODULE_7__["SecurityContext"].RESOURCE_URL:
          if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵallowSanitizationBypassAndThrow"])(value, "ResourceURL"
          /* ResourceUrl */
          )) {
            return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵunwrapSafeValue"])(value);
          }

          throw new Error('unsafe value used in a resource URL context (see http://g.co/ng/security#xss)');

        default:
          throw new Error("Unexpected SecurityContext ".concat(ctx, " (see http://g.co/ng/security#xss)"));
      }
    }
  }, {
    key: "bypassSecurityTrustHtml",
    value: function bypassSecurityTrustHtml(value) {
      return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵbypassSanitizationTrustHtml"])(value);
    }
  }, {
    key: "bypassSecurityTrustStyle",
    value: function bypassSecurityTrustStyle(value) {
      return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵbypassSanitizationTrustStyle"])(value);
    }
  }, {
    key: "bypassSecurityTrustScript",
    value: function bypassSecurityTrustScript(value) {
      return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵbypassSanitizationTrustScript"])(value);
    }
  }, {
    key: "bypassSecurityTrustUrl",
    value: function bypassSecurityTrustUrl(value) {
      return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵbypassSanitizationTrustUrl"])(value);
    }
  }, {
    key: "bypassSecurityTrustResourceUrl",
    value: function bypassSecurityTrustResourceUrl(value) {
      return Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵbypassSanitizationTrustResourceUrl"])(value);
    }
  }]);

  return DomSanitizerImpl;
}(DomSanitizer);

DomSanitizerImpl.ɵfac = function DomSanitizerImpl_Factory(t) {
  return new (t || DomSanitizerImpl)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
};

DomSanitizerImpl.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"])({
  factory: function DomSanitizerImpl_Factory() {
    return domSanitizerImplFactory(Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"])(_angular_core__WEBPACK_IMPORTED_MODULE_7__["INJECTOR"]));
  },
  token: DomSanitizerImpl,
  providedIn: "root"
});

DomSanitizerImpl.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](DomSanitizerImpl, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"],
    args: [{
      providedIn: 'root',
      useFactory: domSanitizerImplFactory,
      deps: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["Injector"]]
    }]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function initDomAdapter() {
  BrowserDomAdapter.makeCurrent();
  BrowserGetTestability.init();
}

function errorHandler() {
  return new _angular_core__WEBPACK_IMPORTED_MODULE_7__["ErrorHandler"]();
}

function _document() {
  // Tell ivy about the global document
  Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetDocument"])(document);
  return document;
}

var ɵ0$4 = _angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵPLATFORM_BROWSER_ID"];
var INTERNAL_BROWSER_PLATFORM_PROVIDERS = [{
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["PLATFORM_ID"],
  useValue: ɵ0$4
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["PLATFORM_INITIALIZER"],
  useValue: initDomAdapter,
  multi: true
}, {
  provide: _angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"],
  useFactory: _document,
  deps: []
}];
var BROWSER_SANITIZATION_PROVIDERS__PRE_R3__ = [{
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Sanitizer"],
  useExisting: DomSanitizer
}, {
  provide: DomSanitizer,
  useClass: DomSanitizerImpl,
  deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
}];
var BROWSER_SANITIZATION_PROVIDERS__POST_R3__ = [];
/**
 * @security Replacing built-in sanitization providers exposes the application to XSS risks.
 * Attacker-controlled data introduced by an unsanitized provider could expose your
 * application to XSS risks. For more detail, see the [Security Guide](http://g.co/ng/security).
 * @publicApi
 */

var BROWSER_SANITIZATION_PROVIDERS = BROWSER_SANITIZATION_PROVIDERS__POST_R3__;
/**
 * A factory function that returns a `PlatformRef` instance associated with browser service
 * providers.
 *
 * @publicApi
 */

var platformBrowser = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["createPlatformFactory"])(_angular_core__WEBPACK_IMPORTED_MODULE_7__["platformCore"], 'browser', INTERNAL_BROWSER_PLATFORM_PROVIDERS);
var BROWSER_MODULE_PROVIDERS = [BROWSER_SANITIZATION_PROVIDERS, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵINJECTOR_SCOPE"],
  useValue: 'root'
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["ErrorHandler"],
  useFactory: errorHandler,
  deps: []
}, {
  provide: EVENT_MANAGER_PLUGINS,
  useClass: DomEventsPlugin,
  multi: true,
  deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["PLATFORM_ID"]]
}, {
  provide: EVENT_MANAGER_PLUGINS,
  useClass: KeyEventsPlugin,
  multi: true,
  deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
}, HAMMER_PROVIDERS, {
  provide: DomRendererFactory2,
  useClass: DomRendererFactory2,
  deps: [EventManager, DomSharedStylesHost, _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]]
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["RendererFactory2"],
  useExisting: DomRendererFactory2
}, {
  provide: SharedStylesHost,
  useExisting: DomSharedStylesHost
}, {
  provide: DomSharedStylesHost,
  useClass: DomSharedStylesHost,
  deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Testability"],
  useClass: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Testability"],
  deps: [_angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"]]
}, {
  provide: EventManager,
  useClass: EventManager,
  deps: [EVENT_MANAGER_PLUGINS, _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgZone"]]
}, ELEMENT_PROBE_PROVIDERS];
/**
 * Exports required infrastructure for all Angular apps.
 * Included by default in all Angular apps created with the CLI
 * `new` command.
 * Re-exports `CommonModule` and `ApplicationModule`, making their
 * exports and providers available to all apps.
 *
 * @publicApi
 */

var BrowserModule = /*#__PURE__*/function () {
  function BrowserModule(parentModule) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, BrowserModule);

    if (parentModule) {
      throw new Error("BrowserModule has already been loaded. If you need access to common directives such as NgIf and NgFor from a lazy loaded module, import CommonModule instead.");
    }
  }
  /**
   * Configures a browser-based app to transition from a server-rendered app, if
   * one is present on the page.
   *
   * @param params An object containing an identifier for the app to transition.
   * The ID must match between the client and server versions of the app.
   * @returns The reconfigured `BrowserModule` to import into the app's root `AppModule`.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(BrowserModule, null, [{
    key: "withServerTransition",
    value: function withServerTransition(params) {
      return {
        ngModule: BrowserModule,
        providers: [{
          provide: _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"],
          useValue: params.appId
        }, {
          provide: TRANSITION_ID,
          useExisting: _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]
        }, SERVER_TRANSITION_PROVIDERS]
      };
    }
  }]);

  return BrowserModule;
}();

BrowserModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineNgModule"]({
  type: BrowserModule
});
BrowserModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjector"]({
  factory: function BrowserModule_Factory(t) {
    return new (t || BrowserModule)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](BrowserModule, 12));
  },
  providers: BROWSER_MODULE_PROVIDERS,
  imports: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["CommonModule"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ApplicationModule"]]
});

BrowserModule.ctorParameters = function () {
  return [{
    type: BrowserModule,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [BrowserModule]
    }]
  }];
};

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵsetNgModuleScope"](BrowserModule, {
    exports: function exports() {
      return [_angular_common__WEBPACK_IMPORTED_MODULE_6__["CommonModule"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ApplicationModule"]];
    }
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](BrowserModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgModule"],
    args: [{
      providers: BROWSER_MODULE_PROVIDERS,
      exports: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["CommonModule"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["ApplicationModule"]]
    }]
  }], function () {
    return [{
      type: BrowserModule,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["SkipSelf"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [BrowserModule]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Factory to create a `Meta` service instance for the current DOM document.
 */


function createMeta() {
  return new Meta(Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"])(_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
}
/**
 * A service for managing HTML `<meta>` tags.
 *
 * Properties of the `MetaDefinition` object match the attributes of the
 * HTML `<meta>` tag. These tags define document metadata that is important for
 * things like configuring a Content Security Policy, defining browser compatibility
 * and security settings, setting HTTP Headers, defining rich content for social sharing,
 * and Search Engine Optimization (SEO).
 *
 * To identify specific `<meta>` tags in a document, use an attribute selection
 * string in the format `"tag_attribute='value string'"`.
 * For example, an `attrSelector` value of `"name='description'"` matches a tag
 * whose `name` attribute has the value `"description"`.
 * Selectors are used with the `querySelector()` Document method,
 * in the format `meta[{attrSelector}]`.
 *
 * @see [HTML meta tag](https://developer.mozilla.org/docs/Web/HTML/Element/meta)
 * @see [Document.querySelector()](https://developer.mozilla.org/docs/Web/API/Document/querySelector)
 *
 *
 * @publicApi
 */


var Meta = /*#__PURE__*/function () {
  function Meta(_doc) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, Meta);

    this._doc = _doc;
    this._dom = Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])();
  }
  /**
   * Retrieves or creates a specific `<meta>` tag element in the current HTML document.
   * In searching for an existing tag, Angular attempts to match the `name` or `property` attribute
   * values in the provided tag definition, and verifies that all other attribute values are equal.
   * If an existing element is found, it is returned and is not modified in any way.
   * @param tag The definition of a `<meta>` element to match or create.
   * @param forceCreation True to create a new element without checking whether one already exists.
   * @returns The existing element with the same attributes and values if found,
   * the new element if no match is found, or `null` if the tag parameter is not defined.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(Meta, [{
    key: "addTag",
    value: function addTag(tag) {
      var forceCreation = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      if (!tag) return null;
      return this._getOrCreateElement(tag, forceCreation);
    }
    /**
     * Retrieves or creates a set of `<meta>` tag elements in the current HTML document.
     * In searching for an existing tag, Angular attempts to match the `name` or `property` attribute
     * values in the provided tag definition, and verifies that all other attribute values are equal.
     * @param tags An array of tag definitions to match or create.
     * @param forceCreation True to create new elements without checking whether they already exist.
     * @returns The matching elements if found, or the new elements.
     */

  }, {
    key: "addTags",
    value: function addTags(tags) {
      var _this12 = this;

      var forceCreation = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      if (!tags) return [];
      return tags.reduce(function (result, tag) {
        if (tag) {
          result.push(_this12._getOrCreateElement(tag, forceCreation));
        }

        return result;
      }, []);
    }
    /**
     * Retrieves a `<meta>` tag element in the current HTML document.
     * @param attrSelector The tag attribute and value to match against, in the format
     * `"tag_attribute='value string'"`.
     * @returns The matching element, if any.
     */

  }, {
    key: "getTag",
    value: function getTag(attrSelector) {
      if (!attrSelector) return null;
      return this._doc.querySelector("meta[".concat(attrSelector, "]")) || null;
    }
    /**
     * Retrieves a set of `<meta>` tag elements in the current HTML document.
     * @param attrSelector The tag attribute and value to match against, in the format
     * `"tag_attribute='value string'"`.
     * @returns The matching elements, if any.
     */

  }, {
    key: "getTags",
    value: function getTags(attrSelector) {
      if (!attrSelector) return [];

      var list
      /*NodeList*/
      = this._doc.querySelectorAll("meta[".concat(attrSelector, "]"));

      return list ? [].slice.call(list) : [];
    }
    /**
     * Modifies an existing `<meta>` tag element in the current HTML document.
     * @param tag The tag description with which to replace the existing tag content.
     * @param selector A tag attribute and value to match against, to identify
     * an existing tag. A string in the format `"tag_attribute=`value string`"`.
     * If not supplied, matches a tag with the same `name` or `property` attribute value as the
     * replacement tag.
     * @return The modified element.
     */

  }, {
    key: "updateTag",
    value: function updateTag(tag, selector) {
      if (!tag) return null;
      selector = selector || this._parseSelector(tag);
      var meta = this.getTag(selector);

      if (meta) {
        return this._setMetaElementAttributes(tag, meta);
      }

      return this._getOrCreateElement(tag, true);
    }
    /**
     * Removes an existing `<meta>` tag element from the current HTML document.
     * @param attrSelector A tag attribute and value to match against, to identify
     * an existing tag. A string in the format `"tag_attribute=`value string`"`.
     */

  }, {
    key: "removeTag",
    value: function removeTag(attrSelector) {
      this.removeTagElement(this.getTag(attrSelector));
    }
    /**
     * Removes an existing `<meta>` tag element from the current HTML document.
     * @param meta The tag definition to match against to identify an existing tag.
     */

  }, {
    key: "removeTagElement",
    value: function removeTagElement(meta) {
      if (meta) {
        this._dom.remove(meta);
      }
    }
  }, {
    key: "_getOrCreateElement",
    value: function _getOrCreateElement(meta) {
      var forceCreation = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

      if (!forceCreation) {
        var selector = this._parseSelector(meta);

        var elem = this.getTag(selector); // It's allowed to have multiple elements with the same name so it's not enough to
        // just check that element with the same name already present on the page. We also need to
        // check if element has tag attributes

        if (elem && this._containsAttributes(meta, elem)) return elem;
      }

      var element = this._dom.createElement('meta');

      this._setMetaElementAttributes(meta, element);

      var head = this._doc.getElementsByTagName('head')[0];

      head.appendChild(element);
      return element;
    }
  }, {
    key: "_setMetaElementAttributes",
    value: function _setMetaElementAttributes(tag, el) {
      Object.keys(tag).forEach(function (prop) {
        return el.setAttribute(prop, tag[prop]);
      });
      return el;
    }
  }, {
    key: "_parseSelector",
    value: function _parseSelector(tag) {
      var attr = tag.name ? 'name' : 'property';
      return "".concat(attr, "=\"").concat(tag[attr], "\"");
    }
  }, {
    key: "_containsAttributes",
    value: function _containsAttributes(tag, elem) {
      return Object.keys(tag).every(function (key) {
        return elem.getAttribute(key) === tag[key];
      });
    }
  }]);

  return Meta;
}();

Meta.ɵfac = function Meta_Factory(t) {
  return new (t || Meta)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
};

Meta.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"])({
  factory: createMeta,
  token: Meta,
  providedIn: "root"
});

Meta.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](Meta, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"],
    args: [{
      providedIn: 'root',
      useFactory: createMeta,
      deps: []
    }]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Factory to create Title service.
 */


function createTitle() {
  return new Title(Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"])(_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
}
/**
 * A service that can be used to get and set the title of a current HTML document.
 *
 * Since an Angular application can't be bootstrapped on the entire HTML document (`<html>` tag)
 * it is not possible to bind to the `text` property of the `HTMLTitleElement` elements
 * (representing the `<title>` tag). Instead, this service can be used to set and get the current
 * title value.
 *
 * @publicApi
 */


var Title = /*#__PURE__*/function () {
  function Title(_doc) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, Title);

    this._doc = _doc;
  }
  /**
   * Get the title of the current HTML document.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(Title, [{
    key: "getTitle",
    value: function getTitle() {
      return this._doc.title;
    }
    /**
     * Set the title of the current HTML document.
     * @param newTitle
     */

  }, {
    key: "setTitle",
    value: function setTitle(newTitle) {
      this._doc.title = newTitle || '';
    }
  }]);

  return Title;
}();

Title.ɵfac = function Title_Factory(t) {
  return new (t || Title)(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]));
};

Title.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"])({
  factory: createTitle,
  token: Title,
  providedIn: "root"
});

Title.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](Title, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"],
    args: [{
      providedIn: 'root',
      useFactory: createTitle,
      deps: []
    }]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var win = typeof window !== 'undefined' && window || {};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

var ChangeDetectionPerfRecord = function ChangeDetectionPerfRecord(msPerTick, numTicks) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ChangeDetectionPerfRecord);

  this.msPerTick = msPerTick;
  this.numTicks = numTicks;
};
/**
 * Entry point for all Angular profiling-related debug tools. This object
 * corresponds to the `ng.profiler` in the dev console.
 */


var AngularProfiler = /*#__PURE__*/function () {
  function AngularProfiler(ref) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, AngularProfiler);

    this.appRef = ref.injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_7__["ApplicationRef"]);
  } // tslint:disable:no-console

  /**
   * Exercises change detection in a loop and then prints the average amount of
   * time in milliseconds how long a single round of change detection takes for
   * the current state of the UI. It runs a minimum of 5 rounds for a minimum
   * of 500 milliseconds.
   *
   * Optionally, a user may pass a `config` parameter containing a map of
   * options. Supported options are:
   *
   * `record` (boolean) - causes the profiler to record a CPU profile while
   * it exercises the change detector. Example:
   *
   * ```
   * ng.profiler.timeChangeDetection({record: true})
   * ```
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(AngularProfiler, [{
    key: "timeChangeDetection",
    value: function timeChangeDetection(config) {
      var record = config && config['record'];
      var profileName = 'Change Detection'; // Profiler is not available in Android browsers, nor in IE 9 without dev tools opened

      var isProfilerAvailable = win.console.profile != null;

      if (record && isProfilerAvailable) {
        win.console.profile(profileName);
      }

      var start = Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().performanceNow();
      var numTicks = 0;

      while (numTicks < 5 || Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().performanceNow() - start < 500) {
        this.appRef.tick();
        numTicks++;
      }

      var end = Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().performanceNow();

      if (record && isProfilerAvailable) {
        win.console.profileEnd(profileName);
      }

      var msPerTick = (end - start) / numTicks;
      win.console.log("ran ".concat(numTicks, " change detection cycles"));
      win.console.log("".concat(msPerTick.toFixed(2), " ms per check"));
      return new ChangeDetectionPerfRecord(msPerTick, numTicks);
    }
  }]);

  return AngularProfiler;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var PROFILER_GLOBAL_NAME = 'profiler';
/**
 * Enabled Angular debug tools that are accessible via your browser's
 * developer console.
 *
 * Usage:
 *
 * 1. Open developer console (e.g. in Chrome Ctrl + Shift + j)
 * 1. Type `ng.` (usually the console will show auto-complete suggestion)
 * 1. Try the change detection profiler `ng.profiler.timeChangeDetection()`
 *    then hit Enter.
 *
 * @publicApi
 */

function enableDebugTools(ref) {
  exportNgVar(PROFILER_GLOBAL_NAME, new AngularProfiler(ref));
  return ref;
}
/**
 * Disables Angular tools.
 *
 * @publicApi
 */


function disableDebugTools() {
  exportNgVar(PROFILER_GLOBAL_NAME, null);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function escapeHtml(text) {
  var escapedText = {
    '&': '&a;',
    '"': '&q;',
    '\'': '&s;',
    '<': '&l;',
    '>': '&g;'
  };
  return text.replace(/[&"'<>]/g, function (s) {
    return escapedText[s];
  });
}

function unescapeHtml(text) {
  var unescapedText = {
    '&a;': '&',
    '&q;': '"',
    '&s;': '\'',
    '&l;': '<',
    '&g;': '>'
  };
  return text.replace(/&[^;]+;/g, function (s) {
    return unescapedText[s];
  });
}
/**
 * Create a `StateKey<T>` that can be used to store value of type T with `TransferState`.
 *
 * Example:
 *
 * ```
 * const COUNTER_KEY = makeStateKey<number>('counter');
 * let value = 10;
 *
 * transferState.set(COUNTER_KEY, value);
 * ```
 *
 * @publicApi
 */


function makeStateKey(key) {
  return key;
}
/**
 * A key value store that is transferred from the application on the server side to the application
 * on the client side.
 *
 * `TransferState` will be available as an injectable token. To use it import
 * `ServerTransferStateModule` on the server and `BrowserTransferStateModule` on the client.
 *
 * The values in the store are serialized/deserialized using JSON.stringify/JSON.parse. So only
 * boolean, number, string, null and non-class objects will be serialized and deserialzied in a
 * non-lossy manner.
 *
 * @publicApi
 */


var TransferState = /*#__PURE__*/function () {
  function TransferState() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, TransferState);

    this.store = {};
    this.onSerializeCallbacks = {};
  }
  /** @internal */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(TransferState, [{
    key: "get",

    /**
     * Get the value corresponding to a key. Return `defaultValue` if key is not found.
     */
    value: function get(key, defaultValue) {
      return this.store[key] !== undefined ? this.store[key] : defaultValue;
    }
    /**
     * Set the value corresponding to a key.
     */

  }, {
    key: "set",
    value: function set(key, value) {
      this.store[key] = value;
    }
    /**
     * Remove a key from the store.
     */

  }, {
    key: "remove",
    value: function remove(key) {
      delete this.store[key];
    }
    /**
     * Test whether a key exists in the store.
     */

  }, {
    key: "hasKey",
    value: function hasKey(key) {
      return this.store.hasOwnProperty(key);
    }
    /**
     * Register a callback to provide the value for a key when `toJson` is called.
     */

  }, {
    key: "onSerialize",
    value: function onSerialize(key, callback) {
      this.onSerializeCallbacks[key] = callback;
    }
    /**
     * Serialize the current state of the store to JSON.
     */

  }, {
    key: "toJson",
    value: function toJson() {
      // Call the onSerialize callbacks and put those values into the store.
      for (var key in this.onSerializeCallbacks) {
        if (this.onSerializeCallbacks.hasOwnProperty(key)) {
          try {
            this.store[key] = this.onSerializeCallbacks[key]();
          } catch (e) {
            console.warn('Exception in onSerialize callback: ', e);
          }
        }
      }

      return JSON.stringify(this.store);
    }
  }], [{
    key: "init",
    value: function init(initState) {
      var transferState = new TransferState();
      transferState.store = initState;
      return transferState;
    }
  }]);

  return TransferState;
}();

TransferState.ɵfac = function TransferState_Factory(t) {
  return new (t || TransferState)();
};

TransferState.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjectable"]({
  token: TransferState,
  factory: TransferState.ɵfac
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](TransferState, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["Injectable"]
  }], function () {
    return [];
  }, null);
})();

function initTransferState(doc, appId) {
  // Locate the script tag with the JSON data transferred from the server.
  // The id of the script tag is set to the Angular appId + 'state'.
  var script = doc.getElementById(appId + '-state');
  var initialState = {};

  if (script && script.textContent) {
    try {
      initialState = JSON.parse(unescapeHtml(script.textContent));
    } catch (e) {
      console.warn('Exception while restoring TransferState for app ' + appId, e);
    }
  }

  return TransferState.init(initialState);
}
/**
 * NgModule to install on the client side while using the `TransferState` to transfer state from
 * server to client.
 *
 * @publicApi
 */


var BrowserTransferStateModule = function BrowserTransferStateModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, BrowserTransferStateModule);
};

BrowserTransferStateModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineNgModule"]({
  type: BrowserTransferStateModule
});
BrowserTransferStateModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵɵdefineInjector"]({
  factory: function BrowserTransferStateModule_Factory(t) {
    return new (t || BrowserTransferStateModule)();
  },
  providers: [{
    provide: TransferState,
    useFactory: initTransferState,
    deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]]
  }]
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_7__["ɵsetClassMetadata"](BrowserTransferStateModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_7__["NgModule"],
    args: [{
      providers: [{
        provide: TransferState,
        useFactory: initTransferState,
        deps: [_angular_common__WEBPACK_IMPORTED_MODULE_6__["DOCUMENT"], _angular_core__WEBPACK_IMPORTED_MODULE_7__["APP_ID"]]
      }]
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Predicates for use with {@link DebugElement}'s query functions.
 *
 * @publicApi
 */


var By = /*#__PURE__*/function () {
  function By() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, By);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(By, null, [{
    key: "all",

    /**
     * Match all nodes.
     *
     * @usageNotes
     * ### Example
     *
     * {@example platform-browser/dom/debug/ts/by/by.ts region='by_all'}
     */
    value: function all() {
      return function () {
        return true;
      };
    }
    /**
     * Match elements by the given CSS selector.
     *
     * @usageNotes
     * ### Example
     *
     * {@example platform-browser/dom/debug/ts/by/by.ts region='by_css'}
     */

  }, {
    key: "css",
    value: function css(selector) {
      return function (debugElement) {
        return debugElement.nativeElement != null ? elementMatches(debugElement.nativeElement, selector) : false;
      };
    }
    /**
     * Match nodes that have the given directive present.
     *
     * @usageNotes
     * ### Example
     *
     * {@example platform-browser/dom/debug/ts/by/by.ts region='by_directive'}
     */

  }, {
    key: "directive",
    value: function directive(type) {
      return function (debugNode) {
        return debugNode.providerTokens.indexOf(type) !== -1;
      };
    }
  }]);

  return By;
}();

function elementMatches(n, selector) {
  if (Object(_angular_common__WEBPACK_IMPORTED_MODULE_6__["ɵgetDOM"])().isElementNode(n)) {
    return n.matches && n.matches(selector) || n.msMatchesSelector && n.msMatchesSelector(selector) || n.webkitMatchesSelector && n.webkitMatchesSelector(selector);
  }

  return false;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var VERSION = new _angular_core__WEBPACK_IMPORTED_MODULE_7__["Version"]('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */



/***/ }),

/***/ "jnO4":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ar.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Arabic [ar]
//! author : Abdel Said: https://github.com/abdelsaid
//! author : Ahmed Elkhatib
//! author : forabi https://github.com/forabi
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '١',
    2: '٢',
    3: '٣',
    4: '٤',
    5: '٥',
    6: '٦',
    7: '٧',
    8: '٨',
    9: '٩',
    0: '٠'
  },
      numberMap = {
    '١': '1',
    '٢': '2',
    '٣': '3',
    '٤': '4',
    '٥': '5',
    '٦': '6',
    '٧': '7',
    '٨': '8',
    '٩': '9',
    '٠': '0'
  },
      pluralForm = function pluralForm(n) {
    return n === 0 ? 0 : n === 1 ? 1 : n === 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5;
  },
      plurals = {
    s: ['أقل من ثانية', 'ثانية واحدة', ['ثانيتان', 'ثانيتين'], '%d ثوان', '%d ثانية', '%d ثانية'],
    m: ['أقل من دقيقة', 'دقيقة واحدة', ['دقيقتان', 'دقيقتين'], '%d دقائق', '%d دقيقة', '%d دقيقة'],
    h: ['أقل من ساعة', 'ساعة واحدة', ['ساعتان', 'ساعتين'], '%d ساعات', '%d ساعة', '%d ساعة'],
    d: ['أقل من يوم', 'يوم واحد', ['يومان', 'يومين'], '%d أيام', '%d يومًا', '%d يوم'],
    M: ['أقل من شهر', 'شهر واحد', ['شهران', 'شهرين'], '%d أشهر', '%d شهرا', '%d شهر'],
    y: ['أقل من عام', 'عام واحد', ['عامان', 'عامين'], '%d أعوام', '%d عامًا', '%d عام']
  },
      pluralize = function pluralize(u) {
    return function (number, withoutSuffix, string, isFuture) {
      var f = pluralForm(number),
          str = plurals[u][pluralForm(number)];

      if (f === 2) {
        str = str[withoutSuffix ? 0 : 1];
      }

      return str.replace(/%d/i, number);
    };
  },
      months = ['يناير', 'فبراير', 'مارس', 'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'];

  var ar = moment.defineLocale('ar', {
    months: months,
    monthsShort: months,
    weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: "D/\u200FM/\u200FYYYY",
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    meridiemParse: /ص|م/,
    isPM: function isPM(input) {
      return 'م' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ص';
      } else {
        return 'م';
      }
    },
    calendar: {
      sameDay: '[اليوم عند الساعة] LT',
      nextDay: '[غدًا عند الساعة] LT',
      nextWeek: 'dddd [عند الساعة] LT',
      lastDay: '[أمس عند الساعة] LT',
      lastWeek: 'dddd [عند الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'بعد %s',
      past: 'منذ %s',
      s: pluralize('s'),
      ss: pluralize('s'),
      m: pluralize('m'),
      mm: pluralize('m'),
      h: pluralize('h'),
      hh: pluralize('h'),
      d: pluralize('d'),
      dd: pluralize('d'),
      M: pluralize('M'),
      MM: pluralize('M'),
      y: pluralize('y'),
      yy: pluralize('y')
    },
    preparse: function preparse(string) {
      return string.replace(/[١٢٣٤٥٦٧٨٩٠]/g, function (match) {
        return numberMap[match];
      }).replace(/،/g, ',');
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      }).replace(/,/g, '،');
    },
    week: {
      dow: 6,
      // Saturday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return ar;
});

/***/ }),

/***/ "jtHE":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/ReplaySubject.js ***!
  \**************************************************************/
/*! exports provided: ReplaySubject */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ReplaySubject", function() { return ReplaySubject; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./Subject */ "XNiG");
/* harmony import */ var _scheduler_queue__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./scheduler/queue */ "qgXg");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./Subscription */ "quSY");
/* harmony import */ var _operators_observeOn__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./operators/observeOn */ "pxpQ");
/* harmony import */ var _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./util/ObjectUnsubscribedError */ "9ppp");
/* harmony import */ var _SubjectSubscription__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./SubjectSubscription */ "Ylt2");












var ReplaySubject = /*#__PURE__*/function (_Subject) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_4__["default"])(ReplaySubject, _Subject);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_5__["default"])(ReplaySubject);

  function ReplaySubject() {
    var _this;

    var bufferSize = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Number.POSITIVE_INFINITY;
    var windowTime = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : Number.POSITIVE_INFINITY;
    var scheduler = arguments.length > 2 ? arguments[2] : undefined;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ReplaySubject);

    _this = _super.call(this);
    _this.scheduler = scheduler;
    _this._events = [];
    _this._infiniteTimeWindow = false;
    _this._bufferSize = bufferSize < 1 ? 1 : bufferSize;
    _this._windowTime = windowTime < 1 ? 1 : windowTime;

    if (windowTime === Number.POSITIVE_INFINITY) {
      _this._infiniteTimeWindow = true;
      _this.next = _this.nextInfiniteTimeWindow;
    } else {
      _this.next = _this.nextTimeWindow;
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(ReplaySubject, [{
    key: "nextInfiniteTimeWindow",
    value: function nextInfiniteTimeWindow(value) {
      if (!this.isStopped) {
        var _events = this._events;

        _events.push(value);

        if (_events.length > this._bufferSize) {
          _events.shift();
        }
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(ReplaySubject.prototype), "next", this).call(this, value);
    }
  }, {
    key: "nextTimeWindow",
    value: function nextTimeWindow(value) {
      if (!this.isStopped) {
        this._events.push(new ReplayEvent(this._getNow(), value));

        this._trimBufferThenGetEvents();
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_3__["default"])(ReplaySubject.prototype), "next", this).call(this, value);
    }
  }, {
    key: "_subscribe",
    value: function _subscribe(subscriber) {
      var _infiniteTimeWindow = this._infiniteTimeWindow;

      var _events = _infiniteTimeWindow ? this._events : this._trimBufferThenGetEvents();

      var scheduler = this.scheduler;
      var len = _events.length;
      var subscription;

      if (this.closed) {
        throw new _util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_10__["ObjectUnsubscribedError"]();
      } else if (this.isStopped || this.hasError) {
        subscription = _Subscription__WEBPACK_IMPORTED_MODULE_8__["Subscription"].EMPTY;
      } else {
        this.observers.push(subscriber);
        subscription = new _SubjectSubscription__WEBPACK_IMPORTED_MODULE_11__["SubjectSubscription"](this, subscriber);
      }

      if (scheduler) {
        subscriber.add(subscriber = new _operators_observeOn__WEBPACK_IMPORTED_MODULE_9__["ObserveOnSubscriber"](subscriber, scheduler));
      }

      if (_infiniteTimeWindow) {
        for (var i = 0; i < len && !subscriber.closed; i++) {
          subscriber.next(_events[i]);
        }
      } else {
        for (var _i = 0; _i < len && !subscriber.closed; _i++) {
          subscriber.next(_events[_i].value);
        }
      }

      if (this.hasError) {
        subscriber.error(this.thrownError);
      } else if (this.isStopped) {
        subscriber.complete();
      }

      return subscription;
    }
  }, {
    key: "_getNow",
    value: function _getNow() {
      return (this.scheduler || _scheduler_queue__WEBPACK_IMPORTED_MODULE_7__["queue"]).now();
    }
  }, {
    key: "_trimBufferThenGetEvents",
    value: function _trimBufferThenGetEvents() {
      var now = this._getNow();

      var _bufferSize = this._bufferSize;
      var _windowTime = this._windowTime;
      var _events = this._events;
      var eventsCount = _events.length;
      var spliceCount = 0;

      while (spliceCount < eventsCount) {
        if (now - _events[spliceCount].time < _windowTime) {
          break;
        }

        spliceCount++;
      }

      if (eventsCount > _bufferSize) {
        spliceCount = Math.max(spliceCount, eventsCount - _bufferSize);
      }

      if (spliceCount > 0) {
        _events.splice(0, spliceCount);
      }

      return _events;
    }
  }]);

  return ReplaySubject;
}(_Subject__WEBPACK_IMPORTED_MODULE_6__["Subject"]);

var ReplayEvent = function ReplayEvent(time, value) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ReplayEvent);

  this.time = time;
  this.value = value;
};

/***/ }),

/***/ "kEOa":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/bn.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Bengali [bn]
//! author : Kaushik Gandhi : https://github.com/kaushikgandhi
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '১',
    2: '২',
    3: '৩',
    4: '৪',
    5: '৫',
    6: '৬',
    7: '৭',
    8: '৮',
    9: '৯',
    0: '০'
  },
      numberMap = {
    '১': '1',
    '২': '2',
    '৩': '3',
    '৪': '4',
    '৫': '5',
    '৬': '6',
    '৭': '7',
    '৮': '8',
    '৯': '9',
    '০': '0'
  };
  var bn = moment.defineLocale('bn', {
    months: 'জানুয়ারি_ফেব্রুয়ারি_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর'.split('_'),
    monthsShort: 'জানু_ফেব্রু_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্ট_অক্টো_নভে_ডিসে'.split('_'),
    weekdays: 'রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পতিবার_শুক্রবার_শনিবার'.split('_'),
    weekdaysShort: 'রবি_সোম_মঙ্গল_বুধ_বৃহস্পতি_শুক্র_শনি'.split('_'),
    weekdaysMin: 'রবি_সোম_মঙ্গল_বুধ_বৃহ_শুক্র_শনি'.split('_'),
    longDateFormat: {
      LT: 'A h:mm সময়',
      LTS: 'A h:mm:ss সময়',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm সময়',
      LLLL: 'dddd, D MMMM YYYY, A h:mm সময়'
    },
    calendar: {
      sameDay: '[আজ] LT',
      nextDay: '[আগামীকাল] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[গতকাল] LT',
      lastWeek: '[গত] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s পরে',
      past: '%s আগে',
      s: 'কয়েক সেকেন্ড',
      ss: '%d সেকেন্ড',
      m: 'এক মিনিট',
      mm: '%d মিনিট',
      h: 'এক ঘন্টা',
      hh: '%d ঘন্টা',
      d: 'এক দিন',
      dd: '%d দিন',
      M: 'এক মাস',
      MM: '%d মাস',
      y: 'এক বছর',
      yy: '%d বছর'
    },
    preparse: function preparse(string) {
      return string.replace(/[১২৩৪৫৬৭৮৯০]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    meridiemParse: /রাত|সকাল|দুপুর|বিকাল|রাত/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'রাত' && hour >= 4 || meridiem === 'দুপুর' && hour < 5 || meridiem === 'বিকাল') {
        return hour + 12;
      } else {
        return hour;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'রাত';
      } else if (hour < 10) {
        return 'সকাল';
      } else if (hour < 17) {
        return 'দুপুর';
      } else if (hour < 20) {
        return 'বিকাল';
      } else {
        return 'রাত';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return bn;
});

/***/ }),

/***/ "kJWO":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/symbol/observable.js ***!
  \******************************************************************/
/*! exports provided: observable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "observable", function() { return observable; });
var observable = function () {
  return typeof Symbol === 'function' && Symbol.observable || '@@observable';
}();

/***/ }),

/***/ "kOpN":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/zh-tw.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Chinese (Taiwan) [zh-tw]
//! author : Ben : https://github.com/ben-lin
//! author : Chris Lam : https://github.com/hehachris
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var zhTw = moment.defineLocale('zh-tw', {
    months: '一月_二月_三月_四月_五月_六月_七月_八月_九月_十月_十一月_十二月'.split('_'),
    monthsShort: '1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月'.split('_'),
    weekdays: '星期日_星期一_星期二_星期三_星期四_星期五_星期六'.split('_'),
    weekdaysShort: '週日_週一_週二_週三_週四_週五_週六'.split('_'),
    weekdaysMin: '日_一_二_三_四_五_六'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY/MM/DD',
      LL: 'YYYY年M月D日',
      LLL: 'YYYY年M月D日 HH:mm',
      LLLL: 'YYYY年M月D日dddd HH:mm',
      l: 'YYYY/M/D',
      ll: 'YYYY年M月D日',
      lll: 'YYYY年M月D日 HH:mm',
      llll: 'YYYY年M月D日dddd HH:mm'
    },
    meridiemParse: /凌晨|早上|上午|中午|下午|晚上/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === '凌晨' || meridiem === '早上' || meridiem === '上午') {
        return hour;
      } else if (meridiem === '中午') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === '下午' || meridiem === '晚上') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      var hm = hour * 100 + minute;

      if (hm < 600) {
        return '凌晨';
      } else if (hm < 900) {
        return '早上';
      } else if (hm < 1130) {
        return '上午';
      } else if (hm < 1230) {
        return '中午';
      } else if (hm < 1800) {
        return '下午';
      } else {
        return '晚上';
      }
    },
    calendar: {
      sameDay: '[今天] LT',
      nextDay: '[明天] LT',
      nextWeek: '[下]dddd LT',
      lastDay: '[昨天] LT',
      lastWeek: '[上]dddd LT',
      sameElse: 'L'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(日|月|週)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + '日';

        case 'M':
          return number + '月';

        case 'w':
        case 'W':
          return number + '週';

        default:
          return number;
      }
    },
    relativeTime: {
      future: '%s後',
      past: '%s前',
      s: '幾秒',
      ss: '%d 秒',
      m: '1 分鐘',
      mm: '%d 分鐘',
      h: '1 小時',
      hh: '%d 小時',
      d: '1 天',
      dd: '%d 天',
      M: '1 個月',
      MM: '%d 個月',
      y: '1 年',
      yy: '%d 年'
    }
  });
  return zhTw;
});

/***/ }),

/***/ "kU1M":
/*!*******************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/operators/index.js ***!
  \*******************************************************/
/*! exports provided: audit, auditTime, buffer, bufferCount, bufferTime, bufferToggle, bufferWhen, catchError, combineAll, combineLatest, concat, concatAll, concatMap, concatMapTo, count, debounce, debounceTime, defaultIfEmpty, delay, delayWhen, dematerialize, distinct, distinctUntilChanged, distinctUntilKeyChanged, elementAt, endWith, every, exhaust, exhaustMap, expand, filter, finalize, find, findIndex, first, groupBy, ignoreElements, isEmpty, last, map, mapTo, materialize, max, merge, mergeAll, mergeMap, flatMap, mergeMapTo, mergeScan, min, multicast, observeOn, onErrorResumeNext, pairwise, partition, pluck, publish, publishBehavior, publishLast, publishReplay, race, reduce, repeat, repeatWhen, retry, retryWhen, refCount, sample, sampleTime, scan, sequenceEqual, share, shareReplay, single, skip, skipLast, skipUntil, skipWhile, startWith, subscribeOn, switchAll, switchMap, switchMapTo, take, takeLast, takeUntil, takeWhile, tap, throttle, throttleTime, throwIfEmpty, timeInterval, timeout, timeoutWith, timestamp, toArray, window, windowCount, windowTime, windowToggle, windowWhen, withLatestFrom, zip, zipAll */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_operators_audit__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../internal/operators/audit */ "tnsW");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "audit", function() { return _internal_operators_audit__WEBPACK_IMPORTED_MODULE_0__["audit"]; });

/* harmony import */ var _internal_operators_auditTime__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../internal/operators/auditTime */ "3UWI");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "auditTime", function() { return _internal_operators_auditTime__WEBPACK_IMPORTED_MODULE_1__["auditTime"]; });

/* harmony import */ var _internal_operators_buffer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../internal/operators/buffer */ "p9/F");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "buffer", function() { return _internal_operators_buffer__WEBPACK_IMPORTED_MODULE_2__["buffer"]; });

/* harmony import */ var _internal_operators_bufferCount__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../internal/operators/bufferCount */ "9M8c");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bufferCount", function() { return _internal_operators_bufferCount__WEBPACK_IMPORTED_MODULE_3__["bufferCount"]; });

/* harmony import */ var _internal_operators_bufferTime__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../internal/operators/bufferTime */ "OsX3");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bufferTime", function() { return _internal_operators_bufferTime__WEBPACK_IMPORTED_MODULE_4__["bufferTime"]; });

/* harmony import */ var _internal_operators_bufferToggle__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../internal/operators/bufferToggle */ "FD9M");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bufferToggle", function() { return _internal_operators_bufferToggle__WEBPACK_IMPORTED_MODULE_5__["bufferToggle"]; });

/* harmony import */ var _internal_operators_bufferWhen__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../internal/operators/bufferWhen */ "PfrF");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bufferWhen", function() { return _internal_operators_bufferWhen__WEBPACK_IMPORTED_MODULE_6__["bufferWhen"]; });

/* harmony import */ var _internal_operators_catchError__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../internal/operators/catchError */ "JIr8");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "catchError", function() { return _internal_operators_catchError__WEBPACK_IMPORTED_MODULE_7__["catchError"]; });

/* harmony import */ var _internal_operators_combineAll__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../internal/operators/combineAll */ "7wxJ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "combineAll", function() { return _internal_operators_combineAll__WEBPACK_IMPORTED_MODULE_8__["combineAll"]; });

/* harmony import */ var _internal_operators_combineLatest__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../internal/operators/combineLatest */ "fFD9");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "combineLatest", function() { return _internal_operators_combineLatest__WEBPACK_IMPORTED_MODULE_9__["combineLatest"]; });

/* harmony import */ var _internal_operators_concat__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../internal/operators/concat */ "f29J");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "concat", function() { return _internal_operators_concat__WEBPACK_IMPORTED_MODULE_10__["concat"]; });

/* harmony import */ var _internal_operators_concatAll__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../internal/operators/concatAll */ "0EUg");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "concatAll", function() { return _internal_operators_concatAll__WEBPACK_IMPORTED_MODULE_11__["concatAll"]; });

/* harmony import */ var _internal_operators_concatMap__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../internal/operators/concatMap */ "bOdf");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "concatMap", function() { return _internal_operators_concatMap__WEBPACK_IMPORTED_MODULE_12__["concatMap"]; });

/* harmony import */ var _internal_operators_concatMapTo__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../internal/operators/concatMapTo */ "q7zd");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "concatMapTo", function() { return _internal_operators_concatMapTo__WEBPACK_IMPORTED_MODULE_13__["concatMapTo"]; });

/* harmony import */ var _internal_operators_count__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../internal/operators/count */ "HrJb");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "count", function() { return _internal_operators_count__WEBPACK_IMPORTED_MODULE_14__["count"]; });

/* harmony import */ var _internal_operators_debounce__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../internal/operators/debounce */ "6eBy");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "debounce", function() { return _internal_operators_debounce__WEBPACK_IMPORTED_MODULE_15__["debounce"]; });

/* harmony import */ var _internal_operators_debounceTime__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../internal/operators/debounceTime */ "Kj3r");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "debounceTime", function() { return _internal_operators_debounceTime__WEBPACK_IMPORTED_MODULE_16__["debounceTime"]; });

/* harmony import */ var _internal_operators_defaultIfEmpty__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../internal/operators/defaultIfEmpty */ "xbPD");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "defaultIfEmpty", function() { return _internal_operators_defaultIfEmpty__WEBPACK_IMPORTED_MODULE_17__["defaultIfEmpty"]; });

/* harmony import */ var _internal_operators_delay__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../internal/operators/delay */ "3E0/");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "delay", function() { return _internal_operators_delay__WEBPACK_IMPORTED_MODULE_18__["delay"]; });

/* harmony import */ var _internal_operators_delayWhen__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../internal/operators/delayWhen */ "coGc");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "delayWhen", function() { return _internal_operators_delayWhen__WEBPACK_IMPORTED_MODULE_19__["delayWhen"]; });

/* harmony import */ var _internal_operators_dematerialize__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ../internal/operators/dematerialize */ "kgNN");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dematerialize", function() { return _internal_operators_dematerialize__WEBPACK_IMPORTED_MODULE_20__["dematerialize"]; });

/* harmony import */ var _internal_operators_distinct__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../internal/operators/distinct */ "02Lk");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "distinct", function() { return _internal_operators_distinct__WEBPACK_IMPORTED_MODULE_21__["distinct"]; });

/* harmony import */ var _internal_operators_distinctUntilChanged__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ../internal/operators/distinctUntilChanged */ "/uUt");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "distinctUntilChanged", function() { return _internal_operators_distinctUntilChanged__WEBPACK_IMPORTED_MODULE_22__["distinctUntilChanged"]; });

/* harmony import */ var _internal_operators_distinctUntilKeyChanged__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ../internal/operators/distinctUntilKeyChanged */ "PZkE");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "distinctUntilKeyChanged", function() { return _internal_operators_distinctUntilKeyChanged__WEBPACK_IMPORTED_MODULE_23__["distinctUntilKeyChanged"]; });

/* harmony import */ var _internal_operators_elementAt__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ../internal/operators/elementAt */ "9ihq");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "elementAt", function() { return _internal_operators_elementAt__WEBPACK_IMPORTED_MODULE_24__["elementAt"]; });

/* harmony import */ var _internal_operators_endWith__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ../internal/operators/endWith */ "0Pi8");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "endWith", function() { return _internal_operators_endWith__WEBPACK_IMPORTED_MODULE_25__["endWith"]; });

/* harmony import */ var _internal_operators_every__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ../internal/operators/every */ "Gi4w");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "every", function() { return _internal_operators_every__WEBPACK_IMPORTED_MODULE_26__["every"]; });

/* harmony import */ var _internal_operators_exhaust__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ../internal/operators/exhaust */ "zt7V");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "exhaust", function() { return _internal_operators_exhaust__WEBPACK_IMPORTED_MODULE_27__["exhaust"]; });

/* harmony import */ var _internal_operators_exhaustMap__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ../internal/operators/exhaustMap */ "XqQ8");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "exhaustMap", function() { return _internal_operators_exhaustMap__WEBPACK_IMPORTED_MODULE_28__["exhaustMap"]; });

/* harmony import */ var _internal_operators_expand__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ../internal/operators/expand */ "FQpF");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "expand", function() { return _internal_operators_expand__WEBPACK_IMPORTED_MODULE_29__["expand"]; });

/* harmony import */ var _internal_operators_filter__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ../internal/operators/filter */ "pLZG");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "filter", function() { return _internal_operators_filter__WEBPACK_IMPORTED_MODULE_30__["filter"]; });

/* harmony import */ var _internal_operators_finalize__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ../internal/operators/finalize */ "nYR2");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "finalize", function() { return _internal_operators_finalize__WEBPACK_IMPORTED_MODULE_31__["finalize"]; });

/* harmony import */ var _internal_operators_find__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ../internal/operators/find */ "cBqT");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "find", function() { return _internal_operators_find__WEBPACK_IMPORTED_MODULE_32__["find"]; });

/* harmony import */ var _internal_operators_findIndex__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ../internal/operators/findIndex */ "K7De");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "findIndex", function() { return _internal_operators_findIndex__WEBPACK_IMPORTED_MODULE_33__["findIndex"]; });

/* harmony import */ var _internal_operators_first__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! ../internal/operators/first */ "SxV6");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "first", function() { return _internal_operators_first__WEBPACK_IMPORTED_MODULE_34__["first"]; });

/* harmony import */ var _internal_operators_groupBy__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! ../internal/operators/groupBy */ "OQgR");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "groupBy", function() { return _internal_operators_groupBy__WEBPACK_IMPORTED_MODULE_35__["groupBy"]; });

/* harmony import */ var _internal_operators_ignoreElements__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! ../internal/operators/ignoreElements */ "4A3s");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ignoreElements", function() { return _internal_operators_ignoreElements__WEBPACK_IMPORTED_MODULE_36__["ignoreElements"]; });

/* harmony import */ var _internal_operators_isEmpty__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! ../internal/operators/isEmpty */ "m2j4");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "isEmpty", function() { return _internal_operators_isEmpty__WEBPACK_IMPORTED_MODULE_37__["isEmpty"]; });

/* harmony import */ var _internal_operators_last__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(/*! ../internal/operators/last */ "NJ9Y");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "last", function() { return _internal_operators_last__WEBPACK_IMPORTED_MODULE_38__["last"]; });

/* harmony import */ var _internal_operators_map__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(/*! ../internal/operators/map */ "lJxs");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "map", function() { return _internal_operators_map__WEBPACK_IMPORTED_MODULE_39__["map"]; });

/* harmony import */ var _internal_operators_mapTo__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(/*! ../internal/operators/mapTo */ "CqXF");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mapTo", function() { return _internal_operators_mapTo__WEBPACK_IMPORTED_MODULE_40__["mapTo"]; });

/* harmony import */ var _internal_operators_materialize__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(/*! ../internal/operators/materialize */ "dkDA");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "materialize", function() { return _internal_operators_materialize__WEBPACK_IMPORTED_MODULE_41__["materialize"]; });

/* harmony import */ var _internal_operators_max__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(/*! ../internal/operators/max */ "yI9Y");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "max", function() { return _internal_operators_max__WEBPACK_IMPORTED_MODULE_42__["max"]; });

/* harmony import */ var _internal_operators_merge__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(/*! ../internal/operators/merge */ "q92s");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "merge", function() { return _internal_operators_merge__WEBPACK_IMPORTED_MODULE_43__["merge"]; });

/* harmony import */ var _internal_operators_mergeAll__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(/*! ../internal/operators/mergeAll */ "bHdf");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeAll", function() { return _internal_operators_mergeAll__WEBPACK_IMPORTED_MODULE_44__["mergeAll"]; });

/* harmony import */ var _internal_operators_mergeMap__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(/*! ../internal/operators/mergeMap */ "5+tZ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeMap", function() { return _internal_operators_mergeMap__WEBPACK_IMPORTED_MODULE_45__["mergeMap"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "flatMap", function() { return _internal_operators_mergeMap__WEBPACK_IMPORTED_MODULE_45__["flatMap"]; });

/* harmony import */ var _internal_operators_mergeMapTo__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(/*! ../internal/operators/mergeMapTo */ "UXbc");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeMapTo", function() { return _internal_operators_mergeMapTo__WEBPACK_IMPORTED_MODULE_46__["mergeMapTo"]; });

/* harmony import */ var _internal_operators_mergeScan__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(/*! ../internal/operators/mergeScan */ "51Bx");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeScan", function() { return _internal_operators_mergeScan__WEBPACK_IMPORTED_MODULE_47__["mergeScan"]; });

/* harmony import */ var _internal_operators_min__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(/*! ../internal/operators/min */ "FZB8");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "min", function() { return _internal_operators_min__WEBPACK_IMPORTED_MODULE_48__["min"]; });

/* harmony import */ var _internal_operators_multicast__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(/*! ../internal/operators/multicast */ "oB13");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "multicast", function() { return _internal_operators_multicast__WEBPACK_IMPORTED_MODULE_49__["multicast"]; });

/* harmony import */ var _internal_operators_observeOn__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(/*! ../internal/operators/observeOn */ "pxpQ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "observeOn", function() { return _internal_operators_observeOn__WEBPACK_IMPORTED_MODULE_50__["observeOn"]; });

/* harmony import */ var _internal_operators_onErrorResumeNext__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(/*! ../internal/operators/onErrorResumeNext */ "uTdr");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "onErrorResumeNext", function() { return _internal_operators_onErrorResumeNext__WEBPACK_IMPORTED_MODULE_51__["onErrorResumeNext"]; });

/* harmony import */ var _internal_operators_pairwise__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(/*! ../internal/operators/pairwise */ "Zy1z");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pairwise", function() { return _internal_operators_pairwise__WEBPACK_IMPORTED_MODULE_52__["pairwise"]; });

/* harmony import */ var _internal_operators_partition__WEBPACK_IMPORTED_MODULE_53__ = __webpack_require__(/*! ../internal/operators/partition */ "A3iJ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "partition", function() { return _internal_operators_partition__WEBPACK_IMPORTED_MODULE_53__["partition"]; });

/* harmony import */ var _internal_operators_pluck__WEBPACK_IMPORTED_MODULE_54__ = __webpack_require__(/*! ../internal/operators/pluck */ "wO+i");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pluck", function() { return _internal_operators_pluck__WEBPACK_IMPORTED_MODULE_54__["pluck"]; });

/* harmony import */ var _internal_operators_publish__WEBPACK_IMPORTED_MODULE_55__ = __webpack_require__(/*! ../internal/operators/publish */ "NfdI");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "publish", function() { return _internal_operators_publish__WEBPACK_IMPORTED_MODULE_55__["publish"]; });

/* harmony import */ var _internal_operators_publishBehavior__WEBPACK_IMPORTED_MODULE_56__ = __webpack_require__(/*! ../internal/operators/publishBehavior */ "UGaM");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "publishBehavior", function() { return _internal_operators_publishBehavior__WEBPACK_IMPORTED_MODULE_56__["publishBehavior"]; });

/* harmony import */ var _internal_operators_publishLast__WEBPACK_IMPORTED_MODULE_57__ = __webpack_require__(/*! ../internal/operators/publishLast */ "qZ0a");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "publishLast", function() { return _internal_operators_publishLast__WEBPACK_IMPORTED_MODULE_57__["publishLast"]; });

/* harmony import */ var _internal_operators_publishReplay__WEBPACK_IMPORTED_MODULE_58__ = __webpack_require__(/*! ../internal/operators/publishReplay */ "05l1");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "publishReplay", function() { return _internal_operators_publishReplay__WEBPACK_IMPORTED_MODULE_58__["publishReplay"]; });

/* harmony import */ var _internal_operators_race__WEBPACK_IMPORTED_MODULE_59__ = __webpack_require__(/*! ../internal/operators/race */ "4f8F");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "race", function() { return _internal_operators_race__WEBPACK_IMPORTED_MODULE_59__["race"]; });

/* harmony import */ var _internal_operators_reduce__WEBPACK_IMPORTED_MODULE_60__ = __webpack_require__(/*! ../internal/operators/reduce */ "128B");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reduce", function() { return _internal_operators_reduce__WEBPACK_IMPORTED_MODULE_60__["reduce"]; });

/* harmony import */ var _internal_operators_repeat__WEBPACK_IMPORTED_MODULE_61__ = __webpack_require__(/*! ../internal/operators/repeat */ "/d8p");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "repeat", function() { return _internal_operators_repeat__WEBPACK_IMPORTED_MODULE_61__["repeat"]; });

/* harmony import */ var _internal_operators_repeatWhen__WEBPACK_IMPORTED_MODULE_62__ = __webpack_require__(/*! ../internal/operators/repeatWhen */ "Gqsl");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "repeatWhen", function() { return _internal_operators_repeatWhen__WEBPACK_IMPORTED_MODULE_62__["repeatWhen"]; });

/* harmony import */ var _internal_operators_retry__WEBPACK_IMPORTED_MODULE_63__ = __webpack_require__(/*! ../internal/operators/retry */ "un/a");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "retry", function() { return _internal_operators_retry__WEBPACK_IMPORTED_MODULE_63__["retry"]; });

/* harmony import */ var _internal_operators_retryWhen__WEBPACK_IMPORTED_MODULE_64__ = __webpack_require__(/*! ../internal/operators/retryWhen */ "MtjB");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "retryWhen", function() { return _internal_operators_retryWhen__WEBPACK_IMPORTED_MODULE_64__["retryWhen"]; });

/* harmony import */ var _internal_operators_refCount__WEBPACK_IMPORTED_MODULE_65__ = __webpack_require__(/*! ../internal/operators/refCount */ "x+ZX");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "refCount", function() { return _internal_operators_refCount__WEBPACK_IMPORTED_MODULE_65__["refCount"]; });

/* harmony import */ var _internal_operators_sample__WEBPACK_IMPORTED_MODULE_66__ = __webpack_require__(/*! ../internal/operators/sample */ "c6ID");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sample", function() { return _internal_operators_sample__WEBPACK_IMPORTED_MODULE_66__["sample"]; });

/* harmony import */ var _internal_operators_sampleTime__WEBPACK_IMPORTED_MODULE_67__ = __webpack_require__(/*! ../internal/operators/sampleTime */ "1Ykd");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sampleTime", function() { return _internal_operators_sampleTime__WEBPACK_IMPORTED_MODULE_67__["sampleTime"]; });

/* harmony import */ var _internal_operators_scan__WEBPACK_IMPORTED_MODULE_68__ = __webpack_require__(/*! ../internal/operators/scan */ "Kqap");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "scan", function() { return _internal_operators_scan__WEBPACK_IMPORTED_MODULE_68__["scan"]; });

/* harmony import */ var _internal_operators_sequenceEqual__WEBPACK_IMPORTED_MODULE_69__ = __webpack_require__(/*! ../internal/operators/sequenceEqual */ "Zyez");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sequenceEqual", function() { return _internal_operators_sequenceEqual__WEBPACK_IMPORTED_MODULE_69__["sequenceEqual"]; });

/* harmony import */ var _internal_operators_share__WEBPACK_IMPORTED_MODULE_70__ = __webpack_require__(/*! ../internal/operators/share */ "w1tV");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "share", function() { return _internal_operators_share__WEBPACK_IMPORTED_MODULE_70__["share"]; });

/* harmony import */ var _internal_operators_shareReplay__WEBPACK_IMPORTED_MODULE_71__ = __webpack_require__(/*! ../internal/operators/shareReplay */ "UXun");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "shareReplay", function() { return _internal_operators_shareReplay__WEBPACK_IMPORTED_MODULE_71__["shareReplay"]; });

/* harmony import */ var _internal_operators_single__WEBPACK_IMPORTED_MODULE_72__ = __webpack_require__(/*! ../internal/operators/single */ "cx9U");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "single", function() { return _internal_operators_single__WEBPACK_IMPORTED_MODULE_72__["single"]; });

/* harmony import */ var _internal_operators_skip__WEBPACK_IMPORTED_MODULE_73__ = __webpack_require__(/*! ../internal/operators/skip */ "zP0r");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "skip", function() { return _internal_operators_skip__WEBPACK_IMPORTED_MODULE_73__["skip"]; });

/* harmony import */ var _internal_operators_skipLast__WEBPACK_IMPORTED_MODULE_74__ = __webpack_require__(/*! ../internal/operators/skipLast */ "kagm");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "skipLast", function() { return _internal_operators_skipLast__WEBPACK_IMPORTED_MODULE_74__["skipLast"]; });

/* harmony import */ var _internal_operators_skipUntil__WEBPACK_IMPORTED_MODULE_75__ = __webpack_require__(/*! ../internal/operators/skipUntil */ "vqkR");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "skipUntil", function() { return _internal_operators_skipUntil__WEBPACK_IMPORTED_MODULE_75__["skipUntil"]; });

/* harmony import */ var _internal_operators_skipWhile__WEBPACK_IMPORTED_MODULE_76__ = __webpack_require__(/*! ../internal/operators/skipWhile */ "32Ea");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "skipWhile", function() { return _internal_operators_skipWhile__WEBPACK_IMPORTED_MODULE_76__["skipWhile"]; });

/* harmony import */ var _internal_operators_startWith__WEBPACK_IMPORTED_MODULE_77__ = __webpack_require__(/*! ../internal/operators/startWith */ "JX91");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "startWith", function() { return _internal_operators_startWith__WEBPACK_IMPORTED_MODULE_77__["startWith"]; });

/* harmony import */ var _internal_operators_subscribeOn__WEBPACK_IMPORTED_MODULE_78__ = __webpack_require__(/*! ../internal/operators/subscribeOn */ "tf+s");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "subscribeOn", function() { return _internal_operators_subscribeOn__WEBPACK_IMPORTED_MODULE_78__["subscribeOn"]; });

/* harmony import */ var _internal_operators_switchAll__WEBPACK_IMPORTED_MODULE_79__ = __webpack_require__(/*! ../internal/operators/switchAll */ "Y6wi");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "switchAll", function() { return _internal_operators_switchAll__WEBPACK_IMPORTED_MODULE_79__["switchAll"]; });

/* harmony import */ var _internal_operators_switchMap__WEBPACK_IMPORTED_MODULE_80__ = __webpack_require__(/*! ../internal/operators/switchMap */ "eIep");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "switchMap", function() { return _internal_operators_switchMap__WEBPACK_IMPORTED_MODULE_80__["switchMap"]; });

/* harmony import */ var _internal_operators_switchMapTo__WEBPACK_IMPORTED_MODULE_81__ = __webpack_require__(/*! ../internal/operators/switchMapTo */ "aGrj");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "switchMapTo", function() { return _internal_operators_switchMapTo__WEBPACK_IMPORTED_MODULE_81__["switchMapTo"]; });

/* harmony import */ var _internal_operators_take__WEBPACK_IMPORTED_MODULE_82__ = __webpack_require__(/*! ../internal/operators/take */ "IzEk");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "take", function() { return _internal_operators_take__WEBPACK_IMPORTED_MODULE_82__["take"]; });

/* harmony import */ var _internal_operators_takeLast__WEBPACK_IMPORTED_MODULE_83__ = __webpack_require__(/*! ../internal/operators/takeLast */ "BFxc");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "takeLast", function() { return _internal_operators_takeLast__WEBPACK_IMPORTED_MODULE_83__["takeLast"]; });

/* harmony import */ var _internal_operators_takeUntil__WEBPACK_IMPORTED_MODULE_84__ = __webpack_require__(/*! ../internal/operators/takeUntil */ "1G5W");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "takeUntil", function() { return _internal_operators_takeUntil__WEBPACK_IMPORTED_MODULE_84__["takeUntil"]; });

/* harmony import */ var _internal_operators_takeWhile__WEBPACK_IMPORTED_MODULE_85__ = __webpack_require__(/*! ../internal/operators/takeWhile */ "GJmQ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "takeWhile", function() { return _internal_operators_takeWhile__WEBPACK_IMPORTED_MODULE_85__["takeWhile"]; });

/* harmony import */ var _internal_operators_tap__WEBPACK_IMPORTED_MODULE_86__ = __webpack_require__(/*! ../internal/operators/tap */ "vkgz");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "tap", function() { return _internal_operators_tap__WEBPACK_IMPORTED_MODULE_86__["tap"]; });

/* harmony import */ var _internal_operators_throttle__WEBPACK_IMPORTED_MODULE_87__ = __webpack_require__(/*! ../internal/operators/throttle */ "yuhW");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "throttle", function() { return _internal_operators_throttle__WEBPACK_IMPORTED_MODULE_87__["throttle"]; });

/* harmony import */ var _internal_operators_throttleTime__WEBPACK_IMPORTED_MODULE_88__ = __webpack_require__(/*! ../internal/operators/throttleTime */ "gcYM");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "throttleTime", function() { return _internal_operators_throttleTime__WEBPACK_IMPORTED_MODULE_88__["throttleTime"]; });

/* harmony import */ var _internal_operators_throwIfEmpty__WEBPACK_IMPORTED_MODULE_89__ = __webpack_require__(/*! ../internal/operators/throwIfEmpty */ "XDbj");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "throwIfEmpty", function() { return _internal_operators_throwIfEmpty__WEBPACK_IMPORTED_MODULE_89__["throwIfEmpty"]; });

/* harmony import */ var _internal_operators_timeInterval__WEBPACK_IMPORTED_MODULE_90__ = __webpack_require__(/*! ../internal/operators/timeInterval */ "4hIw");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "timeInterval", function() { return _internal_operators_timeInterval__WEBPACK_IMPORTED_MODULE_90__["timeInterval"]; });

/* harmony import */ var _internal_operators_timeout__WEBPACK_IMPORTED_MODULE_91__ = __webpack_require__(/*! ../internal/operators/timeout */ "tS1D");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "timeout", function() { return _internal_operators_timeout__WEBPACK_IMPORTED_MODULE_91__["timeout"]; });

/* harmony import */ var _internal_operators_timeoutWith__WEBPACK_IMPORTED_MODULE_92__ = __webpack_require__(/*! ../internal/operators/timeoutWith */ "syX2");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "timeoutWith", function() { return _internal_operators_timeoutWith__WEBPACK_IMPORTED_MODULE_92__["timeoutWith"]; });

/* harmony import */ var _internal_operators_timestamp__WEBPACK_IMPORTED_MODULE_93__ = __webpack_require__(/*! ../internal/operators/timestamp */ "r0WS");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "timestamp", function() { return _internal_operators_timestamp__WEBPACK_IMPORTED_MODULE_93__["timestamp"]; });

/* harmony import */ var _internal_operators_toArray__WEBPACK_IMPORTED_MODULE_94__ = __webpack_require__(/*! ../internal/operators/toArray */ "IAdc");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "toArray", function() { return _internal_operators_toArray__WEBPACK_IMPORTED_MODULE_94__["toArray"]; });

/* harmony import */ var _internal_operators_window__WEBPACK_IMPORTED_MODULE_95__ = __webpack_require__(/*! ../internal/operators/window */ "mk5/");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "window", function() { return _internal_operators_window__WEBPACK_IMPORTED_MODULE_95__["window"]; });

/* harmony import */ var _internal_operators_windowCount__WEBPACK_IMPORTED_MODULE_96__ = __webpack_require__(/*! ../internal/operators/windowCount */ "lpKW");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "windowCount", function() { return _internal_operators_windowCount__WEBPACK_IMPORTED_MODULE_96__["windowCount"]; });

/* harmony import */ var _internal_operators_windowTime__WEBPACK_IMPORTED_MODULE_97__ = __webpack_require__(/*! ../internal/operators/windowTime */ "UHp3");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "windowTime", function() { return _internal_operators_windowTime__WEBPACK_IMPORTED_MODULE_97__["windowTime"]; });

/* harmony import */ var _internal_operators_windowToggle__WEBPACK_IMPORTED_MODULE_98__ = __webpack_require__(/*! ../internal/operators/windowToggle */ "sTY7");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "windowToggle", function() { return _internal_operators_windowToggle__WEBPACK_IMPORTED_MODULE_98__["windowToggle"]; });

/* harmony import */ var _internal_operators_windowWhen__WEBPACK_IMPORTED_MODULE_99__ = __webpack_require__(/*! ../internal/operators/windowWhen */ "pXlZ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "windowWhen", function() { return _internal_operators_windowWhen__WEBPACK_IMPORTED_MODULE_99__["windowWhen"]; });

/* harmony import */ var _internal_operators_withLatestFrom__WEBPACK_IMPORTED_MODULE_100__ = __webpack_require__(/*! ../internal/operators/withLatestFrom */ "zp1y");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "withLatestFrom", function() { return _internal_operators_withLatestFrom__WEBPACK_IMPORTED_MODULE_100__["withLatestFrom"]; });

/* harmony import */ var _internal_operators_zip__WEBPACK_IMPORTED_MODULE_101__ = __webpack_require__(/*! ../internal/operators/zip */ "GjHo");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "zip", function() { return _internal_operators_zip__WEBPACK_IMPORTED_MODULE_101__["zip"]; });

/* harmony import */ var _internal_operators_zipAll__WEBPACK_IMPORTED_MODULE_102__ = __webpack_require__(/*! ../internal/operators/zipAll */ "JmF6");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "zipAll", function() { return _internal_operators_zipAll__WEBPACK_IMPORTED_MODULE_102__["zipAll"]; });









































































































/***/ }),

/***/ "kagm":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/skipLast.js ***!
  \*******************************************************************/
/*! exports provided: skipLast */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "skipLast", function() { return skipLast; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/ArgumentOutOfRangeError */ "4I5i");






function skipLast(count) {
  return function (source) {
    return source.lift(new SkipLastOperator(count));
  };
}

var SkipLastOperator = /*#__PURE__*/function () {
  function SkipLastOperator(_skipCount) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SkipLastOperator);

    this._skipCount = _skipCount;

    if (this._skipCount < 0) {
      throw new _util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_5__["ArgumentOutOfRangeError"]();
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipLastOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      if (this._skipCount === 0) {
        return source.subscribe(new _Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"](subscriber));
      } else {
        return source.subscribe(new SkipLastSubscriber(subscriber, this._skipCount));
      }
    }
  }]);

  return SkipLastOperator;
}();

var SkipLastSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SkipLastSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SkipLastSubscriber);

  function SkipLastSubscriber(destination, _skipCount) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SkipLastSubscriber);

    _this = _super.call(this, destination);
    _this._skipCount = _skipCount;
    _this._count = 0;
    _this._ring = new Array(_skipCount);
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipLastSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var skipCount = this._skipCount;
      var count = this._count++;

      if (count < skipCount) {
        this._ring[count] = value;
      } else {
        var currentIndex = count % skipCount;
        var ring = this._ring;
        var oldValue = ring[currentIndex];
        ring[currentIndex] = value;
        this.destination.next(oldValue);
      }
    }
  }]);

  return SkipLastSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "kgNN":
/*!************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/dematerialize.js ***!
  \************************************************************************/
/*! exports provided: dematerialize */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "dematerialize", function() { return dematerialize; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function dematerialize() {
  return function dematerializeOperatorFunction(source) {
    return source.lift(new DeMaterializeOperator());
  };
}

var DeMaterializeOperator = /*#__PURE__*/function () {
  function DeMaterializeOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DeMaterializeOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DeMaterializeOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DeMaterializeSubscriber(subscriber));
    }
  }]);

  return DeMaterializeOperator;
}();

var DeMaterializeSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(DeMaterializeSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(DeMaterializeSubscriber);

  function DeMaterializeSubscriber(destination) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DeMaterializeSubscriber);

    return _super.call(this, destination);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DeMaterializeSubscriber, [{
    key: "_next",
    value: function _next(value) {
      value.observe(this.destination);
    }
  }]);

  return DeMaterializeSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "l5ep":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/cy.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Welsh [cy]
//! author : Robert Allen : https://github.com/robgallen
//! author : https://github.com/ryangreaves
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var cy = moment.defineLocale('cy', {
    months: 'Ionawr_Chwefror_Mawrth_Ebrill_Mai_Mehefin_Gorffennaf_Awst_Medi_Hydref_Tachwedd_Rhagfyr'.split('_'),
    monthsShort: 'Ion_Chwe_Maw_Ebr_Mai_Meh_Gor_Aws_Med_Hyd_Tach_Rhag'.split('_'),
    weekdays: 'Dydd Sul_Dydd Llun_Dydd Mawrth_Dydd Mercher_Dydd Iau_Dydd Gwener_Dydd Sadwrn'.split('_'),
    weekdaysShort: 'Sul_Llun_Maw_Mer_Iau_Gwe_Sad'.split('_'),
    weekdaysMin: 'Su_Ll_Ma_Me_Ia_Gw_Sa'.split('_'),
    weekdaysParseExact: true,
    // time formats are the same as en-gb
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Heddiw am] LT',
      nextDay: '[Yfory am] LT',
      nextWeek: 'dddd [am] LT',
      lastDay: '[Ddoe am] LT',
      lastWeek: 'dddd [diwethaf am] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'mewn %s',
      past: '%s yn ôl',
      s: 'ychydig eiliadau',
      ss: '%d eiliad',
      m: 'munud',
      mm: '%d munud',
      h: 'awr',
      hh: '%d awr',
      d: 'diwrnod',
      dd: '%d diwrnod',
      M: 'mis',
      MM: '%d mis',
      y: 'blwyddyn',
      yy: '%d flynedd'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(fed|ain|af|il|ydd|ed|eg)/,
    // traditional ordinal numbers above 31 are not commonly used in colloquial Welsh
    ordinal: function ordinal(number) {
      var b = number,
          output = '',
          lookup = ['', 'af', 'il', 'ydd', 'ydd', 'ed', 'ed', 'ed', 'fed', 'fed', 'fed', // 1af to 10fed
      'eg', 'fed', 'eg', 'eg', 'fed', 'eg', 'eg', 'fed', 'eg', 'fed' // 11eg to 20fed
      ];

      if (b > 20) {
        if (b === 40 || b === 50 || b === 60 || b === 80 || b === 100) {
          output = 'fed'; // not 30ain, 70ain or 90ain
        } else {
          output = 'ain';
        }
      } else if (b > 0) {
        output = lookup[b];
      }

      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return cy;
});

/***/ }),

/***/ "l5mm":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/interval.js ***!
  \********************************************************************/
/*! exports provided: interval */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "interval", function() { return interval; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _util_isNumeric__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/isNumeric */ "Y7HM");



function interval() {
  var period = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_1__["async"];

  if (!Object(_util_isNumeric__WEBPACK_IMPORTED_MODULE_2__["isNumeric"])(period) || period < 0) {
    period = 0;
  }

  if (!scheduler || typeof scheduler.schedule !== 'function') {
    scheduler = _scheduler_async__WEBPACK_IMPORTED_MODULE_1__["async"];
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
    subscriber.add(scheduler.schedule(dispatch, period, {
      subscriber: subscriber,
      counter: 0,
      period: period
    }));
    return subscriber;
  });
}

function dispatch(state) {
  var subscriber = state.subscriber,
      counter = state.counter,
      period = state.period;
  subscriber.next(counter);
  this.schedule({
    subscriber: subscriber,
    counter: counter + 1,
    period: period
  }, period);
}

/***/ }),

/***/ "l7GE":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/OuterSubscriber.js ***!
  \****************************************************************/
/*! exports provided: OuterSubscriber */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "OuterSubscriber", function() { return OuterSubscriber; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Subscriber */ "7o/Q");





var OuterSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(OuterSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(OuterSubscriber);

  function OuterSubscriber() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, OuterSubscriber);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(OuterSubscriber, [{
    key: "notifyNext",
    value: function notifyNext(outerValue, innerValue, outerIndex, innerIndex, innerSub) {
      this.destination.next(innerValue);
    }
  }, {
    key: "notifyError",
    value: function notifyError(error, innerSub) {
      this.destination.error(error);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(innerSub) {
      this.destination.complete();
    }
  }]);

  return OuterSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "lJxs":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/map.js ***!
  \**************************************************************/
/*! exports provided: map, MapOperator */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "map", function() { return map; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MapOperator", function() { return MapOperator; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");






function map(project, thisArg) {
  return function mapOperation(source) {
    if (typeof project !== 'function') {
      throw new TypeError('argument is not a function. Are you looking for `mapTo()`?');
    }

    return source.lift(new MapOperator(project, thisArg));
  };
}
var MapOperator = /*#__PURE__*/function () {
  function MapOperator(project, thisArg) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, MapOperator);

    this.project = project;
    this.thisArg = thisArg;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(MapOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new MapSubscriber(subscriber, this.project, this.thisArg));
    }
  }]);

  return MapOperator;
}();

var MapSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(MapSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(MapSubscriber);

  function MapSubscriber(destination, project, thisArg) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, MapSubscriber);

    _this = _super.call(this, destination);
    _this.project = project;
    _this.count = 0;
    _this.thisArg = thisArg || Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this);
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(MapSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var result;

      try {
        result = this.project.call(this.thisArg, value, this.count++);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.destination.next(result);
    }
  }]);

  return MapSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

/***/ }),

/***/ "lXzo":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ru.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Russian [ru]
//! author : Viktorminator : https://github.com/Viktorminator
//! author : Menelion Elensúle : https://github.com/Oire
//! author : Коренберг Марк : https://github.com/socketpair
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function plural(word, num) {
    var forms = word.split('_');
    return num % 10 === 1 && num % 100 !== 11 ? forms[0] : num % 10 >= 2 && num % 10 <= 4 && (num % 100 < 10 || num % 100 >= 20) ? forms[1] : forms[2];
  }

  function relativeTimeWithPlural(number, withoutSuffix, key) {
    var format = {
      ss: withoutSuffix ? 'секунда_секунды_секунд' : 'секунду_секунды_секунд',
      mm: withoutSuffix ? 'минута_минуты_минут' : 'минуту_минуты_минут',
      hh: 'час_часа_часов',
      dd: 'день_дня_дней',
      ww: 'неделя_недели_недель',
      MM: 'месяц_месяца_месяцев',
      yy: 'год_года_лет'
    };

    if (key === 'm') {
      return withoutSuffix ? 'минута' : 'минуту';
    } else {
      return number + ' ' + plural(format[key], +number);
    }
  }

  var monthsParse = [/^янв/i, /^фев/i, /^мар/i, /^апр/i, /^ма[йя]/i, /^июн/i, /^июл/i, /^авг/i, /^сен/i, /^окт/i, /^ноя/i, /^дек/i]; // http://new.gramota.ru/spravka/rules/139-prop : § 103
  // Сокращения месяцев: http://new.gramota.ru/spravka/buro/search-answer?s=242637
  // CLDR data:          http://www.unicode.org/cldr/charts/28/summary/ru.html#1753

  var ru = moment.defineLocale('ru', {
    months: {
      format: 'января_февраля_марта_апреля_мая_июня_июля_августа_сентября_октября_ноября_декабря'.split('_'),
      standalone: 'январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь'.split('_')
    },
    monthsShort: {
      // по CLDR именно "июл." и "июн.", но какой смысл менять букву на точку?
      format: 'янв._февр._мар._апр._мая_июня_июля_авг._сент._окт._нояб._дек.'.split('_'),
      standalone: 'янв._февр._март_апр._май_июнь_июль_авг._сент._окт._нояб._дек.'.split('_')
    },
    weekdays: {
      standalone: 'воскресенье_понедельник_вторник_среда_четверг_пятница_суббота'.split('_'),
      format: 'воскресенье_понедельник_вторник_среду_четверг_пятницу_субботу'.split('_'),
      isFormat: /\[ ?[Вв] ?(?:прошлую|следующую|эту)? ?] ?dddd/
    },
    weekdaysShort: 'вс_пн_вт_ср_чт_пт_сб'.split('_'),
    weekdaysMin: 'вс_пн_вт_ср_чт_пт_сб'.split('_'),
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    // полные названия с падежами, по три буквы, для некоторых, по 4 буквы, сокращения с точкой и без точки
    monthsRegex: /^(январ[ья]|янв\.?|феврал[ья]|февр?\.?|марта?|мар\.?|апрел[ья]|апр\.?|ма[йя]|июн[ья]|июн\.?|июл[ья]|июл\.?|августа?|авг\.?|сентябр[ья]|сент?\.?|октябр[ья]|окт\.?|ноябр[ья]|нояб?\.?|декабр[ья]|дек\.?)/i,
    // копия предыдущего
    monthsShortRegex: /^(январ[ья]|янв\.?|феврал[ья]|февр?\.?|марта?|мар\.?|апрел[ья]|апр\.?|ма[йя]|июн[ья]|июн\.?|июл[ья]|июл\.?|августа?|авг\.?|сентябр[ья]|сент?\.?|октябр[ья]|окт\.?|ноябр[ья]|нояб?\.?|декабр[ья]|дек\.?)/i,
    // полные названия с падежами
    monthsStrictRegex: /^(январ[яь]|феврал[яь]|марта?|апрел[яь]|ма[яй]|июн[яь]|июл[яь]|августа?|сентябр[яь]|октябр[яь]|ноябр[яь]|декабр[яь])/i,
    // Выражение, которое соответствует только сокращённым формам
    monthsShortStrictRegex: /^(янв\.|февр?\.|мар[т.]|апр\.|ма[яй]|июн[ья.]|июл[ья.]|авг\.|сент?\.|окт\.|нояб?\.|дек\.)/i,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY г.',
      LLL: 'D MMMM YYYY г., H:mm',
      LLLL: 'dddd, D MMMM YYYY г., H:mm'
    },
    calendar: {
      sameDay: '[Сегодня, в] LT',
      nextDay: '[Завтра, в] LT',
      lastDay: '[Вчера, в] LT',
      nextWeek: function nextWeek(now) {
        if (now.week() !== this.week()) {
          switch (this.day()) {
            case 0:
              return '[В следующее] dddd, [в] LT';

            case 1:
            case 2:
            case 4:
              return '[В следующий] dddd, [в] LT';

            case 3:
            case 5:
            case 6:
              return '[В следующую] dddd, [в] LT';
          }
        } else {
          if (this.day() === 2) {
            return '[Во] dddd, [в] LT';
          } else {
            return '[В] dddd, [в] LT';
          }
        }
      },
      lastWeek: function lastWeek(now) {
        if (now.week() !== this.week()) {
          switch (this.day()) {
            case 0:
              return '[В прошлое] dddd, [в] LT';

            case 1:
            case 2:
            case 4:
              return '[В прошлый] dddd, [в] LT';

            case 3:
            case 5:
            case 6:
              return '[В прошлую] dddd, [в] LT';
          }
        } else {
          if (this.day() === 2) {
            return '[Во] dddd, [в] LT';
          } else {
            return '[В] dddd, [в] LT';
          }
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'через %s',
      past: '%s назад',
      s: 'несколько секунд',
      ss: relativeTimeWithPlural,
      m: relativeTimeWithPlural,
      mm: relativeTimeWithPlural,
      h: 'час',
      hh: relativeTimeWithPlural,
      d: 'день',
      dd: relativeTimeWithPlural,
      w: 'неделя',
      ww: relativeTimeWithPlural,
      M: 'месяц',
      MM: relativeTimeWithPlural,
      y: 'год',
      yy: relativeTimeWithPlural
    },
    meridiemParse: /ночи|утра|дня|вечера/i,
    isPM: function isPM(input) {
      return /^(дня|вечера)$/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'ночи';
      } else if (hour < 12) {
        return 'утра';
      } else if (hour < 17) {
        return 'дня';
      } else {
        return 'вечера';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(й|го|я)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'M':
        case 'd':
        case 'DDD':
          return number + '-й';

        case 'D':
          return number + '-го';

        case 'w':
        case 'W':
          return number + '-я';

        default:
          return number;
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return ru;
});

/***/ }),

/***/ "lYtQ":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/mn.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Mongolian [mn]
//! author : Javkhlantugs Nyamdorj : https://github.com/javkhaanj7
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function translate(number, withoutSuffix, key, isFuture) {
    switch (key) {
      case 's':
        return withoutSuffix ? 'хэдхэн секунд' : 'хэдхэн секундын';

      case 'ss':
        return number + (withoutSuffix ? ' секунд' : ' секундын');

      case 'm':
      case 'mm':
        return number + (withoutSuffix ? ' минут' : ' минутын');

      case 'h':
      case 'hh':
        return number + (withoutSuffix ? ' цаг' : ' цагийн');

      case 'd':
      case 'dd':
        return number + (withoutSuffix ? ' өдөр' : ' өдрийн');

      case 'M':
      case 'MM':
        return number + (withoutSuffix ? ' сар' : ' сарын');

      case 'y':
      case 'yy':
        return number + (withoutSuffix ? ' жил' : ' жилийн');

      default:
        return number;
    }
  }

  var mn = moment.defineLocale('mn', {
    months: 'Нэгдүгээр сар_Хоёрдугаар сар_Гуравдугаар сар_Дөрөвдүгээр сар_Тавдугаар сар_Зургадугаар сар_Долдугаар сар_Наймдугаар сар_Есдүгээр сар_Аравдугаар сар_Арван нэгдүгээр сар_Арван хоёрдугаар сар'.split('_'),
    monthsShort: '1 сар_2 сар_3 сар_4 сар_5 сар_6 сар_7 сар_8 сар_9 сар_10 сар_11 сар_12 сар'.split('_'),
    monthsParseExact: true,
    weekdays: 'Ням_Даваа_Мягмар_Лхагва_Пүрэв_Баасан_Бямба'.split('_'),
    weekdaysShort: 'Ням_Дав_Мяг_Лха_Пүр_Баа_Бям'.split('_'),
    weekdaysMin: 'Ня_Да_Мя_Лх_Пү_Ба_Бя'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'YYYY-MM-DD',
      LL: 'YYYY оны MMMMын D',
      LLL: 'YYYY оны MMMMын D HH:mm',
      LLLL: 'dddd, YYYY оны MMMMын D HH:mm'
    },
    meridiemParse: /ҮӨ|ҮХ/i,
    isPM: function isPM(input) {
      return input === 'ҮХ';
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ҮӨ';
      } else {
        return 'ҮХ';
      }
    },
    calendar: {
      sameDay: '[Өнөөдөр] LT',
      nextDay: '[Маргааш] LT',
      nextWeek: '[Ирэх] dddd LT',
      lastDay: '[Өчигдөр] LT',
      lastWeek: '[Өнгөрсөн] dddd LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s дараа',
      past: '%s өмнө',
      s: translate,
      ss: translate,
      m: translate,
      mm: translate,
      h: translate,
      hh: translate,
      d: translate,
      dd: translate,
      M: translate,
      MM: translate,
      y: translate,
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2} өдөр/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'd':
        case 'D':
        case 'DDD':
          return number + ' өдөр';

        default:
          return number;
      }
    }
  });
  return mn;
});

/***/ }),

/***/ "lgnt":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ky.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Kyrgyz [ky]
//! author : Chyngyz Arystan uulu : https://github.com/chyngyz
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var suffixes = {
    0: '-чү',
    1: '-чи',
    2: '-чи',
    3: '-чү',
    4: '-чү',
    5: '-чи',
    6: '-чы',
    7: '-чи',
    8: '-чи',
    9: '-чу',
    10: '-чу',
    20: '-чы',
    30: '-чу',
    40: '-чы',
    50: '-чү',
    60: '-чы',
    70: '-чи',
    80: '-чи',
    90: '-чу',
    100: '-чү'
  };
  var ky = moment.defineLocale('ky', {
    months: 'январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь'.split('_'),
    monthsShort: 'янв_фев_март_апр_май_июнь_июль_авг_сен_окт_ноя_дек'.split('_'),
    weekdays: 'Жекшемби_Дүйшөмбү_Шейшемби_Шаршемби_Бейшемби_Жума_Ишемби'.split('_'),
    weekdaysShort: 'Жек_Дүй_Шей_Шар_Бей_Жум_Ише'.split('_'),
    weekdaysMin: 'Жк_Дй_Шй_Шр_Бй_Жм_Иш'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Бүгүн саат] LT',
      nextDay: '[Эртең саат] LT',
      nextWeek: 'dddd [саат] LT',
      lastDay: '[Кечээ саат] LT',
      lastWeek: '[Өткөн аптанын] dddd [күнү] [саат] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s ичинде',
      past: '%s мурун',
      s: 'бирнече секунд',
      ss: '%d секунд',
      m: 'бир мүнөт',
      mm: '%d мүнөт',
      h: 'бир саат',
      hh: '%d саат',
      d: 'бир күн',
      dd: '%d күн',
      M: 'бир ай',
      MM: '%d ай',
      y: 'бир жыл',
      yy: '%d жыл'
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(чи|чы|чү|чу)/,
    ordinal: function ordinal(number) {
      var a = number % 10,
          b = number >= 100 ? 100 : null;
      return number + (suffixes[number] || suffixes[a] || suffixes[b]);
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return ky;
});

/***/ }),

/***/ "loYQ":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/bn-bd.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Bengali (Bangladesh) [bn-bd]
//! author : Asraf Hossain Patoary : https://github.com/ashwoolford
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var symbolMap = {
    1: '১',
    2: '২',
    3: '৩',
    4: '৪',
    5: '৫',
    6: '৬',
    7: '৭',
    8: '৮',
    9: '৯',
    0: '০'
  },
      numberMap = {
    '১': '1',
    '২': '2',
    '৩': '3',
    '৪': '4',
    '৫': '5',
    '৬': '6',
    '৭': '7',
    '৮': '8',
    '৯': '9',
    '০': '0'
  };
  var bnBd = moment.defineLocale('bn-bd', {
    months: 'জানুয়ারি_ফেব্রুয়ারি_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্টেম্বর_অক্টোবর_নভেম্বর_ডিসেম্বর'.split('_'),
    monthsShort: 'জানু_ফেব্রু_মার্চ_এপ্রিল_মে_জুন_জুলাই_আগস্ট_সেপ্ট_অক্টো_নভে_ডিসে'.split('_'),
    weekdays: 'রবিবার_সোমবার_মঙ্গলবার_বুধবার_বৃহস্পতিবার_শুক্রবার_শনিবার'.split('_'),
    weekdaysShort: 'রবি_সোম_মঙ্গল_বুধ_বৃহস্পতি_শুক্র_শনি'.split('_'),
    weekdaysMin: 'রবি_সোম_মঙ্গল_বুধ_বৃহ_শুক্র_শনি'.split('_'),
    longDateFormat: {
      LT: 'A h:mm সময়',
      LTS: 'A h:mm:ss সময়',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY, A h:mm সময়',
      LLLL: 'dddd, D MMMM YYYY, A h:mm সময়'
    },
    calendar: {
      sameDay: '[আজ] LT',
      nextDay: '[আগামীকাল] LT',
      nextWeek: 'dddd, LT',
      lastDay: '[গতকাল] LT',
      lastWeek: '[গত] dddd, LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s পরে',
      past: '%s আগে',
      s: 'কয়েক সেকেন্ড',
      ss: '%d সেকেন্ড',
      m: 'এক মিনিট',
      mm: '%d মিনিট',
      h: 'এক ঘন্টা',
      hh: '%d ঘন্টা',
      d: 'এক দিন',
      dd: '%d দিন',
      M: 'এক মাস',
      MM: '%d মাস',
      y: 'এক বছর',
      yy: '%d বছর'
    },
    preparse: function preparse(string) {
      return string.replace(/[১২৩৪৫৬৭৮৯০]/g, function (match) {
        return numberMap[match];
      });
    },
    postformat: function postformat(string) {
      return string.replace(/\d/g, function (match) {
        return symbolMap[match];
      });
    },
    meridiemParse: /রাত|ভোর|সকাল|দুপুর|বিকাল|সন্ধ্যা|রাত/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'রাত') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'ভোর') {
        return hour;
      } else if (meridiem === 'সকাল') {
        return hour;
      } else if (meridiem === 'দুপুর') {
        return hour >= 3 ? hour : hour + 12;
      } else if (meridiem === 'বিকাল') {
        return hour + 12;
      } else if (meridiem === 'সন্ধ্যা') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'রাত';
      } else if (hour < 6) {
        return 'ভোর';
      } else if (hour < 12) {
        return 'সকাল';
      } else if (hour < 15) {
        return 'দুপুর';
      } else if (hour < 18) {
        return 'বিকাল';
      } else if (hour < 20) {
        return 'সন্ধ্যা';
      } else {
        return 'রাত';
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 6 // The week that contains Jan 6th is the first week of the year.

    }
  });
  return bnBd;
});

/***/ }),

/***/ "lpKW":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/windowCount.js ***!
  \**********************************************************************/
/*! exports provided: windowCount */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "windowCount", function() { return windowCount; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subject */ "XNiG");






function windowCount(windowSize) {
  var startWindowEvery = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return function windowCountOperatorFunction(source) {
    return source.lift(new WindowCountOperator(windowSize, startWindowEvery));
  };
}

var WindowCountOperator = /*#__PURE__*/function () {
  function WindowCountOperator(windowSize, startWindowEvery) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, WindowCountOperator);

    this.windowSize = windowSize;
    this.startWindowEvery = startWindowEvery;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowCountOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new WindowCountSubscriber(subscriber, this.windowSize, this.startWindowEvery));
    }
  }]);

  return WindowCountOperator;
}();

var WindowCountSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(WindowCountSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(WindowCountSubscriber);

  function WindowCountSubscriber(destination, windowSize, startWindowEvery) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, WindowCountSubscriber);

    _this = _super.call(this, destination);
    _this.destination = destination;
    _this.windowSize = windowSize;
    _this.startWindowEvery = startWindowEvery;
    _this.windows = [new _Subject__WEBPACK_IMPORTED_MODULE_5__["Subject"]()];
    _this.count = 0;
    destination.next(_this.windows[0]);
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowCountSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var startWindowEvery = this.startWindowEvery > 0 ? this.startWindowEvery : this.windowSize;
      var destination = this.destination;
      var windowSize = this.windowSize;
      var windows = this.windows;
      var len = windows.length;

      for (var i = 0; i < len && !this.closed; i++) {
        windows[i].next(value);
      }

      var c = this.count - windowSize + 1;

      if (c >= 0 && c % startWindowEvery === 0 && !this.closed) {
        windows.shift().complete();
      }

      if (++this.count % startWindowEvery === 0 && !this.closed) {
        var window = new _Subject__WEBPACK_IMPORTED_MODULE_5__["Subject"]();
        windows.push(window);
        destination.next(window);
      }
    }
  }, {
    key: "_error",
    value: function _error(err) {
      var windows = this.windows;

      if (windows) {
        while (windows.length > 0 && !this.closed) {
          windows.shift().error(err);
        }
      }

      this.destination.error(err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var windows = this.windows;

      if (windows) {
        while (windows.length > 0 && !this.closed) {
          windows.shift().complete();
        }
      }

      this.destination.complete();
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      this.count = 0;
      this.windows = null;
    }
  }]);

  return WindowCountSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "lyxo":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/ro.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Romanian [ro]
//! author : Vlad Gurdiga : https://github.com/gurdiga
//! author : Valentin Agachi : https://github.com/avaly
//! author : Emanuel Cepoi : https://github.com/cepem
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function relativeTimeWithPlural(number, withoutSuffix, key) {
    var format = {
      ss: 'secunde',
      mm: 'minute',
      hh: 'ore',
      dd: 'zile',
      ww: 'săptămâni',
      MM: 'luni',
      yy: 'ani'
    },
        separator = ' ';

    if (number % 100 >= 20 || number >= 100 && number % 100 === 0) {
      separator = ' de ';
    }

    return number + separator + format[key];
  }

  var ro = moment.defineLocale('ro', {
    months: 'ianuarie_februarie_martie_aprilie_mai_iunie_iulie_august_septembrie_octombrie_noiembrie_decembrie'.split('_'),
    monthsShort: 'ian._feb._mart._apr._mai_iun._iul._aug._sept._oct._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'duminică_luni_marți_miercuri_joi_vineri_sâmbătă'.split('_'),
    weekdaysShort: 'Dum_Lun_Mar_Mie_Joi_Vin_Sâm'.split('_'),
    weekdaysMin: 'Du_Lu_Ma_Mi_Jo_Vi_Sâ'.split('_'),
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY H:mm',
      LLLL: 'dddd, D MMMM YYYY H:mm'
    },
    calendar: {
      sameDay: '[azi la] LT',
      nextDay: '[mâine la] LT',
      nextWeek: 'dddd [la] LT',
      lastDay: '[ieri la] LT',
      lastWeek: '[fosta] dddd [la] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'peste %s',
      past: '%s în urmă',
      s: 'câteva secunde',
      ss: relativeTimeWithPlural,
      m: 'un minut',
      mm: relativeTimeWithPlural,
      h: 'o oră',
      hh: relativeTimeWithPlural,
      d: 'o zi',
      dd: relativeTimeWithPlural,
      w: 'o săptămână',
      ww: relativeTimeWithPlural,
      M: 'o lună',
      MM: relativeTimeWithPlural,
      y: 'un an',
      yy: relativeTimeWithPlural
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return ro;
});

/***/ }),

/***/ "m2j4":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/isEmpty.js ***!
  \******************************************************************/
/*! exports provided: isEmpty */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isEmpty", function() { return isEmpty; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function isEmpty() {
  return function (source) {
    return source.lift(new IsEmptyOperator());
  };
}

var IsEmptyOperator = /*#__PURE__*/function () {
  function IsEmptyOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, IsEmptyOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(IsEmptyOperator, [{
    key: "call",
    value: function call(observer, source) {
      return source.subscribe(new IsEmptySubscriber(observer));
    }
  }]);

  return IsEmptyOperator;
}();

var IsEmptySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(IsEmptySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(IsEmptySubscriber);

  function IsEmptySubscriber(destination) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, IsEmptySubscriber);

    return _super.call(this, destination);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(IsEmptySubscriber, [{
    key: "notifyComplete",
    value: function notifyComplete(isEmpty) {
      var destination = this.destination;
      destination.next(isEmpty);
      destination.complete();
    }
  }, {
    key: "_next",
    value: function _next(value) {
      this.notifyComplete(false);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.notifyComplete(true);
    }
  }]);

  return IsEmptySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "mCNh":
/*!**********************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/pipe.js ***!
  \**********************************************************/
/*! exports provided: pipe, pipeFromArray */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "pipe", function() { return pipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "pipeFromArray", function() { return pipeFromArray; });
/* harmony import */ var _identity__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./identity */ "SpAZ");

function pipe() {
  for (var _len = arguments.length, fns = new Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }

  return pipeFromArray(fns);
}
function pipeFromArray(fns) {
  if (fns.length === 0) {
    return _identity__WEBPACK_IMPORTED_MODULE_0__["identity"];
  }

  if (fns.length === 1) {
    return fns[0];
  }

  return function piped(input) {
    return fns.reduce(function (prev, fn) {
      return fn(prev);
    }, input);
  };
}

/***/ }),

/***/ "md7G":
/*!******************************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/possibleConstructorReturn.js ***!
  \******************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _possibleConstructorReturn; });
/* harmony import */ var _helpers_esm_typeof__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../helpers/esm/typeof */ "U8pU");
/* harmony import */ var _assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./assertThisInitialized */ "JX7q");


function _possibleConstructorReturn(self, call) {
  if (call && (Object(_helpers_esm_typeof__WEBPACK_IMPORTED_MODULE_0__["default"])(call) === "object" || typeof call === "function")) {
    return call;
  }

  return Object(_assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__["default"])(self);
}

/***/ }),

/***/ "mk5/":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/window.js ***!
  \*****************************************************************/
/*! exports provided: window */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "window", function() { return window; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");






function window(windowBoundaries) {
  return function windowOperatorFunction(source) {
    return source.lift(new WindowOperator(windowBoundaries));
  };
}

var WindowOperator = /*#__PURE__*/function () {
  function WindowOperator(windowBoundaries) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, WindowOperator);

    this.windowBoundaries = windowBoundaries;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      var windowSubscriber = new WindowSubscriber(subscriber);
      var sourceSubscription = source.subscribe(windowSubscriber);

      if (!sourceSubscription.closed) {
        windowSubscriber.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["innerSubscribe"])(this.windowBoundaries, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["SimpleInnerSubscriber"](windowSubscriber)));
      }

      return sourceSubscription;
    }
  }]);

  return WindowOperator;
}();

var WindowSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(WindowSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(WindowSubscriber);

  function WindowSubscriber(destination) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, WindowSubscriber);

    _this = _super.call(this, destination);
    _this.window = new _Subject__WEBPACK_IMPORTED_MODULE_4__["Subject"]();
    destination.next(_this.window);
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowSubscriber, [{
    key: "notifyNext",
    value: function notifyNext() {
      this.openWindow();
    }
  }, {
    key: "notifyError",
    value: function notifyError(error) {
      this._error(error);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this._complete();
    }
  }, {
    key: "_next",
    value: function _next(value) {
      this.window.next(value);
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.window.error(err);
      this.destination.error(err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.window.complete();
      this.destination.complete();
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      this.window = null;
    }
  }, {
    key: "openWindow",
    value: function openWindow() {
      var prevWindow = this.window;

      if (prevWindow) {
        prevWindow.complete();
      }

      var destination = this.destination;
      var newWindow = this.window = new _Subject__WEBPACK_IMPORTED_MODULE_4__["Subject"]();
      destination.next(newWindow);
    }
  }]);

  return WindowSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "mlxB":
/*!************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isDate.js ***!
  \************************************************************/
/*! exports provided: isDate */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isDate", function() { return isDate; });
function isDate(value) {
  return value instanceof Date && !isNaN(+value);
}

/***/ }),

/***/ "mrSG":
/*!*****************************************!*\
  !*** ./node_modules/tslib/tslib.es6.js ***!
  \*****************************************/
/*! exports provided: __extends, __assign, __rest, __decorate, __param, __metadata, __awaiter, __generator, __createBinding, __exportStar, __values, __read, __spread, __spreadArrays, __await, __asyncGenerator, __asyncDelegator, __asyncValues, __makeTemplateObject, __importStar, __importDefault, __classPrivateFieldGet, __classPrivateFieldSet */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__extends", function() { return __extends; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__assign", function() { return __assign; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__rest", function() { return __rest; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__decorate", function() { return __decorate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__param", function() { return __param; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__metadata", function() { return __metadata; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__awaiter", function() { return __awaiter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__generator", function() { return __generator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__createBinding", function() { return __createBinding; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__exportStar", function() { return __exportStar; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__values", function() { return __values; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__read", function() { return __read; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__spread", function() { return __spread; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__spreadArrays", function() { return __spreadArrays; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__await", function() { return __await; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__asyncGenerator", function() { return __asyncGenerator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__asyncDelegator", function() { return __asyncDelegator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__asyncValues", function() { return __asyncValues; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__makeTemplateObject", function() { return __makeTemplateObject; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__importStar", function() { return __importStar; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__importDefault", function() { return __importDefault; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__classPrivateFieldGet", function() { return __classPrivateFieldGet; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "__classPrivateFieldSet", function() { return __classPrivateFieldSet; });
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    }
    return __assign.apply(this, arguments);
}

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __param(paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
}

function __metadata(metadataKey, metadataValue) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var __createBinding = Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
});

function __exportStar(m, o) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p)) __createBinding(o, m, p);
}

function __values(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
}

function __read(o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
}

function __spread() {
    for (var ar = [], i = 0; i < arguments.length; i++)
        ar = ar.concat(__read(arguments[i]));
    return ar;
}

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};

function __await(v) {
    return this instanceof __await ? (this.v = v, this) : new __await(v);
}

function __asyncGenerator(thisArg, _arguments, generator) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var g = generator.apply(thisArg, _arguments || []), i, q = [];
    return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
    function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
    function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
    function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
    function fulfill(value) { resume("next", value); }
    function reject(value) { resume("throw", value); }
    function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
}

function __asyncDelegator(o) {
    var i, p;
    return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
    function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
}

function __asyncValues(o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
}

function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};

var __setModuleDefault = Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
};

function __importStar(mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
}

function __importDefault(mod) {
    return (mod && mod.__esModule) ? mod : { default: mod };
}

function __classPrivateFieldGet(receiver, privateMap) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
    }
    return privateMap.get(receiver);
}

function __classPrivateFieldSet(receiver, privateMap, value) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
    }
    privateMap.set(receiver, value);
    return value;
}


/***/ }),

/***/ "n6bG":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isFunction.js ***!
  \****************************************************************/
/*! exports provided: isFunction */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isFunction", function() { return isFunction; });
function isFunction(x) {
  return typeof x === 'function';
}

/***/ }),

/***/ "nYR2":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/finalize.js ***!
  \*******************************************************************/
/*! exports provided: finalize */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "finalize", function() { return finalize; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscription */ "quSY");






function finalize(callback) {
  return function (source) {
    return source.lift(new FinallyOperator(callback));
  };
}

var FinallyOperator = /*#__PURE__*/function () {
  function FinallyOperator(callback) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, FinallyOperator);

    this.callback = callback;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(FinallyOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new FinallySubscriber(subscriber, this.callback));
    }
  }]);

  return FinallyOperator;
}();

var FinallySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(FinallySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(FinallySubscriber);

  function FinallySubscriber(destination, callback) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, FinallySubscriber);

    _this = _super.call(this, destination);

    _this.add(new _Subscription__WEBPACK_IMPORTED_MODULE_5__["Subscription"](callback));

    return _this;
  }

  return FinallySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "ngJS":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/subscribeToArray.js ***!
  \**********************************************************************/
/*! exports provided: subscribeToArray */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeToArray", function() { return subscribeToArray; });
var subscribeToArray = function subscribeToArray(array) {
  return function (subscriber) {
    for (var i = 0, len = array.length; i < len && !subscriber.closed; i++) {
      subscriber.next(array[i]);
    }

    subscriber.complete();
  };
};

/***/ }),

/***/ "nyYc":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/fr.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : French [fr]
//! author : John Fischer : https://github.com/jfroffice
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsStrictRegex = /^(janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i,
      monthsShortStrictRegex = /(janv\.?|févr\.?|mars|avr\.?|mai|juin|juil\.?|août|sept\.?|oct\.?|nov\.?|déc\.?)/i,
      monthsRegex = /(janv\.?|févr\.?|mars|avr\.?|mai|juin|juil\.?|août|sept\.?|oct\.?|nov\.?|déc\.?|janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i,
      monthsParse = [/^janv/i, /^févr/i, /^mars/i, /^avr/i, /^mai/i, /^juin/i, /^juil/i, /^août/i, /^sept/i, /^oct/i, /^nov/i, /^déc/i];
  var fr = moment.defineLocale('fr', {
    months: 'janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre'.split('_'),
    monthsShort: 'janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.'.split('_'),
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: monthsStrictRegex,
    monthsShortStrictRegex: monthsShortStrictRegex,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi'.split('_'),
    weekdaysShort: 'dim._lun._mar._mer._jeu._ven._sam.'.split('_'),
    weekdaysMin: 'di_lu_ma_me_je_ve_sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Aujourd’hui à] LT',
      nextDay: '[Demain à] LT',
      nextWeek: 'dddd [à] LT',
      lastDay: '[Hier à] LT',
      lastWeek: 'dddd [dernier à] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dans %s',
      past: 'il y a %s',
      s: 'quelques secondes',
      ss: '%d secondes',
      m: 'une minute',
      mm: '%d minutes',
      h: 'une heure',
      hh: '%d heures',
      d: 'un jour',
      dd: '%d jours',
      w: 'une semaine',
      ww: '%d semaines',
      M: 'un mois',
      MM: '%d mois',
      y: 'un an',
      yy: '%d ans'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(er|)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        // TODO: Return 'e' when day of month > 1. Move this case inside
        // block for masculine words below.
        // See https://github.com/moment/moment/issues/3375
        case 'D':
          return number + (number === 1 ? 'er' : '');
        // Words with masculine grammatical gender: mois, trimestre, jour

        default:
        case 'M':
        case 'Q':
        case 'DDD':
        case 'd':
          return number + (number === 1 ? 'er' : 'e');
        // Words with feminine grammatical gender: semaine

        case 'w':
        case 'W':
          return number + (number === 1 ? 're' : 'e');
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return fr;
});

/***/ }),

/***/ "o1bE":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/ar-dz.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Arabic (Algeria) [ar-dz]
//! author : Amine Roukh: https://github.com/Amine27
//! author : Abdel Said: https://github.com/abdelsaid
//! author : Ahmed Elkhatib
//! author : forabi https://github.com/forabi
//! author : Noureddine LOUAHEDJ : https://github.com/noureddinem
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var pluralForm = function pluralForm(n) {
    return n === 0 ? 0 : n === 1 ? 1 : n === 2 ? 2 : n % 100 >= 3 && n % 100 <= 10 ? 3 : n % 100 >= 11 ? 4 : 5;
  },
      plurals = {
    s: ['أقل من ثانية', 'ثانية واحدة', ['ثانيتان', 'ثانيتين'], '%d ثوان', '%d ثانية', '%d ثانية'],
    m: ['أقل من دقيقة', 'دقيقة واحدة', ['دقيقتان', 'دقيقتين'], '%d دقائق', '%d دقيقة', '%d دقيقة'],
    h: ['أقل من ساعة', 'ساعة واحدة', ['ساعتان', 'ساعتين'], '%d ساعات', '%d ساعة', '%d ساعة'],
    d: ['أقل من يوم', 'يوم واحد', ['يومان', 'يومين'], '%d أيام', '%d يومًا', '%d يوم'],
    M: ['أقل من شهر', 'شهر واحد', ['شهران', 'شهرين'], '%d أشهر', '%d شهرا', '%d شهر'],
    y: ['أقل من عام', 'عام واحد', ['عامان', 'عامين'], '%d أعوام', '%d عامًا', '%d عام']
  },
      pluralize = function pluralize(u) {
    return function (number, withoutSuffix, string, isFuture) {
      var f = pluralForm(number),
          str = plurals[u][pluralForm(number)];

      if (f === 2) {
        str = str[withoutSuffix ? 0 : 1];
      }

      return str.replace(/%d/i, number);
    };
  },
      months = ['جانفي', 'فيفري', 'مارس', 'أفريل', 'ماي', 'جوان', 'جويلية', 'أوت', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'];

  var arDz = moment.defineLocale('ar-dz', {
    months: months,
    monthsShort: months,
    weekdays: 'الأحد_الإثنين_الثلاثاء_الأربعاء_الخميس_الجمعة_السبت'.split('_'),
    weekdaysShort: 'أحد_إثنين_ثلاثاء_أربعاء_خميس_جمعة_سبت'.split('_'),
    weekdaysMin: 'ح_ن_ث_ر_خ_ج_س'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: "D/\u200FM/\u200FYYYY",
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    meridiemParse: /ص|م/,
    isPM: function isPM(input) {
      return 'م' === input;
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ص';
      } else {
        return 'م';
      }
    },
    calendar: {
      sameDay: '[اليوم عند الساعة] LT',
      nextDay: '[غدًا عند الساعة] LT',
      nextWeek: 'dddd [عند الساعة] LT',
      lastDay: '[أمس عند الساعة] LT',
      lastWeek: 'dddd [عند الساعة] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'بعد %s',
      past: 'منذ %s',
      s: pluralize('s'),
      ss: pluralize('s'),
      m: pluralize('m'),
      mm: pluralize('m'),
      h: pluralize('h'),
      hh: pluralize('h'),
      d: pluralize('d'),
      dd: pluralize('d'),
      M: pluralize('M'),
      MM: pluralize('M'),
      y: pluralize('y'),
      yy: pluralize('y')
    },
    postformat: function postformat(string) {
      return string.replace(/,/g, '،');
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return arDz;
});

/***/ }),

/***/ "oB13":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/multicast.js ***!
  \********************************************************************/
/*! exports provided: multicast, MulticastOperator */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "multicast", function() { return multicast; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "MulticastOperator", function() { return MulticastOperator; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _observable_ConnectableObservable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../observable/ConnectableObservable */ "EQ5u");



function multicast(subjectOrSubjectFactory, selector) {
  return function multicastOperatorFunction(source) {
    var subjectFactory;

    if (typeof subjectOrSubjectFactory === 'function') {
      subjectFactory = subjectOrSubjectFactory;
    } else {
      subjectFactory = function subjectFactory() {
        return subjectOrSubjectFactory;
      };
    }

    if (typeof selector === 'function') {
      return source.lift(new MulticastOperator(subjectFactory, selector));
    }

    var connectable = Object.create(source, _observable_ConnectableObservable__WEBPACK_IMPORTED_MODULE_2__["connectableObservableDescriptor"]);
    connectable.source = source;
    connectable.subjectFactory = subjectFactory;
    return connectable;
  };
}
var MulticastOperator = /*#__PURE__*/function () {
  function MulticastOperator(subjectFactory, selector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, MulticastOperator);

    this.subjectFactory = subjectFactory;
    this.selector = selector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(MulticastOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      var selector = this.selector;
      var subject = this.subjectFactory();
      var subscription = selector(subject).subscribe(subscriber);
      subscription.add(source.subscribe(subject));
      return subscription;
    }
  }]);

  return MulticastOperator;
}();

/***/ }),

/***/ "ofXK":
/*!**********************************************************************!*\
  !*** ./node_modules/@angular/common/__ivy_ngcc__/fesm2015/common.js ***!
  \**********************************************************************/
/*! exports provided: APP_BASE_HREF, AsyncPipe, CommonModule, CurrencyPipe, DOCUMENT, DatePipe, DecimalPipe, FormStyle, FormatWidth, HashLocationStrategy, I18nPluralPipe, I18nSelectPipe, JsonPipe, KeyValuePipe, LOCATION_INITIALIZED, Location, LocationStrategy, LowerCasePipe, NgClass, NgComponentOutlet, NgForOf, NgForOfContext, NgIf, NgIfContext, NgLocaleLocalization, NgLocalization, NgPlural, NgPluralCase, NgStyle, NgSwitch, NgSwitchCase, NgSwitchDefault, NgTemplateOutlet, NumberFormatStyle, NumberSymbol, PathLocationStrategy, PercentPipe, PlatformLocation, Plural, SlicePipe, TitleCasePipe, TranslationWidth, UpperCasePipe, VERSION, ViewportScroller, WeekDay, formatCurrency, formatDate, formatNumber, formatPercent, getCurrencySymbol, getLocaleCurrencyCode, getLocaleCurrencyName, getLocaleCurrencySymbol, getLocaleDateFormat, getLocaleDateTimeFormat, getLocaleDayNames, getLocaleDayPeriods, getLocaleDirection, getLocaleEraNames, getLocaleExtraDayPeriodRules, getLocaleExtraDayPeriods, getLocaleFirstDayOfWeek, getLocaleId, getLocaleMonthNames, getLocaleNumberFormat, getLocaleNumberSymbol, getLocalePluralCase, getLocaleTimeFormat, getLocaleWeekEndRange, getNumberOfCurrencyDigits, isPlatformBrowser, isPlatformServer, isPlatformWorkerApp, isPlatformWorkerUi, registerLocaleData, ɵBrowserPlatformLocation, ɵDomAdapter, ɵNullViewportScroller, ɵPLATFORM_BROWSER_ID, ɵPLATFORM_SERVER_ID, ɵPLATFORM_WORKER_APP_ID, ɵPLATFORM_WORKER_UI_ID, ɵangular_packages_common_common_a, ɵangular_packages_common_common_b, ɵangular_packages_common_common_c, ɵangular_packages_common_common_d, ɵangular_packages_common_common_e, ɵangular_packages_common_common_f, ɵgetDOM, ɵparseCookieValue, ɵsetRootDomAdapter */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "APP_BASE_HREF", function() { return APP_BASE_HREF; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AsyncPipe", function() { return AsyncPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CommonModule", function() { return CommonModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "CurrencyPipe", function() { return CurrencyPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DOCUMENT", function() { return DOCUMENT; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DatePipe", function() { return DatePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DecimalPipe", function() { return DecimalPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormStyle", function() { return FormStyle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "FormatWidth", function() { return FormatWidth; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HashLocationStrategy", function() { return HashLocationStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "I18nPluralPipe", function() { return I18nPluralPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "I18nSelectPipe", function() { return I18nSelectPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JsonPipe", function() { return JsonPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "KeyValuePipe", function() { return KeyValuePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LOCATION_INITIALIZED", function() { return LOCATION_INITIALIZED; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Location", function() { return Location; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LocationStrategy", function() { return LocationStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "LowerCasePipe", function() { return LowerCasePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgClass", function() { return NgClass; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgComponentOutlet", function() { return NgComponentOutlet; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgForOf", function() { return NgForOf; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgForOfContext", function() { return NgForOfContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgIf", function() { return NgIf; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgIfContext", function() { return NgIfContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgLocaleLocalization", function() { return NgLocaleLocalization; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgLocalization", function() { return NgLocalization; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgPlural", function() { return NgPlural; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgPluralCase", function() { return NgPluralCase; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgStyle", function() { return NgStyle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgSwitch", function() { return NgSwitch; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgSwitchCase", function() { return NgSwitchCase; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgSwitchDefault", function() { return NgSwitchDefault; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NgTemplateOutlet", function() { return NgTemplateOutlet; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NumberFormatStyle", function() { return NumberFormatStyle; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NumberSymbol", function() { return NumberSymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PathLocationStrategy", function() { return PathLocationStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PercentPipe", function() { return PercentPipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PlatformLocation", function() { return PlatformLocation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Plural", function() { return Plural; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SlicePipe", function() { return SlicePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TitleCasePipe", function() { return TitleCasePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "TranslationWidth", function() { return TranslationWidth; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UpperCasePipe", function() { return UpperCasePipe; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ViewportScroller", function() { return ViewportScroller; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "WeekDay", function() { return WeekDay; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "formatCurrency", function() { return formatCurrency; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "formatDate", function() { return formatDate; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "formatNumber", function() { return formatNumber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "formatPercent", function() { return formatPercent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getCurrencySymbol", function() { return getCurrencySymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleCurrencyCode", function() { return getLocaleCurrencyCode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleCurrencyName", function() { return getLocaleCurrencyName; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleCurrencySymbol", function() { return getLocaleCurrencySymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleDateFormat", function() { return getLocaleDateFormat; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleDateTimeFormat", function() { return getLocaleDateTimeFormat; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleDayNames", function() { return getLocaleDayNames; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleDayPeriods", function() { return getLocaleDayPeriods; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleDirection", function() { return getLocaleDirection; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleEraNames", function() { return getLocaleEraNames; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleExtraDayPeriodRules", function() { return getLocaleExtraDayPeriodRules; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleExtraDayPeriods", function() { return getLocaleExtraDayPeriods; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleFirstDayOfWeek", function() { return getLocaleFirstDayOfWeek; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleId", function() { return getLocaleId; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleMonthNames", function() { return getLocaleMonthNames; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleNumberFormat", function() { return getLocaleNumberFormat; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleNumberSymbol", function() { return getLocaleNumberSymbol; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocalePluralCase", function() { return getLocalePluralCase; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleTimeFormat", function() { return getLocaleTimeFormat; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getLocaleWeekEndRange", function() { return getLocaleWeekEndRange; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "getNumberOfCurrencyDigits", function() { return getNumberOfCurrencyDigits; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isPlatformBrowser", function() { return isPlatformBrowser; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isPlatformServer", function() { return isPlatformServer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isPlatformWorkerApp", function() { return isPlatformWorkerApp; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isPlatformWorkerUi", function() { return isPlatformWorkerUi; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "registerLocaleData", function() { return registerLocaleData; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵBrowserPlatformLocation", function() { return BrowserPlatformLocation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵDomAdapter", function() { return DomAdapter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵNullViewportScroller", function() { return NullViewportScroller; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵPLATFORM_BROWSER_ID", function() { return PLATFORM_BROWSER_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵPLATFORM_SERVER_ID", function() { return PLATFORM_SERVER_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵPLATFORM_WORKER_APP_ID", function() { return PLATFORM_WORKER_APP_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵPLATFORM_WORKER_UI_ID", function() { return PLATFORM_WORKER_UI_ID; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_common_a", function() { return useBrowserPlatformLocation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_common_b", function() { return createBrowserPlatformLocation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_common_c", function() { return createLocation; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_common_d", function() { return provideLocationStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_common_e", function() { return COMMON_DIRECTIVES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_common_f", function() { return COMMON_PIPES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵgetDOM", function() { return getDOM; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵparseCookieValue", function() { return parseCookieValue; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵsetRootDomAdapter", function() { return setRootDomAdapter; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createForOfIteratorHelper */ "uFwe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ "ODXe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @angular/core */ "fXoL");







/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _DOM = null;

function getDOM() {
  return _DOM;
}

function setDOM(adapter) {
  _DOM = adapter;
}

function setRootDomAdapter(adapter) {
  if (!_DOM) {
    _DOM = adapter;
  }
}
/* tslint:disable:requireParameterType */

/**
 * Provides DOM operations in an environment-agnostic way.
 *
 * @security Tread carefully! Interacting with the DOM directly is dangerous and
 * can introduce XSS risks.
 */


var DomAdapter = function DomAdapter() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, DomAdapter);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A DI Token representing the main rendering context. In a browser this is the DOM Document.
 *
 * Note: Document might not be available in the Application Context when Application and Rendering
 * Contexts are not the same (e.g. when running the application in a Web Worker).
 *
 * @publicApi
 */


var DOCUMENT = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('DocumentToken');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This class should not be used directly by an application developer. Instead, use
 * {@link Location}.
 *
 * `PlatformLocation` encapsulates all calls to DOM APIs, which allows the Router to be
 * platform-agnostic.
 * This means that we can have different implementation of `PlatformLocation` for the different
 * platforms that Angular supports. For example, `@angular/platform-browser` provides an
 * implementation specific to the browser environment, while `@angular/platform-server` provides
 * one suitable for use with server-side rendering.
 *
 * The `PlatformLocation` class is used directly by all implementations of {@link LocationStrategy}
 * when they need to interact with the DOM APIs like pushState, popState, etc.
 *
 * {@link LocationStrategy} in turn is used by the {@link Location} service which is used directly
 * by the {@link Router} in order to navigate between routes. Since all interactions between {@link
 * Router} /
 * {@link Location} / {@link LocationStrategy} and DOM APIs flow through the `PlatformLocation`
 * class, they are all platform-agnostic.
 *
 * @publicApi
 */

var PlatformLocation = function PlatformLocation() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, PlatformLocation);
};

PlatformLocation.ɵfac = function PlatformLocation_Factory(t) {
  return new (t || PlatformLocation)();
};

PlatformLocation.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"])({
  factory: useBrowserPlatformLocation,
  token: PlatformLocation,
  providedIn: "platform"
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](PlatformLocation, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"],
    args: [{
      providedIn: 'platform',
      // See #23917
      useFactory: useBrowserPlatformLocation
    }]
  }], null, null);
})();

function useBrowserPlatformLocation() {
  return Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(BrowserPlatformLocation);
}
/**
 * @description
 * Indicates when a location is initialized.
 *
 * @publicApi
 */


var LOCATION_INITIALIZED = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('Location Initialized');
/**
 * `PlatformLocation` encapsulates all of the direct calls to platform APIs.
 * This class should not be used directly by an application developer. Instead, use
 * {@link Location}.
 */

var BrowserPlatformLocation = /*#__PURE__*/function (_PlatformLocation) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(BrowserPlatformLocation, _PlatformLocation);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(BrowserPlatformLocation);

  function BrowserPlatformLocation(_doc) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BrowserPlatformLocation);

    _this = _super.call(this);
    _this._doc = _doc;

    _this._init();

    return _this;
  } // This is moved to its own method so that `MockPlatformLocationStrategy` can overwrite it

  /** @internal */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(BrowserPlatformLocation, [{
    key: "_init",
    value: function _init() {
      this.location = getDOM().getLocation();
      this._history = getDOM().getHistory();
    }
  }, {
    key: "getBaseHrefFromDOM",
    value: function getBaseHrefFromDOM() {
      return getDOM().getBaseHref(this._doc);
    }
  }, {
    key: "onPopState",
    value: function onPopState(fn) {
      getDOM().getGlobalEventTarget(this._doc, 'window').addEventListener('popstate', fn, false);
    }
  }, {
    key: "onHashChange",
    value: function onHashChange(fn) {
      getDOM().getGlobalEventTarget(this._doc, 'window').addEventListener('hashchange', fn, false);
    }
  }, {
    key: "pushState",
    value: function pushState(state, title, url) {
      if (supportsState()) {
        this._history.pushState(state, title, url);
      } else {
        this.location.hash = url;
      }
    }
  }, {
    key: "replaceState",
    value: function replaceState(state, title, url) {
      if (supportsState()) {
        this._history.replaceState(state, title, url);
      } else {
        this.location.hash = url;
      }
    }
  }, {
    key: "forward",
    value: function forward() {
      this._history.forward();
    }
  }, {
    key: "back",
    value: function back() {
      this._history.back();
    }
  }, {
    key: "getState",
    value: function getState() {
      return this._history.state;
    }
  }, {
    key: "href",
    get: function get() {
      return this.location.href;
    }
  }, {
    key: "protocol",
    get: function get() {
      return this.location.protocol;
    }
  }, {
    key: "hostname",
    get: function get() {
      return this.location.hostname;
    }
  }, {
    key: "port",
    get: function get() {
      return this.location.port;
    }
  }, {
    key: "pathname",
    get: function get() {
      return this.location.pathname;
    },
    set: function set(newPath) {
      this.location.pathname = newPath;
    }
  }, {
    key: "search",
    get: function get() {
      return this.location.search;
    }
  }, {
    key: "hash",
    get: function get() {
      return this.location.hash;
    }
  }]);

  return BrowserPlatformLocation;
}(PlatformLocation);

BrowserPlatformLocation.ɵfac = function BrowserPlatformLocation_Factory(t) {
  return new (t || BrowserPlatformLocation)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](DOCUMENT));
};

BrowserPlatformLocation.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"])({
  factory: createBrowserPlatformLocation,
  token: BrowserPlatformLocation,
  providedIn: "platform"
});

BrowserPlatformLocation.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [DOCUMENT]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](BrowserPlatformLocation, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"],
    args: [{
      providedIn: 'platform',
      // See #23917
      useFactory: createBrowserPlatformLocation
    }]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [DOCUMENT]
      }]
    }];
  }, null);
})();

function supportsState() {
  return !!window.history.pushState;
}

function createBrowserPlatformLocation() {
  return new BrowserPlatformLocation(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(DOCUMENT));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Joins two parts of a URL with a slash if needed.
 *
 * @param start  URL string
 * @param end    URL string
 *
 *
 * @returns The joined URL string.
 */


function joinWithSlash(start, end) {
  if (start.length == 0) {
    return end;
  }

  if (end.length == 0) {
    return start;
  }

  var slashes = 0;

  if (start.endsWith('/')) {
    slashes++;
  }

  if (end.startsWith('/')) {
    slashes++;
  }

  if (slashes == 2) {
    return start + end.substring(1);
  }

  if (slashes == 1) {
    return start + end;
  }

  return start + '/' + end;
}
/**
 * Removes a trailing slash from a URL string if needed.
 * Looks for the first occurrence of either `#`, `?`, or the end of the
 * line as `/` characters and removes the trailing slash if one exists.
 *
 * @param url URL string.
 *
 * @returns The URL string, modified if needed.
 */


function stripTrailingSlash(url) {
  var match = url.match(/#|\?|$/);
  var pathEndIdx = match && match.index || url.length;
  var droppedSlashIdx = pathEndIdx - (url[pathEndIdx - 1] === '/' ? 1 : 0);
  return url.slice(0, droppedSlashIdx) + url.slice(pathEndIdx);
}
/**
 * Normalizes URL parameters by prepending with `?` if needed.
 *
 * @param  params String of URL parameters.
 *
 * @returns The normalized URL parameters string.
 */


function normalizeQueryParams(params) {
  return params && params[0] !== '?' ? '?' + params : params;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Enables the `Location` service to read route state from the browser's URL.
 * Angular provides two strategies:
 * `HashLocationStrategy` and `PathLocationStrategy`.
 *
 * Applications should use the `Router` or `Location` services to
 * interact with application route state.
 *
 * For instance, `HashLocationStrategy` produces URLs like
 * <code class="no-auto-link">http://example.com#/foo</code>,
 * and `PathLocationStrategy` produces
 * <code class="no-auto-link">http://example.com/foo</code> as an equivalent URL.
 *
 * See these two classes for more.
 *
 * @publicApi
 */


var LocationStrategy = function LocationStrategy() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, LocationStrategy);
};

LocationStrategy.ɵfac = function LocationStrategy_Factory(t) {
  return new (t || LocationStrategy)();
};

LocationStrategy.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"])({
  factory: provideLocationStrategy,
  token: LocationStrategy,
  providedIn: "root"
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](LocationStrategy, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"],
    args: [{
      providedIn: 'root',
      useFactory: provideLocationStrategy
    }]
  }], null, null);
})();

function provideLocationStrategy(platformLocation) {
  // See #23917
  var location = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(DOCUMENT).location;
  return new PathLocationStrategy(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(PlatformLocation), location && location.origin || '');
}
/**
 * A predefined [DI token](guide/glossary#di-token) for the base href
 * to be used with the `PathLocationStrategy`.
 * The base href is the URL prefix that should be preserved when generating
 * and recognizing URLs.
 *
 * @usageNotes
 *
 * The following example shows how to use this token to configure the root app injector
 * with a base href value, so that the DI framework can supply the dependency anywhere in the app.
 *
 * ```typescript
 * import {Component, NgModule} from '@angular/core';
 * import {APP_BASE_HREF} from '@angular/common';
 *
 * @NgModule({
 *   providers: [{provide: APP_BASE_HREF, useValue: '/my/app'}]
 * })
 * class AppModule {}
 * ```
 *
 * @publicApi
 */


var APP_BASE_HREF = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('appBaseHref');
/**
 * @description
 * A {@link LocationStrategy} used to configure the {@link Location} service to
 * represent its state in the
 * [path](https://en.wikipedia.org/wiki/Uniform_Resource_Locator#Syntax) of the
 * browser's URL.
 *
 * If you're using `PathLocationStrategy`, you must provide a {@link APP_BASE_HREF}
 * or add a `<base href>` element to the document.
 *
 * For instance, if you provide an `APP_BASE_HREF` of `'/my/app/'` and call
 * `location.go('/foo')`, the browser's URL will become
 * `example.com/my/app/foo`. To ensure all relative URIs resolve correctly,
 * the `<base href>` and/or `APP_BASE_HREF` should end with a `/`.
 *
 * Similarly, if you add `<base href='/my/app/'/>` to the document and call
 * `location.go('/foo')`, the browser's URL will become
 * `example.com/my/app/foo`.
 *
 * Note that when using `PathLocationStrategy`, neither the query nor
 * the fragment in the `<base href>` will be preserved, as outlined
 * by the [RFC](https://tools.ietf.org/html/rfc3986#section-5.2.2).
 *
 * @usageNotes
 *
 * ### Example
 *
 * {@example common/location/ts/path_location_component.ts region='LocationComponent'}
 *
 * @publicApi
 */

var PathLocationStrategy = /*#__PURE__*/function (_LocationStrategy) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(PathLocationStrategy, _LocationStrategy);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(PathLocationStrategy);

  function PathLocationStrategy(_platformLocation, href) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, PathLocationStrategy);

    _this2 = _super2.call(this);
    _this2._platformLocation = _platformLocation;

    if (href == null) {
      href = _this2._platformLocation.getBaseHrefFromDOM();
    }

    if (href == null) {
      throw new Error("No base href set. Please provide a value for the APP_BASE_HREF token or add a base element to the document.");
    }

    _this2._baseHref = href;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(PathLocationStrategy, [{
    key: "onPopState",
    value: function onPopState(fn) {
      this._platformLocation.onPopState(fn);

      this._platformLocation.onHashChange(fn);
    }
  }, {
    key: "getBaseHref",
    value: function getBaseHref() {
      return this._baseHref;
    }
  }, {
    key: "prepareExternalUrl",
    value: function prepareExternalUrl(internal) {
      return joinWithSlash(this._baseHref, internal);
    }
  }, {
    key: "path",
    value: function path() {
      var includeHash = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      var pathname = this._platformLocation.pathname + normalizeQueryParams(this._platformLocation.search);
      var hash = this._platformLocation.hash;
      return hash && includeHash ? "".concat(pathname).concat(hash) : pathname;
    }
  }, {
    key: "pushState",
    value: function pushState(state, title, url, queryParams) {
      var externalUrl = this.prepareExternalUrl(url + normalizeQueryParams(queryParams));

      this._platformLocation.pushState(state, title, externalUrl);
    }
  }, {
    key: "replaceState",
    value: function replaceState(state, title, url, queryParams) {
      var externalUrl = this.prepareExternalUrl(url + normalizeQueryParams(queryParams));

      this._platformLocation.replaceState(state, title, externalUrl);
    }
  }, {
    key: "forward",
    value: function forward() {
      this._platformLocation.forward();
    }
  }, {
    key: "back",
    value: function back() {
      this._platformLocation.back();
    }
  }]);

  return PathLocationStrategy;
}(LocationStrategy);

PathLocationStrategy.ɵfac = function PathLocationStrategy_Factory(t) {
  return new (t || PathLocationStrategy)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](PlatformLocation), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](APP_BASE_HREF, 8));
};

PathLocationStrategy.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: PathLocationStrategy,
  factory: PathLocationStrategy.ɵfac
});

PathLocationStrategy.ctorParameters = function () {
  return [{
    type: PlatformLocation
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [APP_BASE_HREF]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](PathLocationStrategy, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: PlatformLocation
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [APP_BASE_HREF]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 * A {@link LocationStrategy} used to configure the {@link Location} service to
 * represent its state in the
 * [hash fragment](https://en.wikipedia.org/wiki/Uniform_Resource_Locator#Syntax)
 * of the browser's URL.
 *
 * For instance, if you call `location.go('/foo')`, the browser's URL will become
 * `example.com#/foo`.
 *
 * @usageNotes
 *
 * ### Example
 *
 * {@example common/location/ts/hash_location_component.ts region='LocationComponent'}
 *
 * @publicApi
 */


var HashLocationStrategy = /*#__PURE__*/function (_LocationStrategy2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(HashLocationStrategy, _LocationStrategy2);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(HashLocationStrategy);

  function HashLocationStrategy(_platformLocation, _baseHref) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HashLocationStrategy);

    _this3 = _super3.call(this);
    _this3._platformLocation = _platformLocation;
    _this3._baseHref = '';

    if (_baseHref != null) {
      _this3._baseHref = _baseHref;
    }

    return _this3;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(HashLocationStrategy, [{
    key: "onPopState",
    value: function onPopState(fn) {
      this._platformLocation.onPopState(fn);

      this._platformLocation.onHashChange(fn);
    }
  }, {
    key: "getBaseHref",
    value: function getBaseHref() {
      return this._baseHref;
    }
  }, {
    key: "path",
    value: function path() {
      var includeHash = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      // the hash value is always prefixed with a `#`
      // and if it is empty then it will stay empty
      var path = this._platformLocation.hash;
      if (path == null) path = '#';
      return path.length > 0 ? path.substring(1) : path;
    }
  }, {
    key: "prepareExternalUrl",
    value: function prepareExternalUrl(internal) {
      var url = joinWithSlash(this._baseHref, internal);
      return url.length > 0 ? '#' + url : url;
    }
  }, {
    key: "pushState",
    value: function pushState(state, title, path, queryParams) {
      var url = this.prepareExternalUrl(path + normalizeQueryParams(queryParams));

      if (url.length == 0) {
        url = this._platformLocation.pathname;
      }

      this._platformLocation.pushState(state, title, url);
    }
  }, {
    key: "replaceState",
    value: function replaceState(state, title, path, queryParams) {
      var url = this.prepareExternalUrl(path + normalizeQueryParams(queryParams));

      if (url.length == 0) {
        url = this._platformLocation.pathname;
      }

      this._platformLocation.replaceState(state, title, url);
    }
  }, {
    key: "forward",
    value: function forward() {
      this._platformLocation.forward();
    }
  }, {
    key: "back",
    value: function back() {
      this._platformLocation.back();
    }
  }]);

  return HashLocationStrategy;
}(LocationStrategy);

HashLocationStrategy.ɵfac = function HashLocationStrategy_Factory(t) {
  return new (t || HashLocationStrategy)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](PlatformLocation), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](APP_BASE_HREF, 8));
};

HashLocationStrategy.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: HashLocationStrategy,
  factory: HashLocationStrategy.ɵfac
});

HashLocationStrategy.ctorParameters = function () {
  return [{
    type: PlatformLocation
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [APP_BASE_HREF]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HashLocationStrategy, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: PlatformLocation
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [APP_BASE_HREF]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * A service that applications can use to interact with a browser's URL.
 *
 * Depending on the `LocationStrategy` used, `Location` persists
 * to the URL's path or the URL's hash segment.
 *
 * @usageNotes
 *
 * It's better to use the `Router#navigate` service to trigger route changes. Use
 * `Location` only if you need to interact with or create normalized URLs outside of
 * routing.
 *
 * `Location` is responsible for normalizing the URL against the application's base href.
 * A normalized URL is absolute from the URL host, includes the application's base href, and has no
 * trailing slash:
 * - `/my/app/user/123` is normalized
 * - `my/app/user/123` **is not** normalized
 * - `/my/app/user/123/` **is not** normalized
 *
 * ### Example
 *
 * <code-example path='common/location/ts/path_location_component.ts'
 * region='LocationComponent'></code-example>
 *
 * @publicApi
 */


var Location = /*#__PURE__*/function () {
  function Location(platformStrategy, platformLocation) {
    var _this4 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, Location);

    /** @internal */
    this._subject = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["EventEmitter"]();
    /** @internal */

    this._urlChangeListeners = [];
    this._platformStrategy = platformStrategy;

    var browserBaseHref = this._platformStrategy.getBaseHref();

    this._platformLocation = platformLocation;
    this._baseHref = stripTrailingSlash(_stripIndexHtml(browserBaseHref));

    this._platformStrategy.onPopState(function (ev) {
      _this4._subject.emit({
        'url': _this4.path(true),
        'pop': true,
        'state': ev.state,
        'type': ev.type
      });
    });
  }
  /**
   * Normalizes the URL path for this location.
   *
   * @param includeHash True to include an anchor fragment in the path.
   *
   * @returns The normalized URL path.
   */
  // TODO: vsavkin. Remove the boolean flag and always include hash once the deprecated router is
  // removed.


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(Location, [{
    key: "path",
    value: function path() {
      var includeHash = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      return this.normalize(this._platformStrategy.path(includeHash));
    }
    /**
     * Reports the current state of the location history.
     * @returns The current value of the `history.state` object.
     */

  }, {
    key: "getState",
    value: function getState() {
      return this._platformLocation.getState();
    }
    /**
     * Normalizes the given path and compares to the current normalized path.
     *
     * @param path The given URL path.
     * @param query Query parameters.
     *
     * @returns True if the given URL path is equal to the current normalized path, false
     * otherwise.
     */

  }, {
    key: "isCurrentPathEqualTo",
    value: function isCurrentPathEqualTo(path) {
      var query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      return this.path() == this.normalize(path + normalizeQueryParams(query));
    }
    /**
     * Normalizes a URL path by stripping any trailing slashes.
     *
     * @param url String representing a URL.
     *
     * @returns The normalized URL string.
     */

  }, {
    key: "normalize",
    value: function normalize(url) {
      return Location.stripTrailingSlash(_stripBaseHref(this._baseHref, _stripIndexHtml(url)));
    }
    /**
     * Normalizes an external URL path.
     * If the given URL doesn't begin with a leading slash (`'/'`), adds one
     * before normalizing. Adds a hash if `HashLocationStrategy` is
     * in use, or the `APP_BASE_HREF` if the `PathLocationStrategy` is in use.
     *
     * @param url String representing a URL.
     *
     * @returns  A normalized platform-specific URL.
     */

  }, {
    key: "prepareExternalUrl",
    value: function prepareExternalUrl(url) {
      if (url && url[0] !== '/') {
        url = '/' + url;
      }

      return this._platformStrategy.prepareExternalUrl(url);
    } // TODO: rename this method to pushState

    /**
     * Changes the browser's URL to a normalized version of a given URL, and pushes a
     * new item onto the platform's history.
     *
     * @param path  URL path to normalize.
     * @param query Query parameters.
     * @param state Location history state.
     *
     */

  }, {
    key: "go",
    value: function go(path) {
      var query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var state = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      this._platformStrategy.pushState(state, '', path, query);

      this._notifyUrlChangeListeners(this.prepareExternalUrl(path + normalizeQueryParams(query)), state);
    }
    /**
     * Changes the browser's URL to a normalized version of the given URL, and replaces
     * the top item on the platform's history stack.
     *
     * @param path  URL path to normalize.
     * @param query Query parameters.
     * @param state Location history state.
     */

  }, {
    key: "replaceState",
    value: function replaceState(path) {
      var query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var state = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      this._platformStrategy.replaceState(state, '', path, query);

      this._notifyUrlChangeListeners(this.prepareExternalUrl(path + normalizeQueryParams(query)), state);
    }
    /**
     * Navigates forward in the platform's history.
     */

  }, {
    key: "forward",
    value: function forward() {
      this._platformStrategy.forward();
    }
    /**
     * Navigates back in the platform's history.
     */

  }, {
    key: "back",
    value: function back() {
      this._platformStrategy.back();
    }
    /**
     * Registers a URL change listener. Use to catch updates performed by the Angular
     * framework that are not detectible through "popstate" or "hashchange" events.
     *
     * @param fn The change handler function, which take a URL and a location history state.
     */

  }, {
    key: "onUrlChange",
    value: function onUrlChange(fn) {
      var _this5 = this;

      this._urlChangeListeners.push(fn);

      if (!this._urlChangeSubscription) {
        this._urlChangeSubscription = this.subscribe(function (v) {
          _this5._notifyUrlChangeListeners(v.url, v.state);
        });
      }
    }
    /** @internal */

  }, {
    key: "_notifyUrlChangeListeners",
    value: function _notifyUrlChangeListeners() {
      var url = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
      var state = arguments.length > 1 ? arguments[1] : undefined;

      this._urlChangeListeners.forEach(function (fn) {
        return fn(url, state);
      });
    }
    /**
     * Subscribes to the platform's `popState` events.
     *
     * @param value Event that is triggered when the state history changes.
     * @param exception The exception to throw.
     *
     * @returns Subscribed events.
     */

  }, {
    key: "subscribe",
    value: function subscribe(onNext, onThrow, onReturn) {
      return this._subject.subscribe({
        next: onNext,
        error: onThrow,
        complete: onReturn
      });
    }
  }]);

  return Location;
}();

Location.ɵfac = function Location_Factory(t) {
  return new (t || Location)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](LocationStrategy), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](PlatformLocation));
};
/**
 * Normalizes URL parameters by prepending with `?` if needed.
 *
 * @param  params String of URL parameters.
 *
 * @returns The normalized URL parameters string.
 */


Location.normalizeQueryParams = normalizeQueryParams;
/**
 * Joins two parts of a URL with a slash if needed.
 *
 * @param start  URL string
 * @param end    URL string
 *
 *
 * @returns The joined URL string.
 */

Location.joinWithSlash = joinWithSlash;
/**
 * Removes a trailing slash from a URL string if needed.
 * Looks for the first occurrence of either `#`, `?`, or the end of the
 * line as `/` characters and removes the trailing slash if one exists.
 *
 * @param url URL string.
 *
 * @returns The URL string, modified if needed.
 */

Location.stripTrailingSlash = stripTrailingSlash;
Location.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"])({
  factory: createLocation,
  token: Location,
  providedIn: "root"
});

Location.ctorParameters = function () {
  return [{
    type: LocationStrategy
  }, {
    type: PlatformLocation
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](Location, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"],
    args: [{
      providedIn: 'root',
      // See #23917
      useFactory: createLocation
    }]
  }], function () {
    return [{
      type: LocationStrategy
    }, {
      type: PlatformLocation
    }];
  }, null);
})();

function createLocation() {
  return new Location(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(LocationStrategy), Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(PlatformLocation));
}

function _stripBaseHref(baseHref, url) {
  return baseHref && url.startsWith(baseHref) ? url.substring(baseHref.length) : url;
}

function _stripIndexHtml(url) {
  return url.replace(/\/index.html$/, '');
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/** @internal */


var CURRENCIES_EN = {
  'ADP': [undefined, undefined, 0],
  'AFN': [undefined, undefined, 0],
  'ALL': [undefined, undefined, 0],
  'AMD': [undefined, undefined, 2],
  'AOA': [undefined, 'Kz'],
  'ARS': [undefined, '$'],
  'AUD': ['A$', '$'],
  'BAM': [undefined, 'KM'],
  'BBD': [undefined, '$'],
  'BDT': [undefined, '৳'],
  'BHD': [undefined, undefined, 3],
  'BIF': [undefined, undefined, 0],
  'BMD': [undefined, '$'],
  'BND': [undefined, '$'],
  'BOB': [undefined, 'Bs'],
  'BRL': ['R$'],
  'BSD': [undefined, '$'],
  'BWP': [undefined, 'P'],
  'BYN': [undefined, 'р.', 2],
  'BYR': [undefined, undefined, 0],
  'BZD': [undefined, '$'],
  'CAD': ['CA$', '$', 2],
  'CHF': [undefined, undefined, 2],
  'CLF': [undefined, undefined, 4],
  'CLP': [undefined, '$', 0],
  'CNY': ['CN¥', '¥'],
  'COP': [undefined, '$', 2],
  'CRC': [undefined, '₡', 2],
  'CUC': [undefined, '$'],
  'CUP': [undefined, '$'],
  'CZK': [undefined, 'Kč', 2],
  'DJF': [undefined, undefined, 0],
  'DKK': [undefined, 'kr', 2],
  'DOP': [undefined, '$'],
  'EGP': [undefined, 'E£'],
  'ESP': [undefined, '₧', 0],
  'EUR': ['€'],
  'FJD': [undefined, '$'],
  'FKP': [undefined, '£'],
  'GBP': ['£'],
  'GEL': [undefined, '₾'],
  'GIP': [undefined, '£'],
  'GNF': [undefined, 'FG', 0],
  'GTQ': [undefined, 'Q'],
  'GYD': [undefined, '$', 2],
  'HKD': ['HK$', '$'],
  'HNL': [undefined, 'L'],
  'HRK': [undefined, 'kn'],
  'HUF': [undefined, 'Ft', 2],
  'IDR': [undefined, 'Rp', 2],
  'ILS': ['₪'],
  'INR': ['₹'],
  'IQD': [undefined, undefined, 0],
  'IRR': [undefined, undefined, 0],
  'ISK': [undefined, 'kr', 0],
  'ITL': [undefined, undefined, 0],
  'JMD': [undefined, '$'],
  'JOD': [undefined, undefined, 3],
  'JPY': ['¥', undefined, 0],
  'KHR': [undefined, '៛'],
  'KMF': [undefined, 'CF', 0],
  'KPW': [undefined, '₩', 0],
  'KRW': ['₩', undefined, 0],
  'KWD': [undefined, undefined, 3],
  'KYD': [undefined, '$'],
  'KZT': [undefined, '₸'],
  'LAK': [undefined, '₭', 0],
  'LBP': [undefined, 'L£', 0],
  'LKR': [undefined, 'Rs'],
  'LRD': [undefined, '$'],
  'LTL': [undefined, 'Lt'],
  'LUF': [undefined, undefined, 0],
  'LVL': [undefined, 'Ls'],
  'LYD': [undefined, undefined, 3],
  'MGA': [undefined, 'Ar', 0],
  'MGF': [undefined, undefined, 0],
  'MMK': [undefined, 'K', 0],
  'MNT': [undefined, '₮', 2],
  'MRO': [undefined, undefined, 0],
  'MUR': [undefined, 'Rs', 2],
  'MXN': ['MX$', '$'],
  'MYR': [undefined, 'RM'],
  'NAD': [undefined, '$'],
  'NGN': [undefined, '₦'],
  'NIO': [undefined, 'C$'],
  'NOK': [undefined, 'kr', 2],
  'NPR': [undefined, 'Rs'],
  'NZD': ['NZ$', '$'],
  'OMR': [undefined, undefined, 3],
  'PHP': [undefined, '₱'],
  'PKR': [undefined, 'Rs', 2],
  'PLN': [undefined, 'zł'],
  'PYG': [undefined, '₲', 0],
  'RON': [undefined, 'lei'],
  'RSD': [undefined, undefined, 0],
  'RUB': [undefined, '₽'],
  'RUR': [undefined, 'р.'],
  'RWF': [undefined, 'RF', 0],
  'SBD': [undefined, '$'],
  'SEK': [undefined, 'kr', 2],
  'SGD': [undefined, '$'],
  'SHP': [undefined, '£'],
  'SLL': [undefined, undefined, 0],
  'SOS': [undefined, undefined, 0],
  'SRD': [undefined, '$'],
  'SSP': [undefined, '£'],
  'STD': [undefined, undefined, 0],
  'STN': [undefined, 'Db'],
  'SYP': [undefined, '£', 0],
  'THB': [undefined, '฿'],
  'TMM': [undefined, undefined, 0],
  'TND': [undefined, undefined, 3],
  'TOP': [undefined, 'T$'],
  'TRL': [undefined, undefined, 0],
  'TRY': [undefined, '₺'],
  'TTD': [undefined, '$'],
  'TWD': ['NT$', '$', 2],
  'TZS': [undefined, undefined, 2],
  'UAH': [undefined, '₴'],
  'UGX': [undefined, undefined, 0],
  'USD': ['$'],
  'UYI': [undefined, undefined, 0],
  'UYU': [undefined, '$'],
  'UYW': [undefined, undefined, 4],
  'UZS': [undefined, undefined, 2],
  'VEF': [undefined, 'Bs', 2],
  'VND': ['₫', undefined, 0],
  'VUV': [undefined, undefined, 0],
  'XAF': ['FCFA', undefined, 0],
  'XCD': ['EC$', '$'],
  'XOF': ['CFA', undefined, 0],
  'XPF': ['CFPF', undefined, 0],
  'XXX': ['¤'],
  'YER': [undefined, undefined, 0],
  'ZAR': [undefined, 'R'],
  'ZMK': [undefined, undefined, 0],
  'ZMW': [undefined, 'ZK'],
  'ZWD': [undefined, undefined, 0]
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Format styles that can be used to represent numbers.
 * @see `getLocaleNumberFormat()`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */

var NumberFormatStyle;

(function (NumberFormatStyle) {
  NumberFormatStyle[NumberFormatStyle["Decimal"] = 0] = "Decimal";
  NumberFormatStyle[NumberFormatStyle["Percent"] = 1] = "Percent";
  NumberFormatStyle[NumberFormatStyle["Currency"] = 2] = "Currency";
  NumberFormatStyle[NumberFormatStyle["Scientific"] = 3] = "Scientific";
})(NumberFormatStyle || (NumberFormatStyle = {}));
/**
 * Plurality cases used for translating plurals to different languages.
 *
 * @see `NgPlural`
 * @see `NgPluralCase`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


var Plural;

(function (Plural) {
  Plural[Plural["Zero"] = 0] = "Zero";
  Plural[Plural["One"] = 1] = "One";
  Plural[Plural["Two"] = 2] = "Two";
  Plural[Plural["Few"] = 3] = "Few";
  Plural[Plural["Many"] = 4] = "Many";
  Plural[Plural["Other"] = 5] = "Other";
})(Plural || (Plural = {}));
/**
 * Context-dependant translation forms for strings.
 * Typically the standalone version is for the nominative form of the word,
 * and the format version is used for the genitive case.
 * @see [CLDR website](http://cldr.unicode.org/translation/date-time-1/date-time#TOC-Standalone-vs.-Format-Styles)
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


var FormStyle;

(function (FormStyle) {
  FormStyle[FormStyle["Format"] = 0] = "Format";
  FormStyle[FormStyle["Standalone"] = 1] = "Standalone";
})(FormStyle || (FormStyle = {}));
/**
 * String widths available for translations.
 * The specific character widths are locale-specific.
 * Examples are given for the word "Sunday" in English.
 *
 * @publicApi
 */


var TranslationWidth;

(function (TranslationWidth) {
  /** 1 character for `en-US`. For example: 'S' */
  TranslationWidth[TranslationWidth["Narrow"] = 0] = "Narrow";
  /** 3 characters for `en-US`. For example: 'Sun' */

  TranslationWidth[TranslationWidth["Abbreviated"] = 1] = "Abbreviated";
  /** Full length for `en-US`. For example: "Sunday" */

  TranslationWidth[TranslationWidth["Wide"] = 2] = "Wide";
  /** 2 characters for `en-US`, For example: "Su" */

  TranslationWidth[TranslationWidth["Short"] = 3] = "Short";
})(TranslationWidth || (TranslationWidth = {}));
/**
 * String widths available for date-time formats.
 * The specific character widths are locale-specific.
 * Examples are given for `en-US`.
 *
 * @see `getLocaleDateFormat()`
 * @see `getLocaleTimeFormat()``
 * @see `getLocaleDateTimeFormat()`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 * @publicApi
 */


var FormatWidth;

(function (FormatWidth) {
  /**
   * For `en-US`, 'M/d/yy, h:mm a'`
   * (Example: `6/15/15, 9:03 AM`)
   */
  FormatWidth[FormatWidth["Short"] = 0] = "Short";
  /**
   * For `en-US`, `'MMM d, y, h:mm:ss a'`
   * (Example: `Jun 15, 2015, 9:03:01 AM`)
   */

  FormatWidth[FormatWidth["Medium"] = 1] = "Medium";
  /**
   * For `en-US`, `'MMMM d, y, h:mm:ss a z'`
   * (Example: `June 15, 2015 at 9:03:01 AM GMT+1`)
   */

  FormatWidth[FormatWidth["Long"] = 2] = "Long";
  /**
   * For `en-US`, `'EEEE, MMMM d, y, h:mm:ss a zzzz'`
   * (Example: `Monday, June 15, 2015 at 9:03:01 AM GMT+01:00`)
   */

  FormatWidth[FormatWidth["Full"] = 3] = "Full";
})(FormatWidth || (FormatWidth = {}));
/**
 * Symbols that can be used to replace placeholders in number patterns.
 * Examples are based on `en-US` values.
 *
 * @see `getLocaleNumberSymbol()`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


var NumberSymbol;

(function (NumberSymbol) {
  /**
   * Decimal separator.
   * For `en-US`, the dot character.
   * Example : 2,345`.`67
   */
  NumberSymbol[NumberSymbol["Decimal"] = 0] = "Decimal";
  /**
   * Grouping separator, typically for thousands.
   * For `en-US`, the comma character.
   * Example: 2`,`345.67
   */

  NumberSymbol[NumberSymbol["Group"] = 1] = "Group";
  /**
   * List-item separator.
   * Example: "one, two, and three"
   */

  NumberSymbol[NumberSymbol["List"] = 2] = "List";
  /**
   * Sign for percentage (out of 100).
   * Example: 23.4%
   */

  NumberSymbol[NumberSymbol["PercentSign"] = 3] = "PercentSign";
  /**
   * Sign for positive numbers.
   * Example: +23
   */

  NumberSymbol[NumberSymbol["PlusSign"] = 4] = "PlusSign";
  /**
   * Sign for negative numbers.
   * Example: -23
   */

  NumberSymbol[NumberSymbol["MinusSign"] = 5] = "MinusSign";
  /**
   * Computer notation for exponential value (n times a power of 10).
   * Example: 1.2E3
   */

  NumberSymbol[NumberSymbol["Exponential"] = 6] = "Exponential";
  /**
   * Human-readable format of exponential.
   * Example: 1.2x103
   */

  NumberSymbol[NumberSymbol["SuperscriptingExponent"] = 7] = "SuperscriptingExponent";
  /**
   * Sign for permille (out of 1000).
   * Example: 23.4‰
   */

  NumberSymbol[NumberSymbol["PerMille"] = 8] = "PerMille";
  /**
   * Infinity, can be used with plus and minus.
   * Example: ∞, +∞, -∞
   */

  NumberSymbol[NumberSymbol["Infinity"] = 9] = "Infinity";
  /**
   * Not a number.
   * Example: NaN
   */

  NumberSymbol[NumberSymbol["NaN"] = 10] = "NaN";
  /**
   * Symbol used between time units.
   * Example: 10:52
   */

  NumberSymbol[NumberSymbol["TimeSeparator"] = 11] = "TimeSeparator";
  /**
   * Decimal separator for currency values (fallback to `Decimal`).
   * Example: $2,345.67
   */

  NumberSymbol[NumberSymbol["CurrencyDecimal"] = 12] = "CurrencyDecimal";
  /**
   * Group separator for currency values (fallback to `Group`).
   * Example: $2,345.67
   */

  NumberSymbol[NumberSymbol["CurrencyGroup"] = 13] = "CurrencyGroup";
})(NumberSymbol || (NumberSymbol = {}));
/**
 * The value for each day of the week, based on the `en-US` locale
 *
 * @publicApi
 */


var WeekDay;

(function (WeekDay) {
  WeekDay[WeekDay["Sunday"] = 0] = "Sunday";
  WeekDay[WeekDay["Monday"] = 1] = "Monday";
  WeekDay[WeekDay["Tuesday"] = 2] = "Tuesday";
  WeekDay[WeekDay["Wednesday"] = 3] = "Wednesday";
  WeekDay[WeekDay["Thursday"] = 4] = "Thursday";
  WeekDay[WeekDay["Friday"] = 5] = "Friday";
  WeekDay[WeekDay["Saturday"] = 6] = "Saturday";
})(WeekDay || (WeekDay = {}));
/**
 * Retrieves the locale ID from the currently loaded locale.
 * The loaded locale could be, for example, a global one rather than a regional one.
 * @param locale A locale code, such as `fr-FR`.
 * @returns The locale code. For example, `fr`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleId(locale) {
  return Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale)[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].LocaleId];
}
/**
 * Retrieves day period strings for the given locale.
 *
 * @param locale A locale code for the locale format rules to use.
 * @param formStyle The required grammatical form.
 * @param width The required character width.
 * @returns An array of localized period strings. For example, `[AM, PM]` for `en-US`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleDayPeriods(locale, formStyle, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  var amPmData = [data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].DayPeriodsFormat], data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].DayPeriodsStandalone]];
  var amPm = getLastDefinedValue(amPmData, formStyle);
  return getLastDefinedValue(amPm, width);
}
/**
 * Retrieves days of the week for the given locale, using the Gregorian calendar.
 *
 * @param locale A locale code for the locale format rules to use.
 * @param formStyle The required grammatical form.
 * @param width The required character width.
 * @returns An array of localized name strings.
 * For example,`[Sunday, Monday, ... Saturday]` for `en-US`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleDayNames(locale, formStyle, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  var daysData = [data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].DaysFormat], data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].DaysStandalone]];
  var days = getLastDefinedValue(daysData, formStyle);
  return getLastDefinedValue(days, width);
}
/**
 * Retrieves months of the year for the given locale, using the Gregorian calendar.
 *
 * @param locale A locale code for the locale format rules to use.
 * @param formStyle The required grammatical form.
 * @param width The required character width.
 * @returns An array of localized name strings.
 * For example,  `[January, February, ...]` for `en-US`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleMonthNames(locale, formStyle, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  var monthsData = [data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].MonthsFormat], data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].MonthsStandalone]];
  var months = getLastDefinedValue(monthsData, formStyle);
  return getLastDefinedValue(months, width);
}
/**
 * Retrieves Gregorian-calendar eras for the given locale.
 * @param locale A locale code for the locale format rules to use.
 * @param formStyle The required grammatical form.
 * @param width The required character width.

 * @returns An array of localized era strings.
 * For example, `[AD, BC]` for `en-US`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleEraNames(locale, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  var erasData = data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].Eras];
  return getLastDefinedValue(erasData, width);
}
/**
 * Retrieves the first day of the week for the given locale.
 *
 * @param locale A locale code for the locale format rules to use.
 * @returns A day index number, using the 0-based week-day index for `en-US`
 * (Sunday = 0, Monday = 1, ...).
 * For example, for `fr-FR`, returns 1 to indicate that the first day is Monday.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleFirstDayOfWeek(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].FirstDayOfWeek];
}
/**
 * Range of week days that are considered the week-end for the given locale.
 *
 * @param locale A locale code for the locale format rules to use.
 * @returns The range of day values, `[startDay, endDay]`.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleWeekEndRange(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].WeekendRange];
}
/**
 * Retrieves a localized date-value formating string.
 *
 * @param locale A locale code for the locale format rules to use.
 * @param width The format type.
 * @returns The localized formating string.
 * @see `FormatWidth`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleDateFormat(locale, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return getLastDefinedValue(data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].DateFormat], width);
}
/**
 * Retrieves a localized time-value formatting string.
 *
 * @param locale A locale code for the locale format rules to use.
 * @param width The format type.
 * @returns The localized formatting string.
 * @see `FormatWidth`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)

 * @publicApi
 */


function getLocaleTimeFormat(locale, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return getLastDefinedValue(data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].TimeFormat], width);
}
/**
 * Retrieves a localized date-time formatting string.
 *
 * @param locale A locale code for the locale format rules to use.
 * @param width The format type.
 * @returns The localized formatting string.
 * @see `FormatWidth`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleDateTimeFormat(locale, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  var dateTimeFormatData = data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].DateTimeFormat];
  return getLastDefinedValue(dateTimeFormatData, width);
}
/**
 * Retrieves a localized number symbol that can be used to replace placeholders in number formats.
 * @param locale The locale code.
 * @param symbol The symbol to localize.
 * @returns The character for the localized symbol.
 * @see `NumberSymbol`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleNumberSymbol(locale, symbol) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  var res = data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].NumberSymbols][symbol];

  if (typeof res === 'undefined') {
    if (symbol === NumberSymbol.CurrencyDecimal) {
      return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].NumberSymbols][NumberSymbol.Decimal];
    } else if (symbol === NumberSymbol.CurrencyGroup) {
      return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].NumberSymbols][NumberSymbol.Group];
    }
  }

  return res;
}
/**
 * Retrieves a number format for a given locale.
 *
 * Numbers are formatted using patterns, like `#,###.00`. For example, the pattern `#,###.00`
 * when used to format the number 12345.678 could result in "12'345,678". That would happen if the
 * grouping separator for your language is an apostrophe, and the decimal separator is a comma.
 *
 * <b>Important:</b> The characters `.` `,` `0` `#` (and others below) are special placeholders
 * that stand for the decimal separator, and so on, and are NOT real characters.
 * You must NOT "translate" the placeholders. For example, don't change `.` to `,` even though in
 * your language the decimal point is written with a comma. The symbols should be replaced by the
 * local equivalents, using the appropriate `NumberSymbol` for your language.
 *
 * Here are the special characters used in number patterns:
 *
 * | Symbol | Meaning |
 * |--------|---------|
 * | . | Replaced automatically by the character used for the decimal point. |
 * | , | Replaced by the "grouping" (thousands) separator. |
 * | 0 | Replaced by a digit (or zero if there aren't enough digits). |
 * | # | Replaced by a digit (or nothing if there aren't enough). |
 * | ¤ | Replaced by a currency symbol, such as $ or USD. |
 * | % | Marks a percent format. The % symbol may change position, but must be retained. |
 * | E | Marks a scientific format. The E symbol may change position, but must be retained. |
 * | ' | Special characters used as literal characters are quoted with ASCII single quotes. |
 *
 * @param locale A locale code for the locale format rules to use.
 * @param type The type of numeric value to be formatted (such as `Decimal` or `Currency`.)
 * @returns The localized format string.
 * @see `NumberFormatStyle`
 * @see [CLDR website](http://cldr.unicode.org/translation/number-patterns)
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleNumberFormat(locale, type) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].NumberFormats][type];
}
/**
 * Retrieves the symbol used to represent the currency for the main country
 * corresponding to a given locale. For example, '$' for `en-US`.
 *
 * @param locale A locale code for the locale format rules to use.
 * @returns The localized symbol character,
 * or `null` if the main country cannot be determined.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleCurrencySymbol(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].CurrencySymbol] || null;
}
/**
 * Retrieves the name of the currency for the main country corresponding
 * to a given locale. For example, 'US Dollar' for `en-US`.
 * @param locale A locale code for the locale format rules to use.
 * @returns The currency name,
 * or `null` if the main country cannot be determined.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleCurrencyName(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].CurrencyName] || null;
}
/**
 * Retrieves the default currency code for the given locale.
 *
 * The default is defined as the first currency which is still in use.
 *
 * @param locale The code of the locale whose currency code we want.
 * @returns The code of the default currency for the given locale.
 *
 * @publicApi
 */


function getLocaleCurrencyCode(locale) {
  return Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵgetLocaleCurrencyCode"])(locale);
}
/**
 * Retrieves the currency values for a given locale.
 * @param locale A locale code for the locale format rules to use.
 * @returns The currency values.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 */


function getLocaleCurrencies(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].Currencies];
}
/**
 * @alias core/ɵgetLocalePluralCase
 * @publicApi
 */


var getLocalePluralCase = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵgetLocalePluralCase"];

function checkFullData(data) {
  if (!data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].ExtraData]) {
    throw new Error("Missing extra locale data for the locale \"".concat(data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].LocaleId], "\". Use \"registerLocaleData\" to load new data. See the \"I18n guide\" on angular.io to know more."));
  }
}
/**
 * Retrieves locale-specific rules used to determine which day period to use
 * when more than one period is defined for a locale.
 *
 * There is a rule for each defined day period. The
 * first rule is applied to the first day period and so on.
 * Fall back to AM/PM when no rules are available.
 *
 * A rule can specify a period as time range, or as a single time value.
 *
 * This functionality is only available when you have loaded the full locale data.
 * See the ["I18n guide"](guide/i18n#i18n-pipes).
 *
 * @param locale A locale code for the locale format rules to use.
 * @returns The rules for the locale, a single time value or array of *from-time, to-time*,
 * or null if no periods are available.
 *
 * @see `getLocaleExtraDayPeriods()`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleExtraDayPeriodRules(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  checkFullData(data);
  var rules = data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].ExtraData][2
  /* ExtraDayPeriodsRules */
  ] || [];
  return rules.map(function (rule) {
    if (typeof rule === 'string') {
      return extractTime(rule);
    }

    return [extractTime(rule[0]), extractTime(rule[1])];
  });
}
/**
 * Retrieves locale-specific day periods, which indicate roughly how a day is broken up
 * in different languages.
 * For example, for `en-US`, periods are morning, noon, afternoon, evening, and midnight.
 *
 * This functionality is only available when you have loaded the full locale data.
 * See the ["I18n guide"](guide/i18n#i18n-pipes).
 *
 * @param locale A locale code for the locale format rules to use.
 * @param formStyle The required grammatical form.
 * @param width The required character width.
 * @returns The translated day-period strings.
 * @see `getLocaleExtraDayPeriodRules()`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLocaleExtraDayPeriods(locale, formStyle, width) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  checkFullData(data);
  var dayPeriodsData = [data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].ExtraData][0
  /* ExtraDayPeriodFormats */
  ], data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].ExtraData][1
  /* ExtraDayPeriodStandalone */
  ]];
  var dayPeriods = getLastDefinedValue(dayPeriodsData, formStyle) || [];
  return getLastDefinedValue(dayPeriods, width) || [];
}
/**
 * Retrieves the writing direction of a specified locale
 * @param locale A locale code for the locale format rules to use.
 * @publicApi
 * @returns 'rtl' or 'ltr'
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 */


function getLocaleDirection(locale) {
  var data = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵfindLocaleData"])(locale);
  return data[_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵLocaleDataIndex"].Directionality];
}
/**
 * Retrieves the first value that is defined in an array, going backwards from an index position.
 *
 * To avoid repeating the same data (as when the "format" and "standalone" forms are the same)
 * add the first value to the locale data arrays, and add other values only if they are different.
 *
 * @param data The data array to retrieve from.
 * @param index A 0-based index into the array to start from.
 * @returns The value immediately before the given index position.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getLastDefinedValue(data, index) {
  for (var i = index; i > -1; i--) {
    if (typeof data[i] !== 'undefined') {
      return data[i];
    }
  }

  throw new Error('Locale data API: locale data undefined');
}
/**
 * Extracts the hours and minutes from a string like "15:45"
 */


function extractTime(time) {
  var _time$split = time.split(':'),
      _time$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_time$split, 2),
      h = _time$split2[0],
      m = _time$split2[1];

  return {
    hours: +h,
    minutes: +m
  };
}
/**
 * Retrieves the currency symbol for a given currency code.
 *
 * For example, for the default `en-US` locale, the code `USD` can
 * be represented by the narrow symbol `$` or the wide symbol `US$`.
 *
 * @param code The currency code.
 * @param format The format, `wide` or `narrow`.
 * @param locale A locale code for the locale format rules to use.
 *
 * @returns The symbol, or the currency code if no symbol is available.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function getCurrencySymbol(code, format) {
  var locale = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'en';
  var currency = getLocaleCurrencies(locale)[code] || CURRENCIES_EN[code] || [];
  var symbolNarrow = currency[1
  /* SymbolNarrow */
  ];

  if (format === 'narrow' && typeof symbolNarrow === 'string') {
    return symbolNarrow;
  }

  return currency[0
  /* Symbol */
  ] || code;
} // Most currencies have cents, that's why the default is 2


var DEFAULT_NB_OF_CURRENCY_DIGITS = 2;
/**
 * Reports the number of decimal digits for a given currency.
 * The value depends upon the presence of cents in that particular currency.
 *
 * @param code The currency code.
 * @returns The number of decimal digits, typically 0 or 2.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */

function getNumberOfCurrencyDigits(code) {
  var digits;
  var currency = CURRENCIES_EN[code];

  if (currency) {
    digits = currency[2
    /* NbOfDigits */
    ];
  }

  return typeof digits === 'number' ? digits : DEFAULT_NB_OF_CURRENCY_DIGITS;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ISO8601_DATE_REGEX = /^(\d{4})-?(\d\d)-?(\d\d)(?:T(\d\d)(?::?(\d\d)(?::?(\d\d)(?:\.(\d+))?)?)?(Z|([+-])(\d\d):?(\d\d))?)?$/; //    1        2       3         4          5          6          7          8  9     10      11

var NAMED_FORMATS = {};
var DATE_FORMATS_SPLIT = /((?:[^GyMLwWdEabBhHmsSzZO']+)|(?:'(?:[^']|'')*')|(?:G{1,5}|y{1,4}|M{1,5}|L{1,5}|w{1,2}|W{1}|d{1,2}|E{1,6}|a{1,5}|b{1,5}|B{1,5}|h{1,2}|H{1,2}|m{1,2}|s{1,2}|S{1,3}|z{1,4}|Z{1,5}|O{1,4}))([\s\S]*)/;
var ZoneWidth;

(function (ZoneWidth) {
  ZoneWidth[ZoneWidth["Short"] = 0] = "Short";
  ZoneWidth[ZoneWidth["ShortGMT"] = 1] = "ShortGMT";
  ZoneWidth[ZoneWidth["Long"] = 2] = "Long";
  ZoneWidth[ZoneWidth["Extended"] = 3] = "Extended";
})(ZoneWidth || (ZoneWidth = {}));

var DateType;

(function (DateType) {
  DateType[DateType["FullYear"] = 0] = "FullYear";
  DateType[DateType["Month"] = 1] = "Month";
  DateType[DateType["Date"] = 2] = "Date";
  DateType[DateType["Hours"] = 3] = "Hours";
  DateType[DateType["Minutes"] = 4] = "Minutes";
  DateType[DateType["Seconds"] = 5] = "Seconds";
  DateType[DateType["FractionalSeconds"] = 6] = "FractionalSeconds";
  DateType[DateType["Day"] = 7] = "Day";
})(DateType || (DateType = {}));

var TranslationType;

(function (TranslationType) {
  TranslationType[TranslationType["DayPeriods"] = 0] = "DayPeriods";
  TranslationType[TranslationType["Days"] = 1] = "Days";
  TranslationType[TranslationType["Months"] = 2] = "Months";
  TranslationType[TranslationType["Eras"] = 3] = "Eras";
})(TranslationType || (TranslationType = {}));
/**
 * @ngModule CommonModule
 * @description
 *
 * Formats a date according to locale rules.
 *
 * @param value The date to format, as a Date, or a number (milliseconds since UTC epoch)
 * or an [ISO date-time string](https://www.w3.org/TR/NOTE-datetime).
 * @param format The date-time components to include. See `DatePipe` for details.
 * @param locale A locale code for the locale format rules to use.
 * @param timezone The time zone. A time zone offset from GMT (such as `'+0430'`),
 * or a standard UTC/GMT or continental US time zone abbreviation.
 * If not specified, uses host system settings.
 *
 * @returns The formatted date string.
 *
 * @see `DatePipe`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function formatDate(value, format, locale, timezone) {
  var date = toDate(value);
  var namedFormat = getNamedFormat(locale, format);
  format = namedFormat || format;
  var parts = [];
  var match;

  while (format) {
    match = DATE_FORMATS_SPLIT.exec(format);

    if (match) {
      parts = parts.concat(match.slice(1));
      var part = parts.pop();

      if (!part) {
        break;
      }

      format = part;
    } else {
      parts.push(format);
      break;
    }
  }

  var dateTimezoneOffset = date.getTimezoneOffset();

  if (timezone) {
    dateTimezoneOffset = timezoneToOffset(timezone, dateTimezoneOffset);
    date = convertTimezoneToLocal(date, timezone, true);
  }

  var text = '';
  parts.forEach(function (value) {
    var dateFormatter = getDateFormatter(value);
    text += dateFormatter ? dateFormatter(date, locale, dateTimezoneOffset) : value === '\'\'' ? '\'' : value.replace(/(^'|'$)/g, '').replace(/''/g, '\'');
  });
  return text;
}

function getNamedFormat(locale, format) {
  var localeId = getLocaleId(locale);
  NAMED_FORMATS[localeId] = NAMED_FORMATS[localeId] || {};

  if (NAMED_FORMATS[localeId][format]) {
    return NAMED_FORMATS[localeId][format];
  }

  var formatValue = '';

  switch (format) {
    case 'shortDate':
      formatValue = getLocaleDateFormat(locale, FormatWidth.Short);
      break;

    case 'mediumDate':
      formatValue = getLocaleDateFormat(locale, FormatWidth.Medium);
      break;

    case 'longDate':
      formatValue = getLocaleDateFormat(locale, FormatWidth.Long);
      break;

    case 'fullDate':
      formatValue = getLocaleDateFormat(locale, FormatWidth.Full);
      break;

    case 'shortTime':
      formatValue = getLocaleTimeFormat(locale, FormatWidth.Short);
      break;

    case 'mediumTime':
      formatValue = getLocaleTimeFormat(locale, FormatWidth.Medium);
      break;

    case 'longTime':
      formatValue = getLocaleTimeFormat(locale, FormatWidth.Long);
      break;

    case 'fullTime':
      formatValue = getLocaleTimeFormat(locale, FormatWidth.Full);
      break;

    case 'short':
      var shortTime = getNamedFormat(locale, 'shortTime');
      var shortDate = getNamedFormat(locale, 'shortDate');
      formatValue = formatDateTime(getLocaleDateTimeFormat(locale, FormatWidth.Short), [shortTime, shortDate]);
      break;

    case 'medium':
      var mediumTime = getNamedFormat(locale, 'mediumTime');
      var mediumDate = getNamedFormat(locale, 'mediumDate');
      formatValue = formatDateTime(getLocaleDateTimeFormat(locale, FormatWidth.Medium), [mediumTime, mediumDate]);
      break;

    case 'long':
      var longTime = getNamedFormat(locale, 'longTime');
      var longDate = getNamedFormat(locale, 'longDate');
      formatValue = formatDateTime(getLocaleDateTimeFormat(locale, FormatWidth.Long), [longTime, longDate]);
      break;

    case 'full':
      var fullTime = getNamedFormat(locale, 'fullTime');
      var fullDate = getNamedFormat(locale, 'fullDate');
      formatValue = formatDateTime(getLocaleDateTimeFormat(locale, FormatWidth.Full), [fullTime, fullDate]);
      break;
  }

  if (formatValue) {
    NAMED_FORMATS[localeId][format] = formatValue;
  }

  return formatValue;
}

function formatDateTime(str, opt_values) {
  if (opt_values) {
    str = str.replace(/\{([^}]+)}/g, function (match, key) {
      return opt_values != null && key in opt_values ? opt_values[key] : match;
    });
  }

  return str;
}

function padNumber(num, digits) {
  var minusSign = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '-';
  var trim = arguments.length > 3 ? arguments[3] : undefined;
  var negWrap = arguments.length > 4 ? arguments[4] : undefined;
  var neg = '';

  if (num < 0 || negWrap && num <= 0) {
    if (negWrap) {
      num = -num + 1;
    } else {
      num = -num;
      neg = minusSign;
    }
  }

  var strNum = String(num);

  while (strNum.length < digits) {
    strNum = '0' + strNum;
  }

  if (trim) {
    strNum = strNum.substr(strNum.length - digits);
  }

  return neg + strNum;
}

function formatFractionalSeconds(milliseconds, digits) {
  var strMs = padNumber(milliseconds, 3);
  return strMs.substr(0, digits);
}
/**
 * Returns a date formatter that transforms a date into its locale digit representation
 */


function dateGetter(name, size) {
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var trim = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
  var negWrap = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
  return function (date, locale) {
    var part = getDatePart(name, date);

    if (offset > 0 || part > -offset) {
      part += offset;
    }

    if (name === DateType.Hours) {
      if (part === 0 && offset === -12) {
        part = 12;
      }
    } else if (name === DateType.FractionalSeconds) {
      return formatFractionalSeconds(part, size);
    }

    var localeMinus = getLocaleNumberSymbol(locale, NumberSymbol.MinusSign);
    return padNumber(part, size, localeMinus, trim, negWrap);
  };
}

function getDatePart(part, date) {
  switch (part) {
    case DateType.FullYear:
      return date.getFullYear();

    case DateType.Month:
      return date.getMonth();

    case DateType.Date:
      return date.getDate();

    case DateType.Hours:
      return date.getHours();

    case DateType.Minutes:
      return date.getMinutes();

    case DateType.Seconds:
      return date.getSeconds();

    case DateType.FractionalSeconds:
      return date.getMilliseconds();

    case DateType.Day:
      return date.getDay();

    default:
      throw new Error("Unknown DateType value \"".concat(part, "\"."));
  }
}
/**
 * Returns a date formatter that transforms a date into its locale string representation
 */


function dateStrGetter(name, width) {
  var form = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : FormStyle.Format;
  var extended = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
  return function (date, locale) {
    return getDateTranslation(date, locale, name, width, form, extended);
  };
}
/**
 * Returns the locale translation of a date for a given form, type and width
 */


function getDateTranslation(date, locale, name, width, form, extended) {
  switch (name) {
    case TranslationType.Months:
      return getLocaleMonthNames(locale, form, width)[date.getMonth()];

    case TranslationType.Days:
      return getLocaleDayNames(locale, form, width)[date.getDay()];

    case TranslationType.DayPeriods:
      var currentHours = date.getHours();
      var currentMinutes = date.getMinutes();

      if (extended) {
        var rules = getLocaleExtraDayPeriodRules(locale);
        var dayPeriods = getLocaleExtraDayPeriods(locale, form, width);
        var index = rules.findIndex(function (rule) {
          if (Array.isArray(rule)) {
            // morning, afternoon, evening, night
            var _rule = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(rule, 2),
                from = _rule[0],
                to = _rule[1];

            var afterFrom = currentHours >= from.hours && currentMinutes >= from.minutes;
            var beforeTo = currentHours < to.hours || currentHours === to.hours && currentMinutes < to.minutes; // We must account for normal rules that span a period during the day (e.g. 6am-9am)
            // where `from` is less (earlier) than `to`. But also rules that span midnight (e.g.
            // 10pm - 5am) where `from` is greater (later!) than `to`.
            //
            // In the first case the current time must be BOTH after `from` AND before `to`
            // (e.g. 8am is after 6am AND before 10am).
            //
            // In the second case the current time must be EITHER after `from` OR before `to`
            // (e.g. 4am is before 5am but not after 10pm; and 11pm is not before 5am but it is
            // after 10pm).

            if (from.hours < to.hours) {
              if (afterFrom && beforeTo) {
                return true;
              }
            } else if (afterFrom || beforeTo) {
              return true;
            }
          } else {
            // noon or midnight
            if (rule.hours === currentHours && rule.minutes === currentMinutes) {
              return true;
            }
          }

          return false;
        });

        if (index !== -1) {
          return dayPeriods[index];
        }
      } // if no rules for the day periods, we use am/pm by default


      return getLocaleDayPeriods(locale, form, width)[currentHours < 12 ? 0 : 1];

    case TranslationType.Eras:
      return getLocaleEraNames(locale, width)[date.getFullYear() <= 0 ? 0 : 1];

    default:
      // This default case is not needed by TypeScript compiler, as the switch is exhaustive.
      // However Closure Compiler does not understand that and reports an error in typed mode.
      // The `throw new Error` below works around the problem, and the unexpected: never variable
      // makes sure tsc still checks this code is unreachable.
      var unexpected = name;
      throw new Error("unexpected translation type ".concat(unexpected));
  }
}
/**
 * Returns a date formatter that transforms a date and an offset into a timezone with ISO8601 or
 * GMT format depending on the width (eg: short = +0430, short:GMT = GMT+4, long = GMT+04:30,
 * extended = +04:30)
 */


function timeZoneGetter(width) {
  return function (date, locale, offset) {
    var zone = -1 * offset;
    var minusSign = getLocaleNumberSymbol(locale, NumberSymbol.MinusSign);
    var hours = zone > 0 ? Math.floor(zone / 60) : Math.ceil(zone / 60);

    switch (width) {
      case ZoneWidth.Short:
        return (zone >= 0 ? '+' : '') + padNumber(hours, 2, minusSign) + padNumber(Math.abs(zone % 60), 2, minusSign);

      case ZoneWidth.ShortGMT:
        return 'GMT' + (zone >= 0 ? '+' : '') + padNumber(hours, 1, minusSign);

      case ZoneWidth.Long:
        return 'GMT' + (zone >= 0 ? '+' : '') + padNumber(hours, 2, minusSign) + ':' + padNumber(Math.abs(zone % 60), 2, minusSign);

      case ZoneWidth.Extended:
        if (offset === 0) {
          return 'Z';
        } else {
          return (zone >= 0 ? '+' : '') + padNumber(hours, 2, minusSign) + ':' + padNumber(Math.abs(zone % 60), 2, minusSign);
        }

      default:
        throw new Error("Unknown zone width \"".concat(width, "\""));
    }
  };
}

var JANUARY = 0;
var THURSDAY = 4;

function getFirstThursdayOfYear(year) {
  var firstDayOfYear = new Date(year, JANUARY, 1).getDay();
  return new Date(year, 0, 1 + (firstDayOfYear <= THURSDAY ? THURSDAY : THURSDAY + 7) - firstDayOfYear);
}

function getThursdayThisWeek(datetime) {
  return new Date(datetime.getFullYear(), datetime.getMonth(), datetime.getDate() + (THURSDAY - datetime.getDay()));
}

function weekGetter(size) {
  var monthBased = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  return function (date, locale) {
    var result;

    if (monthBased) {
      var nbDaysBefore1stDayOfMonth = new Date(date.getFullYear(), date.getMonth(), 1).getDay() - 1;
      var today = date.getDate();
      result = 1 + Math.floor((today + nbDaysBefore1stDayOfMonth) / 7);
    } else {
      var thisThurs = getThursdayThisWeek(date); // Some days of a year are part of next year according to ISO 8601.
      // Compute the firstThurs from the year of this week's Thursday

      var firstThurs = getFirstThursdayOfYear(thisThurs.getFullYear());
      var diff = thisThurs.getTime() - firstThurs.getTime();
      result = 1 + Math.round(diff / 6.048e8); // 6.048e8 ms per week
    }

    return padNumber(result, size, getLocaleNumberSymbol(locale, NumberSymbol.MinusSign));
  };
}

var DATE_FORMATS = {}; // Based on CLDR formats:
// See complete list: http://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
// See also explanations: http://cldr.unicode.org/translation/date-time
// TODO(ocombe): support all missing cldr formats: Y, U, Q, D, F, e, c, j, J, C, A, v, V, X, x

function getDateFormatter(format) {
  if (DATE_FORMATS[format]) {
    return DATE_FORMATS[format];
  }

  var formatter;

  switch (format) {
    // Era name (AD/BC)
    case 'G':
    case 'GG':
    case 'GGG':
      formatter = dateStrGetter(TranslationType.Eras, TranslationWidth.Abbreviated);
      break;

    case 'GGGG':
      formatter = dateStrGetter(TranslationType.Eras, TranslationWidth.Wide);
      break;

    case 'GGGGG':
      formatter = dateStrGetter(TranslationType.Eras, TranslationWidth.Narrow);
      break;
    // 1 digit representation of the year, e.g. (AD 1 => 1, AD 199 => 199)

    case 'y':
      formatter = dateGetter(DateType.FullYear, 1, 0, false, true);
      break;
    // 2 digit representation of the year, padded (00-99). (e.g. AD 2001 => 01, AD 2010 => 10)

    case 'yy':
      formatter = dateGetter(DateType.FullYear, 2, 0, true, true);
      break;
    // 3 digit representation of the year, padded (000-999). (e.g. AD 2001 => 01, AD 2010 => 10)

    case 'yyy':
      formatter = dateGetter(DateType.FullYear, 3, 0, false, true);
      break;
    // 4 digit representation of the year (e.g. AD 1 => 0001, AD 2010 => 2010)

    case 'yyyy':
      formatter = dateGetter(DateType.FullYear, 4, 0, false, true);
      break;
    // Month of the year (1-12), numeric

    case 'M':
    case 'L':
      formatter = dateGetter(DateType.Month, 1, 1);
      break;

    case 'MM':
    case 'LL':
      formatter = dateGetter(DateType.Month, 2, 1);
      break;
    // Month of the year (January, ...), string, format

    case 'MMM':
      formatter = dateStrGetter(TranslationType.Months, TranslationWidth.Abbreviated);
      break;

    case 'MMMM':
      formatter = dateStrGetter(TranslationType.Months, TranslationWidth.Wide);
      break;

    case 'MMMMM':
      formatter = dateStrGetter(TranslationType.Months, TranslationWidth.Narrow);
      break;
    // Month of the year (January, ...), string, standalone

    case 'LLL':
      formatter = dateStrGetter(TranslationType.Months, TranslationWidth.Abbreviated, FormStyle.Standalone);
      break;

    case 'LLLL':
      formatter = dateStrGetter(TranslationType.Months, TranslationWidth.Wide, FormStyle.Standalone);
      break;

    case 'LLLLL':
      formatter = dateStrGetter(TranslationType.Months, TranslationWidth.Narrow, FormStyle.Standalone);
      break;
    // Week of the year (1, ... 52)

    case 'w':
      formatter = weekGetter(1);
      break;

    case 'ww':
      formatter = weekGetter(2);
      break;
    // Week of the month (1, ...)

    case 'W':
      formatter = weekGetter(1, true);
      break;
    // Day of the month (1-31)

    case 'd':
      formatter = dateGetter(DateType.Date, 1);
      break;

    case 'dd':
      formatter = dateGetter(DateType.Date, 2);
      break;
    // Day of the Week

    case 'E':
    case 'EE':
    case 'EEE':
      formatter = dateStrGetter(TranslationType.Days, TranslationWidth.Abbreviated);
      break;

    case 'EEEE':
      formatter = dateStrGetter(TranslationType.Days, TranslationWidth.Wide);
      break;

    case 'EEEEE':
      formatter = dateStrGetter(TranslationType.Days, TranslationWidth.Narrow);
      break;

    case 'EEEEEE':
      formatter = dateStrGetter(TranslationType.Days, TranslationWidth.Short);
      break;
    // Generic period of the day (am-pm)

    case 'a':
    case 'aa':
    case 'aaa':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Abbreviated);
      break;

    case 'aaaa':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Wide);
      break;

    case 'aaaaa':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Narrow);
      break;
    // Extended period of the day (midnight, at night, ...), standalone

    case 'b':
    case 'bb':
    case 'bbb':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Abbreviated, FormStyle.Standalone, true);
      break;

    case 'bbbb':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Wide, FormStyle.Standalone, true);
      break;

    case 'bbbbb':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Narrow, FormStyle.Standalone, true);
      break;
    // Extended period of the day (midnight, night, ...), standalone

    case 'B':
    case 'BB':
    case 'BBB':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Abbreviated, FormStyle.Format, true);
      break;

    case 'BBBB':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Wide, FormStyle.Format, true);
      break;

    case 'BBBBB':
      formatter = dateStrGetter(TranslationType.DayPeriods, TranslationWidth.Narrow, FormStyle.Format, true);
      break;
    // Hour in AM/PM, (1-12)

    case 'h':
      formatter = dateGetter(DateType.Hours, 1, -12);
      break;

    case 'hh':
      formatter = dateGetter(DateType.Hours, 2, -12);
      break;
    // Hour of the day (0-23)

    case 'H':
      formatter = dateGetter(DateType.Hours, 1);
      break;
    // Hour in day, padded (00-23)

    case 'HH':
      formatter = dateGetter(DateType.Hours, 2);
      break;
    // Minute of the hour (0-59)

    case 'm':
      formatter = dateGetter(DateType.Minutes, 1);
      break;

    case 'mm':
      formatter = dateGetter(DateType.Minutes, 2);
      break;
    // Second of the minute (0-59)

    case 's':
      formatter = dateGetter(DateType.Seconds, 1);
      break;

    case 'ss':
      formatter = dateGetter(DateType.Seconds, 2);
      break;
    // Fractional second

    case 'S':
      formatter = dateGetter(DateType.FractionalSeconds, 1);
      break;

    case 'SS':
      formatter = dateGetter(DateType.FractionalSeconds, 2);
      break;

    case 'SSS':
      formatter = dateGetter(DateType.FractionalSeconds, 3);
      break;
    // Timezone ISO8601 short format (-0430)

    case 'Z':
    case 'ZZ':
    case 'ZZZ':
      formatter = timeZoneGetter(ZoneWidth.Short);
      break;
    // Timezone ISO8601 extended format (-04:30)

    case 'ZZZZZ':
      formatter = timeZoneGetter(ZoneWidth.Extended);
      break;
    // Timezone GMT short format (GMT+4)

    case 'O':
    case 'OO':
    case 'OOO': // Should be location, but fallback to format O instead because we don't have the data yet

    case 'z':
    case 'zz':
    case 'zzz':
      formatter = timeZoneGetter(ZoneWidth.ShortGMT);
      break;
    // Timezone GMT long format (GMT+0430)

    case 'OOOO':
    case 'ZZZZ': // Should be location, but fallback to format O instead because we don't have the data yet

    case 'zzzz':
      formatter = timeZoneGetter(ZoneWidth.Long);
      break;

    default:
      return null;
  }

  DATE_FORMATS[format] = formatter;
  return formatter;
}

function timezoneToOffset(timezone, fallback) {
  // Support: IE 9-11 only, Edge 13-15+
  // IE/Edge do not "understand" colon (`:`) in timezone
  timezone = timezone.replace(/:/g, '');
  var requestedTimezoneOffset = Date.parse('Jan 01, 1970 00:00:00 ' + timezone) / 60000;
  return isNaN(requestedTimezoneOffset) ? fallback : requestedTimezoneOffset;
}

function addDateMinutes(date, minutes) {
  date = new Date(date.getTime());
  date.setMinutes(date.getMinutes() + minutes);
  return date;
}

function convertTimezoneToLocal(date, timezone, reverse) {
  var reverseValue = reverse ? -1 : 1;
  var dateTimezoneOffset = date.getTimezoneOffset();
  var timezoneOffset = timezoneToOffset(timezone, dateTimezoneOffset);
  return addDateMinutes(date, reverseValue * (timezoneOffset - dateTimezoneOffset));
}
/**
 * Converts a value to date.
 *
 * Supported input formats:
 * - `Date`
 * - number: timestamp
 * - string: numeric (e.g. "1234"), ISO and date strings in a format supported by
 *   [Date.parse()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/parse).
 *   Note: ISO strings without time return a date without timeoffset.
 *
 * Throws if unable to convert to a date.
 */


function toDate(value) {
  if (isDate(value)) {
    return value;
  }

  if (typeof value === 'number' && !isNaN(value)) {
    return new Date(value);
  }

  if (typeof value === 'string') {
    value = value.trim();
    var parsedNb = parseFloat(value); // any string that only contains numbers, like "1234" but not like "1234hello"

    if (!isNaN(value - parsedNb)) {
      return new Date(parsedNb);
    }

    if (/^(\d{4}-\d{1,2}-\d{1,2})$/.test(value)) {
      /* For ISO Strings without time the day, month and year must be extracted from the ISO String
      before Date creation to avoid time offset and errors in the new Date.
      If we only replace '-' with ',' in the ISO String ("2015,01,01"), and try to create a new
      date, some browsers (e.g. IE 9) will throw an invalid Date error.
      If we leave the '-' ("2015-01-01") and try to create a new Date("2015-01-01") the timeoffset
      is applied.
      Note: ISO months are 0 for January, 1 for February, ... */
      var _value$split$map = value.split('-').map(function (val) {
        return +val;
      }),
          _value$split$map2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_value$split$map, 3),
          y = _value$split$map2[0],
          m = _value$split$map2[1],
          d = _value$split$map2[2];

      return new Date(y, m - 1, d);
    }

    var match;

    if (match = value.match(ISO8601_DATE_REGEX)) {
      return isoStringToDate(match);
    }
  }

  var date = new Date(value);

  if (!isDate(date)) {
    throw new Error("Unable to convert \"".concat(value, "\" into a date"));
  }

  return date;
}
/**
 * Converts a date in ISO8601 to a Date.
 * Used instead of `Date.parse` because of browser discrepancies.
 */


function isoStringToDate(match) {
  var date = new Date(0);
  var tzHour = 0;
  var tzMin = 0; // match[8] means that the string contains "Z" (UTC) or a timezone like "+01:00" or "+0100"

  var dateSetter = match[8] ? date.setUTCFullYear : date.setFullYear;
  var timeSetter = match[8] ? date.setUTCHours : date.setHours; // if there is a timezone defined like "+01:00" or "+0100"

  if (match[9]) {
    tzHour = Number(match[9] + match[10]);
    tzMin = Number(match[9] + match[11]);
  }

  dateSetter.call(date, Number(match[1]), Number(match[2]) - 1, Number(match[3]));
  var h = Number(match[4] || 0) - tzHour;
  var m = Number(match[5] || 0) - tzMin;
  var s = Number(match[6] || 0);
  var ms = Math.round(parseFloat('0.' + (match[7] || 0)) * 1000);
  timeSetter.call(date, h, m, s, ms);
  return date;
}

function isDate(value) {
  return value instanceof Date && !isNaN(value.valueOf());
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NUMBER_FORMAT_REGEXP = /^(\d+)?\.((\d+)(-(\d+))?)?$/;
var MAX_DIGITS = 22;
var DECIMAL_SEP = '.';
var ZERO_CHAR = '0';
var PATTERN_SEP = ';';
var GROUP_SEP = ',';
var DIGIT_CHAR = '#';
var CURRENCY_CHAR = '¤';
var PERCENT_CHAR = '%';
/**
 * Transforms a number to a locale string based on a style and a format.
 */

function formatNumberToLocaleString(value, pattern, locale, groupSymbol, decimalSymbol, digitsInfo) {
  var isPercent = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;
  var formattedText = '';
  var isZero = false;

  if (!isFinite(value)) {
    formattedText = getLocaleNumberSymbol(locale, NumberSymbol.Infinity);
  } else {
    var parsedNumber = parseNumber(value);

    if (isPercent) {
      parsedNumber = toPercent(parsedNumber);
    }

    var minInt = pattern.minInt;
    var minFraction = pattern.minFrac;
    var maxFraction = pattern.maxFrac;

    if (digitsInfo) {
      var parts = digitsInfo.match(NUMBER_FORMAT_REGEXP);

      if (parts === null) {
        throw new Error("".concat(digitsInfo, " is not a valid digit info"));
      }

      var minIntPart = parts[1];
      var minFractionPart = parts[3];
      var maxFractionPart = parts[5];

      if (minIntPart != null) {
        minInt = parseIntAutoRadix(minIntPart);
      }

      if (minFractionPart != null) {
        minFraction = parseIntAutoRadix(minFractionPart);
      }

      if (maxFractionPart != null) {
        maxFraction = parseIntAutoRadix(maxFractionPart);
      } else if (minFractionPart != null && minFraction > maxFraction) {
        maxFraction = minFraction;
      }
    }

    roundNumber(parsedNumber, minFraction, maxFraction);
    var digits = parsedNumber.digits;
    var integerLen = parsedNumber.integerLen;
    var exponent = parsedNumber.exponent;
    var decimals = [];
    isZero = digits.every(function (d) {
      return !d;
    }); // pad zeros for small numbers

    for (; integerLen < minInt; integerLen++) {
      digits.unshift(0);
    } // pad zeros for small numbers


    for (; integerLen < 0; integerLen++) {
      digits.unshift(0);
    } // extract decimals digits


    if (integerLen > 0) {
      decimals = digits.splice(integerLen, digits.length);
    } else {
      decimals = digits;
      digits = [0];
    } // format the integer digits with grouping separators


    var groups = [];

    if (digits.length >= pattern.lgSize) {
      groups.unshift(digits.splice(-pattern.lgSize, digits.length).join(''));
    }

    while (digits.length > pattern.gSize) {
      groups.unshift(digits.splice(-pattern.gSize, digits.length).join(''));
    }

    if (digits.length) {
      groups.unshift(digits.join(''));
    }

    formattedText = groups.join(getLocaleNumberSymbol(locale, groupSymbol)); // append the decimal digits

    if (decimals.length) {
      formattedText += getLocaleNumberSymbol(locale, decimalSymbol) + decimals.join('');
    }

    if (exponent) {
      formattedText += getLocaleNumberSymbol(locale, NumberSymbol.Exponential) + '+' + exponent;
    }
  }

  if (value < 0 && !isZero) {
    formattedText = pattern.negPre + formattedText + pattern.negSuf;
  } else {
    formattedText = pattern.posPre + formattedText + pattern.posSuf;
  }

  return formattedText;
}
/**
 * @ngModule CommonModule
 * @description
 *
 * Formats a number as currency using locale rules.
 *
 * @param value The number to format.
 * @param locale A locale code for the locale format rules to use.
 * @param currency A string containing the currency symbol or its name,
 * such as "$" or "Canadian Dollar". Used in output string, but does not affect the operation
 * of the function.
 * @param currencyCode The [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)
 * currency code, such as `USD` for the US dollar and `EUR` for the euro.
 * Used to determine the number of digits in the decimal part.
 * @param digitInfo Decimal representation options, specified by a string in the following format:
 * `{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}`. See `DecimalPipe` for more details.
 *
 * @returns The formatted currency value.
 *
 * @see `formatNumber()`
 * @see `DecimalPipe`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function formatCurrency(value, locale, currency, currencyCode, digitsInfo) {
  var format = getLocaleNumberFormat(locale, NumberFormatStyle.Currency);
  var pattern = parseNumberFormat(format, getLocaleNumberSymbol(locale, NumberSymbol.MinusSign));
  pattern.minFrac = getNumberOfCurrencyDigits(currencyCode);
  pattern.maxFrac = pattern.minFrac;
  var res = formatNumberToLocaleString(value, pattern, locale, NumberSymbol.CurrencyGroup, NumberSymbol.CurrencyDecimal, digitsInfo);
  return res.replace(CURRENCY_CHAR, currency) // if we have 2 time the currency character, the second one is ignored
  .replace(CURRENCY_CHAR, '') // If there is a spacing between currency character and the value and
  // the currency character is supressed by passing an empty string, the
  // spacing character would remain as part of the string. Then we
  // should remove it.
  .trim();
}
/**
 * @ngModule CommonModule
 * @description
 *
 * Formats a number as a percentage according to locale rules.
 *
 * @param value The number to format.
 * @param locale A locale code for the locale format rules to use.
 * @param digitInfo Decimal representation options, specified by a string in the following format:
 * `{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}`. See `DecimalPipe` for more details.
 *
 * @returns The formatted percentage value.
 *
 * @see `formatNumber()`
 * @see `DecimalPipe`
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 * @publicApi
 *
 */


function formatPercent(value, locale, digitsInfo) {
  var format = getLocaleNumberFormat(locale, NumberFormatStyle.Percent);
  var pattern = parseNumberFormat(format, getLocaleNumberSymbol(locale, NumberSymbol.MinusSign));
  var res = formatNumberToLocaleString(value, pattern, locale, NumberSymbol.Group, NumberSymbol.Decimal, digitsInfo, true);
  return res.replace(new RegExp(PERCENT_CHAR, 'g'), getLocaleNumberSymbol(locale, NumberSymbol.PercentSign));
}
/**
 * @ngModule CommonModule
 * @description
 *
 * Formats a number as text, with group sizing, separator, and other
 * parameters based on the locale.
 *
 * @param value The number to format.
 * @param locale A locale code for the locale format rules to use.
 * @param digitInfo Decimal representation options, specified by a string in the following format:
 * `{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}`. See `DecimalPipe` for more details.
 *
 * @returns The formatted text string.
 * @see [Internationalization (i18n) Guide](https://angular.io/guide/i18n)
 *
 * @publicApi
 */


function formatNumber(value, locale, digitsInfo) {
  var format = getLocaleNumberFormat(locale, NumberFormatStyle.Decimal);
  var pattern = parseNumberFormat(format, getLocaleNumberSymbol(locale, NumberSymbol.MinusSign));
  return formatNumberToLocaleString(value, pattern, locale, NumberSymbol.Group, NumberSymbol.Decimal, digitsInfo);
}

function parseNumberFormat(format) {
  var minusSign = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '-';
  var p = {
    minInt: 1,
    minFrac: 0,
    maxFrac: 0,
    posPre: '',
    posSuf: '',
    negPre: '',
    negSuf: '',
    gSize: 0,
    lgSize: 0
  };
  var patternParts = format.split(PATTERN_SEP);
  var positive = patternParts[0];
  var negative = patternParts[1];
  var positiveParts = positive.indexOf(DECIMAL_SEP) !== -1 ? positive.split(DECIMAL_SEP) : [positive.substring(0, positive.lastIndexOf(ZERO_CHAR) + 1), positive.substring(positive.lastIndexOf(ZERO_CHAR) + 1)],
      integer = positiveParts[0],
      fraction = positiveParts[1] || '';
  p.posPre = integer.substr(0, integer.indexOf(DIGIT_CHAR));

  for (var i = 0; i < fraction.length; i++) {
    var ch = fraction.charAt(i);

    if (ch === ZERO_CHAR) {
      p.minFrac = p.maxFrac = i + 1;
    } else if (ch === DIGIT_CHAR) {
      p.maxFrac = i + 1;
    } else {
      p.posSuf += ch;
    }
  }

  var groups = integer.split(GROUP_SEP);
  p.gSize = groups[1] ? groups[1].length : 0;
  p.lgSize = groups[2] || groups[1] ? (groups[2] || groups[1]).length : 0;

  if (negative) {
    var trunkLen = positive.length - p.posPre.length - p.posSuf.length,
        pos = negative.indexOf(DIGIT_CHAR);
    p.negPre = negative.substr(0, pos).replace(/'/g, '');
    p.negSuf = negative.substr(pos + trunkLen).replace(/'/g, '');
  } else {
    p.negPre = minusSign + p.posPre;
    p.negSuf = p.posSuf;
  }

  return p;
} // Transforms a parsed number into a percentage by multiplying it by 100


function toPercent(parsedNumber) {
  // if the number is 0, don't do anything
  if (parsedNumber.digits[0] === 0) {
    return parsedNumber;
  } // Getting the current number of decimals


  var fractionLen = parsedNumber.digits.length - parsedNumber.integerLen;

  if (parsedNumber.exponent) {
    parsedNumber.exponent += 2;
  } else {
    if (fractionLen === 0) {
      parsedNumber.digits.push(0, 0);
    } else if (fractionLen === 1) {
      parsedNumber.digits.push(0);
    }

    parsedNumber.integerLen += 2;
  }

  return parsedNumber;
}
/**
 * Parses a number.
 * Significant bits of this parse algorithm came from https://github.com/MikeMcl/big.js/
 */


function parseNumber(num) {
  var numStr = Math.abs(num) + '';
  var exponent = 0,
      digits,
      integerLen;
  var i, j, zeros; // Decimal point?

  if ((integerLen = numStr.indexOf(DECIMAL_SEP)) > -1) {
    numStr = numStr.replace(DECIMAL_SEP, '');
  } // Exponential form?


  if ((i = numStr.search(/e/i)) > 0) {
    // Work out the exponent.
    if (integerLen < 0) integerLen = i;
    integerLen += +numStr.slice(i + 1);
    numStr = numStr.substring(0, i);
  } else if (integerLen < 0) {
    // There was no decimal point or exponent so it is an integer.
    integerLen = numStr.length;
  } // Count the number of leading zeros.


  for (i = 0; numStr.charAt(i) === ZERO_CHAR; i++) {
    /* empty */
  }

  if (i === (zeros = numStr.length)) {
    // The digits are all zero.
    digits = [0];
    integerLen = 1;
  } else {
    // Count the number of trailing zeros
    zeros--;

    while (numStr.charAt(zeros) === ZERO_CHAR) {
      zeros--;
    } // Trailing zeros are insignificant so ignore them


    integerLen -= i;
    digits = []; // Convert string to array of digits without leading/trailing zeros.

    for (j = 0; i <= zeros; i++, j++) {
      digits[j] = Number(numStr.charAt(i));
    }
  } // If the number overflows the maximum allowed digits then use an exponent.


  if (integerLen > MAX_DIGITS) {
    digits = digits.splice(0, MAX_DIGITS - 1);
    exponent = integerLen - 1;
    integerLen = 1;
  }

  return {
    digits: digits,
    exponent: exponent,
    integerLen: integerLen
  };
}
/**
 * Round the parsed number to the specified number of decimal places
 * This function changes the parsedNumber in-place
 */


function roundNumber(parsedNumber, minFrac, maxFrac) {
  if (minFrac > maxFrac) {
    throw new Error("The minimum number of digits after fraction (".concat(minFrac, ") is higher than the maximum (").concat(maxFrac, ")."));
  }

  var digits = parsedNumber.digits;
  var fractionLen = digits.length - parsedNumber.integerLen;
  var fractionSize = Math.min(Math.max(minFrac, fractionLen), maxFrac); // The index of the digit to where rounding is to occur

  var roundAt = fractionSize + parsedNumber.integerLen;
  var digit = digits[roundAt];

  if (roundAt > 0) {
    // Drop fractional digits beyond `roundAt`
    digits.splice(Math.max(parsedNumber.integerLen, roundAt)); // Set non-fractional digits beyond `roundAt` to 0

    for (var j = roundAt; j < digits.length; j++) {
      digits[j] = 0;
    }
  } else {
    // We rounded to zero so reset the parsedNumber
    fractionLen = Math.max(0, fractionLen);
    parsedNumber.integerLen = 1;
    digits.length = Math.max(1, roundAt = fractionSize + 1);
    digits[0] = 0;

    for (var i = 1; i < roundAt; i++) {
      digits[i] = 0;
    }
  }

  if (digit >= 5) {
    if (roundAt - 1 < 0) {
      for (var k = 0; k > roundAt; k--) {
        digits.unshift(0);
        parsedNumber.integerLen++;
      }

      digits.unshift(1);
      parsedNumber.integerLen++;
    } else {
      digits[roundAt - 1]++;
    }
  } // Pad out with zeros to get the required fraction length


  for (; fractionLen < Math.max(0, fractionSize); fractionLen++) {
    digits.push(0);
  }

  var dropTrailingZeros = fractionSize !== 0; // Minimal length = nb of decimals required + current nb of integers
  // Any number besides that is optional and can be removed if it's a trailing 0

  var minLen = minFrac + parsedNumber.integerLen; // Do any carrying, e.g. a digit was rounded up to 10

  var carry = digits.reduceRight(function (carry, d, i, digits) {
    d = d + carry;
    digits[i] = d < 10 ? d : d - 10; // d % 10

    if (dropTrailingZeros) {
      // Do not keep meaningless fractional trailing zeros (e.g. 15.52000 --> 15.52)
      if (digits[i] === 0 && i >= minLen) {
        digits.pop();
      } else {
        dropTrailingZeros = false;
      }
    }

    return d >= 10 ? 1 : 0; // Math.floor(d / 10);
  }, 0);

  if (carry) {
    digits.unshift(carry);
    parsedNumber.integerLen++;
  }
}

function parseIntAutoRadix(text) {
  var result = parseInt(text);

  if (isNaN(result)) {
    throw new Error('Invalid integer literal when parsing ' + text);
  }

  return result;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var NgLocalization = function NgLocalization() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgLocalization);
};
/**
 * Returns the plural category for a given value.
 * - "=value" when the case exists,
 * - the plural category otherwise
 */


function getPluralCategory(value, cases, ngLocalization, locale) {
  var key = "=".concat(value);

  if (cases.indexOf(key) > -1) {
    return key;
  }

  key = ngLocalization.getPluralCategory(value, locale);

  if (cases.indexOf(key) > -1) {
    return key;
  }

  if (cases.indexOf('other') > -1) {
    return 'other';
  }

  throw new Error("No plural message found for value \"".concat(value, "\""));
}
/**
 * Returns the plural case based on the locale
 *
 * @publicApi
 */


var NgLocaleLocalization = /*#__PURE__*/function (_NgLocalization) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(NgLocaleLocalization, _NgLocalization);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(NgLocaleLocalization);

  function NgLocaleLocalization(locale) {
    var _this6;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgLocaleLocalization);

    _this6 = _super4.call(this);
    _this6.locale = locale;
    return _this6;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgLocaleLocalization, [{
    key: "getPluralCategory",
    value: function getPluralCategory(value, locale) {
      var plural = getLocalePluralCase(locale || this.locale)(value);

      switch (plural) {
        case Plural.Zero:
          return 'zero';

        case Plural.One:
          return 'one';

        case Plural.Two:
          return 'two';

        case Plural.Few:
          return 'few';

        case Plural.Many:
          return 'many';

        default:
          return 'other';
      }
    }
  }]);

  return NgLocaleLocalization;
}(NgLocalization);

NgLocaleLocalization.ɵfac = function NgLocaleLocalization_Factory(t) {
  return new (t || NgLocaleLocalization)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]));
};

NgLocaleLocalization.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: NgLocaleLocalization,
  factory: NgLocaleLocalization.ɵfac
});

NgLocaleLocalization.ctorParameters = function () {
  return [{
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgLocaleLocalization, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Register global data to be used internally by Angular. See the
 * ["I18n guide"](guide/i18n#i18n-pipes) to know how to import additional locale data.
 *
 * The signature registerLocaleData(data: any, extraData?: any) is deprecated since v5.1
 *
 * @publicApi
 */


function registerLocaleData(data, localeId, extraData) {
  return Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵregisterLocaleData"])(data, localeId, extraData);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function parseCookieValue(cookieStr, name) {
  name = encodeURIComponent(name);

  var _iterator = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_0__["default"])(cookieStr.split(';')),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var cookie = _step.value;
      var eqIndex = cookie.indexOf('=');

      var _ref2 = eqIndex == -1 ? [cookie, ''] : [cookie.slice(0, eqIndex), cookie.slice(eqIndex + 1)],
          _ref3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_ref2, 2),
          cookieName = _ref3[0],
          cookieValue = _ref3[1];

      if (cookieName.trim() === name) {
        return decodeURIComponent(cookieValue);
      }
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  return null;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 *
 * @usageNotes
 * ```
 *     <some-element [ngClass]="'first second'">...</some-element>
 *
 *     <some-element [ngClass]="['first', 'second']">...</some-element>
 *
 *     <some-element [ngClass]="{'first': true, 'second': true, 'third': false}">...</some-element>
 *
 *     <some-element [ngClass]="stringExp|arrayExp|objExp">...</some-element>
 *
 *     <some-element [ngClass]="{'class1 class2 class3' : true}">...</some-element>
 * ```
 *
 * @description
 *
 * Adds and removes CSS classes on an HTML element.
 *
 * The CSS classes are updated as follows, depending on the type of the expression evaluation:
 * - `string` - the CSS classes listed in the string (space delimited) are added,
 * - `Array` - the CSS classes declared as Array elements are added,
 * - `Object` - keys are CSS classes that get added when the expression given in the value
 *              evaluates to a truthy value, otherwise they are removed.
 *
 * @publicApi
 */


var NgClass = /*#__PURE__*/function () {
  function NgClass(_iterableDiffers, _keyValueDiffers, _ngEl, _renderer) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgClass);

    this._iterableDiffers = _iterableDiffers;
    this._keyValueDiffers = _keyValueDiffers;
    this._ngEl = _ngEl;
    this._renderer = _renderer;
    this._iterableDiffer = null;
    this._keyValueDiffer = null;
    this._initialClasses = [];
    this._rawClass = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgClass, [{
    key: "ngDoCheck",
    value: function ngDoCheck() {
      if (this._iterableDiffer) {
        var iterableChanges = this._iterableDiffer.diff(this._rawClass);

        if (iterableChanges) {
          this._applyIterableChanges(iterableChanges);
        }
      } else if (this._keyValueDiffer) {
        var keyValueChanges = this._keyValueDiffer.diff(this._rawClass);

        if (keyValueChanges) {
          this._applyKeyValueChanges(keyValueChanges);
        }
      }
    }
  }, {
    key: "_applyKeyValueChanges",
    value: function _applyKeyValueChanges(changes) {
      var _this7 = this;

      changes.forEachAddedItem(function (record) {
        return _this7._toggleClass(record.key, record.currentValue);
      });
      changes.forEachChangedItem(function (record) {
        return _this7._toggleClass(record.key, record.currentValue);
      });
      changes.forEachRemovedItem(function (record) {
        if (record.previousValue) {
          _this7._toggleClass(record.key, false);
        }
      });
    }
  }, {
    key: "_applyIterableChanges",
    value: function _applyIterableChanges(changes) {
      var _this8 = this;

      changes.forEachAddedItem(function (record) {
        if (typeof record.item === 'string') {
          _this8._toggleClass(record.item, true);
        } else {
          throw new Error("NgClass can only toggle CSS classes expressed as strings, got ".concat(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵstringify"])(record.item)));
        }
      });
      changes.forEachRemovedItem(function (record) {
        return _this8._toggleClass(record.item, false);
      });
    }
    /**
     * Applies a collection of CSS classes to the DOM element.
     *
     * For argument of type Set and Array CSS class names contained in those collections are always
     * added.
     * For argument of type Map CSS class name in the map's key is toggled based on the value (added
     * for truthy and removed for falsy).
     */

  }, {
    key: "_applyClasses",
    value: function _applyClasses(rawClassVal) {
      var _this9 = this;

      if (rawClassVal) {
        if (Array.isArray(rawClassVal) || rawClassVal instanceof Set) {
          rawClassVal.forEach(function (klass) {
            return _this9._toggleClass(klass, true);
          });
        } else {
          Object.keys(rawClassVal).forEach(function (klass) {
            return _this9._toggleClass(klass, !!rawClassVal[klass]);
          });
        }
      }
    }
    /**
     * Removes a collection of CSS classes from the DOM element. This is mostly useful for cleanup
     * purposes.
     */

  }, {
    key: "_removeClasses",
    value: function _removeClasses(rawClassVal) {
      var _this10 = this;

      if (rawClassVal) {
        if (Array.isArray(rawClassVal) || rawClassVal instanceof Set) {
          rawClassVal.forEach(function (klass) {
            return _this10._toggleClass(klass, false);
          });
        } else {
          Object.keys(rawClassVal).forEach(function (klass) {
            return _this10._toggleClass(klass, false);
          });
        }
      }
    }
  }, {
    key: "_toggleClass",
    value: function _toggleClass(klass, enabled) {
      var _this11 = this;

      klass = klass.trim();

      if (klass) {
        klass.split(/\s+/g).forEach(function (klass) {
          if (enabled) {
            _this11._renderer.addClass(_this11._ngEl.nativeElement, klass);
          } else {
            _this11._renderer.removeClass(_this11._ngEl.nativeElement, klass);
          }
        });
      }
    }
  }, {
    key: "klass",
    set: function set(value) {
      this._removeClasses(this._initialClasses);

      this._initialClasses = typeof value === 'string' ? value.split(/\s+/) : [];

      this._applyClasses(this._initialClasses);

      this._applyClasses(this._rawClass);
    }
  }, {
    key: "ngClass",
    set: function set(value) {
      this._removeClasses(this._rawClass);

      this._applyClasses(this._initialClasses);

      this._iterableDiffer = null;
      this._keyValueDiffer = null;
      this._rawClass = typeof value === 'string' ? value.split(/\s+/) : value;

      if (this._rawClass) {
        if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵisListLikeIterable"])(this._rawClass)) {
          this._iterableDiffer = this._iterableDiffers.find(this._rawClass).create();
        } else {
          this._keyValueDiffer = this._keyValueDiffers.find(this._rawClass).create();
        }
      }
    }
  }]);

  return NgClass;
}();

NgClass.ɵfac = function NgClass_Factory(t) {
  return new (t || NgClass)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["IterableDiffers"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]));
};

NgClass.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgClass,
  selectors: [["", "ngClass", ""]],
  inputs: {
    klass: ["class", "klass"],
    ngClass: "ngClass"
  }
});

NgClass.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["IterableDiffers"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]
  }];
};

NgClass.propDecorators = {
  klass: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"],
    args: ['class']
  }],
  ngClass: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"],
    args: ['ngClass']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgClass, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngClass]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["IterableDiffers"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]
    }];
  }, {
    klass: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"],
      args: ['class']
    }],
    ngClass: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"],
      args: ['ngClass']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Instantiates a single {@link Component} type and inserts its Host View into current View.
 * `NgComponentOutlet` provides a declarative approach for dynamic component creation.
 *
 * `NgComponentOutlet` requires a component type, if a falsy value is set the view will clear and
 * any existing component will get destroyed.
 *
 * @usageNotes
 *
 * ### Fine tune control
 *
 * You can control the component creation process by using the following optional attributes:
 *
 * * `ngComponentOutletInjector`: Optional custom {@link Injector} that will be used as parent for
 * the Component. Defaults to the injector of the current view container.
 *
 * * `ngComponentOutletContent`: Optional list of projectable nodes to insert into the content
 * section of the component, if exists.
 *
 * * `ngComponentOutletNgModuleFactory`: Optional module factory to allow dynamically loading other
 * module, then load a component from that module.
 *
 * ### Syntax
 *
 * Simple
 * ```
 * <ng-container *ngComponentOutlet="componentTypeExpression"></ng-container>
 * ```
 *
 * Customized injector/content
 * ```
 * <ng-container *ngComponentOutlet="componentTypeExpression;
 *                                   injector: injectorExpression;
 *                                   content: contentNodesExpression;">
 * </ng-container>
 * ```
 *
 * Customized ngModuleFactory
 * ```
 * <ng-container *ngComponentOutlet="componentTypeExpression;
 *                                   ngModuleFactory: moduleFactory;">
 * </ng-container>
 * ```
 *
 * ### A simple example
 *
 * {@example common/ngComponentOutlet/ts/module.ts region='SimpleExample'}
 *
 * A more complete example with additional options:
 *
 * {@example common/ngComponentOutlet/ts/module.ts region='CompleteExample'}
 *
 * @publicApi
 * @ngModule CommonModule
 */


var NgComponentOutlet = /*#__PURE__*/function () {
  function NgComponentOutlet(_viewContainerRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgComponentOutlet);

    this._viewContainerRef = _viewContainerRef;
    this._componentRef = null;
    this._moduleRef = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgComponentOutlet, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      this._viewContainerRef.clear();

      this._componentRef = null;

      if (this.ngComponentOutlet) {
        var elInjector = this.ngComponentOutletInjector || this._viewContainerRef.parentInjector;

        if (changes['ngComponentOutletNgModuleFactory']) {
          if (this._moduleRef) this._moduleRef.destroy();

          if (this.ngComponentOutletNgModuleFactory) {
            var parentModule = elInjector.get(_angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModuleRef"]);
            this._moduleRef = this.ngComponentOutletNgModuleFactory.create(parentModule.injector);
          } else {
            this._moduleRef = null;
          }
        }

        var componentFactoryResolver = this._moduleRef ? this._moduleRef.componentFactoryResolver : elInjector.get(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ComponentFactoryResolver"]);
        var componentFactory = componentFactoryResolver.resolveComponentFactory(this.ngComponentOutlet);
        this._componentRef = this._viewContainerRef.createComponent(componentFactory, this._viewContainerRef.length, elInjector, this.ngComponentOutletContent);
      }
    }
  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this._moduleRef) this._moduleRef.destroy();
    }
  }]);

  return NgComponentOutlet;
}();

NgComponentOutlet.ɵfac = function NgComponentOutlet_Factory(t) {
  return new (t || NgComponentOutlet)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]));
};

NgComponentOutlet.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgComponentOutlet,
  selectors: [["", "ngComponentOutlet", ""]],
  inputs: {
    ngComponentOutlet: "ngComponentOutlet",
    ngComponentOutletInjector: "ngComponentOutletInjector",
    ngComponentOutletContent: "ngComponentOutletContent",
    ngComponentOutletNgModuleFactory: "ngComponentOutletNgModuleFactory"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵNgOnChangesFeature"]]
});

NgComponentOutlet.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }];
};

NgComponentOutlet.propDecorators = {
  ngComponentOutlet: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngComponentOutletInjector: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngComponentOutletContent: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngComponentOutletNgModuleFactory: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgComponentOutlet, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngComponentOutlet]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }];
  }, {
    ngComponentOutlet: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngComponentOutletInjector: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngComponentOutletContent: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngComponentOutletNgModuleFactory: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var NgForOfContext = /*#__PURE__*/function () {
  function NgForOfContext($implicit, ngForOf, index, count) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgForOfContext);

    this.$implicit = $implicit;
    this.ngForOf = ngForOf;
    this.index = index;
    this.count = count;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgForOfContext, [{
    key: "first",
    get: function get() {
      return this.index === 0;
    }
  }, {
    key: "last",
    get: function get() {
      return this.index === this.count - 1;
    }
  }, {
    key: "even",
    get: function get() {
      return this.index % 2 === 0;
    }
  }, {
    key: "odd",
    get: function get() {
      return !this.even;
    }
  }]);

  return NgForOfContext;
}();
/**
 * A [structural directive](guide/structural-directives) that renders
 * a template for each item in a collection.
 * The directive is placed on an element, which becomes the parent
 * of the cloned templates.
 *
 * The `ngForOf` directive is generally used in the
 * [shorthand form](guide/structural-directives#the-asterisk--prefix) `*ngFor`.
 * In this form, the template to be rendered for each iteration is the content
 * of an anchor element containing the directive.
 *
 * The following example shows the shorthand syntax with some options,
 * contained in an `<li>` element.
 *
 * ```
 * <li *ngFor="let item of items; index as i; trackBy: trackByFn">...</li>
 * ```
 *
 * The shorthand form expands into a long form that uses the `ngForOf` selector
 * on an `<ng-template>` element.
 * The content of the `<ng-template>` element is the `<li>` element that held the
 * short-form directive.
 *
 * Here is the expanded version of the short-form example.
 *
 * ```
 * <ng-template ngFor let-item [ngForOf]="items" let-i="index" [ngForTrackBy]="trackByFn">
 *   <li>...</li>
 * </ng-template>
 * ```
 *
 * Angular automatically expands the shorthand syntax as it compiles the template.
 * The context for each embedded view is logically merged to the current component
 * context according to its lexical position.
 *
 * When using the shorthand syntax, Angular allows only [one structural directive
 * on an element](guide/structural-directives#one-structural-directive-per-host-element).
 * If you want to iterate conditionally, for example,
 * put the `*ngIf` on a container element that wraps the `*ngFor` element.
 * For futher discussion, see
 * [Structural Directives](guide/structural-directives#one-per-element).
 *
 * @usageNotes
 *
 * ### Local variables
 *
 * `NgForOf` provides exported values that can be aliased to local variables.
 * For example:
 *
 *  ```
 * <li *ngFor="let user of users; index as i; first as isFirst">
 *    {{i}}/{{users.length}}. {{user}} <span *ngIf="isFirst">default</span>
 * </li>
 * ```
 *
 * The following exported values can be aliased to local variables:
 *
 * - `$implicit: T`: The value of the individual items in the iterable (`ngForOf`).
 * - `ngForOf: NgIterable<T>`: The value of the iterable expression. Useful when the expression is
 * more complex then a property access, for example when using the async pipe (`userStreams |
 * async`).
 * - `index: number`: The index of the current item in the iterable.
 * - `count: number`: The length of the iterable.
 * - `first: boolean`: True when the item is the first item in the iterable.
 * - `last: boolean`: True when the item is the last item in the iterable.
 * - `even: boolean`: True when the item has an even index in the iterable.
 * - `odd: boolean`: True when the item has an odd index in the iterable.
 *
 * ### Change propagation
 *
 * When the contents of the iterator changes, `NgForOf` makes the corresponding changes to the DOM:
 *
 * * When an item is added, a new instance of the template is added to the DOM.
 * * When an item is removed, its template instance is removed from the DOM.
 * * When items are reordered, their respective templates are reordered in the DOM.
 *
 * Angular uses object identity to track insertions and deletions within the iterator and reproduce
 * those changes in the DOM. This has important implications for animations and any stateful
 * controls that are present, such as `<input>` elements that accept user input. Inserted rows can
 * be animated in, deleted rows can be animated out, and unchanged rows retain any unsaved state
 * such as user input.
 * For more on animations, see [Transitions and Triggers](guide/transition-and-triggers).
 *
 * The identities of elements in the iterator can change while the data does not.
 * This can happen, for example, if the iterator is produced from an RPC to the server, and that
 * RPC is re-run. Even if the data hasn't changed, the second response produces objects with
 * different identities, and Angular must tear down the entire DOM and rebuild it (as if all old
 * elements were deleted and all new elements inserted).
 *
 * To avoid this expensive operation, you can customize the default tracking algorithm.
 * by supplying the `trackBy` option to `NgForOf`.
 * `trackBy` takes a function that has two arguments: `index` and `item`.
 * If `trackBy` is given, Angular tracks changes by the return value of the function.
 *
 * @see [Structural Directives](guide/structural-directives)
 * @ngModule CommonModule
 * @publicApi
 */


var NgForOf = /*#__PURE__*/function () {
  function NgForOf(_viewContainer, _template, _differs) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgForOf);

    this._viewContainer = _viewContainer;
    this._template = _template;
    this._differs = _differs;
    this._ngForOf = null;
    this._ngForOfDirty = true;
    this._differ = null;
  }
  /**
   * The value of the iterable expression, which can be used as a
   * [template input variable](guide/structural-directives#template-input-variable).
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgForOf, [{
    key: "ngDoCheck",

    /**
     * Applies the changes when needed.
     */
    value: function ngDoCheck() {
      if (this._ngForOfDirty) {
        this._ngForOfDirty = false; // React on ngForOf changes only once all inputs have been initialized

        var value = this._ngForOf;

        if (!this._differ && value) {
          try {
            this._differ = this._differs.find(value).create(this.ngForTrackBy);
          } catch (_a) {
            throw new Error("Cannot find a differ supporting object '".concat(value, "' of type '").concat(getTypeName(value), "'. NgFor only supports binding to Iterables such as Arrays."));
          }
        }
      }

      if (this._differ) {
        var changes = this._differ.diff(this._ngForOf);

        if (changes) this._applyChanges(changes);
      }
    }
  }, {
    key: "_applyChanges",
    value: function _applyChanges(changes) {
      var _this12 = this;

      var insertTuples = [];
      changes.forEachOperation(function (item, adjustedPreviousIndex, currentIndex) {
        if (item.previousIndex == null) {
          // NgForOf is never "null" or "undefined" here because the differ detected
          // that a new item needs to be inserted from the iterable. This implies that
          // there is an iterable value for "_ngForOf".
          var view = _this12._viewContainer.createEmbeddedView(_this12._template, new NgForOfContext(null, _this12._ngForOf, -1, -1), currentIndex === null ? undefined : currentIndex);

          var tuple = new RecordViewTuple(item, view);
          insertTuples.push(tuple);
        } else if (currentIndex == null) {
          _this12._viewContainer.remove(adjustedPreviousIndex === null ? undefined : adjustedPreviousIndex);
        } else if (adjustedPreviousIndex !== null) {
          var _view = _this12._viewContainer.get(adjustedPreviousIndex);

          _this12._viewContainer.move(_view, currentIndex);

          var _tuple = new RecordViewTuple(item, _view);

          insertTuples.push(_tuple);
        }
      });

      for (var i = 0; i < insertTuples.length; i++) {
        this._perViewChange(insertTuples[i].view, insertTuples[i].record);
      }

      for (var _i = 0, ilen = this._viewContainer.length; _i < ilen; _i++) {
        var viewRef = this._viewContainer.get(_i);

        viewRef.context.index = _i;
        viewRef.context.count = ilen;
        viewRef.context.ngForOf = this._ngForOf;
      }

      changes.forEachIdentityChange(function (record) {
        var viewRef = _this12._viewContainer.get(record.currentIndex);

        viewRef.context.$implicit = record.item;
      });
    }
  }, {
    key: "_perViewChange",
    value: function _perViewChange(view, record) {
      view.context.$implicit = record.item;
    }
    /**
     * Asserts the correct type of the context for the template that `NgForOf` will render.
     *
     * The presence of this method is a signal to the Ivy template type-check compiler that the
     * `NgForOf` structural directive renders its template with a specific context type.
     */

  }, {
    key: "ngForOf",
    set: function set(ngForOf) {
      this._ngForOf = ngForOf;
      this._ngForOfDirty = true;
    }
    /**
     * A function that defines how to track changes for items in the iterable.
     *
     * When items are added, moved, or removed in the iterable,
     * the directive must re-render the appropriate DOM nodes.
     * To minimize churn in the DOM, only nodes that have changed
     * are re-rendered.
     *
     * By default, the change detector assumes that
     * the object instance identifies the node in the iterable.
     * When this function is supplied, the directive uses
     * the result of calling this function to identify the item node,
     * rather than the identity of the object itself.
     *
     * The function receives two inputs,
     * the iteration index and the associated node data.
     */

  }, {
    key: "ngForTrackBy",
    set: function set(fn) {
      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["isDevMode"])() && fn != null && typeof fn !== 'function') {
        // TODO(vicb): use a log service once there is a public one available
        if (console && console.warn) {
          console.warn("trackBy must be a function, but received ".concat(JSON.stringify(fn), ". ") + "See https://angular.io/api/common/NgForOf#change-propagation for more information.");
        }
      }

      this._trackByFn = fn;
    },
    get: function get() {
      return this._trackByFn;
    }
    /**
     * A reference to the template that is stamped out for each item in the iterable.
     * @see [template reference variable](guide/template-reference-variables)
     */

  }, {
    key: "ngForTemplate",
    set: function set(value) {
      // TODO(TS2.1): make TemplateRef<Partial<NgForRowOf<T>>> once we move to TS v2.1
      // The current type is too restrictive; a template that just uses index, for example,
      // should be acceptable.
      if (value) {
        this._template = value;
      }
    }
  }], [{
    key: "ngTemplateContextGuard",
    value: function ngTemplateContextGuard(dir, ctx) {
      return true;
    }
  }]);

  return NgForOf;
}();

NgForOf.ɵfac = function NgForOf_Factory(t) {
  return new (t || NgForOf)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["IterableDiffers"]));
};

NgForOf.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgForOf,
  selectors: [["", "ngFor", "", "ngForOf", ""]],
  inputs: {
    ngForOf: "ngForOf",
    ngForTrackBy: "ngForTrackBy",
    ngForTemplate: "ngForTemplate"
  }
});

NgForOf.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["IterableDiffers"]
  }];
};

NgForOf.propDecorators = {
  ngForOf: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngForTrackBy: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngForTemplate: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgForOf, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngFor][ngForOf]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["IterableDiffers"]
    }];
  }, {
    ngForOf: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngForTrackBy: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngForTemplate: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();

var RecordViewTuple = function RecordViewTuple(record, view) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, RecordViewTuple);

  this.record = record;
  this.view = view;
};

function getTypeName(type) {
  return type['name'] || typeof type;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A structural directive that conditionally includes a template based on the value of
 * an expression coerced to Boolean.
 * When the expression evaluates to true, Angular renders the template
 * provided in a `then` clause, and when  false or null,
 * Angular renders the template provided in an optional `else` clause. The default
 * template for the `else` clause is blank.
 *
 * A [shorthand form](guide/structural-directives#the-asterisk--prefix) of the directive,
 * `*ngIf="condition"`, is generally used, provided
 * as an attribute of the anchor element for the inserted template.
 * Angular expands this into a more explicit version, in which the anchor element
 * is contained in an `<ng-template>` element.
 *
 * Simple form with shorthand syntax:
 *
 * ```
 * <div *ngIf="condition">Content to render when condition is true.</div>
 * ```
 *
 * Simple form with expanded syntax:
 *
 * ```
 * <ng-template [ngIf]="condition"><div>Content to render when condition is
 * true.</div></ng-template>
 * ```
 *
 * Form with an "else" block:
 *
 * ```
 * <div *ngIf="condition; else elseBlock">Content to render when condition is true.</div>
 * <ng-template #elseBlock>Content to render when condition is false.</ng-template>
 * ```
 *
 * Shorthand form with "then" and "else" blocks:
 *
 * ```
 * <div *ngIf="condition; then thenBlock else elseBlock"></div>
 * <ng-template #thenBlock>Content to render when condition is true.</ng-template>
 * <ng-template #elseBlock>Content to render when condition is false.</ng-template>
 * ```
 *
 * Form with storing the value locally:
 *
 * ```
 * <div *ngIf="condition as value; else elseBlock">{{value}}</div>
 * <ng-template #elseBlock>Content to render when value is null.</ng-template>
 * ```
 *
 * @usageNotes
 *
 * The `*ngIf` directive is most commonly used to conditionally show an inline template,
 * as seen in the following  example.
 * The default `else` template is blank.
 *
 * {@example common/ngIf/ts/module.ts region='NgIfSimple'}
 *
 * ### Showing an alternative template using `else`
 *
 * To display a template when `expression` evaluates to false, use an `else` template
 * binding as shown in the following example.
 * The `else` binding points to an `<ng-template>`  element labeled `#elseBlock`.
 * The template can be defined anywhere in the component view, but is typically placed right after
 * `ngIf` for readability.
 *
 * {@example common/ngIf/ts/module.ts region='NgIfElse'}
 *
 * ### Using an external `then` template
 *
 * In the previous example, the then-clause template is specified inline, as the content of the
 * tag that contains the `ngIf` directive. You can also specify a template that is defined
 * externally, by referencing a labeled `<ng-template>` element. When you do this, you can
 * change which template to use at runtime, as shown in the following example.
 *
 * {@example common/ngIf/ts/module.ts region='NgIfThenElse'}
 *
 * ### Storing a conditional result in a variable
 *
 * You might want to show a set of properties from the same object. If you are waiting
 * for asynchronous data, the object can be undefined.
 * In this case, you can use `ngIf` and store the result of the condition in a local
 * variable as shown in the the following example.
 *
 * {@example common/ngIf/ts/module.ts region='NgIfAs'}
 *
 * This code uses only one `AsyncPipe`, so only one subscription is created.
 * The conditional statement stores the result of `userStream|async` in the local variable `user`.
 * You can then bind the local `user` repeatedly.
 *
 * The conditional displays the data only if `userStream` returns a value,
 * so you don't need to use the
 * [safe-navigation-operator](guide/template-expression-operators#safe-navigation-operator) (`?.`)
 * to guard against null values when accessing properties.
 * You can display an alternative template while waiting for the data.
 *
 * ### Shorthand syntax
 *
 * The shorthand syntax `*ngIf` expands into two separate template specifications
 * for the "then" and "else" clauses. For example, consider the following shorthand statement,
 * that is meant to show a loading page while waiting for data to be loaded.
 *
 * ```
 * <div class="hero-list" *ngIf="heroes else loading">
 *  ...
 * </div>
 *
 * <ng-template #loading>
 *  <div>Loading...</div>
 * </ng-template>
 * ```
 *
 * You can see that the "else" clause references the `<ng-template>`
 * with the `#loading` label, and the template for the "then" clause
 * is provided as the content of the anchor element.
 *
 * However, when Angular expands the shorthand syntax, it creates
 * another `<ng-template>` tag, with `ngIf` and `ngIfElse` directives.
 * The anchor element containing the template for the "then" clause becomes
 * the content of this unlabeled `<ng-template>` tag.
 *
 * ```
 * <ng-template [ngIf]="heroes" [ngIfElse]="loading">
 *  <div class="hero-list">
 *   ...
 *  </div>
 * </ng-template>
 *
 * <ng-template #loading>
 *  <div>Loading...</div>
 * </ng-template>
 * ```
 *
 * The presence of the implicit template object has implications for the nesting of
 * structural directives. For more on this subject, see
 * [Structural Directives](https://angular.io/guide/structural-directives#one-per-element).
 *
 * @ngModule CommonModule
 * @publicApi
 */


var NgIf = /*#__PURE__*/function () {
  function NgIf(_viewContainer, templateRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgIf);

    this._viewContainer = _viewContainer;
    this._context = new NgIfContext();
    this._thenTemplateRef = null;
    this._elseTemplateRef = null;
    this._thenViewRef = null;
    this._elseViewRef = null;
    this._thenTemplateRef = templateRef;
  }
  /**
   * The Boolean expression to evaluate as the condition for showing a template.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgIf, [{
    key: "_updateView",
    value: function _updateView() {
      if (this._context.$implicit) {
        if (!this._thenViewRef) {
          this._viewContainer.clear();

          this._elseViewRef = null;

          if (this._thenTemplateRef) {
            this._thenViewRef = this._viewContainer.createEmbeddedView(this._thenTemplateRef, this._context);
          }
        }
      } else {
        if (!this._elseViewRef) {
          this._viewContainer.clear();

          this._thenViewRef = null;

          if (this._elseTemplateRef) {
            this._elseViewRef = this._viewContainer.createEmbeddedView(this._elseTemplateRef, this._context);
          }
        }
      }
    }
    /**
     * Asserts the correct type of the context for the template that `NgIf` will render.
     *
     * The presence of this method is a signal to the Ivy template type-check compiler that the
     * `NgIf` structural directive renders its template with a specific context type.
     */

  }, {
    key: "ngIf",
    set: function set(condition) {
      this._context.$implicit = this._context.ngIf = condition;

      this._updateView();
    }
    /**
     * A template to show if the condition expression evaluates to true.
     */

  }, {
    key: "ngIfThen",
    set: function set(templateRef) {
      assertTemplate('ngIfThen', templateRef);
      this._thenTemplateRef = templateRef;
      this._thenViewRef = null; // clear previous view if any.

      this._updateView();
    }
    /**
     * A template to show if the condition expression evaluates to false.
     */

  }, {
    key: "ngIfElse",
    set: function set(templateRef) {
      assertTemplate('ngIfElse', templateRef);
      this._elseTemplateRef = templateRef;
      this._elseViewRef = null; // clear previous view if any.

      this._updateView();
    }
  }], [{
    key: "ngTemplateContextGuard",
    value: function ngTemplateContextGuard(dir, ctx) {
      return true;
    }
  }]);

  return NgIf;
}();

NgIf.ɵfac = function NgIf_Factory(t) {
  return new (t || NgIf)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]));
};

NgIf.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgIf,
  selectors: [["", "ngIf", ""]],
  inputs: {
    ngIf: "ngIf",
    ngIfThen: "ngIfThen",
    ngIfElse: "ngIfElse"
  }
});

NgIf.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
  }];
};

NgIf.propDecorators = {
  ngIf: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngIfThen: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngIfElse: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgIf, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngIf]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
    }];
  }, {
    ngIf: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngIfThen: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngIfElse: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();
/**
 * @publicApi
 */


var NgIfContext = function NgIfContext() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgIfContext);

  this.$implicit = null;
  this.ngIf = null;
};

function assertTemplate(property, templateRef) {
  var isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);

  if (!isTemplateRefOrNull) {
    throw new Error("".concat(property, " must be a TemplateRef, but received '").concat(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵstringify"])(templateRef), "'."));
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var SwitchView = /*#__PURE__*/function () {
  function SwitchView(_viewContainerRef, _templateRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, SwitchView);

    this._viewContainerRef = _viewContainerRef;
    this._templateRef = _templateRef;
    this._created = false;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(SwitchView, [{
    key: "create",
    value: function create() {
      this._created = true;

      this._viewContainerRef.createEmbeddedView(this._templateRef);
    }
  }, {
    key: "destroy",
    value: function destroy() {
      this._created = false;

      this._viewContainerRef.clear();
    }
  }, {
    key: "enforceState",
    value: function enforceState(created) {
      if (created && !this._created) {
        this.create();
      } else if (!created && this._created) {
        this.destroy();
      }
    }
  }]);

  return SwitchView;
}();
/**
 * @ngModule CommonModule
 *
 * @description
 * The `[ngSwitch]` directive on a container specifies an expression to match against.
 * The expressions to match are provided by `ngSwitchCase` directives on views within the container.
 * - Every view that matches is rendered.
 * - If there are no matches, a view with the `ngSwitchDefault` directive is rendered.
 * - Elements within the `[NgSwitch]` statement but outside of any `NgSwitchCase`
 * or `ngSwitchDefault` directive are preserved at the location.
 *
 * @usageNotes
 * Define a container element for the directive, and specify the switch expression
 * to match against as an attribute:
 *
 * ```
 * <container-element [ngSwitch]="switch_expression">
 * ```
 *
 * Within the container, `*ngSwitchCase` statements specify the match expressions
 * as attributes. Include `*ngSwitchDefault` as the final case.
 *
 * ```
 * <container-element [ngSwitch]="switch_expression">
 *    <some-element *ngSwitchCase="match_expression_1">...</some-element>
 * ...
 *    <some-element *ngSwitchDefault>...</some-element>
 * </container-element>
 * ```
 *
 * ### Usage Examples
 *
 * The following example shows how to use more than one case to display the same view:
 *
 * ```
 * <container-element [ngSwitch]="switch_expression">
 *   <!-- the same view can be shown in more than one case -->
 *   <some-element *ngSwitchCase="match_expression_1">...</some-element>
 *   <some-element *ngSwitchCase="match_expression_2">...</some-element>
 *   <some-other-element *ngSwitchCase="match_expression_3">...</some-other-element>
 *   <!--default case when there are no matches -->
 *   <some-element *ngSwitchDefault>...</some-element>
 * </container-element>
 * ```
 *
 * The following example shows how cases can be nested:
 * ```
 * <container-element [ngSwitch]="switch_expression">
 *       <some-element *ngSwitchCase="match_expression_1">...</some-element>
 *       <some-element *ngSwitchCase="match_expression_2">...</some-element>
 *       <some-other-element *ngSwitchCase="match_expression_3">...</some-other-element>
 *       <ng-container *ngSwitchCase="match_expression_3">
 *         <!-- use a ng-container to group multiple root nodes -->
 *         <inner-element></inner-element>
 *         <inner-other-element></inner-other-element>
 *       </ng-container>
 *       <some-element *ngSwitchDefault>...</some-element>
 *     </container-element>
 * ```
 *
 * @publicApi
 * @see `NgSwitchCase`
 * @see `NgSwitchDefault`
 * @see [Structural Directives](guide/structural-directives)
 *
 */


var NgSwitch = /*#__PURE__*/function () {
  function NgSwitch() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgSwitch);

    this._defaultUsed = false;
    this._caseCount = 0;
    this._lastCaseCheckIndex = 0;
    this._lastCasesMatched = false;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgSwitch, [{
    key: "_addCase",

    /** @internal */
    value: function _addCase() {
      return this._caseCount++;
    }
    /** @internal */

  }, {
    key: "_addDefault",
    value: function _addDefault(view) {
      if (!this._defaultViews) {
        this._defaultViews = [];
      }

      this._defaultViews.push(view);
    }
    /** @internal */

  }, {
    key: "_matchCase",
    value: function _matchCase(value) {
      var matched = value == this._ngSwitch;
      this._lastCasesMatched = this._lastCasesMatched || matched;
      this._lastCaseCheckIndex++;

      if (this._lastCaseCheckIndex === this._caseCount) {
        this._updateDefaultCases(!this._lastCasesMatched);

        this._lastCaseCheckIndex = 0;
        this._lastCasesMatched = false;
      }

      return matched;
    }
  }, {
    key: "_updateDefaultCases",
    value: function _updateDefaultCases(useDefault) {
      if (this._defaultViews && useDefault !== this._defaultUsed) {
        this._defaultUsed = useDefault;

        for (var i = 0; i < this._defaultViews.length; i++) {
          var defaultView = this._defaultViews[i];
          defaultView.enforceState(useDefault);
        }
      }
    }
  }, {
    key: "ngSwitch",
    set: function set(newValue) {
      this._ngSwitch = newValue;

      if (this._caseCount === 0) {
        this._updateDefaultCases(true);
      }
    }
  }]);

  return NgSwitch;
}();

NgSwitch.ɵfac = function NgSwitch_Factory(t) {
  return new (t || NgSwitch)();
};

NgSwitch.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgSwitch,
  selectors: [["", "ngSwitch", ""]],
  inputs: {
    ngSwitch: "ngSwitch"
  }
});
NgSwitch.propDecorators = {
  ngSwitch: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgSwitch, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngSwitch]'
    }]
  }], function () {
    return [];
  }, {
    ngSwitch: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();
/**
 * @ngModule CommonModule
 *
 * @description
 * Provides a switch case expression to match against an enclosing `ngSwitch` expression.
 * When the expressions match, the given `NgSwitchCase` template is rendered.
 * If multiple match expressions match the switch expression value, all of them are displayed.
 *
 * @usageNotes
 *
 * Within a switch container, `*ngSwitchCase` statements specify the match expressions
 * as attributes. Include `*ngSwitchDefault` as the final case.
 *
 * ```
 * <container-element [ngSwitch]="switch_expression">
 *   <some-element *ngSwitchCase="match_expression_1">...</some-element>
 *   ...
 *   <some-element *ngSwitchDefault>...</some-element>
 * </container-element>
 * ```
 *
 * Each switch-case statement contains an in-line HTML template or template reference
 * that defines the subtree to be selected if the value of the match expression
 * matches the value of the switch expression.
 *
 * Unlike JavaScript, which uses strict equality, Angular uses loose equality.
 * This means that the empty string, `""` matches 0.
 *
 * @publicApi
 * @see `NgSwitch`
 * @see `NgSwitchDefault`
 *
 */


var NgSwitchCase = /*#__PURE__*/function () {
  function NgSwitchCase(viewContainer, templateRef, ngSwitch) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgSwitchCase);

    this.ngSwitch = ngSwitch;

    ngSwitch._addCase();

    this._view = new SwitchView(viewContainer, templateRef);
  }
  /**
   * Performs case matching. For internal use only.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgSwitchCase, [{
    key: "ngDoCheck",
    value: function ngDoCheck() {
      this._view.enforceState(this.ngSwitch._matchCase(this.ngSwitchCase));
    }
  }]);

  return NgSwitchCase;
}();

NgSwitchCase.ɵfac = function NgSwitchCase_Factory(t) {
  return new (t || NgSwitchCase)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](NgSwitch, 1));
};

NgSwitchCase.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgSwitchCase,
  selectors: [["", "ngSwitchCase", ""]],
  inputs: {
    ngSwitchCase: "ngSwitchCase"
  }
});

NgSwitchCase.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
  }, {
    type: NgSwitch,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Host"]
    }]
  }];
};

NgSwitchCase.propDecorators = {
  ngSwitchCase: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgSwitchCase, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngSwitchCase]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
    }, {
      type: NgSwitch,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Host"]
      }]
    }];
  }, {
    ngSwitchCase: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();
/**
 * @ngModule CommonModule
 *
 * @description
 *
 * Creates a view that is rendered when no `NgSwitchCase` expressions
 * match the `NgSwitch` expression.
 * This statement should be the final case in an `NgSwitch`.
 *
 * @publicApi
 * @see `NgSwitch`
 * @see `NgSwitchCase`
 *
 */


var NgSwitchDefault = function NgSwitchDefault(viewContainer, templateRef, ngSwitch) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgSwitchDefault);

  ngSwitch._addDefault(new SwitchView(viewContainer, templateRef));
};

NgSwitchDefault.ɵfac = function NgSwitchDefault_Factory(t) {
  return new (t || NgSwitchDefault)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](NgSwitch, 1));
};

NgSwitchDefault.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgSwitchDefault,
  selectors: [["", "ngSwitchDefault", ""]]
});

NgSwitchDefault.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
  }, {
    type: NgSwitch,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Host"]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgSwitchDefault, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngSwitchDefault]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
    }, {
      type: NgSwitch,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Host"]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 *
 * @usageNotes
 * ```
 * <some-element [ngPlural]="value">
 *   <ng-template ngPluralCase="=0">there is nothing</ng-template>
 *   <ng-template ngPluralCase="=1">there is one</ng-template>
 *   <ng-template ngPluralCase="few">there are a few</ng-template>
 * </some-element>
 * ```
 *
 * @description
 *
 * Adds / removes DOM sub-trees based on a numeric value. Tailored for pluralization.
 *
 * Displays DOM sub-trees that match the switch expression value, or failing that, DOM sub-trees
 * that match the switch expression's pluralization category.
 *
 * To use this directive you must provide a container element that sets the `[ngPlural]` attribute
 * to a switch expression. Inner elements with a `[ngPluralCase]` will display based on their
 * expression:
 * - if `[ngPluralCase]` is set to a value starting with `=`, it will only display if the value
 *   matches the switch expression exactly,
 * - otherwise, the view will be treated as a "category match", and will only display if exact
 *   value matches aren't found and the value maps to its category for the defined locale.
 *
 * See http://cldr.unicode.org/index/cldr-spec/plural-rules
 *
 * @publicApi
 */


var NgPlural = /*#__PURE__*/function () {
  function NgPlural(_localization) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgPlural);

    this._localization = _localization;
    this._caseViews = {};
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgPlural, [{
    key: "addCase",
    value: function addCase(value, switchView) {
      this._caseViews[value] = switchView;
    }
  }, {
    key: "_updateView",
    value: function _updateView() {
      this._clearViews();

      var cases = Object.keys(this._caseViews);
      var key = getPluralCategory(this._switchValue, cases, this._localization);

      this._activateView(this._caseViews[key]);
    }
  }, {
    key: "_clearViews",
    value: function _clearViews() {
      if (this._activeView) this._activeView.destroy();
    }
  }, {
    key: "_activateView",
    value: function _activateView(view) {
      if (view) {
        this._activeView = view;

        this._activeView.create();
      }
    }
  }, {
    key: "ngPlural",
    set: function set(value) {
      this._switchValue = value;

      this._updateView();
    }
  }]);

  return NgPlural;
}();

NgPlural.ɵfac = function NgPlural_Factory(t) {
  return new (t || NgPlural)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](NgLocalization));
};

NgPlural.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgPlural,
  selectors: [["", "ngPlural", ""]],
  inputs: {
    ngPlural: "ngPlural"
  }
});

NgPlural.ctorParameters = function () {
  return [{
    type: NgLocalization
  }];
};

NgPlural.propDecorators = {
  ngPlural: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgPlural, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngPlural]'
    }]
  }], function () {
    return [{
      type: NgLocalization
    }];
  }, {
    ngPlural: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();
/**
 * @ngModule CommonModule
 *
 * @description
 *
 * Creates a view that will be added/removed from the parent {@link NgPlural} when the
 * given expression matches the plural expression according to CLDR rules.
 *
 * @usageNotes
 * ```
 * <some-element [ngPlural]="value">
 *   <ng-template ngPluralCase="=0">...</ng-template>
 *   <ng-template ngPluralCase="other">...</ng-template>
 * </some-element>
 *```
 *
 * See {@link NgPlural} for more details and example.
 *
 * @publicApi
 */


var NgPluralCase = function NgPluralCase(value, template, viewContainer, ngPlural) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgPluralCase);

  this.value = value;
  var isANumber = !isNaN(Number(value));
  ngPlural.addCase(isANumber ? "=".concat(value) : value, new SwitchView(viewContainer, template));
};

NgPluralCase.ɵfac = function NgPluralCase_Factory(t) {
  return new (t || NgPluralCase)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinjectAttribute"]('ngPluralCase'), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](NgPlural, 1));
};

NgPluralCase.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgPluralCase,
  selectors: [["", "ngPluralCase", ""]]
});

NgPluralCase.ctorParameters = function () {
  return [{
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Attribute"],
      args: ['ngPluralCase']
    }]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }, {
    type: NgPlural,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Host"]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgPluralCase, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngPluralCase]'
    }]
  }], function () {
    return [{
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Attribute"],
        args: ['ngPluralCase']
      }]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["TemplateRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }, {
      type: NgPlural,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Host"]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 *
 * @usageNotes
 *
 * Set the font of the containing element to the result of an expression.
 *
 * ```
 * <some-element [ngStyle]="{'font-style': styleExp}">...</some-element>
 * ```
 *
 * Set the width of the containing element to a pixel value returned by an expression.
 *
 * ```
 * <some-element [ngStyle]="{'max-width.px': widthExp}">...</some-element>
 * ```
 *
 * Set a collection of style values using an expression that returns key-value pairs.
 *
 * ```
 * <some-element [ngStyle]="objExp">...</some-element>
 * ```
 *
 * @description
 *
 * An attribute directive that updates styles for the containing HTML element.
 * Sets one or more style properties, specified as colon-separated key-value pairs.
 * The key is a style name, with an optional `.<unit>` suffix
 * (such as 'top.px', 'font-style.em').
 * The value is an expression to be evaluated.
 * The resulting non-null value, expressed in the given unit,
 * is assigned to the given style property.
 * If the result of evaluation is null, the corresponding style is removed.
 *
 * @publicApi
 */


var NgStyle = /*#__PURE__*/function () {
  function NgStyle(_ngEl, _differs, _renderer) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgStyle);

    this._ngEl = _ngEl;
    this._differs = _differs;
    this._renderer = _renderer;
    this._ngStyle = null;
    this._differ = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgStyle, [{
    key: "ngDoCheck",
    value: function ngDoCheck() {
      if (this._differ) {
        var changes = this._differ.diff(this._ngStyle);

        if (changes) {
          this._applyChanges(changes);
        }
      }
    }
  }, {
    key: "_setStyle",
    value: function _setStyle(nameAndUnit, value) {
      var _nameAndUnit$split = nameAndUnit.split('.'),
          _nameAndUnit$split2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_1__["default"])(_nameAndUnit$split, 2),
          name = _nameAndUnit$split2[0],
          unit = _nameAndUnit$split2[1];

      value = value != null && unit ? "".concat(value).concat(unit) : value;

      if (value != null) {
        this._renderer.setStyle(this._ngEl.nativeElement, name, value);
      } else {
        this._renderer.removeStyle(this._ngEl.nativeElement, name);
      }
    }
  }, {
    key: "_applyChanges",
    value: function _applyChanges(changes) {
      var _this13 = this;

      changes.forEachRemovedItem(function (record) {
        return _this13._setStyle(record.key, null);
      });
      changes.forEachAddedItem(function (record) {
        return _this13._setStyle(record.key, record.currentValue);
      });
      changes.forEachChangedItem(function (record) {
        return _this13._setStyle(record.key, record.currentValue);
      });
    }
  }, {
    key: "ngStyle",
    set: function set(values) {
      this._ngStyle = values;

      if (!this._differ && values) {
        this._differ = this._differs.find(values).create();
      }
    }
  }]);

  return NgStyle;
}();

NgStyle.ɵfac = function NgStyle_Factory(t) {
  return new (t || NgStyle)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]));
};

NgStyle.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgStyle,
  selectors: [["", "ngStyle", ""]],
  inputs: {
    ngStyle: "ngStyle"
  }
});

NgStyle.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]
  }];
};

NgStyle.propDecorators = {
  ngStyle: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"],
    args: ['ngStyle']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgStyle, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngStyle]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ElementRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Renderer2"]
    }];
  }, {
    ngStyle: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"],
      args: ['ngStyle']
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 *
 * @description
 *
 * Inserts an embedded view from a prepared `TemplateRef`.
 *
 * You can attach a context object to the `EmbeddedViewRef` by setting `[ngTemplateOutletContext]`.
 * `[ngTemplateOutletContext]` should be an object, the object's keys will be available for binding
 * by the local template `let` declarations.
 *
 * @usageNotes
 * ```
 * <ng-container *ngTemplateOutlet="templateRefExp; context: contextExp"></ng-container>
 * ```
 *
 * Using the key `$implicit` in the context object will set its value as default.
 *
 * ### Example
 *
 * {@example common/ngTemplateOutlet/ts/module.ts region='NgTemplateOutlet'}
 *
 * @publicApi
 */


var NgTemplateOutlet = /*#__PURE__*/function () {
  function NgTemplateOutlet(_viewContainerRef) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NgTemplateOutlet);

    this._viewContainerRef = _viewContainerRef;
    this._viewRef = null;
    /**
     * A context object to attach to the {@link EmbeddedViewRef}. This should be an
     * object, the object's keys will be available for binding by the local template `let`
     * declarations.
     * Using the key `$implicit` in the context object will set its value as default.
     */

    this.ngTemplateOutletContext = null;
    /**
     * A string defining the template reference and optionally the context object for the template.
     */

    this.ngTemplateOutlet = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NgTemplateOutlet, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      var recreateView = this._shouldRecreateView(changes);

      if (recreateView) {
        var viewContainerRef = this._viewContainerRef;

        if (this._viewRef) {
          viewContainerRef.remove(viewContainerRef.indexOf(this._viewRef));
        }

        this._viewRef = this.ngTemplateOutlet ? viewContainerRef.createEmbeddedView(this.ngTemplateOutlet, this.ngTemplateOutletContext) : null;
      } else if (this._viewRef && this.ngTemplateOutletContext) {
        this._updateExistingContext(this.ngTemplateOutletContext);
      }
    }
    /**
     * We need to re-create existing embedded view if:
     * - templateRef has changed
     * - context has changes
     *
     * We mark context object as changed when the corresponding object
     * shape changes (new properties are added or existing properties are removed).
     * In other words we consider context with the same properties as "the same" even
     * if object reference changes (see https://github.com/angular/angular/issues/13407).
     */

  }, {
    key: "_shouldRecreateView",
    value: function _shouldRecreateView(changes) {
      var ctxChange = changes['ngTemplateOutletContext'];
      return !!changes['ngTemplateOutlet'] || ctxChange && this._hasContextShapeChanged(ctxChange);
    }
  }, {
    key: "_hasContextShapeChanged",
    value: function _hasContextShapeChanged(ctxChange) {
      var prevCtxKeys = Object.keys(ctxChange.previousValue || {});
      var currCtxKeys = Object.keys(ctxChange.currentValue || {});

      if (prevCtxKeys.length === currCtxKeys.length) {
        var _iterator2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_0__["default"])(currCtxKeys),
            _step2;

        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var propName = _step2.value;

            if (prevCtxKeys.indexOf(propName) === -1) {
              return true;
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }

        return false;
      }

      return true;
    }
  }, {
    key: "_updateExistingContext",
    value: function _updateExistingContext(ctx) {
      for (var _i2 = 0, _Object$keys = Object.keys(ctx); _i2 < _Object$keys.length; _i2++) {
        var propName = _Object$keys[_i2];
        this._viewRef.context[propName] = this.ngTemplateOutletContext[propName];
      }
    }
  }]);

  return NgTemplateOutlet;
}();

NgTemplateOutlet.ɵfac = function NgTemplateOutlet_Factory(t) {
  return new (t || NgTemplateOutlet)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]));
};

NgTemplateOutlet.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineDirective"]({
  type: NgTemplateOutlet,
  selectors: [["", "ngTemplateOutlet", ""]],
  inputs: {
    ngTemplateOutletContext: "ngTemplateOutletContext",
    ngTemplateOutlet: "ngTemplateOutlet"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵNgOnChangesFeature"]]
});

NgTemplateOutlet.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
  }];
};

NgTemplateOutlet.propDecorators = {
  ngTemplateOutletContext: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }],
  ngTemplateOutlet: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NgTemplateOutlet, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Directive"],
    args: [{
      selector: '[ngTemplateOutlet]'
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ViewContainerRef"]
    }];
  }, {
    ngTemplateOutletContext: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }],
    ngTemplateOutlet: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Input"]
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A collection of Angular directives that are likely to be used in each and every Angular
 * application.
 */


var COMMON_DIRECTIVES = [NgClass, NgComponentOutlet, NgForOf, NgIf, NgTemplateOutlet, NgStyle, NgSwitch, NgSwitchCase, NgSwitchDefault, NgPlural, NgPluralCase];
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

function invalidPipeArgumentError(type, value) {
  return Error("InvalidPipeArgument: '".concat(value, "' for pipe '").concat(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵstringify"])(type), "'"));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var ObservableStrategy = /*#__PURE__*/function () {
  function ObservableStrategy() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ObservableStrategy);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(ObservableStrategy, [{
    key: "createSubscription",
    value: function createSubscription(async, updateLatestValue) {
      return async.subscribe({
        next: updateLatestValue,
        error: function error(e) {
          throw e;
        }
      });
    }
  }, {
    key: "dispose",
    value: function dispose(subscription) {
      subscription.unsubscribe();
    }
  }, {
    key: "onDestroy",
    value: function onDestroy(subscription) {
      subscription.unsubscribe();
    }
  }]);

  return ObservableStrategy;
}();

var PromiseStrategy = /*#__PURE__*/function () {
  function PromiseStrategy() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, PromiseStrategy);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(PromiseStrategy, [{
    key: "createSubscription",
    value: function createSubscription(async, updateLatestValue) {
      return async.then(updateLatestValue, function (e) {
        throw e;
      });
    }
  }, {
    key: "dispose",
    value: function dispose(subscription) {}
  }, {
    key: "onDestroy",
    value: function onDestroy(subscription) {}
  }]);

  return PromiseStrategy;
}();

var _promiseStrategy = new PromiseStrategy();

var _observableStrategy = new ObservableStrategy();
/**
 * @ngModule CommonModule
 * @description
 *
 * Unwraps a value from an asynchronous primitive.
 *
 * The `async` pipe subscribes to an `Observable` or `Promise` and returns the latest value it has
 * emitted. When a new value is emitted, the `async` pipe marks the component to be checked for
 * changes. When the component gets destroyed, the `async` pipe unsubscribes automatically to avoid
 * potential memory leaks.
 *
 * @usageNotes
 *
 * ### Examples
 *
 * This example binds a `Promise` to the view. Clicking the `Resolve` button resolves the
 * promise.
 *
 * {@example common/pipes/ts/async_pipe.ts region='AsyncPipePromise'}
 *
 * It's also possible to use `async` with Observables. The example below binds the `time` Observable
 * to the view. The Observable continuously updates the view with the current time.
 *
 * {@example common/pipes/ts/async_pipe.ts region='AsyncPipeObservable'}
 *
 * @publicApi
 */


var AsyncPipe = /*#__PURE__*/function () {
  function AsyncPipe(_ref) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, AsyncPipe);

    this._ref = _ref;
    this._latestValue = null;
    this._subscription = null;
    this._obj = null;
    this._strategy = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(AsyncPipe, [{
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this._subscription) {
        this._dispose();
      }
    }
  }, {
    key: "transform",
    value: function transform(obj) {
      if (!this._obj) {
        if (obj) {
          this._subscribe(obj);
        }

        return this._latestValue;
      }

      if (obj !== this._obj) {
        this._dispose();

        return this.transform(obj);
      }

      return this._latestValue;
    }
  }, {
    key: "_subscribe",
    value: function _subscribe(obj) {
      var _this14 = this;

      this._obj = obj;
      this._strategy = this._selectStrategy(obj);
      this._subscription = this._strategy.createSubscription(obj, function (value) {
        return _this14._updateLatestValue(obj, value);
      });
    }
  }, {
    key: "_selectStrategy",
    value: function _selectStrategy(obj) {
      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵisPromise"])(obj)) {
        return _promiseStrategy;
      }

      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵisObservable"])(obj)) {
        return _observableStrategy;
      }

      throw invalidPipeArgumentError(AsyncPipe, obj);
    }
  }, {
    key: "_dispose",
    value: function _dispose() {
      this._strategy.dispose(this._subscription);

      this._latestValue = null;
      this._subscription = null;
      this._obj = null;
    }
  }, {
    key: "_updateLatestValue",
    value: function _updateLatestValue(async, value) {
      if (async === this._obj) {
        this._latestValue = value;

        this._ref.markForCheck();
      }
    }
  }]);

  return AsyncPipe;
}();

AsyncPipe.ɵfac = function AsyncPipe_Factory(t) {
  return new (t || AsyncPipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinjectPipeChangeDetectorRef"]());
};

AsyncPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "async",
  type: AsyncPipe,
  pure: false
});

AsyncPipe.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ChangeDetectorRef"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](AsyncPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'async',
      pure: false
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["ChangeDetectorRef"]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Transforms text to all lower case.
 *
 * @see `UpperCasePipe`
 * @see `TitleCasePipe`
 * @usageNotes
 *
 * The following example defines a view that allows the user to enter
 * text, and then uses the pipe to convert the input text to all lower case.
 *
 * <code-example path="common/pipes/ts/lowerupper_pipe.ts" region='LowerUpperPipe'></code-example>
 *
 * @ngModule CommonModule
 * @publicApi
 */


var LowerCasePipe = /*#__PURE__*/function () {
  function LowerCasePipe() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, LowerCasePipe);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(LowerCasePipe, [{
    key: "transform",

    /**
     * @param value The string to transform to lower case.
     */
    value: function transform(value) {
      if (!value) return value;

      if (typeof value !== 'string') {
        throw invalidPipeArgumentError(LowerCasePipe, value);
      }

      return value.toLowerCase();
    }
  }]);

  return LowerCasePipe;
}();

LowerCasePipe.ɵfac = function LowerCasePipe_Factory(t) {
  return new (t || LowerCasePipe)();
};

LowerCasePipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "lowercase",
  type: LowerCasePipe,
  pure: true
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](LowerCasePipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'lowercase'
    }]
  }], null, null);
})(); //
// Regex below matches any Unicode word and compatible with ES5. In ES2018 the same result
// can be achieved by using /\p{L}\S*/gu and also known as Unicode Property Escapes
// (http://2ality.com/2017/07/regexp-unicode-property-escapes.html). Since there is no
// transpilation of this functionality down to ES5 without external tool, the only solution is
// to use already transpiled form. Example can be found here -
// https://mothereff.in/regexpu#input=var+regex+%3D+/%5Cp%7BL%7D/u%3B&unicodePropertyEscape=1
//


var unicodeWordMatch = /(?:[A-Za-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16F1-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312E\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEA\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF2D-\uDF40\uDF42-\uDF49\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE83\uDE86-\uDE89\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46]|\uD808[\uDC00-\uDF99]|\uD809[\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D])\S*/g;
/**
 * Transforms text to title case.
 * Capitalizes the first letter of each word and transforms the
 * rest of the word to lower case.
 * Words are delimited by any whitespace character, such as a space, tab, or line-feed character.
 *
 * @see `LowerCasePipe`
 * @see `UpperCasePipe`
 *
 * @usageNotes
 * The following example shows the result of transforming various strings into title case.
 *
 * <code-example path="common/pipes/ts/titlecase_pipe.ts" region='TitleCasePipe'></code-example>
 *
 * @ngModule CommonModule
 * @publicApi
 */

var TitleCasePipe = /*#__PURE__*/function () {
  function TitleCasePipe() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, TitleCasePipe);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(TitleCasePipe, [{
    key: "transform",

    /**
     * @param value The string to transform to title case.
     */
    value: function transform(value) {
      if (!value) return value;

      if (typeof value !== 'string') {
        throw invalidPipeArgumentError(TitleCasePipe, value);
      }

      return value.replace(unicodeWordMatch, function (txt) {
        return txt[0].toUpperCase() + txt.substr(1).toLowerCase();
      });
    }
  }]);

  return TitleCasePipe;
}();

TitleCasePipe.ɵfac = function TitleCasePipe_Factory(t) {
  return new (t || TitleCasePipe)();
};

TitleCasePipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "titlecase",
  type: TitleCasePipe,
  pure: true
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](TitleCasePipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'titlecase'
    }]
  }], null, null);
})();
/**
 * Transforms text to all upper case.
 * @see `LowerCasePipe`
 * @see `TitleCasePipe`
 *
 * @ngModule CommonModule
 * @publicApi
 */


var UpperCasePipe = /*#__PURE__*/function () {
  function UpperCasePipe() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, UpperCasePipe);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(UpperCasePipe, [{
    key: "transform",

    /**
     * @param value The string to transform to upper case.
     */
    value: function transform(value) {
      if (!value) return value;

      if (typeof value !== 'string') {
        throw invalidPipeArgumentError(UpperCasePipe, value);
      }

      return value.toUpperCase();
    }
  }]);

  return UpperCasePipe;
}();

UpperCasePipe.ɵfac = function UpperCasePipe_Factory(t) {
  return new (t || UpperCasePipe)();
};

UpperCasePipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "uppercase",
  type: UpperCasePipe,
  pure: true
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](UpperCasePipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'uppercase'
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// clang-format off

/**
 * @ngModule CommonModule
 * @description
 *
 * Formats a date value according to locale rules.
 *
 * Only the `en-US` locale data comes with Angular. To localize dates
 * in another language, you must import the corresponding locale data.
 * See the [I18n guide](guide/i18n#i18n-pipes) for more information.
 *
 * @see `formatDate()`
 *
 *
 * @usageNotes
 *
 * The result of this pipe is not reevaluated when the input is mutated. To avoid the need to
 * reformat the date on every change-detection cycle, treat the date as an immutable object
 * and change the reference when the pipe needs to run again.
 *
 * ### Pre-defined format options
 *
 * Examples are given in `en-US` locale.
 *
 * - `'short'`: equivalent to `'M/d/yy, h:mm a'` (`6/15/15, 9:03 AM`).
 * - `'medium'`: equivalent to `'MMM d, y, h:mm:ss a'` (`Jun 15, 2015, 9:03:01 AM`).
 * - `'long'`: equivalent to `'MMMM d, y, h:mm:ss a z'` (`June 15, 2015 at 9:03:01 AM
 * GMT+1`).
 * - `'full'`: equivalent to `'EEEE, MMMM d, y, h:mm:ss a zzzz'` (`Monday, June 15, 2015 at
 * 9:03:01 AM GMT+01:00`).
 * - `'shortDate'`: equivalent to `'M/d/yy'` (`6/15/15`).
 * - `'mediumDate'`: equivalent to `'MMM d, y'` (`Jun 15, 2015`).
 * - `'longDate'`: equivalent to `'MMMM d, y'` (`June 15, 2015`).
 * - `'fullDate'`: equivalent to `'EEEE, MMMM d, y'` (`Monday, June 15, 2015`).
 * - `'shortTime'`: equivalent to `'h:mm a'` (`9:03 AM`).
 * - `'mediumTime'`: equivalent to `'h:mm:ss a'` (`9:03:01 AM`).
 * - `'longTime'`: equivalent to `'h:mm:ss a z'` (`9:03:01 AM GMT+1`).
 * - `'fullTime'`: equivalent to `'h:mm:ss a zzzz'` (`9:03:01 AM GMT+01:00`).
 *
 * ### Custom format options
 *
 * You can construct a format string using symbols to specify the components
 * of a date-time value, as described in the following table.
 * Format details depend on the locale.
 * Fields marked with (*) are only available in the extra data set for the given locale.
 *
 *  | Field type         | Format      | Description                                                   | Example Value                                              |
 *  |--------------------|-------------|---------------------------------------------------------------|------------------------------------------------------------|
 *  | Era                | G, GG & GGG | Abbreviated                                                   | AD                                                         |
 *  |                    | GGGG        | Wide                                                          | Anno Domini                                                |
 *  |                    | GGGGG       | Narrow                                                        | A                                                          |
 *  | Year               | y           | Numeric: minimum digits                                       | 2, 20, 201, 2017, 20173                                    |
 *  |                    | yy          | Numeric: 2 digits + zero padded                               | 02, 20, 01, 17, 73                                         |
 *  |                    | yyy         | Numeric: 3 digits + zero padded                               | 002, 020, 201, 2017, 20173                                 |
 *  |                    | yyyy        | Numeric: 4 digits or more + zero padded                       | 0002, 0020, 0201, 2017, 20173                              |
 *  | Month              | M           | Numeric: 1 digit                                              | 9, 12                                                      |
 *  |                    | MM          | Numeric: 2 digits + zero padded                               | 09, 12                                                     |
 *  |                    | MMM         | Abbreviated                                                   | Sep                                                        |
 *  |                    | MMMM        | Wide                                                          | September                                                  |
 *  |                    | MMMMM       | Narrow                                                        | S                                                          |
 *  | Month standalone   | L           | Numeric: 1 digit                                              | 9, 12                                                      |
 *  |                    | LL          | Numeric: 2 digits + zero padded                               | 09, 12                                                     |
 *  |                    | LLL         | Abbreviated                                                   | Sep                                                        |
 *  |                    | LLLL        | Wide                                                          | September                                                  |
 *  |                    | LLLLL       | Narrow                                                        | S                                                          |
 *  | Week of year       | w           | Numeric: minimum digits                                       | 1... 53                                                    |
 *  |                    | ww          | Numeric: 2 digits + zero padded                               | 01... 53                                                   |
 *  | Week of month      | W           | Numeric: 1 digit                                              | 1... 5                                                     |
 *  | Day of month       | d           | Numeric: minimum digits                                       | 1                                                          |
 *  |                    | dd          | Numeric: 2 digits + zero padded                               | 01                                                          |
 *  | Week day           | E, EE & EEE | Abbreviated                                                   | Tue                                                        |
 *  |                    | EEEE        | Wide                                                          | Tuesday                                                    |
 *  |                    | EEEEE       | Narrow                                                        | T                                                          |
 *  |                    | EEEEEE      | Short                                                         | Tu                                                         |
 *  | Period             | a, aa & aaa | Abbreviated                                                   | am/pm or AM/PM                                             |
 *  |                    | aaaa        | Wide (fallback to `a` when missing)                           | ante meridiem/post meridiem                                |
 *  |                    | aaaaa       | Narrow                                                        | a/p                                                        |
 *  | Period*            | B, BB & BBB | Abbreviated                                                   | mid.                                                       |
 *  |                    | BBBB        | Wide                                                          | am, pm, midnight, noon, morning, afternoon, evening, night |
 *  |                    | BBBBB       | Narrow                                                        | md                                                         |
 *  | Period standalone* | b, bb & bbb | Abbreviated                                                   | mid.                                                       |
 *  |                    | bbbb        | Wide                                                          | am, pm, midnight, noon, morning, afternoon, evening, night |
 *  |                    | bbbbb       | Narrow                                                        | md                                                         |
 *  | Hour 1-12          | h           | Numeric: minimum digits                                       | 1, 12                                                      |
 *  |                    | hh          | Numeric: 2 digits + zero padded                               | 01, 12                                                     |
 *  | Hour 0-23          | H           | Numeric: minimum digits                                       | 0, 23                                                      |
 *  |                    | HH          | Numeric: 2 digits + zero padded                               | 00, 23                                                     |
 *  | Minute             | m           | Numeric: minimum digits                                       | 8, 59                                                      |
 *  |                    | mm          | Numeric: 2 digits + zero padded                               | 08, 59                                                     |
 *  | Second             | s           | Numeric: minimum digits                                       | 0... 59                                                    |
 *  |                    | ss          | Numeric: 2 digits + zero padded                               | 00... 59                                                   |
 *  | Fractional seconds | S           | Numeric: 1 digit                                              | 0... 9                                                     |
 *  |                    | SS          | Numeric: 2 digits + zero padded                               | 00... 99                                                   |
 *  |                    | SSS         | Numeric: 3 digits + zero padded (= milliseconds)              | 000... 999                                                 |
 *  | Zone               | z, zz & zzz | Short specific non location format (fallback to O)            | GMT-8                                                      |
 *  |                    | zzzz        | Long specific non location format (fallback to OOOO)          | GMT-08:00                                                  |
 *  |                    | Z, ZZ & ZZZ | ISO8601 basic format                                          | -0800                                                      |
 *  |                    | ZZZZ        | Long localized GMT format                                     | GMT-8:00                                                   |
 *  |                    | ZZZZZ       | ISO8601 extended format + Z indicator for offset 0 (= XXXXX)  | -08:00                                                     |
 *  |                    | O, OO & OOO | Short localized GMT format                                    | GMT-8                                                      |
 *  |                    | OOOO        | Long localized GMT format                                     | GMT-08:00                                                  |
 *
 * Note that timezone correction is not applied to an ISO string that has no time component, such as "2016-09-19"
 *
 * ### Format examples
 *
 * These examples transform a date into various formats,
 * assuming that `dateObj` is a JavaScript `Date` object for
 * year: 2015, month: 6, day: 15, hour: 21, minute: 43, second: 11,
 * given in the local time for the `en-US` locale.
 *
 * ```
 * {{ dateObj | date }}               // output is 'Jun 15, 2015'
 * {{ dateObj | date:'medium' }}      // output is 'Jun 15, 2015, 9:43:11 PM'
 * {{ dateObj | date:'shortTime' }}   // output is '9:43 PM'
 * {{ dateObj | date:'mm:ss' }}       // output is '43:11'
 * ```
 *
 * ### Usage example
 *
 * The following component uses a date pipe to display the current date in different formats.
 *
 * ```
 * @Component({
 *  selector: 'date-pipe',
 *  template: `<div>
 *    <p>Today is {{today | date}}</p>
 *    <p>Or if you prefer, {{today | date:'fullDate'}}</p>
 *    <p>The time is {{today | date:'h:mm a z'}}</p>
 *  </div>`
 * })
 * // Get the current date and time as a date-time value.
 * export class DatePipeComponent {
 *   today: number = Date.now();
 * }
 * ```
 *
 * @publicApi
 */
// clang-format on


var DatePipe = /*#__PURE__*/function () {
  function DatePipe(locale) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, DatePipe);

    this.locale = locale;
  }
  /**
   * @param value The date expression: a `Date` object,  a number
   * (milliseconds since UTC epoch), or an ISO string (https://www.w3.org/TR/NOTE-datetime).
   * @param format The date/time components to include, using predefined options or a
   * custom format string.
   * @param timezone A timezone offset (such as `'+0430'`), or a standard
   * UTC/GMT or continental US timezone abbreviation.
   * When not supplied, uses the end-user's local system timezone.
   * @param locale A locale code for the locale format rules to use.
   * When not supplied, uses the value of `LOCALE_ID`, which is `en-US` by default.
   * See [Setting your app locale](guide/i18n#setting-up-the-locale-of-your-app).
   * @returns A date string in the desired format.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(DatePipe, [{
    key: "transform",
    value: function transform(value) {
      var format = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'mediumDate';
      var timezone = arguments.length > 2 ? arguments[2] : undefined;
      var locale = arguments.length > 3 ? arguments[3] : undefined;
      if (value == null || value === '' || value !== value) return null;

      try {
        return formatDate(value, format, locale || this.locale, timezone);
      } catch (error) {
        throw invalidPipeArgumentError(DatePipe, error.message);
      }
    }
  }]);

  return DatePipe;
}();

DatePipe.ɵfac = function DatePipe_Factory(t) {
  return new (t || DatePipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]));
};

DatePipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "date",
  type: DatePipe,
  pure: true
});

DatePipe.ctorParameters = function () {
  return [{
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](DatePipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'date',
      pure: true
    }]
  }], function () {
    return [{
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var _INTERPOLATION_REGEXP = /#/g;
/**
 * @ngModule CommonModule
 * @description
 *
 * Maps a value to a string that pluralizes the value according to locale rules.
 *
 * @usageNotes
 *
 * ### Example
 *
 * {@example common/pipes/ts/i18n_pipe.ts region='I18nPluralPipeComponent'}
 *
 * @publicApi
 */

var I18nPluralPipe = /*#__PURE__*/function () {
  function I18nPluralPipe(_localization) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, I18nPluralPipe);

    this._localization = _localization;
  }
  /**
   * @param value the number to be formatted
   * @param pluralMap an object that mimics the ICU format, see
   * http://userguide.icu-project.org/formatparse/messages.
   * @param locale a `string` defining the locale to use (uses the current {@link LOCALE_ID} by
   * default).
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(I18nPluralPipe, [{
    key: "transform",
    value: function transform(value, pluralMap, locale) {
      if (value == null) return '';

      if (typeof pluralMap !== 'object' || pluralMap === null) {
        throw invalidPipeArgumentError(I18nPluralPipe, pluralMap);
      }

      var key = getPluralCategory(value, Object.keys(pluralMap), this._localization, locale);
      return pluralMap[key].replace(_INTERPOLATION_REGEXP, value.toString());
    }
  }]);

  return I18nPluralPipe;
}();

I18nPluralPipe.ɵfac = function I18nPluralPipe_Factory(t) {
  return new (t || I18nPluralPipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](NgLocalization));
};

I18nPluralPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "i18nPlural",
  type: I18nPluralPipe,
  pure: true
});

I18nPluralPipe.ctorParameters = function () {
  return [{
    type: NgLocalization
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](I18nPluralPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'i18nPlural',
      pure: true
    }]
  }], function () {
    return [{
      type: NgLocalization
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 * @description
 *
 * Generic selector that displays the string that matches the current value.
 *
 * If none of the keys of the `mapping` match the `value`, then the content
 * of the `other` key is returned when present, otherwise an empty string is returned.
 *
 * @usageNotes
 *
 * ### Example
 *
 * {@example common/pipes/ts/i18n_pipe.ts region='I18nSelectPipeComponent'}
 *
 * @publicApi
 */


var I18nSelectPipe = /*#__PURE__*/function () {
  function I18nSelectPipe() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, I18nSelectPipe);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(I18nSelectPipe, [{
    key: "transform",

    /**
     * @param value a string to be internationalized.
     * @param mapping an object that indicates the text that should be displayed
     * for different values of the provided `value`.
     */
    value: function transform(value, mapping) {
      if (value == null) return '';

      if (typeof mapping !== 'object' || typeof value !== 'string') {
        throw invalidPipeArgumentError(I18nSelectPipe, mapping);
      }

      if (mapping.hasOwnProperty(value)) {
        return mapping[value];
      }

      if (mapping.hasOwnProperty('other')) {
        return mapping['other'];
      }

      return '';
    }
  }]);

  return I18nSelectPipe;
}();

I18nSelectPipe.ɵfac = function I18nSelectPipe_Factory(t) {
  return new (t || I18nSelectPipe)();
};

I18nSelectPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "i18nSelect",
  type: I18nSelectPipe,
  pure: true
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](I18nSelectPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'i18nSelect',
      pure: true
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 * @description
 *
 * Converts a value into its JSON-format representation.  Useful for debugging.
 *
 * @usageNotes
 *
 * The following component uses a JSON pipe to convert an object
 * to JSON format, and displays the string in both formats for comparison.
 *
 * {@example common/pipes/ts/json_pipe.ts region='JsonPipe'}
 *
 * @publicApi
 */


var JsonPipe = /*#__PURE__*/function () {
  function JsonPipe() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, JsonPipe);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(JsonPipe, [{
    key: "transform",

    /**
     * @param value A value of any type to convert into a JSON-format string.
     */
    value: function transform(value) {
      return JSON.stringify(value, null, 2);
    }
  }]);

  return JsonPipe;
}();

JsonPipe.ɵfac = function JsonPipe_Factory(t) {
  return new (t || JsonPipe)();
};

JsonPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "json",
  type: JsonPipe,
  pure: false
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](JsonPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'json',
      pure: false
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function makeKeyValuePair(key, value) {
  return {
    key: key,
    value: value
  };
}
/**
 * @ngModule CommonModule
 * @description
 *
 * Transforms Object or Map into an array of key value pairs.
 *
 * The output array will be ordered by keys.
 * By default the comparator will be by Unicode point value.
 * You can optionally pass a compareFn if your keys are complex types.
 *
 * @usageNotes
 * ### Examples
 *
 * This examples show how an Object or a Map can be iterated by ngFor with the use of this
 * keyvalue pipe.
 *
 * {@example common/pipes/ts/keyvalue_pipe.ts region='KeyValuePipe'}
 *
 * @publicApi
 */


var KeyValuePipe = /*#__PURE__*/function () {
  function KeyValuePipe(differs) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, KeyValuePipe);

    this.differs = differs;
    this.keyValues = [];
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(KeyValuePipe, [{
    key: "transform",
    value: function transform(input) {
      var _this15 = this;

      var compareFn = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultComparator;

      if (!input || !(input instanceof Map) && typeof input !== 'object') {
        return null;
      }

      if (!this.differ) {
        // make a differ for whatever type we've been passed in
        this.differ = this.differs.find(input).create();
      }

      var differChanges = this.differ.diff(input);

      if (differChanges) {
        this.keyValues = [];
        differChanges.forEachItem(function (r) {
          _this15.keyValues.push(makeKeyValuePair(r.key, r.currentValue));
        });
        this.keyValues.sort(compareFn);
      }

      return this.keyValues;
    }
  }]);

  return KeyValuePipe;
}();

KeyValuePipe.ɵfac = function KeyValuePipe_Factory(t) {
  return new (t || KeyValuePipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]));
};

KeyValuePipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "keyvalue",
  type: KeyValuePipe,
  pure: false
});

KeyValuePipe.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](KeyValuePipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'keyvalue',
      pure: false
    }]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["KeyValueDiffers"]
    }];
  }, null);
})();

function defaultComparator(keyValueA, keyValueB) {
  var a = keyValueA.key;
  var b = keyValueB.key; // if same exit with 0;

  if (a === b) return 0; // make sure that undefined are at the end of the sort.

  if (a === undefined) return 1;
  if (b === undefined) return -1; // make sure that nulls are at the end of the sort.

  if (a === null) return 1;
  if (b === null) return -1;

  if (typeof a == 'string' && typeof b == 'string') {
    return a < b ? -1 : 1;
  }

  if (typeof a == 'number' && typeof b == 'number') {
    return a - b;
  }

  if (typeof a == 'boolean' && typeof b == 'boolean') {
    return a < b ? -1 : 1;
  } // `a` and `b` are of different types. Compare their string values.


  var aString = String(a);
  var bString = String(b);
  return aString == bString ? 0 : aString < bString ? -1 : 1;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 * @description
 *
 * Transforms a number into a string,
 * formatted according to locale rules that determine group sizing and
 * separator, decimal-point character, and other locale-specific
 * configurations.
 *
 * If no parameters are specified, the function rounds off to the nearest value using this
 * [rounding method](https://en.wikibooks.org/wiki/Arithmetic/Rounding).
 * The behavior differs from that of the JavaScript ```Math.round()``` function.
 * In the following case for example, the pipe rounds down where
 * ```Math.round()``` rounds up:
 *
 * ```html
 * -2.5 | number:'1.0-0'
 * > -3
 * Math.round(-2.5)
 * > -2
 * ```
 *
 * @see `formatNumber()`
 *
 * @usageNotes
 * The following code shows how the pipe transforms numbers
 * into text strings, according to various format specifications,
 * where the caller's default locale is `en-US`.
 *
 * ### Example
 *
 * <code-example path="common/pipes/ts/number_pipe.ts" region='NumberPipe'></code-example>
 *
 * @publicApi
 */


var DecimalPipe = /*#__PURE__*/function () {
  function DecimalPipe(_locale) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, DecimalPipe);

    this._locale = _locale;
  }
  /**
   * @param value The number to be formatted.
   * @param digitsInfo Decimal representation options, specified by a string
   * in the following format:<br>
   * <code>{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}</code>.
   *   - `minIntegerDigits`: The minimum number of integer digits before the decimal point.
   * Default is `1`.
   *   - `minFractionDigits`: The minimum number of digits after the decimal point.
   * Default is `0`.
   *   - `maxFractionDigits`: The maximum number of digits after the decimal point.
   * Default is `3`.
   * @param locale A locale code for the locale format rules to use.
   * When not supplied, uses the value of `LOCALE_ID`, which is `en-US` by default.
   * See [Setting your app locale](guide/i18n#setting-up-the-locale-of-your-app).
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(DecimalPipe, [{
    key: "transform",
    value: function transform(value, digitsInfo, locale) {
      if (isEmpty(value)) return null;
      locale = locale || this._locale;

      try {
        var num = strToNumber(value);
        return formatNumber(num, locale, digitsInfo);
      } catch (error) {
        throw invalidPipeArgumentError(DecimalPipe, error.message);
      }
    }
  }]);

  return DecimalPipe;
}();

DecimalPipe.ɵfac = function DecimalPipe_Factory(t) {
  return new (t || DecimalPipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]));
};

DecimalPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "number",
  type: DecimalPipe,
  pure: true
});

DecimalPipe.ctorParameters = function () {
  return [{
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](DecimalPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'number'
    }]
  }], function () {
    return [{
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
      }]
    }];
  }, null);
})();
/**
 * @ngModule CommonModule
 * @description
 *
 * Transforms a number to a percentage
 * string, formatted according to locale rules that determine group sizing and
 * separator, decimal-point character, and other locale-specific
 * configurations.
 *
 * @see `formatPercent()`
 *
 * @usageNotes
 * The following code shows how the pipe transforms numbers
 * into text strings, according to various format specifications,
 * where the caller's default locale is `en-US`.
 *
 * <code-example path="common/pipes/ts/percent_pipe.ts" region='PercentPipe'></code-example>
 *
 * @publicApi
 */


var PercentPipe = /*#__PURE__*/function () {
  function PercentPipe(_locale) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, PercentPipe);

    this._locale = _locale;
  }
  /**
   *
   * @param value The number to be formatted as a percentage.
   * @param digitsInfo Decimal representation options, specified by a string
   * in the following format:<br>
   * <code>{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}</code>.
   *   - `minIntegerDigits`: The minimum number of integer digits before the decimal point.
   * Default is `1`.
   *   - `minFractionDigits`: The minimum number of digits after the decimal point.
   * Default is `0`.
   *   - `maxFractionDigits`: The maximum number of digits after the decimal point.
   * Default is `0`.
   * @param locale A locale code for the locale format rules to use.
   * When not supplied, uses the value of `LOCALE_ID`, which is `en-US` by default.
   * See [Setting your app locale](guide/i18n#setting-up-the-locale-of-your-app).
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(PercentPipe, [{
    key: "transform",
    value: function transform(value, digitsInfo, locale) {
      if (isEmpty(value)) return null;
      locale = locale || this._locale;

      try {
        var num = strToNumber(value);
        return formatPercent(num, locale, digitsInfo);
      } catch (error) {
        throw invalidPipeArgumentError(PercentPipe, error.message);
      }
    }
  }]);

  return PercentPipe;
}();

PercentPipe.ɵfac = function PercentPipe_Factory(t) {
  return new (t || PercentPipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]));
};

PercentPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "percent",
  type: PercentPipe,
  pure: true
});

PercentPipe.ctorParameters = function () {
  return [{
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](PercentPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'percent'
    }]
  }], function () {
    return [{
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
      }]
    }];
  }, null);
})();
/**
 * @ngModule CommonModule
 * @description
 *
 * Transforms a number to a currency string, formatted according to locale rules
 * that determine group sizing and separator, decimal-point character,
 * and other locale-specific configurations.
 *
 * {@a currency-code-deprecation}
 * <div class="alert is-helpful">
 *
 * **Deprecation notice:**
 *
 * The default currency code is currently always `USD` but this is deprecated from v9.
 *
 * **In v11 the default currency code will be taken from the current locale identified by
 * the `LOCAL_ID` token. See the [i18n guide](guide/i18n#setting-up-the-locale-of-your-app) for
 * more information.**
 *
 * If you need the previous behavior then set it by creating a `DEFAULT_CURRENCY_CODE` provider in
 * your application `NgModule`:
 *
 * ```ts
 * {provide: DEFAULT_CURRENCY_CODE, useValue: 'USD'}
 * ```
 *
 * </div>
 *
 * @see `getCurrencySymbol()`
 * @see `formatCurrency()`
 *
 * @usageNotes
 * The following code shows how the pipe transforms numbers
 * into text strings, according to various format specifications,
 * where the caller's default locale is `en-US`.
 *
 * <code-example path="common/pipes/ts/currency_pipe.ts" region='CurrencyPipe'></code-example>
 *
 * @publicApi
 */


var CurrencyPipe = /*#__PURE__*/function () {
  function CurrencyPipe(_locale) {
    var _defaultCurrencyCode = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'USD';

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, CurrencyPipe);

    this._locale = _locale;
    this._defaultCurrencyCode = _defaultCurrencyCode;
  }
  /**
   *
   * @param value The number to be formatted as currency.
   * @param currencyCode The [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code,
   * such as `USD` for the US dollar and `EUR` for the euro. The default currency code can be
   * configured using the `DEFAULT_CURRENCY_CODE` injection token.
   * @param display The format for the currency indicator. One of the following:
   *   - `code`: Show the code (such as `USD`).
   *   - `symbol`(default): Show the symbol (such as `$`).
   *   - `symbol-narrow`: Use the narrow symbol for locales that have two symbols for their
   * currency.
   * For example, the Canadian dollar CAD has the symbol `CA$` and the symbol-narrow `$`. If the
   * locale has no narrow symbol, uses the standard symbol for the locale.
   *   - String: Use the given string value instead of a code or a symbol.
   * For example, an empty string will suppress the currency & symbol.
   *   - Boolean (marked deprecated in v5): `true` for symbol and false for `code`.
   *
   * @param digitsInfo Decimal representation options, specified by a string
   * in the following format:<br>
   * <code>{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}</code>.
   *   - `minIntegerDigits`: The minimum number of integer digits before the decimal point.
   * Default is `1`.
   *   - `minFractionDigits`: The minimum number of digits after the decimal point.
   * Default is `2`.
   *   - `maxFractionDigits`: The maximum number of digits after the decimal point.
   * Default is `2`.
   * If not provided, the number will be formatted with the proper amount of digits,
   * depending on what the [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) specifies.
   * For example, the Canadian dollar has 2 digits, whereas the Chilean peso has none.
   * @param locale A locale code for the locale format rules to use.
   * When not supplied, uses the value of `LOCALE_ID`, which is `en-US` by default.
   * See [Setting your app locale](guide/i18n#setting-up-the-locale-of-your-app).
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(CurrencyPipe, [{
    key: "transform",
    value: function transform(value, currencyCode) {
      var display = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'symbol';
      var digitsInfo = arguments.length > 3 ? arguments[3] : undefined;
      var locale = arguments.length > 4 ? arguments[4] : undefined;
      if (isEmpty(value)) return null;
      locale = locale || this._locale;

      if (typeof display === 'boolean') {
        if (console && console.warn) {
          console.warn("Warning: the currency pipe has been changed in Angular v5. The symbolDisplay option (third parameter) is now a string instead of a boolean. The accepted values are \"code\", \"symbol\" or \"symbol-narrow\".");
        }

        display = display ? 'symbol' : 'code';
      }

      var currency = currencyCode || this._defaultCurrencyCode;

      if (display !== 'code') {
        if (display === 'symbol' || display === 'symbol-narrow') {
          currency = getCurrencySymbol(currency, display === 'symbol' ? 'wide' : 'narrow', locale);
        } else {
          currency = display;
        }
      }

      try {
        var num = strToNumber(value);
        return formatCurrency(num, locale, currency, currencyCode, digitsInfo);
      } catch (error) {
        throw invalidPipeArgumentError(CurrencyPipe, error.message);
      }
    }
  }]);

  return CurrencyPipe;
}();

CurrencyPipe.ɵfac = function CurrencyPipe_Factory(t) {
  return new (t || CurrencyPipe)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["DEFAULT_CURRENCY_CODE"]));
};

CurrencyPipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "currency",
  type: CurrencyPipe,
  pure: true
});

CurrencyPipe.ctorParameters = function () {
  return [{
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
    }]
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["DEFAULT_CURRENCY_CODE"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](CurrencyPipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'currency'
    }]
  }], function () {
    return [{
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["LOCALE_ID"]]
      }]
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["DEFAULT_CURRENCY_CODE"]]
      }]
    }];
  }, null);
})();

function isEmpty(value) {
  return value == null || value === '' || value !== value;
}
/**
 * Transforms a string into a number (if needed).
 */


function strToNumber(value) {
  // Convert strings to numbers
  if (typeof value === 'string' && !isNaN(Number(value) - parseFloat(value))) {
    return Number(value);
  }

  if (typeof value !== 'number') {
    throw new Error("".concat(value, " is not a number"));
  }

  return value;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @ngModule CommonModule
 * @description
 *
 * Creates a new `Array` or `String` containing a subset (slice) of the elements.
 *
 * @usageNotes
 *
 * All behavior is based on the expected behavior of the JavaScript API `Array.prototype.slice()`
 * and `String.prototype.slice()`.
 *
 * When operating on an `Array`, the returned `Array` is always a copy even when all
 * the elements are being returned.
 *
 * When operating on a blank value, the pipe returns the blank value.
 *
 * ### List Example
 *
 * This `ngFor` example:
 *
 * {@example common/pipes/ts/slice_pipe.ts region='SlicePipe_list'}
 *
 * produces the following:
 *
 * ```html
 * <li>b</li>
 * <li>c</li>
 * ```
 *
 * ### String Examples
 *
 * {@example common/pipes/ts/slice_pipe.ts region='SlicePipe_string'}
 *
 * @publicApi
 */


var SlicePipe = /*#__PURE__*/function () {
  function SlicePipe() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, SlicePipe);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(SlicePipe, [{
    key: "transform",
    value: function transform(value, start, end) {
      if (value == null) return value;

      if (!this.supports(value)) {
        throw invalidPipeArgumentError(SlicePipe, value);
      }

      return value.slice(start, end);
    }
  }, {
    key: "supports",
    value: function supports(obj) {
      return typeof obj === 'string' || Array.isArray(obj);
    }
  }]);

  return SlicePipe;
}();

SlicePipe.ɵfac = function SlicePipe_Factory(t) {
  return new (t || SlicePipe)();
};

SlicePipe.ɵpipe = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefinePipe"]({
  name: "slice",
  type: SlicePipe,
  pure: false
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](SlicePipe, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Pipe"],
    args: [{
      name: 'slice',
      pure: false
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * A collection of Angular pipes that are likely to be used in each and every application.
 */


var COMMON_PIPES = [AsyncPipe, UpperCasePipe, LowerCasePipe, JsonPipe, SlicePipe, DecimalPipe, PercentPipe, TitleCasePipe, CurrencyPipe, DatePipe, I18nPluralPipe, I18nSelectPipe, KeyValuePipe];
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Note: This does not contain the location providers,
// as they need some platform specific implementations to work.

/**
 * Exports all the basic Angular directives and pipes,
 * such as `NgIf`, `NgForOf`, `DecimalPipe`, and so on.
 * Re-exported by `BrowserModule`, which is included automatically in the root
 * `AppModule` when you create a new app with the CLI `new` command.
 *
 * * The `providers` options configure the NgModule's injector to provide
 * localization dependencies to members.
 * * The `exports` options make the declared directives and pipes available for import
 * by other NgModules.
 *
 * @publicApi
 */

var CommonModule = function CommonModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, CommonModule);
};

CommonModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineNgModule"]({
  type: CommonModule
});
CommonModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjector"]({
  factory: function CommonModule_Factory(t) {
    return new (t || CommonModule)();
  },
  providers: [{
    provide: NgLocalization,
    useClass: NgLocaleLocalization
  }]
});

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵsetNgModuleScope"](CommonModule, {
    declarations: [NgClass, NgComponentOutlet, NgForOf, NgIf, NgTemplateOutlet, NgStyle, NgSwitch, NgSwitchCase, NgSwitchDefault, NgPlural, NgPluralCase, AsyncPipe, UpperCasePipe, LowerCasePipe, JsonPipe, SlicePipe, DecimalPipe, PercentPipe, TitleCasePipe, CurrencyPipe, DatePipe, I18nPluralPipe, I18nSelectPipe, KeyValuePipe],
    exports: [NgClass, NgComponentOutlet, NgForOf, NgIf, NgTemplateOutlet, NgStyle, NgSwitch, NgSwitchCase, NgSwitchDefault, NgPlural, NgPluralCase, AsyncPipe, UpperCasePipe, LowerCasePipe, JsonPipe, SlicePipe, DecimalPipe, PercentPipe, TitleCasePipe, CurrencyPipe, DatePipe, I18nPluralPipe, I18nSelectPipe, KeyValuePipe]
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](CommonModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModule"],
    args: [{
      declarations: [COMMON_DIRECTIVES, COMMON_PIPES],
      exports: [COMMON_DIRECTIVES, COMMON_PIPES],
      providers: [{
        provide: NgLocalization,
        useClass: NgLocaleLocalization
      }]
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var PLATFORM_BROWSER_ID = 'browser';
var PLATFORM_SERVER_ID = 'server';
var PLATFORM_WORKER_APP_ID = 'browserWorkerApp';
var PLATFORM_WORKER_UI_ID = 'browserWorkerUi';
/**
 * Returns whether a platform id represents a browser platform.
 * @publicApi
 */

function isPlatformBrowser(platformId) {
  return platformId === PLATFORM_BROWSER_ID;
}
/**
 * Returns whether a platform id represents a server platform.
 * @publicApi
 */


function isPlatformServer(platformId) {
  return platformId === PLATFORM_SERVER_ID;
}
/**
 * Returns whether a platform id represents a web worker app platform.
 * @publicApi
 */


function isPlatformWorkerApp(platformId) {
  return platformId === PLATFORM_WORKER_APP_ID;
}
/**
 * Returns whether a platform id represents a web worker UI platform.
 * @publicApi
 */


function isPlatformWorkerUi(platformId) {
  return platformId === PLATFORM_WORKER_UI_ID;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var VERSION = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["Version"]('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Defines a scroll position manager. Implemented by `BrowserViewportScroller`.
 *
 * @publicApi
 */

var ViewportScroller = function ViewportScroller() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, ViewportScroller);
}; // De-sugared tree-shakable injection
// See #23917

/** @nocollapse */


ViewportScroller.ɵprov = Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"])({
  token: ViewportScroller,
  providedIn: 'root',
  factory: function factory() {
    return new BrowserViewportScroller(Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(DOCUMENT), window, Object(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"])(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ErrorHandler"]));
  }
});
/**
 * Manages the scroll position for a browser window.
 */

var BrowserViewportScroller = /*#__PURE__*/function () {
  function BrowserViewportScroller(document, window, errorHandler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BrowserViewportScroller);

    this.document = document;
    this.window = window;
    this.errorHandler = errorHandler;

    this.offset = function () {
      return [0, 0];
    };
  }
  /**
   * Configures the top offset used when scrolling to an anchor.
   * @param offset A position in screen coordinates (a tuple with x and y values)
   * or a function that returns the top offset position.
   *
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(BrowserViewportScroller, [{
    key: "setOffset",
    value: function setOffset(offset) {
      if (Array.isArray(offset)) {
        this.offset = function () {
          return offset;
        };
      } else {
        this.offset = offset;
      }
    }
    /**
     * Retrieves the current scroll position.
     * @returns The position in screen coordinates.
     */

  }, {
    key: "getScrollPosition",
    value: function getScrollPosition() {
      if (this.supportsScrolling()) {
        return [this.window.scrollX, this.window.scrollY];
      } else {
        return [0, 0];
      }
    }
    /**
     * Sets the scroll position.
     * @param position The new position in screen coordinates.
     */

  }, {
    key: "scrollToPosition",
    value: function scrollToPosition(position) {
      if (this.supportsScrolling()) {
        this.window.scrollTo(position[0], position[1]);
      }
    }
    /**
     * Scrolls to an anchor element.
     * @param anchor The ID of the anchor element.
     */

  }, {
    key: "scrollToAnchor",
    value: function scrollToAnchor(anchor) {
      if (this.supportsScrolling()) {
        var elSelected = this.document.getElementById(anchor) || this.document.getElementsByName(anchor)[0];

        if (elSelected) {
          this.scrollToElement(elSelected);
        }
      }
    }
    /**
     * Disables automatic scroll restoration provided by the browser.
     */

  }, {
    key: "setHistoryScrollRestoration",
    value: function setHistoryScrollRestoration(scrollRestoration) {
      if (this.supportScrollRestoration()) {
        var history = this.window.history;

        if (history && history.scrollRestoration) {
          history.scrollRestoration = scrollRestoration;
        }
      }
    }
  }, {
    key: "scrollToElement",
    value: function scrollToElement(el) {
      var rect = el.getBoundingClientRect();
      var left = rect.left + this.window.pageXOffset;
      var top = rect.top + this.window.pageYOffset;
      var offset = this.offset();
      this.window.scrollTo(left - offset[0], top - offset[1]);
    }
    /**
     * We only support scroll restoration when we can get a hold of window.
     * This means that we do not support this behavior when running in a web worker.
     *
     * Lifting this restriction right now would require more changes in the dom adapter.
     * Since webworkers aren't widely used, we will lift it once RouterScroller is
     * battle-tested.
     */

  }, {
    key: "supportScrollRestoration",
    value: function supportScrollRestoration() {
      try {
        if (!this.window || !this.window.scrollTo) {
          return false;
        } // The `scrollRestoration` property could be on the `history` instance or its prototype.


        var scrollRestorationDescriptor = getScrollRestorationProperty(this.window.history) || getScrollRestorationProperty(Object.getPrototypeOf(this.window.history)); // We can write to the `scrollRestoration` property if it is a writable data field or it has a
        // setter function.

        return !!scrollRestorationDescriptor && !!(scrollRestorationDescriptor.writable || scrollRestorationDescriptor.set);
      } catch (_a) {
        return false;
      }
    }
  }, {
    key: "supportsScrolling",
    value: function supportsScrolling() {
      try {
        return !!this.window.scrollTo;
      } catch (_a) {
        return false;
      }
    }
  }]);

  return BrowserViewportScroller;
}();

function getScrollRestorationProperty(obj) {
  return Object.getOwnPropertyDescriptor(obj, 'scrollRestoration');
}
/**
 * Provides an empty implementation of the viewport scroller. This will
 * live in @angular/common as it will be used by both platform-server and platform-webworker.
 */


var NullViewportScroller = /*#__PURE__*/function () {
  function NullViewportScroller() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NullViewportScroller);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_2__["default"])(NullViewportScroller, [{
    key: "setOffset",

    /**
     * Empty implementation
     */
    value: function setOffset(offset) {}
    /**
     * Empty implementation
     */

  }, {
    key: "getScrollPosition",
    value: function getScrollPosition() {
      return [0, 0];
    }
    /**
     * Empty implementation
     */

  }, {
    key: "scrollToPosition",
    value: function scrollToPosition(position) {}
    /**
     * Empty implementation
     */

  }, {
    key: "scrollToAnchor",
    value: function scrollToAnchor(anchor) {}
    /**
     * Empty implementation
     */

  }, {
    key: "setHistoryScrollRestoration",
    value: function setHistoryScrollRestoration(scrollRestoration) {}
  }]);

  return NullViewportScroller;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */




/***/ }),

/***/ "p/rL":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/bm.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Bambara [bm]
//! author : Estelle Comment : https://github.com/estellecomment
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var bm = moment.defineLocale('bm', {
    months: 'Zanwuyekalo_Fewuruyekalo_Marisikalo_Awirilikalo_Mɛkalo_Zuwɛnkalo_Zuluyekalo_Utikalo_Sɛtanburukalo_ɔkutɔburukalo_Nowanburukalo_Desanburukalo'.split('_'),
    monthsShort: 'Zan_Few_Mar_Awi_Mɛ_Zuw_Zul_Uti_Sɛt_ɔku_Now_Des'.split('_'),
    weekdays: 'Kari_Ntɛnɛn_Tarata_Araba_Alamisa_Juma_Sibiri'.split('_'),
    weekdaysShort: 'Kar_Ntɛ_Tar_Ara_Ala_Jum_Sib'.split('_'),
    weekdaysMin: 'Ka_Nt_Ta_Ar_Al_Ju_Si'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'MMMM [tile] D [san] YYYY',
      LLL: 'MMMM [tile] D [san] YYYY [lɛrɛ] HH:mm',
      LLLL: 'dddd MMMM [tile] D [san] YYYY [lɛrɛ] HH:mm'
    },
    calendar: {
      sameDay: '[Bi lɛrɛ] LT',
      nextDay: '[Sini lɛrɛ] LT',
      nextWeek: 'dddd [don lɛrɛ] LT',
      lastDay: '[Kunu lɛrɛ] LT',
      lastWeek: 'dddd [tɛmɛnen lɛrɛ] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s kɔnɔ',
      past: 'a bɛ %s bɔ',
      s: 'sanga dama dama',
      ss: 'sekondi %d',
      m: 'miniti kelen',
      mm: 'miniti %d',
      h: 'lɛrɛ kelen',
      hh: 'lɛrɛ %d',
      d: 'tile kelen',
      dd: 'tile %d',
      M: 'kalo kelen',
      MM: 'kalo %d',
      y: 'san kelen',
      yy: 'san %d'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return bm;
});

/***/ }),

/***/ "p9/F":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/buffer.js ***!
  \*****************************************************************/
/*! exports provided: buffer */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "buffer", function() { return buffer; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");






function buffer(closingNotifier) {
  return function bufferOperatorFunction(source) {
    return source.lift(new BufferOperator(closingNotifier));
  };
}

var BufferOperator = /*#__PURE__*/function () {
  function BufferOperator(closingNotifier) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, BufferOperator);

    this.closingNotifier = closingNotifier;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(BufferOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new BufferSubscriber(subscriber, this.closingNotifier));
    }
  }]);

  return BufferOperator;
}();

var BufferSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(BufferSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(BufferSubscriber);

  function BufferSubscriber(destination, closingNotifier) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, BufferSubscriber);

    _this = _super.call(this, destination);
    _this.buffer = [];

    _this.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["innerSubscribe"])(closingNotifier, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["SimpleInnerSubscriber"](Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this))));

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(BufferSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.buffer.push(value);
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      var buffer = this.buffer;
      this.buffer = [];
      this.destination.next(buffer);
    }
  }]);

  return BufferSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_5__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "pLZG":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/filter.js ***!
  \*****************************************************************/
/*! exports provided: filter */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "filter", function() { return filter; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function filter(predicate, thisArg) {
  return function filterOperatorFunction(source) {
    return source.lift(new FilterOperator(predicate, thisArg));
  };
}

var FilterOperator = /*#__PURE__*/function () {
  function FilterOperator(predicate, thisArg) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, FilterOperator);

    this.predicate = predicate;
    this.thisArg = thisArg;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(FilterOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new FilterSubscriber(subscriber, this.predicate, this.thisArg));
    }
  }]);

  return FilterOperator;
}();

var FilterSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(FilterSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(FilterSubscriber);

  function FilterSubscriber(destination, predicate, thisArg) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, FilterSubscriber);

    _this = _super.call(this, destination);
    _this.predicate = predicate;
    _this.thisArg = thisArg;
    _this.count = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(FilterSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var result;

      try {
        result = this.predicate.call(this.thisArg, value, this.count++);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      if (result) {
        this.destination.next(value);
      }
    }
  }]);

  return FilterSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "pLzU":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/subscribeToIterable.js ***!
  \*************************************************************************/
/*! exports provided: subscribeToIterable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeToIterable", function() { return subscribeToIterable; });
/* harmony import */ var _symbol_iterator__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../symbol/iterator */ "Lhse");

var subscribeToIterable = function subscribeToIterable(iterable) {
  return function (subscriber) {
    var iterator = iterable[_symbol_iterator__WEBPACK_IMPORTED_MODULE_0__["iterator"]]();

    do {
      var item = void 0;

      try {
        item = iterator.next();
      } catch (err) {
        subscriber.error(err);
        return subscriber;
      }

      if (item.done) {
        subscriber.complete();
        break;
      }

      subscriber.next(item.value);

      if (subscriber.closed) {
        break;
      }
    } while (true);

    if (typeof iterator.return === 'function') {
      subscriber.add(function () {
        if (iterator.return) {
          iterator.return();
        }
      });
    }

    return subscriber;
  };
};

/***/ }),

/***/ "pXlZ":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/windowWhen.js ***!
  \*********************************************************************/
/*! exports provided: windowWhen */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "windowWhen", function() { return windowWhen; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");







function windowWhen(closingSelector) {
  return function windowWhenOperatorFunction(source) {
    return source.lift(new WindowOperator(closingSelector));
  };
}

var WindowOperator = /*#__PURE__*/function () {
  function WindowOperator(closingSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, WindowOperator);

    this.closingSelector = closingSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new WindowSubscriber(subscriber, this.closingSelector));
    }
  }]);

  return WindowOperator;
}();

var WindowSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(WindowSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(WindowSubscriber);

  function WindowSubscriber(destination, closingSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, WindowSubscriber);

    _this = _super.call(this, destination);
    _this.destination = destination;
    _this.closingSelector = closingSelector;

    _this.openWindow();

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowSubscriber, [{
    key: "notifyNext",
    value: function notifyNext(_outerValue, _innerValue, _outerIndex, _innerIndex, innerSub) {
      this.openWindow(innerSub);
    }
  }, {
    key: "notifyError",
    value: function notifyError(error) {
      this._error(error);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(innerSub) {
      this.openWindow(innerSub);
    }
  }, {
    key: "_next",
    value: function _next(value) {
      this.window.next(value);
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.window.error(err);
      this.destination.error(err);
      this.unsubscribeClosingNotification();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.window.complete();
      this.destination.complete();
      this.unsubscribeClosingNotification();
    }
  }, {
    key: "unsubscribeClosingNotification",
    value: function unsubscribeClosingNotification() {
      if (this.closingNotification) {
        this.closingNotification.unsubscribe();
      }
    }
  }, {
    key: "openWindow",
    value: function openWindow() {
      var innerSub = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

      if (innerSub) {
        this.remove(innerSub);
        innerSub.unsubscribe();
      }

      var prevWindow = this.window;

      if (prevWindow) {
        prevWindow.complete();
      }

      var window = this.window = new _Subject__WEBPACK_IMPORTED_MODULE_4__["Subject"]();
      this.destination.next(window);
      var closingNotifier;

      try {
        var closingSelector = this.closingSelector;
        closingNotifier = closingSelector();
      } catch (e) {
        this.destination.error(e);
        this.window.error(e);
        return;
      }

      this.add(this.closingNotification = Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_6__["subscribeToResult"])(this, closingNotifier));
    }
  }]);

  return WindowSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_5__["OuterSubscriber"]);

/***/ }),

/***/ "pjAE":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/UnsubscriptionError.js ***!
  \*************************************************************************/
/*! exports provided: UnsubscriptionError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UnsubscriptionError", function() { return UnsubscriptionError; });
var UnsubscriptionErrorImpl = function () {
  function UnsubscriptionErrorImpl(errors) {
    Error.call(this);
    this.message = errors ? "".concat(errors.length, " errors occurred during unsubscription:\n").concat(errors.map(function (err, i) {
      return "".concat(i + 1, ") ").concat(err.toString());
    }).join('\n  ')) : '';
    this.name = 'UnsubscriptionError';
    this.errors = errors;
    return this;
  }

  UnsubscriptionErrorImpl.prototype = Object.create(Error.prototype);
  return UnsubscriptionErrorImpl;
}();

var UnsubscriptionError = UnsubscriptionErrorImpl;

/***/ }),

/***/ "pxpQ":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/observeOn.js ***!
  \********************************************************************/
/*! exports provided: observeOn, ObserveOnOperator, ObserveOnSubscriber, ObserveOnMessage */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "observeOn", function() { return observeOn; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ObserveOnOperator", function() { return ObserveOnOperator; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ObserveOnSubscriber", function() { return ObserveOnSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ObserveOnMessage", function() { return ObserveOnMessage; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _Notification__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Notification */ "WMd4");






function observeOn(scheduler) {
  var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return function observeOnOperatorFunction(source) {
    return source.lift(new ObserveOnOperator(scheduler, delay));
  };
}
var ObserveOnOperator = /*#__PURE__*/function () {
  function ObserveOnOperator(scheduler) {
    var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ObserveOnOperator);

    this.scheduler = scheduler;
    this.delay = delay;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ObserveOnOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ObserveOnSubscriber(subscriber, this.scheduler, this.delay));
    }
  }]);

  return ObserveOnOperator;
}();
var ObserveOnSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ObserveOnSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ObserveOnSubscriber);

  function ObserveOnSubscriber(destination, scheduler) {
    var _this;

    var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ObserveOnSubscriber);

    _this = _super.call(this, destination);
    _this.scheduler = scheduler;
    _this.delay = delay;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ObserveOnSubscriber, [{
    key: "scheduleMessage",
    value: function scheduleMessage(notification) {
      var destination = this.destination;
      destination.add(this.scheduler.schedule(ObserveOnSubscriber.dispatch, this.delay, new ObserveOnMessage(notification, this.destination)));
    }
  }, {
    key: "_next",
    value: function _next(value) {
      this.scheduleMessage(_Notification__WEBPACK_IMPORTED_MODULE_5__["Notification"].createNext(value));
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.scheduleMessage(_Notification__WEBPACK_IMPORTED_MODULE_5__["Notification"].createError(err));
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.scheduleMessage(_Notification__WEBPACK_IMPORTED_MODULE_5__["Notification"].createComplete());
      this.unsubscribe();
    }
  }], [{
    key: "dispatch",
    value: function dispatch(arg) {
      var notification = arg.notification,
          destination = arg.destination;
      notification.observe(destination);
      this.unsubscribe();
    }
  }]);

  return ObserveOnSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);
var ObserveOnMessage = function ObserveOnMessage(notification, destination) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ObserveOnMessage);

  this.notification = notification;
  this.destination = destination;
};

/***/ }),

/***/ "q7zd":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/concatMapTo.js ***!
  \**********************************************************************/
/*! exports provided: concatMapTo */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "concatMapTo", function() { return concatMapTo; });
/* harmony import */ var _concatMap__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./concatMap */ "bOdf");

function concatMapTo(innerObservable, resultSelector) {
  return Object(_concatMap__WEBPACK_IMPORTED_MODULE_0__["concatMap"])(function () {
    return innerObservable;
  }, resultSelector);
}

/***/ }),

/***/ "q92s":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/merge.js ***!
  \****************************************************************/
/*! exports provided: merge */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "merge", function() { return merge; });
/* harmony import */ var _observable_merge__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../observable/merge */ "VRyK");

function merge() {
  for (var _len = arguments.length, observables = new Array(_len), _key = 0; _key < _len; _key++) {
    observables[_key] = arguments[_key];
  }

  return function (source) {
    return source.lift.call(_observable_merge__WEBPACK_IMPORTED_MODULE_0__["merge"].apply(void 0, [source].concat(observables)));
  };
}

/***/ }),

/***/ "qCKp":
/*!*********************************************!*\
  !*** ./node_modules/rxjs/_esm2015/index.js ***!
  \*********************************************/
/*! exports provided: Observable, ConnectableObservable, GroupedObservable, observable, Subject, BehaviorSubject, ReplaySubject, AsyncSubject, asap, asapScheduler, async, asyncScheduler, queue, queueScheduler, animationFrame, animationFrameScheduler, VirtualTimeScheduler, VirtualAction, Scheduler, Subscription, Subscriber, Notification, NotificationKind, pipe, noop, identity, isObservable, ArgumentOutOfRangeError, EmptyError, ObjectUnsubscribedError, UnsubscriptionError, TimeoutError, bindCallback, bindNodeCallback, combineLatest, concat, defer, empty, forkJoin, from, fromEvent, fromEventPattern, generate, iif, interval, merge, never, of, onErrorResumeNext, pairs, partition, race, range, throwError, timer, using, zip, scheduled, EMPTY, NEVER, config */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/Observable */ "HDdC");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Observable", function() { return _internal_Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"]; });

/* harmony import */ var _internal_observable_ConnectableObservable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/observable/ConnectableObservable */ "EQ5u");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ConnectableObservable", function() { return _internal_observable_ConnectableObservable__WEBPACK_IMPORTED_MODULE_1__["ConnectableObservable"]; });

/* harmony import */ var _internal_operators_groupBy__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/operators/groupBy */ "OQgR");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "GroupedObservable", function() { return _internal_operators_groupBy__WEBPACK_IMPORTED_MODULE_2__["GroupedObservable"]; });

/* harmony import */ var _internal_symbol_observable__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/symbol/observable */ "kJWO");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "observable", function() { return _internal_symbol_observable__WEBPACK_IMPORTED_MODULE_3__["observable"]; });

/* harmony import */ var _internal_Subject__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./internal/Subject */ "XNiG");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Subject", function() { return _internal_Subject__WEBPACK_IMPORTED_MODULE_4__["Subject"]; });

/* harmony import */ var _internal_BehaviorSubject__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./internal/BehaviorSubject */ "2Vo4");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "BehaviorSubject", function() { return _internal_BehaviorSubject__WEBPACK_IMPORTED_MODULE_5__["BehaviorSubject"]; });

/* harmony import */ var _internal_ReplaySubject__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./internal/ReplaySubject */ "jtHE");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ReplaySubject", function() { return _internal_ReplaySubject__WEBPACK_IMPORTED_MODULE_6__["ReplaySubject"]; });

/* harmony import */ var _internal_AsyncSubject__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./internal/AsyncSubject */ "NHP+");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "AsyncSubject", function() { return _internal_AsyncSubject__WEBPACK_IMPORTED_MODULE_7__["AsyncSubject"]; });

/* harmony import */ var _internal_scheduler_asap__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./internal/scheduler/asap */ "7Hc7");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "asap", function() { return _internal_scheduler_asap__WEBPACK_IMPORTED_MODULE_8__["asap"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "asapScheduler", function() { return _internal_scheduler_asap__WEBPACK_IMPORTED_MODULE_8__["asapScheduler"]; });

/* harmony import */ var _internal_scheduler_async__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./internal/scheduler/async */ "D0XW");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "async", function() { return _internal_scheduler_async__WEBPACK_IMPORTED_MODULE_9__["async"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "asyncScheduler", function() { return _internal_scheduler_async__WEBPACK_IMPORTED_MODULE_9__["asyncScheduler"]; });

/* harmony import */ var _internal_scheduler_queue__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./internal/scheduler/queue */ "qgXg");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "queue", function() { return _internal_scheduler_queue__WEBPACK_IMPORTED_MODULE_10__["queue"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "queueScheduler", function() { return _internal_scheduler_queue__WEBPACK_IMPORTED_MODULE_10__["queueScheduler"]; });

/* harmony import */ var _internal_scheduler_animationFrame__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./internal/scheduler/animationFrame */ "eNwd");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "animationFrame", function() { return _internal_scheduler_animationFrame__WEBPACK_IMPORTED_MODULE_11__["animationFrame"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "animationFrameScheduler", function() { return _internal_scheduler_animationFrame__WEBPACK_IMPORTED_MODULE_11__["animationFrameScheduler"]; });

/* harmony import */ var _internal_scheduler_VirtualTimeScheduler__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./internal/scheduler/VirtualTimeScheduler */ "iKkX");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "VirtualTimeScheduler", function() { return _internal_scheduler_VirtualTimeScheduler__WEBPACK_IMPORTED_MODULE_12__["VirtualTimeScheduler"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "VirtualAction", function() { return _internal_scheduler_VirtualTimeScheduler__WEBPACK_IMPORTED_MODULE_12__["VirtualAction"]; });

/* harmony import */ var _internal_Scheduler__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./internal/Scheduler */ "Y/cZ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Scheduler", function() { return _internal_Scheduler__WEBPACK_IMPORTED_MODULE_13__["Scheduler"]; });

/* harmony import */ var _internal_Subscription__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./internal/Subscription */ "quSY");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Subscription", function() { return _internal_Subscription__WEBPACK_IMPORTED_MODULE_14__["Subscription"]; });

/* harmony import */ var _internal_Subscriber__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./internal/Subscriber */ "7o/Q");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Subscriber", function() { return _internal_Subscriber__WEBPACK_IMPORTED_MODULE_15__["Subscriber"]; });

/* harmony import */ var _internal_Notification__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./internal/Notification */ "WMd4");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Notification", function() { return _internal_Notification__WEBPACK_IMPORTED_MODULE_16__["Notification"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "NotificationKind", function() { return _internal_Notification__WEBPACK_IMPORTED_MODULE_16__["NotificationKind"]; });

/* harmony import */ var _internal_util_pipe__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./internal/util/pipe */ "mCNh");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pipe", function() { return _internal_util_pipe__WEBPACK_IMPORTED_MODULE_17__["pipe"]; });

/* harmony import */ var _internal_util_noop__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./internal/util/noop */ "KqfI");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "noop", function() { return _internal_util_noop__WEBPACK_IMPORTED_MODULE_18__["noop"]; });

/* harmony import */ var _internal_util_identity__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./internal/util/identity */ "SpAZ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "identity", function() { return _internal_util_identity__WEBPACK_IMPORTED_MODULE_19__["identity"]; });

/* harmony import */ var _internal_util_isObservable__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./internal/util/isObservable */ "7+OI");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "isObservable", function() { return _internal_util_isObservable__WEBPACK_IMPORTED_MODULE_20__["isObservable"]; });

/* harmony import */ var _internal_util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./internal/util/ArgumentOutOfRangeError */ "4I5i");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ArgumentOutOfRangeError", function() { return _internal_util_ArgumentOutOfRangeError__WEBPACK_IMPORTED_MODULE_21__["ArgumentOutOfRangeError"]; });

/* harmony import */ var _internal_util_EmptyError__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./internal/util/EmptyError */ "sVev");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "EmptyError", function() { return _internal_util_EmptyError__WEBPACK_IMPORTED_MODULE_22__["EmptyError"]; });

/* harmony import */ var _internal_util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./internal/util/ObjectUnsubscribedError */ "9ppp");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ObjectUnsubscribedError", function() { return _internal_util_ObjectUnsubscribedError__WEBPACK_IMPORTED_MODULE_23__["ObjectUnsubscribedError"]; });

/* harmony import */ var _internal_util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./internal/util/UnsubscriptionError */ "pjAE");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "UnsubscriptionError", function() { return _internal_util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_24__["UnsubscriptionError"]; });

/* harmony import */ var _internal_util_TimeoutError__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./internal/util/TimeoutError */ "Y6u4");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "TimeoutError", function() { return _internal_util_TimeoutError__WEBPACK_IMPORTED_MODULE_25__["TimeoutError"]; });

/* harmony import */ var _internal_observable_bindCallback__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./internal/observable/bindCallback */ "QqCr");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bindCallback", function() { return _internal_observable_bindCallback__WEBPACK_IMPORTED_MODULE_26__["bindCallback"]; });

/* harmony import */ var _internal_observable_bindNodeCallback__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./internal/observable/bindNodeCallback */ "4O5X");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bindNodeCallback", function() { return _internal_observable_bindNodeCallback__WEBPACK_IMPORTED_MODULE_27__["bindNodeCallback"]; });

/* harmony import */ var _internal_observable_combineLatest__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./internal/observable/combineLatest */ "itXk");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "combineLatest", function() { return _internal_observable_combineLatest__WEBPACK_IMPORTED_MODULE_28__["combineLatest"]; });

/* harmony import */ var _internal_observable_concat__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./internal/observable/concat */ "GyhO");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "concat", function() { return _internal_observable_concat__WEBPACK_IMPORTED_MODULE_29__["concat"]; });

/* harmony import */ var _internal_observable_defer__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ./internal/observable/defer */ "NXyV");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "defer", function() { return _internal_observable_defer__WEBPACK_IMPORTED_MODULE_30__["defer"]; });

/* harmony import */ var _internal_observable_empty__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ./internal/observable/empty */ "EY2u");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "empty", function() { return _internal_observable_empty__WEBPACK_IMPORTED_MODULE_31__["empty"]; });

/* harmony import */ var _internal_observable_forkJoin__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ./internal/observable/forkJoin */ "cp0P");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "forkJoin", function() { return _internal_observable_forkJoin__WEBPACK_IMPORTED_MODULE_32__["forkJoin"]; });

/* harmony import */ var _internal_observable_from__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ./internal/observable/from */ "Cfvw");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "from", function() { return _internal_observable_from__WEBPACK_IMPORTED_MODULE_33__["from"]; });

/* harmony import */ var _internal_observable_fromEvent__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! ./internal/observable/fromEvent */ "xgIS");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "fromEvent", function() { return _internal_observable_fromEvent__WEBPACK_IMPORTED_MODULE_34__["fromEvent"]; });

/* harmony import */ var _internal_observable_fromEventPattern__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! ./internal/observable/fromEventPattern */ "04ZW");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "fromEventPattern", function() { return _internal_observable_fromEventPattern__WEBPACK_IMPORTED_MODULE_35__["fromEventPattern"]; });

/* harmony import */ var _internal_observable_generate__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! ./internal/observable/generate */ "WPMC");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "generate", function() { return _internal_observable_generate__WEBPACK_IMPORTED_MODULE_36__["generate"]; });

/* harmony import */ var _internal_observable_iif__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! ./internal/observable/iif */ "r0o6");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "iif", function() { return _internal_observable_iif__WEBPACK_IMPORTED_MODULE_37__["iif"]; });

/* harmony import */ var _internal_observable_interval__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(/*! ./internal/observable/interval */ "l5mm");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "interval", function() { return _internal_observable_interval__WEBPACK_IMPORTED_MODULE_38__["interval"]; });

/* harmony import */ var _internal_observable_merge__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(/*! ./internal/observable/merge */ "VRyK");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "merge", function() { return _internal_observable_merge__WEBPACK_IMPORTED_MODULE_39__["merge"]; });

/* harmony import */ var _internal_observable_never__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(/*! ./internal/observable/never */ "5yfJ");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "never", function() { return _internal_observable_never__WEBPACK_IMPORTED_MODULE_40__["never"]; });

/* harmony import */ var _internal_observable_of__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(/*! ./internal/observable/of */ "LRne");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "of", function() { return _internal_observable_of__WEBPACK_IMPORTED_MODULE_41__["of"]; });

/* harmony import */ var _internal_observable_onErrorResumeNext__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(/*! ./internal/observable/onErrorResumeNext */ "Hkhx");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "onErrorResumeNext", function() { return _internal_observable_onErrorResumeNext__WEBPACK_IMPORTED_MODULE_42__["onErrorResumeNext"]; });

/* harmony import */ var _internal_observable_pairs__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(/*! ./internal/observable/pairs */ "hKy8");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pairs", function() { return _internal_observable_pairs__WEBPACK_IMPORTED_MODULE_43__["pairs"]; });

/* harmony import */ var _internal_observable_partition__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(/*! ./internal/observable/partition */ "2QGa");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "partition", function() { return _internal_observable_partition__WEBPACK_IMPORTED_MODULE_44__["partition"]; });

/* harmony import */ var _internal_observable_race__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(/*! ./internal/observable/race */ "Nv8m");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "race", function() { return _internal_observable_race__WEBPACK_IMPORTED_MODULE_45__["race"]; });

/* harmony import */ var _internal_observable_range__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(/*! ./internal/observable/range */ "NNCq");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "range", function() { return _internal_observable_range__WEBPACK_IMPORTED_MODULE_46__["range"]; });

/* harmony import */ var _internal_observable_throwError__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(/*! ./internal/observable/throwError */ "z6cu");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "throwError", function() { return _internal_observable_throwError__WEBPACK_IMPORTED_MODULE_47__["throwError"]; });

/* harmony import */ var _internal_observable_timer__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(/*! ./internal/observable/timer */ "PqYM");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "timer", function() { return _internal_observable_timer__WEBPACK_IMPORTED_MODULE_48__["timer"]; });

/* harmony import */ var _internal_observable_using__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(/*! ./internal/observable/using */ "Qn8I");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "using", function() { return _internal_observable_using__WEBPACK_IMPORTED_MODULE_49__["using"]; });

/* harmony import */ var _internal_observable_zip__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(/*! ./internal/observable/zip */ "1uah");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "zip", function() { return _internal_observable_zip__WEBPACK_IMPORTED_MODULE_50__["zip"]; });

/* harmony import */ var _internal_scheduled_scheduled__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(/*! ./internal/scheduled/scheduled */ "7HRe");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "scheduled", function() { return _internal_scheduled_scheduled__WEBPACK_IMPORTED_MODULE_51__["scheduled"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "EMPTY", function() { return _internal_observable_empty__WEBPACK_IMPORTED_MODULE_31__["EMPTY"]; });

/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "NEVER", function() { return _internal_observable_never__WEBPACK_IMPORTED_MODULE_40__["NEVER"]; });

/* harmony import */ var _internal_config__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(/*! ./internal/config */ "2fFW");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "config", function() { return _internal_config__WEBPACK_IMPORTED_MODULE_52__["config"]; });

























































/***/ }),

/***/ "qZ0a":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/publishLast.js ***!
  \**********************************************************************/
/*! exports provided: publishLast */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "publishLast", function() { return publishLast; });
/* harmony import */ var _AsyncSubject__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../AsyncSubject */ "NHP+");
/* harmony import */ var _multicast__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./multicast */ "oB13");


function publishLast() {
  return function (source) {
    return Object(_multicast__WEBPACK_IMPORTED_MODULE_1__["multicast"])(new _AsyncSubject__WEBPACK_IMPORTED_MODULE_0__["AsyncSubject"]())(source);
  };
}

/***/ }),

/***/ "qgXg":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/queue.js ***!
  \****************************************************************/
/*! exports provided: queueScheduler, queue */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "queueScheduler", function() { return queueScheduler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "queue", function() { return queue; });
/* harmony import */ var _QueueAction__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./QueueAction */ "YuR2");
/* harmony import */ var _QueueScheduler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./QueueScheduler */ "Hh5Z");


var queueScheduler = new _QueueScheduler__WEBPACK_IMPORTED_MODULE_1__["QueueScheduler"](_QueueAction__WEBPACK_IMPORTED_MODULE_0__["QueueAction"]);
var queue = queueScheduler;

/***/ }),

/***/ "quSY":
/*!*************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/Subscription.js ***!
  \*************************************************************/
/*! exports provided: Subscription */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Subscription", function() { return Subscription; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util/isArray */ "DH7j");
/* harmony import */ var _util_isObject__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./util/isObject */ "XoHu");
/* harmony import */ var _util_isFunction__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./util/isFunction */ "n6bG");
/* harmony import */ var _util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./util/UnsubscriptionError */ "pjAE");






var Subscription = /*#__PURE__*/function () {
  function Subscription(unsubscribe) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Subscription);

    this.closed = false;
    this._parentOrParents = null;
    this._subscriptions = null;

    if (unsubscribe) {
      this._ctorUnsubscribe = true;
      this._unsubscribe = unsubscribe;
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(Subscription, [{
    key: "unsubscribe",
    value: function unsubscribe() {
      var errors;

      if (this.closed) {
        return;
      }

      var _parentOrParents = this._parentOrParents,
          _ctorUnsubscribe = this._ctorUnsubscribe,
          _unsubscribe = this._unsubscribe,
          _subscriptions = this._subscriptions;
      this.closed = true;
      this._parentOrParents = null;
      this._subscriptions = null;

      if (_parentOrParents instanceof Subscription) {
        _parentOrParents.remove(this);
      } else if (_parentOrParents !== null) {
        for (var index = 0; index < _parentOrParents.length; ++index) {
          var parent = _parentOrParents[index];
          parent.remove(this);
        }
      }

      if (Object(_util_isFunction__WEBPACK_IMPORTED_MODULE_4__["isFunction"])(_unsubscribe)) {
        if (_ctorUnsubscribe) {
          this._unsubscribe = undefined;
        }

        try {
          _unsubscribe.call(this);
        } catch (e) {
          errors = e instanceof _util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_5__["UnsubscriptionError"] ? flattenUnsubscriptionErrors(e.errors) : [e];
        }
      }

      if (Object(_util_isArray__WEBPACK_IMPORTED_MODULE_2__["isArray"])(_subscriptions)) {
        var _index = -1;

        var len = _subscriptions.length;

        while (++_index < len) {
          var sub = _subscriptions[_index];

          if (Object(_util_isObject__WEBPACK_IMPORTED_MODULE_3__["isObject"])(sub)) {
            try {
              sub.unsubscribe();
            } catch (e) {
              errors = errors || [];

              if (e instanceof _util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_5__["UnsubscriptionError"]) {
                errors = errors.concat(flattenUnsubscriptionErrors(e.errors));
              } else {
                errors.push(e);
              }
            }
          }
        }
      }

      if (errors) {
        throw new _util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_5__["UnsubscriptionError"](errors);
      }
    }
  }, {
    key: "add",
    value: function add(teardown) {
      var subscription = teardown;

      if (!teardown) {
        return Subscription.EMPTY;
      }

      switch (typeof teardown) {
        case 'function':
          subscription = new Subscription(teardown);

        case 'object':
          if (subscription === this || subscription.closed || typeof subscription.unsubscribe !== 'function') {
            return subscription;
          } else if (this.closed) {
            subscription.unsubscribe();
            return subscription;
          } else if (!(subscription instanceof Subscription)) {
            var tmp = subscription;
            subscription = new Subscription();
            subscription._subscriptions = [tmp];
          }

          break;

        default:
          {
            throw new Error('unrecognized teardown ' + teardown + ' added to Subscription.');
          }
      }

      var _subscription = subscription,
          _parentOrParents = _subscription._parentOrParents;

      if (_parentOrParents === null) {
        subscription._parentOrParents = this;
      } else if (_parentOrParents instanceof Subscription) {
        if (_parentOrParents === this) {
          return subscription;
        }

        subscription._parentOrParents = [_parentOrParents, this];
      } else if (_parentOrParents.indexOf(this) === -1) {
        _parentOrParents.push(this);
      } else {
        return subscription;
      }

      var subscriptions = this._subscriptions;

      if (subscriptions === null) {
        this._subscriptions = [subscription];
      } else {
        subscriptions.push(subscription);
      }

      return subscription;
    }
  }, {
    key: "remove",
    value: function remove(subscription) {
      var subscriptions = this._subscriptions;

      if (subscriptions) {
        var subscriptionIndex = subscriptions.indexOf(subscription);

        if (subscriptionIndex !== -1) {
          subscriptions.splice(subscriptionIndex, 1);
        }
      }
    }
  }]);

  return Subscription;
}();

Subscription.EMPTY = function (empty) {
  empty.closed = true;
  return empty;
}(new Subscription());

function flattenUnsubscriptionErrors(errors) {
  return errors.reduce(function (errs, err) {
    return errs.concat(err instanceof _util_UnsubscriptionError__WEBPACK_IMPORTED_MODULE_5__["UnsubscriptionError"] ? err.errors : err);
  }, []);
}

/***/ }),

/***/ "qvJo":
/*!************************************************!*\
  !*** ./node_modules/moment/locale/gom-deva.js ***!
  \************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Konkani Devanagari script [gom-deva]
//! author : The Discoverer : https://github.com/WikiDiscoverer
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      s: ['थोडया सॅकंडांनी', 'थोडे सॅकंड'],
      ss: [number + ' सॅकंडांनी', number + ' सॅकंड'],
      m: ['एका मिणटान', 'एक मिनूट'],
      mm: [number + ' मिणटांनी', number + ' मिणटां'],
      h: ['एका वरान', 'एक वर'],
      hh: [number + ' वरांनी', number + ' वरां'],
      d: ['एका दिसान', 'एक दीस'],
      dd: [number + ' दिसांनी', number + ' दीस'],
      M: ['एका म्हयन्यान', 'एक म्हयनो'],
      MM: [number + ' म्हयन्यानी', number + ' म्हयने'],
      y: ['एका वर्सान', 'एक वर्स'],
      yy: [number + ' वर्सांनी', number + ' वर्सां']
    };
    return isFuture ? format[key][0] : format[key][1];
  }

  var gomDeva = moment.defineLocale('gom-deva', {
    months: {
      standalone: 'जानेवारी_फेब्रुवारी_मार्च_एप्रील_मे_जून_जुलय_ऑगस्ट_सप्टेंबर_ऑक्टोबर_नोव्हेंबर_डिसेंबर'.split('_'),
      format: 'जानेवारीच्या_फेब्रुवारीच्या_मार्चाच्या_एप्रीलाच्या_मेयाच्या_जूनाच्या_जुलयाच्या_ऑगस्टाच्या_सप्टेंबराच्या_ऑक्टोबराच्या_नोव्हेंबराच्या_डिसेंबराच्या'.split('_'),
      isFormat: /MMMM(\s)+D[oD]?/
    },
    monthsShort: 'जाने._फेब्रु._मार्च_एप्री._मे_जून_जुल._ऑग._सप्टें._ऑक्टो._नोव्हें._डिसें.'.split('_'),
    monthsParseExact: true,
    weekdays: 'आयतार_सोमार_मंगळार_बुधवार_बिरेस्तार_सुक्रार_शेनवार'.split('_'),
    weekdaysShort: 'आयत._सोम._मंगळ._बुध._ब्रेस्त._सुक्र._शेन.'.split('_'),
    weekdaysMin: 'आ_सो_मं_बु_ब्रे_सु_शे'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'A h:mm [वाजतां]',
      LTS: 'A h:mm:ss [वाजतां]',
      L: 'DD-MM-YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY A h:mm [वाजतां]',
      LLLL: 'dddd, MMMM Do, YYYY, A h:mm [वाजतां]',
      llll: 'ddd, D MMM YYYY, A h:mm [वाजतां]'
    },
    calendar: {
      sameDay: '[आयज] LT',
      nextDay: '[फाल्यां] LT',
      nextWeek: '[फुडलो] dddd[,] LT',
      lastDay: '[काल] LT',
      lastWeek: '[फाटलो] dddd[,] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: '%s',
      past: '%s आदीं',
      s: processRelativeTime,
      ss: processRelativeTime,
      m: processRelativeTime,
      mm: processRelativeTime,
      h: processRelativeTime,
      hh: processRelativeTime,
      d: processRelativeTime,
      dd: processRelativeTime,
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}(वेर)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        // the ordinal 'वेर' only applies to day of the month
        case 'D':
          return number + 'वेर';

        default:
        case 'M':
        case 'Q':
        case 'DDD':
        case 'd':
        case 'w':
        case 'W':
          return number;
      }
    },
    week: {
      dow: 0,
      // Sunday is the first day of the week
      doy: 3 // The week that contains Jan 4th is the first week of the year (7 + 0 - 4)

    },
    meridiemParse: /राती|सकाळीं|दनपारां|सांजे/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'राती') {
        return hour < 4 ? hour : hour + 12;
      } else if (meridiem === 'सकाळीं') {
        return hour;
      } else if (meridiem === 'दनपारां') {
        return hour > 12 ? hour : hour + 12;
      } else if (meridiem === 'सांजे') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'राती';
      } else if (hour < 12) {
        return 'सकाळीं';
      } else if (hour < 16) {
        return 'दनपारां';
      } else if (hour < 20) {
        return 'सांजे';
      } else {
        return 'राती';
      }
    }
  });
  return gomDeva;
});

/***/ }),

/***/ "r0WS":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/timestamp.js ***!
  \********************************************************************/
/*! exports provided: timestamp, Timestamp */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "timestamp", function() { return timestamp; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Timestamp", function() { return Timestamp; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./map */ "lJxs");



function timestamp() {
  var scheduler = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _scheduler_async__WEBPACK_IMPORTED_MODULE_1__["async"];
  return Object(_map__WEBPACK_IMPORTED_MODULE_2__["map"])(function (value) {
    return new Timestamp(value, scheduler.now());
  });
}
var Timestamp = function Timestamp(value, timestamp) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, Timestamp);

  this.value = value;
  this.timestamp = timestamp;
};

/***/ }),

/***/ "r0o6":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/iif.js ***!
  \***************************************************************/
/*! exports provided: iif */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "iif", function() { return iif; });
/* harmony import */ var _defer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./defer */ "NXyV");
/* harmony import */ var _empty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./empty */ "EY2u");


function iif(condition) {
  var trueResult = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _empty__WEBPACK_IMPORTED_MODULE_1__["EMPTY"];
  var falseResult = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _empty__WEBPACK_IMPORTED_MODULE_1__["EMPTY"];
  return Object(_defer__WEBPACK_IMPORTED_MODULE_0__["defer"])(function () {
    return condition() ? trueResult : falseResult;
  });
}

/***/ }),

/***/ "raLr":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/uk.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Ukrainian [uk]
//! author : zemlanin : https://github.com/zemlanin
//! Author : Menelion Elensúle : https://github.com/Oire
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function plural(word, num) {
    var forms = word.split('_');
    return num % 10 === 1 && num % 100 !== 11 ? forms[0] : num % 10 >= 2 && num % 10 <= 4 && (num % 100 < 10 || num % 100 >= 20) ? forms[1] : forms[2];
  }

  function relativeTimeWithPlural(number, withoutSuffix, key) {
    var format = {
      ss: withoutSuffix ? 'секунда_секунди_секунд' : 'секунду_секунди_секунд',
      mm: withoutSuffix ? 'хвилина_хвилини_хвилин' : 'хвилину_хвилини_хвилин',
      hh: withoutSuffix ? 'година_години_годин' : 'годину_години_годин',
      dd: 'день_дні_днів',
      MM: 'місяць_місяці_місяців',
      yy: 'рік_роки_років'
    };

    if (key === 'm') {
      return withoutSuffix ? 'хвилина' : 'хвилину';
    } else if (key === 'h') {
      return withoutSuffix ? 'година' : 'годину';
    } else {
      return number + ' ' + plural(format[key], +number);
    }
  }

  function weekdaysCaseReplace(m, format) {
    var weekdays = {
      nominative: 'неділя_понеділок_вівторок_середа_четвер_п’ятниця_субота'.split('_'),
      accusative: 'неділю_понеділок_вівторок_середу_четвер_п’ятницю_суботу'.split('_'),
      genitive: 'неділі_понеділка_вівторка_середи_четверга_п’ятниці_суботи'.split('_')
    },
        nounCase;

    if (m === true) {
      return weekdays['nominative'].slice(1, 7).concat(weekdays['nominative'].slice(0, 1));
    }

    if (!m) {
      return weekdays['nominative'];
    }

    nounCase = /(\[[ВвУу]\]) ?dddd/.test(format) ? 'accusative' : /\[?(?:минулої|наступної)? ?\] ?dddd/.test(format) ? 'genitive' : 'nominative';
    return weekdays[nounCase][m.day()];
  }

  function processHoursFunction(str) {
    return function () {
      return str + 'о' + (this.hours() === 11 ? 'б' : '') + '] LT';
    };
  }

  var uk = moment.defineLocale('uk', {
    months: {
      format: 'січня_лютого_березня_квітня_травня_червня_липня_серпня_вересня_жовтня_листопада_грудня'.split('_'),
      standalone: 'січень_лютий_березень_квітень_травень_червень_липень_серпень_вересень_жовтень_листопад_грудень'.split('_')
    },
    monthsShort: 'січ_лют_бер_квіт_трав_черв_лип_серп_вер_жовт_лист_груд'.split('_'),
    weekdays: weekdaysCaseReplace,
    weekdaysShort: 'нд_пн_вт_ср_чт_пт_сб'.split('_'),
    weekdaysMin: 'нд_пн_вт_ср_чт_пт_сб'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY р.',
      LLL: 'D MMMM YYYY р., HH:mm',
      LLLL: 'dddd, D MMMM YYYY р., HH:mm'
    },
    calendar: {
      sameDay: processHoursFunction('[Сьогодні '),
      nextDay: processHoursFunction('[Завтра '),
      lastDay: processHoursFunction('[Вчора '),
      nextWeek: processHoursFunction('[У] dddd ['),
      lastWeek: function lastWeek() {
        switch (this.day()) {
          case 0:
          case 3:
          case 5:
          case 6:
            return processHoursFunction('[Минулої] dddd [').call(this);

          case 1:
          case 2:
          case 4:
            return processHoursFunction('[Минулого] dddd [').call(this);
        }
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'за %s',
      past: '%s тому',
      s: 'декілька секунд',
      ss: relativeTimeWithPlural,
      m: relativeTimeWithPlural,
      mm: relativeTimeWithPlural,
      h: 'годину',
      hh: relativeTimeWithPlural,
      d: 'день',
      dd: relativeTimeWithPlural,
      M: 'місяць',
      MM: relativeTimeWithPlural,
      y: 'рік',
      yy: relativeTimeWithPlural
    },
    // M. E.: those two are virtually unused but a user might want to implement them for his/her website for some reason
    meridiemParse: /ночі|ранку|дня|вечора/,
    isPM: function isPM(input) {
      return /^(дня|вечора)$/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 4) {
        return 'ночі';
      } else if (hour < 12) {
        return 'ранку';
      } else if (hour < 17) {
        return 'дня';
      } else {
        return 'вечора';
      }
    },
    dayOfMonthOrdinalParse: /\d{1,2}-(й|го)/,
    ordinal: function ordinal(number, period) {
      switch (period) {
        case 'M':
        case 'd':
        case 'DDD':
        case 'w':
        case 'W':
          return number + '-й';

        case 'D':
          return number + '-го';

        default:
          return number;
      }
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return uk;
});

/***/ }),

/***/ "rePB":
/*!*******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/defineProperty.js ***!
  \*******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _defineProperty; });
function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

/***/ }),

/***/ "s+uk":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/de-at.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : German (Austria) [de-at]
//! author : lluchs : https://github.com/lluchs
//! author: Menelion Elensúle: https://github.com/Oire
//! author : Martin Groller : https://github.com/MadMG
//! author : Mikolaj Dadela : https://github.com/mik01aj
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      m: ['eine Minute', 'einer Minute'],
      h: ['eine Stunde', 'einer Stunde'],
      d: ['ein Tag', 'einem Tag'],
      dd: [number + ' Tage', number + ' Tagen'],
      w: ['eine Woche', 'einer Woche'],
      M: ['ein Monat', 'einem Monat'],
      MM: [number + ' Monate', number + ' Monaten'],
      y: ['ein Jahr', 'einem Jahr'],
      yy: [number + ' Jahre', number + ' Jahren']
    };
    return withoutSuffix ? format[key][0] : format[key][1];
  }

  var deAt = moment.defineLocale('de-at', {
    months: 'Jänner_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
    monthsShort: 'Jän._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.'.split('_'),
    monthsParseExact: true,
    weekdays: 'Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag'.split('_'),
    weekdaysShort: 'So._Mo._Di._Mi._Do._Fr._Sa.'.split('_'),
    weekdaysMin: 'So_Mo_Di_Mi_Do_Fr_Sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY HH:mm',
      LLLL: 'dddd, D. MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[heute um] LT [Uhr]',
      sameElse: 'L',
      nextDay: '[morgen um] LT [Uhr]',
      nextWeek: 'dddd [um] LT [Uhr]',
      lastDay: '[gestern um] LT [Uhr]',
      lastWeek: '[letzten] dddd [um] LT [Uhr]'
    },
    relativeTime: {
      future: 'in %s',
      past: 'vor %s',
      s: 'ein paar Sekunden',
      ss: '%d Sekunden',
      m: processRelativeTime,
      mm: '%d Minuten',
      h: processRelativeTime,
      hh: '%d Stunden',
      d: processRelativeTime,
      dd: processRelativeTime,
      w: processRelativeTime,
      ww: '%d Wochen',
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return deAt;
});

/***/ }),

/***/ "s4An":
/*!*******************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/setPrototypeOf.js ***!
  \*******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _setPrototypeOf; });
function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

/***/ }),

/***/ "sTY7":
/*!***********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/windowToggle.js ***!
  \***********************************************************************/
/*! exports provided: windowToggle */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "windowToggle", function() { return windowToggle; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../Subject */ "XNiG");
/* harmony import */ var _Subscription__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../Subscription */ "quSY");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");











function windowToggle(openings, closingSelector) {
  return function (source) {
    return source.lift(new WindowToggleOperator(openings, closingSelector));
  };
}

var WindowToggleOperator = /*#__PURE__*/function () {
  function WindowToggleOperator(openings, closingSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, WindowToggleOperator);

    this.openings = openings;
    this.closingSelector = closingSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(WindowToggleOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new WindowToggleSubscriber(subscriber, this.openings, this.closingSelector));
    }
  }]);

  return WindowToggleOperator;
}();

var WindowToggleSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(WindowToggleSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(WindowToggleSubscriber);

  function WindowToggleSubscriber(destination, openings, closingSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, WindowToggleSubscriber);

    _this = _super.call(this, destination);
    _this.openings = openings;
    _this.closingSelector = closingSelector;
    _this.contexts = [];

    _this.add(_this.openSubscription = Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_10__["subscribeToResult"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this), openings, openings));

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(WindowToggleSubscriber, [{
    key: "_next",
    value: function _next(value) {
      var contexts = this.contexts;

      if (contexts) {
        var len = contexts.length;

        for (var i = 0; i < len; i++) {
          contexts[i].window.next(value);
        }
      }
    }
  }, {
    key: "_error",
    value: function _error(err) {
      var contexts = this.contexts;
      this.contexts = null;

      if (contexts) {
        var len = contexts.length;
        var index = -1;

        while (++index < len) {
          var context = contexts[index];
          context.window.error(err);
          context.subscription.unsubscribe();
        }
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(WindowToggleSubscriber.prototype), "_error", this).call(this, err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      var contexts = this.contexts;
      this.contexts = null;

      if (contexts) {
        var len = contexts.length;
        var index = -1;

        while (++index < len) {
          var context = contexts[index];
          context.window.complete();
          context.subscription.unsubscribe();
        }
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(WindowToggleSubscriber.prototype), "_complete", this).call(this);
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var contexts = this.contexts;
      this.contexts = null;

      if (contexts) {
        var len = contexts.length;
        var index = -1;

        while (++index < len) {
          var context = contexts[index];
          context.window.unsubscribe();
          context.subscription.unsubscribe();
        }
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext(outerValue, innerValue, outerIndex, innerIndex, innerSub) {
      if (outerValue === this.openings) {
        var closingNotifier;

        try {
          var closingSelector = this.closingSelector;
          closingNotifier = closingSelector(innerValue);
        } catch (e) {
          return this.error(e);
        }

        var window = new _Subject__WEBPACK_IMPORTED_MODULE_7__["Subject"]();
        var subscription = new _Subscription__WEBPACK_IMPORTED_MODULE_8__["Subscription"]();
        var context = {
          window: window,
          subscription: subscription
        };
        this.contexts.push(context);
        var innerSubscription = Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_10__["subscribeToResult"])(this, closingNotifier, context);

        if (innerSubscription.closed) {
          this.closeWindow(this.contexts.length - 1);
        } else {
          innerSubscription.context = context;
          subscription.add(innerSubscription);
        }

        this.destination.next(window);
      } else {
        this.closeWindow(this.contexts.indexOf(outerValue));
      }
    }
  }, {
    key: "notifyError",
    value: function notifyError(err) {
      this.error(err);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(inner) {
      if (inner !== this.openSubscription) {
        this.closeWindow(this.contexts.indexOf(inner.context));
      }
    }
  }, {
    key: "closeWindow",
    value: function closeWindow(index) {
      if (index === -1) {
        return;
      }

      var contexts = this.contexts;
      var context = contexts[index];
      var window = context.window,
          subscription = context.subscription;
      contexts.splice(index, 1);
      window.complete();
      subscription.unsubscribe();
    }
  }]);

  return WindowToggleSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_9__["OuterSubscriber"]);

/***/ }),

/***/ "sVev":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/EmptyError.js ***!
  \****************************************************************/
/*! exports provided: EmptyError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "EmptyError", function() { return EmptyError; });
var EmptyErrorImpl = function () {
  function EmptyErrorImpl() {
    Error.call(this);
    this.message = 'no elements in sequence';
    this.name = 'EmptyError';
    return this;
  }

  EmptyErrorImpl.prototype = Object.create(Error.prototype);
  return EmptyErrorImpl;
}();

var EmptyError = EmptyErrorImpl;

/***/ }),

/***/ "sp3z":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/lo.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Lao [lo]
//! author : Ryan Hart : https://github.com/ryanhart2
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var lo = moment.defineLocale('lo', {
    months: 'ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ'.split('_'),
    monthsShort: 'ມັງກອນ_ກຸມພາ_ມີນາ_ເມສາ_ພຶດສະພາ_ມິຖຸນາ_ກໍລະກົດ_ສິງຫາ_ກັນຍາ_ຕຸລາ_ພະຈິກ_ທັນວາ'.split('_'),
    weekdays: 'ອາທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ'.split('_'),
    weekdaysShort: 'ທິດ_ຈັນ_ອັງຄານ_ພຸດ_ພະຫັດ_ສຸກ_ເສົາ'.split('_'),
    weekdaysMin: 'ທ_ຈ_ອຄ_ພ_ພຫ_ສກ_ສ'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'ວັນdddd D MMMM YYYY HH:mm'
    },
    meridiemParse: /ຕອນເຊົ້າ|ຕອນແລງ/,
    isPM: function isPM(input) {
      return input === 'ຕອນແລງ';
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 12) {
        return 'ຕອນເຊົ້າ';
      } else {
        return 'ຕອນແລງ';
      }
    },
    calendar: {
      sameDay: '[ມື້ນີ້ເວລາ] LT',
      nextDay: '[ມື້ອື່ນເວລາ] LT',
      nextWeek: '[ວັນ]dddd[ໜ້າເວລາ] LT',
      lastDay: '[ມື້ວານນີ້ເວລາ] LT',
      lastWeek: '[ວັນ]dddd[ແລ້ວນີ້ເວລາ] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'ອີກ %s',
      past: '%sຜ່ານມາ',
      s: 'ບໍ່ເທົ່າໃດວິນາທີ',
      ss: '%d ວິນາທີ',
      m: '1 ນາທີ',
      mm: '%d ນາທີ',
      h: '1 ຊົ່ວໂມງ',
      hh: '%d ຊົ່ວໂມງ',
      d: '1 ມື້',
      dd: '%d ມື້',
      M: '1 ເດືອນ',
      MM: '%d ເດືອນ',
      y: '1 ປີ',
      yy: '%d ປີ'
    },
    dayOfMonthOrdinalParse: /(ທີ່)\d{1,2}/,
    ordinal: function ordinal(number) {
      return 'ທີ່' + number;
    }
  });
  return lo;
});

/***/ }),

/***/ "syX2":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/timeoutWith.js ***!
  \**********************************************************************/
/*! exports provided: timeoutWith */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "timeoutWith", function() { return timeoutWith; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _util_isDate__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/isDate */ "mlxB");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");









function timeoutWith(due, withObservable) {
  var scheduler = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _scheduler_async__WEBPACK_IMPORTED_MODULE_6__["async"];
  return function (source) {
    var absoluteTimeout = Object(_util_isDate__WEBPACK_IMPORTED_MODULE_7__["isDate"])(due);
    var waitFor = absoluteTimeout ? +due - scheduler.now() : Math.abs(due);
    return source.lift(new TimeoutWithOperator(waitFor, absoluteTimeout, withObservable, scheduler));
  };
}

var TimeoutWithOperator = /*#__PURE__*/function () {
  function TimeoutWithOperator(waitFor, absoluteTimeout, withObservable, scheduler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, TimeoutWithOperator);

    this.waitFor = waitFor;
    this.absoluteTimeout = absoluteTimeout;
    this.withObservable = withObservable;
    this.scheduler = scheduler;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(TimeoutWithOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new TimeoutWithSubscriber(subscriber, this.absoluteTimeout, this.waitFor, this.withObservable, this.scheduler));
    }
  }]);

  return TimeoutWithOperator;
}();

var TimeoutWithSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(TimeoutWithSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(TimeoutWithSubscriber);

  function TimeoutWithSubscriber(destination, absoluteTimeout, waitFor, withObservable, scheduler) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, TimeoutWithSubscriber);

    _this = _super.call(this, destination);
    _this.absoluteTimeout = absoluteTimeout;
    _this.waitFor = waitFor;
    _this.withObservable = withObservable;
    _this.scheduler = scheduler;

    _this.scheduleTimeout();

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(TimeoutWithSubscriber, [{
    key: "scheduleTimeout",
    value: function scheduleTimeout() {
      var action = this.action;

      if (action) {
        this.action = action.schedule(this, this.waitFor);
      } else {
        this.add(this.action = this.scheduler.schedule(TimeoutWithSubscriber.dispatchTimeout, this.waitFor, this));
      }
    }
  }, {
    key: "_next",
    value: function _next(value) {
      if (!this.absoluteTimeout) {
        this.scheduleTimeout();
      }

      Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(TimeoutWithSubscriber.prototype), "_next", this).call(this, value);
    }
  }, {
    key: "_unsubscribe",
    value: function _unsubscribe() {
      this.action = undefined;
      this.scheduler = null;
      this.withObservable = null;
    }
  }], [{
    key: "dispatchTimeout",
    value: function dispatchTimeout(subscriber) {
      var withObservable = subscriber.withObservable;

      subscriber._unsubscribeAndRecycle();

      subscriber.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["innerSubscribe"])(withObservable, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["SimpleInnerSubscriber"](subscriber)));
    }
  }]);

  return TimeoutWithSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_8__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "t+mt":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/en-sg.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : English (Singapore) [en-sg]
//! author : Matthew Castrillon-Madrigal : https://github.com/techdimension
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var enSg = moment.defineLocale('en-sg', {
    months: 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
    weekdays: 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
    weekdaysShort: 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
    weekdaysMin: 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Today at] LT',
      nextDay: '[Tomorrow at] LT',
      nextWeek: 'dddd [at] LT',
      lastDay: '[Yesterday at] LT',
      lastWeek: '[Last] dddd [at] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'in %s',
      past: '%s ago',
      s: 'a few seconds',
      ss: '%d seconds',
      m: 'a minute',
      mm: '%d minutes',
      h: 'an hour',
      hh: '%d hours',
      d: 'a day',
      dd: '%d days',
      M: 'a month',
      MM: '%d months',
      y: 'a year',
      yy: '%d years'
    },
    dayOfMonthOrdinalParse: /\d{1,2}(st|nd|rd|th)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = ~~(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return enSg;
});

/***/ }),

/***/ "tGlX":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/de.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : German [de]
//! author : lluchs : https://github.com/lluchs
//! author: Menelion Elensúle: https://github.com/Oire
//! author : Mikolaj Dadela : https://github.com/mik01aj
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      m: ['eine Minute', 'einer Minute'],
      h: ['eine Stunde', 'einer Stunde'],
      d: ['ein Tag', 'einem Tag'],
      dd: [number + ' Tage', number + ' Tagen'],
      w: ['eine Woche', 'einer Woche'],
      M: ['ein Monat', 'einem Monat'],
      MM: [number + ' Monate', number + ' Monaten'],
      y: ['ein Jahr', 'einem Jahr'],
      yy: [number + ' Jahre', number + ' Jahren']
    };
    return withoutSuffix ? format[key][0] : format[key][1];
  }

  var de = moment.defineLocale('de', {
    months: 'Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
    monthsShort: 'Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.'.split('_'),
    monthsParseExact: true,
    weekdays: 'Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag'.split('_'),
    weekdaysShort: 'So._Mo._Di._Mi._Do._Fr._Sa.'.split('_'),
    weekdaysMin: 'So_Mo_Di_Mi_Do_Fr_Sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY HH:mm',
      LLLL: 'dddd, D. MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[heute um] LT [Uhr]',
      sameElse: 'L',
      nextDay: '[morgen um] LT [Uhr]',
      nextWeek: 'dddd [um] LT [Uhr]',
      lastDay: '[gestern um] LT [Uhr]',
      lastWeek: '[letzten] dddd [um] LT [Uhr]'
    },
    relativeTime: {
      future: 'in %s',
      past: 'vor %s',
      s: 'ein paar Sekunden',
      ss: '%d Sekunden',
      m: processRelativeTime,
      mm: '%d Minuten',
      h: processRelativeTime,
      hh: '%d Stunden',
      d: processRelativeTime,
      dd: processRelativeTime,
      w: processRelativeTime,
      ww: '%d Wochen',
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return de;
});

/***/ }),

/***/ "tS1D":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/timeout.js ***!
  \******************************************************************/
/*! exports provided: timeout */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "timeout", function() { return timeout; });
/* harmony import */ var _scheduler_async__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../scheduler/async */ "D0XW");
/* harmony import */ var _util_TimeoutError__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/TimeoutError */ "Y6u4");
/* harmony import */ var _timeoutWith__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./timeoutWith */ "syX2");
/* harmony import */ var _observable_throwError__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../observable/throwError */ "z6cu");




function timeout(due) {
  var scheduler = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _scheduler_async__WEBPACK_IMPORTED_MODULE_0__["async"];
  return Object(_timeoutWith__WEBPACK_IMPORTED_MODULE_2__["timeoutWith"])(due, Object(_observable_throwError__WEBPACK_IMPORTED_MODULE_3__["throwError"])(new _util_TimeoutError__WEBPACK_IMPORTED_MODULE_1__["TimeoutError"]()), scheduler);
}

/***/ }),

/***/ "tT3J":
/*!************************************************!*\
  !*** ./node_modules/moment/locale/tzm-latn.js ***!
  \************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Central Atlas Tamazight Latin [tzm-latn]
//! author : Abdel Said : https://github.com/abdelsaid
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var tzmLatn = moment.defineLocale('tzm-latn', {
    months: 'innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir'.split('_'),
    monthsShort: 'innayr_brˤayrˤ_marˤsˤ_ibrir_mayyw_ywnyw_ywlywz_ɣwšt_šwtanbir_ktˤwbrˤ_nwwanbir_dwjnbir'.split('_'),
    weekdays: 'asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas'.split('_'),
    weekdaysShort: 'asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas'.split('_'),
    weekdaysMin: 'asamas_aynas_asinas_akras_akwas_asimwas_asiḍyas'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[asdkh g] LT',
      nextDay: '[aska g] LT',
      nextWeek: 'dddd [g] LT',
      lastDay: '[assant g] LT',
      lastWeek: 'dddd [g] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'dadkh s yan %s',
      past: 'yan %s',
      s: 'imik',
      ss: '%d imik',
      m: 'minuḍ',
      mm: '%d minuḍ',
      h: 'saɛa',
      hh: '%d tassaɛin',
      d: 'ass',
      dd: '%d ossan',
      M: 'ayowr',
      MM: '%d iyyirn',
      y: 'asgas',
      yy: '%d isgasn'
    },
    week: {
      dow: 6,
      // Saturday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return tzmLatn;
});

/***/ }),

/***/ "tUCv":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/jv.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Javanese [jv]
//! author : Rony Lantip : https://github.com/lantip
//! reference: http://jv.wikipedia.org/wiki/Basa_Jawa
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var jv = moment.defineLocale('jv', {
    months: 'Januari_Februari_Maret_April_Mei_Juni_Juli_Agustus_September_Oktober_Nopember_Desember'.split('_'),
    monthsShort: 'Jan_Feb_Mar_Apr_Mei_Jun_Jul_Ags_Sep_Okt_Nop_Des'.split('_'),
    weekdays: 'Minggu_Senen_Seloso_Rebu_Kemis_Jemuwah_Septu'.split('_'),
    weekdaysShort: 'Min_Sen_Sel_Reb_Kem_Jem_Sep'.split('_'),
    weekdaysMin: 'Mg_Sn_Sl_Rb_Km_Jm_Sp'.split('_'),
    longDateFormat: {
      LT: 'HH.mm',
      LTS: 'HH.mm.ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY [pukul] HH.mm',
      LLLL: 'dddd, D MMMM YYYY [pukul] HH.mm'
    },
    meridiemParse: /enjing|siyang|sonten|ndalu/,
    meridiemHour: function meridiemHour(hour, meridiem) {
      if (hour === 12) {
        hour = 0;
      }

      if (meridiem === 'enjing') {
        return hour;
      } else if (meridiem === 'siyang') {
        return hour >= 11 ? hour : hour + 12;
      } else if (meridiem === 'sonten' || meridiem === 'ndalu') {
        return hour + 12;
      }
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours < 11) {
        return 'enjing';
      } else if (hours < 15) {
        return 'siyang';
      } else if (hours < 19) {
        return 'sonten';
      } else {
        return 'ndalu';
      }
    },
    calendar: {
      sameDay: '[Dinten puniko pukul] LT',
      nextDay: '[Mbenjang pukul] LT',
      nextWeek: 'dddd [pukul] LT',
      lastDay: '[Kala wingi pukul] LT',
      lastWeek: 'dddd [kepengker pukul] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'wonten ing %s',
      past: '%s ingkang kepengker',
      s: 'sawetawis detik',
      ss: '%d detik',
      m: 'setunggal menit',
      mm: '%d menit',
      h: 'setunggal jam',
      hh: '%d jam',
      d: 'sedinten',
      dd: '%d dinten',
      M: 'sewulan',
      MM: '%d wulan',
      y: 'setaun',
      yy: '%d taun'
    },
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return jv;
});

/***/ }),

/***/ "tbfe":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/es-mx.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Spanish (Mexico) [es-mx]
//! author : JC Franco : https://github.com/jcfranco
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var monthsShortDot = 'ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.'.split('_'),
      _monthsShort = 'ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic'.split('_'),
      monthsParse = [/^ene/i, /^feb/i, /^mar/i, /^abr/i, /^may/i, /^jun/i, /^jul/i, /^ago/i, /^sep/i, /^oct/i, /^nov/i, /^dic/i],
      monthsRegex = /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;

  var esMx = moment.defineLocale('es-mx', {
    months: 'enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre'.split('_'),
    monthsShort: function monthsShort(m, format) {
      if (!m) {
        return monthsShortDot;
      } else if (/-MMM-/.test(format)) {
        return _monthsShort[m.month()];
      } else {
        return monthsShortDot[m.month()];
      }
    },
    monthsRegex: monthsRegex,
    monthsShortRegex: monthsRegex,
    monthsStrictRegex: /^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,
    monthsShortStrictRegex: /^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,
    monthsParse: monthsParse,
    longMonthsParse: monthsParse,
    shortMonthsParse: monthsParse,
    weekdays: 'domingo_lunes_martes_miércoles_jueves_viernes_sábado'.split('_'),
    weekdaysShort: 'dom._lun._mar._mié._jue._vie._sáb.'.split('_'),
    weekdaysMin: 'do_lu_ma_mi_ju_vi_sá'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [de] MMMM [de] YYYY',
      LLL: 'D [de] MMMM [de] YYYY H:mm',
      LLLL: 'dddd, D [de] MMMM [de] YYYY H:mm'
    },
    calendar: {
      sameDay: function sameDay() {
        return '[hoy a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextDay: function nextDay() {
        return '[mañana a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      nextWeek: function nextWeek() {
        return 'dddd [a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastDay: function lastDay() {
        return '[ayer a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      lastWeek: function lastWeek() {
        return '[el] dddd [pasado a la' + (this.hours() !== 1 ? 's' : '') + '] LT';
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'en %s',
      past: 'hace %s',
      s: 'unos segundos',
      ss: '%d segundos',
      m: 'un minuto',
      mm: '%d minutos',
      h: 'una hora',
      hh: '%d horas',
      d: 'un día',
      dd: '%d días',
      w: 'una semana',
      ww: '%d semanas',
      M: 'un mes',
      MM: '%d meses',
      y: 'un año',
      yy: '%d años'
    },
    dayOfMonthOrdinalParse: /\d{1,2}º/,
    ordinal: '%dº',
    week: {
      dow: 0,
      // Sunday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    },
    invalidDate: 'Fecha inválida'
  });
  return esMx;
});

/***/ }),

/***/ "tf+s":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/subscribeOn.js ***!
  \**********************************************************************/
/*! exports provided: subscribeOn */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "subscribeOn", function() { return subscribeOn; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _observable_SubscribeOnObservable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../observable/SubscribeOnObservable */ "O4y0");



function subscribeOn(scheduler) {
  var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  return function subscribeOnOperatorFunction(source) {
    return source.lift(new SubscribeOnOperator(scheduler, delay));
  };
}

var SubscribeOnOperator = /*#__PURE__*/function () {
  function SubscribeOnOperator(scheduler, delay) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SubscribeOnOperator);

    this.scheduler = scheduler;
    this.delay = delay;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SubscribeOnOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return new _observable_SubscribeOnObservable__WEBPACK_IMPORTED_MODULE_2__["SubscribeOnObservable"](source, this.delay, this.scheduler).subscribe(subscriber);
    }
  }]);

  return SubscribeOnOperator;
}();

/***/ }),

/***/ "tk/3":
/*!********************************************************************!*\
  !*** ./node_modules/@angular/common/__ivy_ngcc__/fesm2015/http.js ***!
  \********************************************************************/
/*! exports provided: HTTP_INTERCEPTORS, HttpBackend, HttpClient, HttpClientJsonpModule, HttpClientModule, HttpClientXsrfModule, HttpErrorResponse, HttpEventType, HttpHandler, HttpHeaderResponse, HttpHeaders, HttpParams, HttpRequest, HttpResponse, HttpResponseBase, HttpUrlEncodingCodec, HttpXhrBackend, HttpXsrfTokenExtractor, JsonpClientBackend, JsonpInterceptor, XhrFactory, ɵHttpInterceptingHandler, ɵangular_packages_common_http_http_a, ɵangular_packages_common_http_http_b, ɵangular_packages_common_http_http_c, ɵangular_packages_common_http_http_d, ɵangular_packages_common_http_http_e, ɵangular_packages_common_http_http_f, ɵangular_packages_common_http_http_g, ɵangular_packages_common_http_http_h */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HTTP_INTERCEPTORS", function() { return HTTP_INTERCEPTORS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpBackend", function() { return HttpBackend; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpClient", function() { return HttpClient; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpClientJsonpModule", function() { return HttpClientJsonpModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpClientModule", function() { return HttpClientModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpClientXsrfModule", function() { return HttpClientXsrfModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpErrorResponse", function() { return HttpErrorResponse; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpEventType", function() { return HttpEventType; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpHandler", function() { return HttpHandler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpHeaderResponse", function() { return HttpHeaderResponse; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpHeaders", function() { return HttpHeaders; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpParams", function() { return HttpParams; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpRequest", function() { return HttpRequest; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpResponse", function() { return HttpResponse; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpResponseBase", function() { return HttpResponseBase; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpUrlEncodingCodec", function() { return HttpUrlEncodingCodec; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpXhrBackend", function() { return HttpXhrBackend; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "HttpXsrfTokenExtractor", function() { return HttpXsrfTokenExtractor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JsonpClientBackend", function() { return JsonpClientBackend; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "JsonpInterceptor", function() { return JsonpInterceptor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "XhrFactory", function() { return XhrFactory; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵHttpInterceptingHandler", function() { return HttpInterceptingHandler; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_a", function() { return NoopInterceptor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_b", function() { return JsonpCallbackContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_c", function() { return jsonpCallbackContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_d", function() { return BrowserXhr; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_e", function() { return XSRF_COOKIE_NAME; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_f", function() { return XSRF_HEADER_NAME; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_g", function() { return HttpXsrfCookieExtractor; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_common_http_http_h", function() { return HttpXsrfInterceptor; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ "ODXe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @angular/core */ "fXoL");
/* harmony import */ var rxjs__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! rxjs */ "qCKp");
/* harmony import */ var rxjs_operators__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! rxjs/operators */ "kU1M");
/* harmony import */ var _angular_common__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! @angular/common */ "ofXK");







/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */




/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Transforms an `HttpRequest` into a stream of `HttpEvent`s, one of which will likely be a
 * `HttpResponse`.
 *
 * `HttpHandler` is injectable. When injected, the handler instance dispatches requests to the
 * first interceptor in the chain, which dispatches to the second, etc, eventually reaching the
 * `HttpBackend`.
 *
 * In an `HttpInterceptor`, the `HttpHandler` parameter is the next interceptor in the chain.
 *
 * @publicApi
 */



var HttpHandler = function HttpHandler() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpHandler);
};
/**
 * A final `HttpHandler` which will dispatch the request via browser HTTP APIs to a backend.
 *
 * Interceptors sit between the `HttpClient` interface and the `HttpBackend`.
 *
 * When injected, `HttpBackend` dispatches requests directly to the backend, without going
 * through the interceptor chain.
 *
 * @publicApi
 */


var HttpBackend = function HttpBackend() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpBackend);
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents the header configuration options for an HTTP request.
 * Instances are immutable. Modifying methods return a cloned
 * instance with the change. The original object is never changed.
 *
 * @publicApi
 */


var HttpHeaders = /*#__PURE__*/function () {
  /**  Constructs a new HTTP header object with the given values.*/
  function HttpHeaders(headers) {
    var _this = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpHeaders);

    /**
     * Internal map of lowercased header names to the normalized
     * form of the name (the form seen first).
     */
    this.normalizedNames = new Map();
    /**
     * Queued updates to be materialized the next initialization.
     */

    this.lazyUpdate = null;

    if (!headers) {
      this.headers = new Map();
    } else if (typeof headers === 'string') {
      this.lazyInit = function () {
        _this.headers = new Map();
        headers.split('\n').forEach(function (line) {
          var index = line.indexOf(':');

          if (index > 0) {
            var name = line.slice(0, index);
            var key = name.toLowerCase();
            var value = line.slice(index + 1).trim();

            _this.maybeSetNormalizedName(name, key);

            if (_this.headers.has(key)) {
              _this.headers.get(key).push(value);
            } else {
              _this.headers.set(key, [value]);
            }
          }
        });
      };
    } else {
      this.lazyInit = function () {
        _this.headers = new Map();
        Object.keys(headers).forEach(function (name) {
          var values = headers[name];
          var key = name.toLowerCase();

          if (typeof values === 'string') {
            values = [values];
          }

          if (values.length > 0) {
            _this.headers.set(key, values);

            _this.maybeSetNormalizedName(name, key);
          }
        });
      };
    }
  }
  /**
   * Checks for existence of a given header.
   *
   * @param name The header name to check for existence.
   *
   * @returns True if the header exists, false otherwise.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpHeaders, [{
    key: "has",
    value: function has(name) {
      this.init();
      return this.headers.has(name.toLowerCase());
    }
    /**
     * Retrieves the first value of a given header.
     *
     * @param name The header name.
     *
     * @returns The value string if the header exists, null otherwise
     */

  }, {
    key: "get",
    value: function get(name) {
      this.init();
      var values = this.headers.get(name.toLowerCase());
      return values && values.length > 0 ? values[0] : null;
    }
    /**
     * Retrieves the names of the headers.
     *
     * @returns A list of header names.
     */

  }, {
    key: "keys",
    value: function keys() {
      this.init();
      return Array.from(this.normalizedNames.values());
    }
    /**
     * Retrieves a list of values for a given header.
     *
     * @param name The header name from which to retrieve values.
     *
     * @returns A string of values if the header exists, null otherwise.
     */

  }, {
    key: "getAll",
    value: function getAll(name) {
      this.init();
      return this.headers.get(name.toLowerCase()) || null;
    }
    /**
     * Appends a new value to the existing set of values for a header
     * and returns them in a clone of the original instance.
     *
     * @param name The header name for which to append the values.
     * @param value The value to append.
     *
     * @returns A clone of the HTTP headers object with the value appended to the given header.
     */

  }, {
    key: "append",
    value: function append(name, value) {
      return this.clone({
        name: name,
        value: value,
        op: 'a'
      });
    }
    /**
     * Sets or modifies a value for a given header in a clone of the original instance.
     * If the header already exists, its value is replaced with the given value
     * in the returned object.
     *
     * @param name The header name.
     * @param value The value or values to set or overide for the given header.
     *
     * @returns A clone of the HTTP headers object with the newly set header value.
     */

  }, {
    key: "set",
    value: function set(name, value) {
      return this.clone({
        name: name,
        value: value,
        op: 's'
      });
    }
    /**
     * Deletes values for a given header in a clone of the original instance.
     *
     * @param name The header name.
     * @param value The value or values to delete for the given header.
     *
     * @returns A clone of the HTTP headers object with the given value deleted.
     */

  }, {
    key: "delete",
    value: function _delete(name, value) {
      return this.clone({
        name: name,
        value: value,
        op: 'd'
      });
    }
  }, {
    key: "maybeSetNormalizedName",
    value: function maybeSetNormalizedName(name, lcName) {
      if (!this.normalizedNames.has(lcName)) {
        this.normalizedNames.set(lcName, name);
      }
    }
  }, {
    key: "init",
    value: function init() {
      var _this2 = this;

      if (!!this.lazyInit) {
        if (this.lazyInit instanceof HttpHeaders) {
          this.copyFrom(this.lazyInit);
        } else {
          this.lazyInit();
        }

        this.lazyInit = null;

        if (!!this.lazyUpdate) {
          this.lazyUpdate.forEach(function (update) {
            return _this2.applyUpdate(update);
          });
          this.lazyUpdate = null;
        }
      }
    }
  }, {
    key: "copyFrom",
    value: function copyFrom(other) {
      var _this3 = this;

      other.init();
      Array.from(other.headers.keys()).forEach(function (key) {
        _this3.headers.set(key, other.headers.get(key));

        _this3.normalizedNames.set(key, other.normalizedNames.get(key));
      });
    }
  }, {
    key: "clone",
    value: function clone(update) {
      var clone = new HttpHeaders();
      clone.lazyInit = !!this.lazyInit && this.lazyInit instanceof HttpHeaders ? this.lazyInit : this;
      clone.lazyUpdate = (this.lazyUpdate || []).concat([update]);
      return clone;
    }
  }, {
    key: "applyUpdate",
    value: function applyUpdate(update) {
      var key = update.name.toLowerCase();

      switch (update.op) {
        case 'a':
        case 's':
          var value = update.value;

          if (typeof value === 'string') {
            value = [value];
          }

          if (value.length === 0) {
            return;
          }

          this.maybeSetNormalizedName(update.name, key);
          var base = (update.op === 'a' ? this.headers.get(key) : undefined) || [];
          base.push.apply(base, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(value));
          this.headers.set(key, base);
          break;

        case 'd':
          var toDelete = update.value;

          if (!toDelete) {
            this.headers.delete(key);
            this.normalizedNames.delete(key);
          } else {
            var existing = this.headers.get(key);

            if (!existing) {
              return;
            }

            existing = existing.filter(function (value) {
              return toDelete.indexOf(value) === -1;
            });

            if (existing.length === 0) {
              this.headers.delete(key);
              this.normalizedNames.delete(key);
            } else {
              this.headers.set(key, existing);
            }
          }

          break;
      }
    }
    /**
     * @internal
     */

  }, {
    key: "forEach",
    value: function forEach(fn) {
      var _this4 = this;

      this.init();
      Array.from(this.normalizedNames.keys()).forEach(function (key) {
        return fn(_this4.normalizedNames.get(key), _this4.headers.get(key));
      });
    }
  }]);

  return HttpHeaders;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Provides encoding and decoding of URL parameter and query-string values.
 *
 * Serializes and parses URL parameter keys and values to encode and decode them.
 * If you pass URL query parameters without encoding,
 * the query parameters can be misinterpreted at the receiving end.
 *
 *
 * @publicApi
 */


var HttpUrlEncodingCodec = /*#__PURE__*/function () {
  function HttpUrlEncodingCodec() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpUrlEncodingCodec);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpUrlEncodingCodec, [{
    key: "encodeKey",

    /**
     * Encodes a key name for a URL parameter or query-string.
     * @param key The key name.
     * @returns The encoded key name.
     */
    value: function encodeKey(key) {
      return standardEncoding(key);
    }
    /**
     * Encodes the value of a URL parameter or query-string.
     * @param value The value.
     * @returns The encoded value.
     */

  }, {
    key: "encodeValue",
    value: function encodeValue(value) {
      return standardEncoding(value);
    }
    /**
     * Decodes an encoded URL parameter or query-string key.
     * @param key The encoded key name.
     * @returns The decoded key name.
     */

  }, {
    key: "decodeKey",
    value: function decodeKey(key) {
      return decodeURIComponent(key);
    }
    /**
     * Decodes an encoded URL parameter or query-string value.
     * @param value The encoded value.
     * @returns The decoded value.
     */

  }, {
    key: "decodeValue",
    value: function decodeValue(value) {
      return decodeURIComponent(value);
    }
  }]);

  return HttpUrlEncodingCodec;
}();

function paramParser(rawParams, codec) {
  var map = new Map();

  if (rawParams.length > 0) {
    var params = rawParams.split('&');
    params.forEach(function (param) {
      var eqIdx = param.indexOf('=');

      var _ref = eqIdx == -1 ? [codec.decodeKey(param), ''] : [codec.decodeKey(param.slice(0, eqIdx)), codec.decodeValue(param.slice(eqIdx + 1))],
          _ref2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_2__["default"])(_ref, 2),
          key = _ref2[0],
          val = _ref2[1];

      var list = map.get(key) || [];
      list.push(val);
      map.set(key, list);
    });
  }

  return map;
}

function standardEncoding(v) {
  return encodeURIComponent(v).replace(/%40/gi, '@').replace(/%3A/gi, ':').replace(/%24/gi, '$').replace(/%2C/gi, ',').replace(/%3B/gi, ';').replace(/%2B/gi, '+').replace(/%3D/gi, '=').replace(/%3F/gi, '?').replace(/%2F/gi, '/');
}
/**
 * An HTTP request/response body that represents serialized parameters,
 * per the MIME type `application/x-www-form-urlencoded`.
 *
 * This class is immutable; all mutation operations return a new instance.
 *
 * @publicApi
 */


var HttpParams = /*#__PURE__*/function () {
  function HttpParams() {
    var _this5 = this;

    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpParams);

    this.updates = null;
    this.cloneFrom = null;
    this.encoder = options.encoder || new HttpUrlEncodingCodec();

    if (!!options.fromString) {
      if (!!options.fromObject) {
        throw new Error("Cannot specify both fromString and fromObject.");
      }

      this.map = paramParser(options.fromString, this.encoder);
    } else if (!!options.fromObject) {
      this.map = new Map();
      Object.keys(options.fromObject).forEach(function (key) {
        var value = options.fromObject[key];

        _this5.map.set(key, Array.isArray(value) ? value : [value]);
      });
    } else {
      this.map = null;
    }
  }
  /**
   * Reports whether the body includes one or more values for a given parameter.
   * @param param The parameter name.
   * @returns True if the parameter has one or more values,
   * false if it has no value or is not present.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpParams, [{
    key: "has",
    value: function has(param) {
      this.init();
      return this.map.has(param);
    }
    /**
     * Retrieves the first value for a parameter.
     * @param param The parameter name.
     * @returns The first value of the given parameter,
     * or `null` if the parameter is not present.
     */

  }, {
    key: "get",
    value: function get(param) {
      this.init();
      var res = this.map.get(param);
      return !!res ? res[0] : null;
    }
    /**
     * Retrieves all values for a  parameter.
     * @param param The parameter name.
     * @returns All values in a string array,
     * or `null` if the parameter not present.
     */

  }, {
    key: "getAll",
    value: function getAll(param) {
      this.init();
      return this.map.get(param) || null;
    }
    /**
     * Retrieves all the parameters for this body.
     * @returns The parameter names in a string array.
     */

  }, {
    key: "keys",
    value: function keys() {
      this.init();
      return Array.from(this.map.keys());
    }
    /**
     * Appends a new value to existing values for a parameter.
     * @param param The parameter name.
     * @param value The new value to add.
     * @return A new body with the appended value.
     */

  }, {
    key: "append",
    value: function append(param, value) {
      return this.clone({
        param: param,
        value: value,
        op: 'a'
      });
    }
    /**
     * Replaces the value for a parameter.
     * @param param The parameter name.
     * @param value The new value.
     * @return A new body with the new value.
     */

  }, {
    key: "set",
    value: function set(param, value) {
      return this.clone({
        param: param,
        value: value,
        op: 's'
      });
    }
    /**
     * Removes a given value or all values from a parameter.
     * @param param The parameter name.
     * @param value The value to remove, if provided.
     * @return A new body with the given value removed, or with all values
     * removed if no value is specified.
     */

  }, {
    key: "delete",
    value: function _delete(param, value) {
      return this.clone({
        param: param,
        value: value,
        op: 'd'
      });
    }
    /**
     * Serializes the body to an encoded string, where key-value pairs (separated by `=`) are
     * separated by `&`s.
     */

  }, {
    key: "toString",
    value: function toString() {
      var _this6 = this;

      this.init();
      return this.keys().map(function (key) {
        var eKey = _this6.encoder.encodeKey(key); // `a: ['1']` produces `'a=1'`
        // `b: []` produces `''`
        // `c: ['1', '2']` produces `'c=1&c=2'`


        return _this6.map.get(key).map(function (value) {
          return eKey + '=' + _this6.encoder.encodeValue(value);
        }).join('&');
      }) // filter out empty values because `b: []` produces `''`
      // which results in `a=1&&c=1&c=2` instead of `a=1&c=1&c=2` if we don't
      .filter(function (param) {
        return param !== '';
      }).join('&');
    }
  }, {
    key: "clone",
    value: function clone(update) {
      var clone = new HttpParams({
        encoder: this.encoder
      });
      clone.cloneFrom = this.cloneFrom || this;
      clone.updates = (this.updates || []).concat([update]);
      return clone;
    }
  }, {
    key: "init",
    value: function init() {
      var _this7 = this;

      if (this.map === null) {
        this.map = new Map();
      }

      if (this.cloneFrom !== null) {
        this.cloneFrom.init();
        this.cloneFrom.keys().forEach(function (key) {
          return _this7.map.set(key, _this7.cloneFrom.map.get(key));
        });
        this.updates.forEach(function (update) {
          switch (update.op) {
            case 'a':
            case 's':
              var base = (update.op === 'a' ? _this7.map.get(update.param) : undefined) || [];
              base.push(update.value);

              _this7.map.set(update.param, base);

              break;

            case 'd':
              if (update.value !== undefined) {
                var _base = _this7.map.get(update.param) || [];

                var idx = _base.indexOf(update.value);

                if (idx !== -1) {
                  _base.splice(idx, 1);
                }

                if (_base.length > 0) {
                  _this7.map.set(update.param, _base);
                } else {
                  _this7.map.delete(update.param);
                }
              } else {
                _this7.map.delete(update.param);

                break;
              }

          }
        });
        this.cloneFrom = this.updates = null;
      }
    }
  }]);

  return HttpParams;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Determine whether the given HTTP method may include a body.
 */


function mightHaveBody(method) {
  switch (method) {
    case 'DELETE':
    case 'GET':
    case 'HEAD':
    case 'OPTIONS':
    case 'JSONP':
      return false;

    default:
      return true;
  }
}
/**
 * Safely assert whether the given value is an ArrayBuffer.
 *
 * In some execution environments ArrayBuffer is not defined.
 */


function isArrayBuffer(value) {
  return typeof ArrayBuffer !== 'undefined' && value instanceof ArrayBuffer;
}
/**
 * Safely assert whether the given value is a Blob.
 *
 * In some execution environments Blob is not defined.
 */


function isBlob(value) {
  return typeof Blob !== 'undefined' && value instanceof Blob;
}
/**
 * Safely assert whether the given value is a FormData instance.
 *
 * In some execution environments FormData is not defined.
 */


function isFormData(value) {
  return typeof FormData !== 'undefined' && value instanceof FormData;
}
/**
 * An outgoing HTTP request with an optional typed body.
 *
 * `HttpRequest` represents an outgoing request, including URL, method,
 * headers, body, and other request configuration options. Instances should be
 * assumed to be immutable. To modify a `HttpRequest`, the `clone`
 * method should be used.
 *
 * @publicApi
 */


var HttpRequest = /*#__PURE__*/function () {
  function HttpRequest(method, url, third, fourth) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpRequest);

    this.url = url;
    /**
     * The request body, or `null` if one isn't set.
     *
     * Bodies are not enforced to be immutable, as they can include a reference to any
     * user-defined data type. However, interceptors should take care to preserve
     * idempotence by treating them as such.
     */

    this.body = null;
    /**
     * Whether this request should be made in a way that exposes progress events.
     *
     * Progress events are expensive (change detection runs on each event) and so
     * they should only be requested if the consumer intends to monitor them.
     */

    this.reportProgress = false;
    /**
     * Whether this request should be sent with outgoing credentials (cookies).
     */

    this.withCredentials = false;
    /**
     * The expected response type of the server.
     *
     * This is used to parse the response appropriately before returning it to
     * the requestee.
     */

    this.responseType = 'json';
    this.method = method.toUpperCase(); // Next, need to figure out which argument holds the HttpRequestInit
    // options, if any.

    var options; // Check whether a body argument is expected. The only valid way to omit
    // the body argument is to use a known no-body method like GET.

    if (mightHaveBody(this.method) || !!fourth) {
      // Body is the third argument, options are the fourth.
      this.body = third !== undefined ? third : null;
      options = fourth;
    } else {
      // No body required, options are the third argument. The body stays null.
      options = third;
    } // If options have been passed, interpret them.


    if (options) {
      // Normalize reportProgress and withCredentials.
      this.reportProgress = !!options.reportProgress;
      this.withCredentials = !!options.withCredentials; // Override default response type of 'json' if one is provided.

      if (!!options.responseType) {
        this.responseType = options.responseType;
      } // Override headers if they're provided.


      if (!!options.headers) {
        this.headers = options.headers;
      }

      if (!!options.params) {
        this.params = options.params;
      }
    } // If no headers have been passed in, construct a new HttpHeaders instance.


    if (!this.headers) {
      this.headers = new HttpHeaders();
    } // If no parameters have been passed in, construct a new HttpUrlEncodedParams instance.


    if (!this.params) {
      this.params = new HttpParams();
      this.urlWithParams = url;
    } else {
      // Encode the parameters to a string in preparation for inclusion in the URL.
      var params = this.params.toString();

      if (params.length === 0) {
        // No parameters, the visible URL is just the URL given at creation time.
        this.urlWithParams = url;
      } else {
        // Does the URL already have query parameters? Look for '?'.
        var qIdx = url.indexOf('?'); // There are 3 cases to handle:
        // 1) No existing parameters -> append '?' followed by params.
        // 2) '?' exists and is followed by existing query string ->
        //    append '&' followed by params.
        // 3) '?' exists at the end of the url -> append params directly.
        // This basically amounts to determining the character, if any, with
        // which to join the URL and parameters.

        var sep = qIdx === -1 ? '?' : qIdx < url.length - 1 ? '&' : '';
        this.urlWithParams = url + sep + params;
      }
    }
  }
  /**
   * Transform the free-form body into a serialized format suitable for
   * transmission to the server.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpRequest, [{
    key: "serializeBody",
    value: function serializeBody() {
      // If no body is present, no need to serialize it.
      if (this.body === null) {
        return null;
      } // Check whether the body is already in a serialized form. If so,
      // it can just be returned directly.


      if (isArrayBuffer(this.body) || isBlob(this.body) || isFormData(this.body) || typeof this.body === 'string') {
        return this.body;
      } // Check whether the body is an instance of HttpUrlEncodedParams.


      if (this.body instanceof HttpParams) {
        return this.body.toString();
      } // Check whether the body is an object or array, and serialize with JSON if so.


      if (typeof this.body === 'object' || typeof this.body === 'boolean' || Array.isArray(this.body)) {
        return JSON.stringify(this.body);
      } // Fall back on toString() for everything else.


      return this.body.toString();
    }
    /**
     * Examine the body and attempt to infer an appropriate MIME type
     * for it.
     *
     * If no such type can be inferred, this method will return `null`.
     */

  }, {
    key: "detectContentTypeHeader",
    value: function detectContentTypeHeader() {
      // An empty body has no content type.
      if (this.body === null) {
        return null;
      } // FormData bodies rely on the browser's content type assignment.


      if (isFormData(this.body)) {
        return null;
      } // Blobs usually have their own content type. If it doesn't, then
      // no type can be inferred.


      if (isBlob(this.body)) {
        return this.body.type || null;
      } // Array buffers have unknown contents and thus no type can be inferred.


      if (isArrayBuffer(this.body)) {
        return null;
      } // Technically, strings could be a form of JSON data, but it's safe enough
      // to assume they're plain strings.


      if (typeof this.body === 'string') {
        return 'text/plain';
      } // `HttpUrlEncodedParams` has its own content-type.


      if (this.body instanceof HttpParams) {
        return 'application/x-www-form-urlencoded;charset=UTF-8';
      } // Arrays, objects, and numbers will be encoded as JSON.


      if (typeof this.body === 'object' || typeof this.body === 'number' || Array.isArray(this.body)) {
        return 'application/json';
      } // No type could be inferred.


      return null;
    }
  }, {
    key: "clone",
    value: function clone() {
      var update = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      // For method, url, and responseType, take the current value unless
      // it is overridden in the update hash.
      var method = update.method || this.method;
      var url = update.url || this.url;
      var responseType = update.responseType || this.responseType; // The body is somewhat special - a `null` value in update.body means
      // whatever current body is present is being overridden with an empty
      // body, whereas an `undefined` value in update.body implies no
      // override.

      var body = update.body !== undefined ? update.body : this.body; // Carefully handle the boolean options to differentiate between
      // `false` and `undefined` in the update args.

      var withCredentials = update.withCredentials !== undefined ? update.withCredentials : this.withCredentials;
      var reportProgress = update.reportProgress !== undefined ? update.reportProgress : this.reportProgress; // Headers and params may be appended to if `setHeaders` or
      // `setParams` are used.

      var headers = update.headers || this.headers;
      var params = update.params || this.params; // Check whether the caller has asked to add headers.

      if (update.setHeaders !== undefined) {
        // Set every requested header.
        headers = Object.keys(update.setHeaders).reduce(function (headers, name) {
          return headers.set(name, update.setHeaders[name]);
        }, headers);
      } // Check whether the caller has asked to set params.


      if (update.setParams) {
        // Set every requested param.
        params = Object.keys(update.setParams).reduce(function (params, param) {
          return params.set(param, update.setParams[param]);
        }, params);
      } // Finally, construct the new HttpRequest using the pieces from above.


      return new HttpRequest(method, url, body, {
        params: params,
        headers: headers,
        reportProgress: reportProgress,
        responseType: responseType,
        withCredentials: withCredentials
      });
    }
  }]);

  return HttpRequest;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Type enumeration for the different kinds of `HttpEvent`.
 *
 * @publicApi
 */


var HttpEventType;

(function (HttpEventType) {
  /**
   * The request was sent out over the wire.
   */
  HttpEventType[HttpEventType["Sent"] = 0] = "Sent";
  /**
   * An upload progress event was received.
   */

  HttpEventType[HttpEventType["UploadProgress"] = 1] = "UploadProgress";
  /**
   * The response status code and headers were received.
   */

  HttpEventType[HttpEventType["ResponseHeader"] = 2] = "ResponseHeader";
  /**
   * A download progress event was received.
   */

  HttpEventType[HttpEventType["DownloadProgress"] = 3] = "DownloadProgress";
  /**
   * The full response including the body was received.
   */

  HttpEventType[HttpEventType["Response"] = 4] = "Response";
  /**
   * A custom event from an interceptor or a backend.
   */

  HttpEventType[HttpEventType["User"] = 5] = "User";
})(HttpEventType || (HttpEventType = {}));
/**
 * Base class for both `HttpResponse` and `HttpHeaderResponse`.
 *
 * @publicApi
 */


var HttpResponseBase =
/**
 * Super-constructor for all responses.
 *
 * The single parameter accepted is an initialization hash. Any properties
 * of the response passed there will override the default values.
 */
function HttpResponseBase(init) {
  var defaultStatus = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 200;
  var defaultStatusText = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'OK';

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpResponseBase);

  // If the hash has values passed, use them to initialize the response.
  // Otherwise use the default values.
  this.headers = init.headers || new HttpHeaders();
  this.status = init.status !== undefined ? init.status : defaultStatus;
  this.statusText = init.statusText || defaultStatusText;
  this.url = init.url || null; // Cache the ok value to avoid defining a getter.

  this.ok = this.status >= 200 && this.status < 300;
};
/**
 * A partial HTTP response which only includes the status and header data,
 * but no response body.
 *
 * `HttpHeaderResponse` is a `HttpEvent` available on the response
 * event stream, only when progress events are requested.
 *
 * @publicApi
 */


var HttpHeaderResponse = /*#__PURE__*/function (_HttpResponseBase) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(HttpHeaderResponse, _HttpResponseBase);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(HttpHeaderResponse);

  /**
   * Create a new `HttpHeaderResponse` with the given parameters.
   */
  function HttpHeaderResponse() {
    var _this8;

    var init = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpHeaderResponse);

    _this8 = _super.call(this, init);
    _this8.type = HttpEventType.ResponseHeader;
    return _this8;
  }
  /**
   * Copy this `HttpHeaderResponse`, overriding its contents with the
   * given parameter hash.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpHeaderResponse, [{
    key: "clone",
    value: function clone() {
      var update = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      // Perform a straightforward initialization of the new HttpHeaderResponse,
      // overriding the current parameters with new ones if given.
      return new HttpHeaderResponse({
        headers: update.headers || this.headers,
        status: update.status !== undefined ? update.status : this.status,
        statusText: update.statusText || this.statusText,
        url: update.url || this.url || undefined
      });
    }
  }]);

  return HttpHeaderResponse;
}(HttpResponseBase);
/**
 * A full HTTP response, including a typed response body (which may be `null`
 * if one was not returned).
 *
 * `HttpResponse` is a `HttpEvent` available on the response event
 * stream.
 *
 * @publicApi
 */


var HttpResponse = /*#__PURE__*/function (_HttpResponseBase2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(HttpResponse, _HttpResponseBase2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(HttpResponse);

  /**
   * Construct a new `HttpResponse`.
   */
  function HttpResponse() {
    var _this9;

    var init = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpResponse);

    _this9 = _super2.call(this, init);
    _this9.type = HttpEventType.Response;
    _this9.body = init.body !== undefined ? init.body : null;
    return _this9;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpResponse, [{
    key: "clone",
    value: function clone() {
      var update = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return new HttpResponse({
        body: update.body !== undefined ? update.body : this.body,
        headers: update.headers || this.headers,
        status: update.status !== undefined ? update.status : this.status,
        statusText: update.statusText || this.statusText,
        url: update.url || this.url || undefined
      });
    }
  }]);

  return HttpResponse;
}(HttpResponseBase);
/**
 * A response that represents an error or failure, either from a
 * non-successful HTTP status, an error while executing the request,
 * or some other failure which occurred during the parsing of the response.
 *
 * Any error returned on the `Observable` response stream will be
 * wrapped in an `HttpErrorResponse` to provide additional context about
 * the state of the HTTP layer when the error occurred. The error property
 * will contain either a wrapped Error object or the error response returned
 * from the server.
 *
 * @publicApi
 */


var HttpErrorResponse = /*#__PURE__*/function (_HttpResponseBase3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(HttpErrorResponse, _HttpResponseBase3);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(HttpErrorResponse);

  function HttpErrorResponse(init) {
    var _this10;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpErrorResponse);

    // Initialize with a default status of 0 / Unknown Error.
    _this10 = _super3.call(this, init, 0, 'Unknown Error');
    _this10.name = 'HttpErrorResponse';
    /**
     * Errors are never okay, even when the status code is in the 2xx success range.
     */

    _this10.ok = false; // If the response was successful, then this was a parse error. Otherwise, it was
    // a protocol-level failure of some sort. Either the request failed in transit
    // or the server returned an unsuccessful status code.

    if (_this10.status >= 200 && _this10.status < 300) {
      _this10.message = "Http failure during parsing for ".concat(init.url || '(unknown url)');
    } else {
      _this10.message = "Http failure response for ".concat(init.url || '(unknown url)', ": ").concat(init.status, " ").concat(init.statusText);
    }

    _this10.error = init.error || null;
    return _this10;
  }

  return HttpErrorResponse;
}(HttpResponseBase);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Constructs an instance of `HttpRequestOptions<T>` from a source `HttpMethodOptions` and
 * the given `body`. This function clones the object and adds the body.
 *
 * Note that the `responseType` *options* value is a String that identifies the
 * single data type of the response.
 * A single overload version of the method handles each response type.
 * The value of `responseType` cannot be a union, as the combined signature could imply.
 *
 */


function addBody(options, body) {
  return {
    body: body,
    headers: options.headers,
    observe: options.observe,
    params: options.params,
    reportProgress: options.reportProgress,
    responseType: options.responseType,
    withCredentials: options.withCredentials
  };
}
/**
 * Performs HTTP requests.
 * This service is available as an injectable class, with methods to perform HTTP requests.
 * Each request method has multiple signatures, and the return type varies based on
 * the signature that is called (mainly the values of `observe` and `responseType`).
 *
 * Note that the `responseType` *options* value is a String that identifies the
 * single data type of the response.
 * A single overload version of the method handles each response type.
 * The value of `responseType` cannot be a union, as the combined signature could imply.

 *
 * @usageNotes
 * Sample HTTP requests for the [Tour of Heroes](/tutorial/toh-pt0) application.
 *
 * ### HTTP Request Example
 *
 * ```
 *  // GET heroes whose name contains search term
 * searchHeroes(term: string): observable<Hero[]>{
 *
 *  const params = new HttpParams({fromString: 'name=term'});
 *    return this.httpClient.request('GET', this.heroesUrl, {responseType:'json', params});
 * }
 * ```
 * ### JSONP Example
 * ```
 * requestJsonp(url, callback = 'callback') {
 *  return this.httpClient.jsonp(this.heroesURL, callback);
 * }
 * ```
 *
 * ### PATCH Example
 * ```
 * // PATCH one of the heroes' name
 * patchHero (id: number, heroName: string): Observable<{}> {
 * const url = `${this.heroesUrl}/${id}`;   // PATCH api/heroes/42
 *  return this.httpClient.patch(url, {name: heroName}, httpOptions)
 *    .pipe(catchError(this.handleError('patchHero')));
 * }
 * ```
 *
 * @see [HTTP Guide](guide/http)
 *
 * @publicApi
 */


var HttpClient = /*#__PURE__*/function () {
  function HttpClient(handler) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpClient);

    this.handler = handler;
  }
  /**
   * Constructs an observable for a generic HTTP request that, when subscribed,
   * fires the request through the chain of registered interceptors and on to the
   * server.
   *
   * You can pass an `HttpRequest` directly as the only parameter. In this case,
   * the call returns an observable of the raw `HttpEvent` stream.
   *
   * Alternatively you can pass an HTTP method as the first parameter,
   * a URL string as the second, and an options hash containing the request body as the third.
   * See `addBody()`. In this case, the specified `responseType` and `observe` options determine the
   * type of returned observable.
   *   * The `responseType` value determines how a successful response body is parsed.
   *   * If `responseType` is the default `json`, you can pass a type interface for the resulting
   * object as a type parameter to the call.
   *
   * The `observe` value determines the return type, according to what you are interested in
   * observing.
   *   * An `observe` value of events returns an observable of the raw `HttpEvent` stream, including
   * progress events by default.
   *   * An `observe` value of response returns an observable of `HttpResponse<T>`,
   * where the `T` parameter depends on the `responseType` and any optionally provided type
   * parameter.
   *   * An `observe` value of body returns an observable of `<T>` with the same `T` body type.
   *
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpClient, [{
    key: "request",
    value: function request(first, url) {
      var _this11 = this;

      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var req; // First, check whether the primary argument is an instance of `HttpRequest`.

      if (first instanceof HttpRequest) {
        // It is. The other arguments must be undefined (per the signatures) and can be
        // ignored.
        req = first;
      } else {
        // It's a string, so it represents a URL. Construct a request based on it,
        // and incorporate the remaining arguments (assuming `GET` unless a method is
        // provided.
        // Figure out the headers.
        var headers = undefined;

        if (options.headers instanceof HttpHeaders) {
          headers = options.headers;
        } else {
          headers = new HttpHeaders(options.headers);
        } // Sort out parameters.


        var params = undefined;

        if (!!options.params) {
          if (options.params instanceof HttpParams) {
            params = options.params;
          } else {
            params = new HttpParams({
              fromObject: options.params
            });
          }
        } // Construct the request.


        req = new HttpRequest(first, url, options.body !== undefined ? options.body : null, {
          headers: headers,
          params: params,
          reportProgress: options.reportProgress,
          // By default, JSON is assumed to be returned for all calls.
          responseType: options.responseType || 'json',
          withCredentials: options.withCredentials
        });
      } // Start with an Observable.of() the initial request, and run the handler (which
      // includes all interceptors) inside a concatMap(). This way, the handler runs
      // inside an Observable chain, which causes interceptors to be re-run on every
      // subscription (this also makes retries re-run the handler, including interceptors).


      var events$ = Object(rxjs__WEBPACK_IMPORTED_MODULE_7__["of"])(req).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_8__["concatMap"])(function (req) {
        return _this11.handler.handle(req);
      })); // If coming via the API signature which accepts a previously constructed HttpRequest,
      // the only option is to get the event stream. Otherwise, return the event stream if
      // that is what was requested.

      if (first instanceof HttpRequest || options.observe === 'events') {
        return events$;
      } // The requested stream contains either the full response or the body. In either
      // case, the first step is to filter the event stream to extract a stream of
      // responses(s).


      var res$ = events$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_8__["filter"])(function (event) {
        return event instanceof HttpResponse;
      })); // Decide which stream to return.

      switch (options.observe || 'body') {
        case 'body':
          // The requested stream is the body. Map the response stream to the response
          // body. This could be done more simply, but a misbehaving interceptor might
          // transform the response body into a different format and ignore the requested
          // responseType. Guard against this by validating that the response is of the
          // requested type.
          switch (req.responseType) {
            case 'arraybuffer':
              return res$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_8__["map"])(function (res) {
                // Validate that the body is an ArrayBuffer.
                if (res.body !== null && !(res.body instanceof ArrayBuffer)) {
                  throw new Error('Response is not an ArrayBuffer.');
                }

                return res.body;
              }));

            case 'blob':
              return res$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_8__["map"])(function (res) {
                // Validate that the body is a Blob.
                if (res.body !== null && !(res.body instanceof Blob)) {
                  throw new Error('Response is not a Blob.');
                }

                return res.body;
              }));

            case 'text':
              return res$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_8__["map"])(function (res) {
                // Validate that the body is a string.
                if (res.body !== null && typeof res.body !== 'string') {
                  throw new Error('Response is not a string.');
                }

                return res.body;
              }));

            case 'json':
            default:
              // No validation needed for JSON responses, as they can be of any type.
              return res$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_8__["map"])(function (res) {
                return res.body;
              }));
          }

        case 'response':
          // The response stream was requested directly, so return it.
          return res$;

        default:
          // Guard against new future observe types being added.
          throw new Error("Unreachable: unhandled observe type ".concat(options.observe, "}"));
      }
    }
    /**
     * Constructs an observable that, when subscribed, causes the configured
     * `DELETE` request to execute on the server. See the individual overloads for
     * details on the return type.
     *
     * @param url     The endpoint URL.
     * @param options The HTTP options to send with the request.
     *
     */

  }, {
    key: "delete",
    value: function _delete(url) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      return this.request('DELETE', url, options);
    }
    /**
     * Constructs an observable that, when subscribed, causes the configured
     * `GET` request to execute on the server. See the individual overloads for
     * details on the return type.
     */

  }, {
    key: "get",
    value: function get(url) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      return this.request('GET', url, options);
    }
    /**
     * Constructs an observable that, when subscribed, causes the configured
     * `HEAD` request to execute on the server. The `HEAD` method returns
     * meta information about the resource without transferring the
     * resource itself. See the individual overloads for
     * details on the return type.
     */

  }, {
    key: "head",
    value: function head(url) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      return this.request('HEAD', url, options);
    }
    /**
     * Constructs an `Observable` that, when subscribed, causes a request with the special method
     * `JSONP` to be dispatched via the interceptor pipeline.
     * The [JSONP pattern](https://en.wikipedia.org/wiki/JSONP) works around limitations of certain
     * API endpoints that don't support newer,
     * and preferable [CORS](https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS) protocol.
     * JSONP treats the endpoint API as a JavaScript file and tricks the browser to process the
     * requests even if the API endpoint is not located on the same domain (origin) as the client-side
     * application making the request.
     * The endpoint API must support JSONP callback for JSONP requests to work.
     * The resource API returns the JSON response wrapped in a callback function.
     * You can pass the callback function name as one of the query parameters.
     * Note that JSONP requests can only be used with `GET` requests.
     *
     * @param url The resource URL.
     * @param callbackParam The callback function name.
     *
     */

  }, {
    key: "jsonp",
    value: function jsonp(url, callbackParam) {
      return this.request('JSONP', url, {
        params: new HttpParams().append(callbackParam, 'JSONP_CALLBACK'),
        observe: 'body',
        responseType: 'json'
      });
    }
    /**
     * Constructs an `Observable` that, when subscribed, causes the configured
     * `OPTIONS` request to execute on the server. This method allows the client
     * to determine the supported HTTP methods and other capabilites of an endpoint,
     * without implying a resource action. See the individual overloads for
     * details on the return type.
     */

  }, {
    key: "options",
    value: function options(url) {
      var _options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      return this.request('OPTIONS', url, _options);
    }
    /**
     * Constructs an observable that, when subscribed, causes the configured
     * `PATCH` request to execute on the server. See the individual overloads for
     * details on the return type.
     */

  }, {
    key: "patch",
    value: function patch(url, body) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      return this.request('PATCH', url, addBody(options, body));
    }
    /**
     * Constructs an observable that, when subscribed, causes the configured
     * `POST` request to execute on the server. The server responds with the location of
     * the replaced resource. See the individual overloads for
     * details on the return type.
     */

  }, {
    key: "post",
    value: function post(url, body) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      return this.request('POST', url, addBody(options, body));
    }
    /**
     * Constructs an observable that, when subscribed, causes the configured
     * `PUT` request to execute on the server. The `PUT` method replaces an existing resource
     * with a new set of values.
     * See the individual overloads for details on the return type.
     */

  }, {
    key: "put",
    value: function put(url, body) {
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      return this.request('PUT', url, addBody(options, body));
    }
  }]);

  return HttpClient;
}();

HttpClient.ɵfac = function HttpClient_Factory(t) {
  return new (t || HttpClient)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](HttpHandler));
};

HttpClient.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: HttpClient,
  factory: HttpClient.ɵfac
});

HttpClient.ctorParameters = function () {
  return [{
    type: HttpHandler
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpClient, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: HttpHandler
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * `HttpHandler` which applies an `HttpInterceptor` to an `HttpRequest`.
 *
 *
 */


var HttpInterceptorHandler = /*#__PURE__*/function () {
  function HttpInterceptorHandler(next, interceptor) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpInterceptorHandler);

    this.next = next;
    this.interceptor = interceptor;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpInterceptorHandler, [{
    key: "handle",
    value: function handle(req) {
      return this.interceptor.intercept(req, this.next);
    }
  }]);

  return HttpInterceptorHandler;
}();
/**
 * A multi-provider token that represents the array of registered
 * `HttpInterceptor` objects.
 *
 * @publicApi
 */


var HTTP_INTERCEPTORS = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('HTTP_INTERCEPTORS');

var NoopInterceptor = /*#__PURE__*/function () {
  function NoopInterceptor() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, NoopInterceptor);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(NoopInterceptor, [{
    key: "intercept",
    value: function intercept(req, next) {
      return next.handle(req);
    }
  }]);

  return NoopInterceptor;
}();

NoopInterceptor.ɵfac = function NoopInterceptor_Factory(t) {
  return new (t || NoopInterceptor)();
};

NoopInterceptor.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: NoopInterceptor,
  factory: NoopInterceptor.ɵfac
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](NoopInterceptor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// Every request made through JSONP needs a callback name that's unique across the
// whole page. Each request is assigned an id and the callback name is constructed
// from that. The next id to be assigned is tracked in a global variable here that
// is shared among all applications on the page.


var nextRequestId = 0; // Error text given when a JSONP script is injected, but doesn't invoke the callback
// passed in its URL.

var JSONP_ERR_NO_CALLBACK = 'JSONP injected script did not invoke callback.'; // Error text given when a request is passed to the JsonpClientBackend that doesn't
// have a request method JSONP.

var JSONP_ERR_WRONG_METHOD = 'JSONP requests must use JSONP request method.';
var JSONP_ERR_WRONG_RESPONSE_TYPE = 'JSONP requests must use Json response type.';
/**
 * DI token/abstract type representing a map of JSONP callbacks.
 *
 * In the browser, this should always be the `window` object.
 *
 *
 */

var JsonpCallbackContext = function JsonpCallbackContext() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, JsonpCallbackContext);
};
/**
 * Processes an `HttpRequest` with the JSONP method,
 * by performing JSONP style requests.
 * @see `HttpHandler`
 * @see `HttpXhrBackend`
 *
 * @publicApi
 */


var JsonpClientBackend = /*#__PURE__*/function () {
  function JsonpClientBackend(callbackMap, document) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, JsonpClientBackend);

    this.callbackMap = callbackMap;
    this.document = document;
  }
  /**
   * Get the name of the next callback method, by incrementing the global `nextRequestId`.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(JsonpClientBackend, [{
    key: "nextCallback",
    value: function nextCallback() {
      return "ng_jsonp_callback_".concat(nextRequestId++);
    }
    /**
     * Processes a JSONP request and returns an event stream of the results.
     * @param req The request object.
     * @returns An observable of the response events.
     *
     */

  }, {
    key: "handle",
    value: function handle(req) {
      var _this12 = this;

      // Firstly, check both the method and response type. If either doesn't match
      // then the request was improperly routed here and cannot be handled.
      if (req.method !== 'JSONP') {
        throw new Error(JSONP_ERR_WRONG_METHOD);
      } else if (req.responseType !== 'json') {
        throw new Error(JSONP_ERR_WRONG_RESPONSE_TYPE);
      } // Everything else happens inside the Observable boundary.


      return new rxjs__WEBPACK_IMPORTED_MODULE_7__["Observable"](function (observer) {
        // The first step to make a request is to generate the callback name, and replace the
        // callback placeholder in the URL with the name. Care has to be taken here to ensure
        // a trailing &, if matched, gets inserted back into the URL in the correct place.
        var callback = _this12.nextCallback();

        var url = req.urlWithParams.replace(/=JSONP_CALLBACK(&|$)/, "=".concat(callback, "$1")); // Construct the <script> tag and point it at the URL.

        var node = _this12.document.createElement('script');

        node.src = url; // A JSONP request requires waiting for multiple callbacks. These variables
        // are closed over and track state across those callbacks.
        // The response object, if one has been received, or null otherwise.

        var body = null; // Whether the response callback has been called.

        var finished = false; // Whether the request has been cancelled (and thus any other callbacks)
        // should be ignored.

        var cancelled = false; // Set the response callback in this.callbackMap (which will be the window
        // object in the browser. The script being loaded via the <script> tag will
        // eventually call this callback.

        _this12.callbackMap[callback] = function (data) {
          // Data has been received from the JSONP script. Firstly, delete this callback.
          delete _this12.callbackMap[callback]; // Next, make sure the request wasn't cancelled in the meantime.

          if (cancelled) {
            return;
          } // Set state to indicate data was received.


          body = data;
          finished = true;
        }; // cleanup() is a utility closure that removes the <script> from the page and
        // the response callback from the window. This logic is used in both the
        // success, error, and cancellation paths, so it's extracted out for convenience.


        var cleanup = function cleanup() {
          // Remove the <script> tag if it's still on the page.
          if (node.parentNode) {
            node.parentNode.removeChild(node);
          } // Remove the response callback from the callbackMap (window object in the
          // browser).


          delete _this12.callbackMap[callback];
        }; // onLoad() is the success callback which runs after the response callback
        // if the JSONP script loads successfully. The event itself is unimportant.
        // If something went wrong, onLoad() may run without the response callback
        // having been invoked.


        var onLoad = function onLoad(event) {
          // Do nothing if the request has been cancelled.
          if (cancelled) {
            return;
          } // Cleanup the page.


          cleanup(); // Check whether the response callback has run.

          if (!finished) {
            // It hasn't, something went wrong with the request. Return an error via
            // the Observable error path. All JSONP errors have status 0.
            observer.error(new HttpErrorResponse({
              url: url,
              status: 0,
              statusText: 'JSONP Error',
              error: new Error(JSONP_ERR_NO_CALLBACK)
            }));
            return;
          } // Success. body either contains the response body or null if none was
          // returned.


          observer.next(new HttpResponse({
            body: body,
            status: 200,
            statusText: 'OK',
            url: url
          })); // Complete the stream, the response is over.

          observer.complete();
        }; // onError() is the error callback, which runs if the script returned generates
        // a Javascript error. It emits the error via the Observable error channel as
        // a HttpErrorResponse.


        var onError = function onError(error) {
          // If the request was already cancelled, no need to emit anything.
          if (cancelled) {
            return;
          }

          cleanup(); // Wrap the error in a HttpErrorResponse.

          observer.error(new HttpErrorResponse({
            error: error,
            status: 0,
            statusText: 'JSONP Error',
            url: url
          }));
        }; // Subscribe to both the success (load) and error events on the <script> tag,
        // and add it to the page.


        node.addEventListener('load', onLoad);
        node.addEventListener('error', onError);

        _this12.document.body.appendChild(node); // The request has now been successfully sent.


        observer.next({
          type: HttpEventType.Sent
        }); // Cancellation handler.

        return function () {
          // Track the cancellation so event listeners won't do anything even if already scheduled.
          cancelled = true; // Remove the event listeners so they won't run if the events later fire.

          node.removeEventListener('load', onLoad);
          node.removeEventListener('error', onError); // And finally, clean up the page.

          cleanup();
        };
      });
    }
  }]);

  return JsonpClientBackend;
}();

JsonpClientBackend.ɵfac = function JsonpClientBackend_Factory(t) {
  return new (t || JsonpClientBackend)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](JsonpCallbackContext), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_9__["DOCUMENT"]));
};

JsonpClientBackend.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: JsonpClientBackend,
  factory: JsonpClientBackend.ɵfac
});

JsonpClientBackend.ctorParameters = function () {
  return [{
    type: JsonpCallbackContext
  }, {
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_9__["DOCUMENT"]]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](JsonpClientBackend, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: JsonpCallbackContext
    }, {
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_9__["DOCUMENT"]]
      }]
    }];
  }, null);
})();
/**
 * Identifies requests with the method JSONP and
 * shifts them to the `JsonpClientBackend`.
 *
 * @see `HttpInterceptor`
 *
 * @publicApi
 */


var JsonpInterceptor = /*#__PURE__*/function () {
  function JsonpInterceptor(jsonp) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, JsonpInterceptor);

    this.jsonp = jsonp;
  }
  /**
   * Identifies and handles a given JSONP request.
   * @param req The outgoing request object to handle.
   * @param next The next interceptor in the chain, or the backend
   * if no interceptors remain in the chain.
   * @returns An observable of the event stream.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(JsonpInterceptor, [{
    key: "intercept",
    value: function intercept(req, next) {
      if (req.method === 'JSONP') {
        return this.jsonp.handle(req);
      } // Fall through for normal HTTP requests.


      return next.handle(req);
    }
  }]);

  return JsonpInterceptor;
}();

JsonpInterceptor.ɵfac = function JsonpInterceptor_Factory(t) {
  return new (t || JsonpInterceptor)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](JsonpClientBackend));
};

JsonpInterceptor.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: JsonpInterceptor,
  factory: JsonpInterceptor.ɵfac
});

JsonpInterceptor.ctorParameters = function () {
  return [{
    type: JsonpClientBackend
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](JsonpInterceptor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: JsonpClientBackend
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var XSSI_PREFIX = /^\)\]\}',?\n/;
/**
 * Determine an appropriate URL for the response, by checking either
 * XMLHttpRequest.responseURL or the X-Request-URL header.
 */

function getResponseUrl(xhr) {
  if ('responseURL' in xhr && xhr.responseURL) {
    return xhr.responseURL;
  }

  if (/^X-Request-URL:/m.test(xhr.getAllResponseHeaders())) {
    return xhr.getResponseHeader('X-Request-URL');
  }

  return null;
}
/**
 * A wrapper around the `XMLHttpRequest` constructor.
 *
 * @publicApi
 */


var XhrFactory = function XhrFactory() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, XhrFactory);
};
/**
 * A factory for `HttpXhrBackend` that uses the `XMLHttpRequest` browser API.
 *
 */


var BrowserXhr = /*#__PURE__*/function () {
  function BrowserXhr() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, BrowserXhr);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(BrowserXhr, [{
    key: "build",
    value: function build() {
      return new XMLHttpRequest();
    }
  }]);

  return BrowserXhr;
}();

BrowserXhr.ɵfac = function BrowserXhr_Factory(t) {
  return new (t || BrowserXhr)();
};

BrowserXhr.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: BrowserXhr,
  factory: BrowserXhr.ɵfac
});

BrowserXhr.ctorParameters = function () {
  return [];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](BrowserXhr, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [];
  }, null);
})();
/**
 * Uses `XMLHttpRequest` to send requests to a backend server.
 * @see `HttpHandler`
 * @see `JsonpClientBackend`
 *
 * @publicApi
 */


var HttpXhrBackend = /*#__PURE__*/function () {
  function HttpXhrBackend(xhrFactory) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpXhrBackend);

    this.xhrFactory = xhrFactory;
  }
  /**
   * Processes a request and returns a stream of response events.
   * @param req The request object.
   * @returns An observable of the response events.
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpXhrBackend, [{
    key: "handle",
    value: function handle(req) {
      var _this13 = this;

      // Quick check to give a better error message when a user attempts to use
      // HttpClient.jsonp() without installing the HttpClientJsonpModule
      if (req.method === 'JSONP') {
        throw new Error("Attempted to construct Jsonp request without HttpClientJsonpModule installed.");
      } // Everything happens on Observable subscription.


      return new rxjs__WEBPACK_IMPORTED_MODULE_7__["Observable"](function (observer) {
        // Start by setting up the XHR object with request method, URL, and withCredentials flag.
        var xhr = _this13.xhrFactory.build();

        xhr.open(req.method, req.urlWithParams);

        if (!!req.withCredentials) {
          xhr.withCredentials = true;
        } // Add all the requested headers.


        req.headers.forEach(function (name, values) {
          return xhr.setRequestHeader(name, values.join(','));
        }); // Add an Accept header if one isn't present already.

        if (!req.headers.has('Accept')) {
          xhr.setRequestHeader('Accept', 'application/json, text/plain, */*');
        } // Auto-detect the Content-Type header if one isn't present already.


        if (!req.headers.has('Content-Type')) {
          var detectedType = req.detectContentTypeHeader(); // Sometimes Content-Type detection fails.

          if (detectedType !== null) {
            xhr.setRequestHeader('Content-Type', detectedType);
          }
        } // Set the responseType if one was requested.


        if (req.responseType) {
          var responseType = req.responseType.toLowerCase(); // JSON responses need to be processed as text. This is because if the server
          // returns an XSSI-prefixed JSON response, the browser will fail to parse it,
          // xhr.response will be null, and xhr.responseText cannot be accessed to
          // retrieve the prefixed JSON data in order to strip the prefix. Thus, all JSON
          // is parsed by first requesting text and then applying JSON.parse.

          xhr.responseType = responseType !== 'json' ? responseType : 'text';
        } // Serialize the request body if one is present. If not, this will be set to null.


        var reqBody = req.serializeBody(); // If progress events are enabled, response headers will be delivered
        // in two events - the HttpHeaderResponse event and the full HttpResponse
        // event. However, since response headers don't change in between these
        // two events, it doesn't make sense to parse them twice. So headerResponse
        // caches the data extracted from the response whenever it's first parsed,
        // to ensure parsing isn't duplicated.

        var headerResponse = null; // partialFromXhr extracts the HttpHeaderResponse from the current XMLHttpRequest
        // state, and memoizes it into headerResponse.

        var partialFromXhr = function partialFromXhr() {
          if (headerResponse !== null) {
            return headerResponse;
          } // Read status and normalize an IE9 bug (http://bugs.jquery.com/ticket/1450).


          var status = xhr.status === 1223 ? 204 : xhr.status;
          var statusText = xhr.statusText || 'OK'; // Parse headers from XMLHttpRequest - this step is lazy.

          var headers = new HttpHeaders(xhr.getAllResponseHeaders()); // Read the response URL from the XMLHttpResponse instance and fall back on the
          // request URL.

          var url = getResponseUrl(xhr) || req.url; // Construct the HttpHeaderResponse and memoize it.

          headerResponse = new HttpHeaderResponse({
            headers: headers,
            status: status,
            statusText: statusText,
            url: url
          });
          return headerResponse;
        }; // Next, a few closures are defined for the various events which XMLHttpRequest can
        // emit. This allows them to be unregistered as event listeners later.
        // First up is the load event, which represents a response being fully available.


        var onLoad = function onLoad() {
          // Read response state from the memoized partial data.
          var _partialFromXhr = partialFromXhr(),
              headers = _partialFromXhr.headers,
              status = _partialFromXhr.status,
              statusText = _partialFromXhr.statusText,
              url = _partialFromXhr.url; // The body will be read out if present.


          var body = null;

          if (status !== 204) {
            // Use XMLHttpRequest.response if set, responseText otherwise.
            body = typeof xhr.response === 'undefined' ? xhr.responseText : xhr.response;
          } // Normalize another potential bug (this one comes from CORS).


          if (status === 0) {
            status = !!body ? 200 : 0;
          } // ok determines whether the response will be transmitted on the event or
          // error channel. Unsuccessful status codes (not 2xx) will always be errors,
          // but a successful status code can still result in an error if the user
          // asked for JSON data and the body cannot be parsed as such.


          var ok = status >= 200 && status < 300; // Check whether the body needs to be parsed as JSON (in many cases the browser
          // will have done that already).

          if (req.responseType === 'json' && typeof body === 'string') {
            // Save the original body, before attempting XSSI prefix stripping.
            var originalBody = body;
            body = body.replace(XSSI_PREFIX, '');

            try {
              // Attempt the parse. If it fails, a parse error should be delivered to the user.
              body = body !== '' ? JSON.parse(body) : null;
            } catch (error) {
              // Since the JSON.parse failed, it's reasonable to assume this might not have been a
              // JSON response. Restore the original body (including any XSSI prefix) to deliver
              // a better error response.
              body = originalBody; // If this was an error request to begin with, leave it as a string, it probably
              // just isn't JSON. Otherwise, deliver the parsing error to the user.

              if (ok) {
                // Even though the response status was 2xx, this is still an error.
                ok = false; // The parse error contains the text of the body that failed to parse.

                body = {
                  error: error,
                  text: body
                };
              }
            }
          }

          if (ok) {
            // A successful response is delivered on the event stream.
            observer.next(new HttpResponse({
              body: body,
              headers: headers,
              status: status,
              statusText: statusText,
              url: url || undefined
            })); // The full body has been received and delivered, no further events
            // are possible. This request is complete.

            observer.complete();
          } else {
            // An unsuccessful request is delivered on the error channel.
            observer.error(new HttpErrorResponse({
              // The error in this case is the response body (error from the server).
              error: body,
              headers: headers,
              status: status,
              statusText: statusText,
              url: url || undefined
            }));
          }
        }; // The onError callback is called when something goes wrong at the network level.
        // Connection timeout, DNS error, offline, etc. These are actual errors, and are
        // transmitted on the error channel.


        var onError = function onError(error) {
          var _partialFromXhr2 = partialFromXhr(),
              url = _partialFromXhr2.url;

          var res = new HttpErrorResponse({
            error: error,
            status: xhr.status || 0,
            statusText: xhr.statusText || 'Unknown Error',
            url: url || undefined
          });
          observer.error(res);
        }; // The sentHeaders flag tracks whether the HttpResponseHeaders event
        // has been sent on the stream. This is necessary to track if progress
        // is enabled since the event will be sent on only the first download
        // progerss event.


        var sentHeaders = false; // The download progress event handler, which is only registered if
        // progress events are enabled.

        var onDownProgress = function onDownProgress(event) {
          // Send the HttpResponseHeaders event if it hasn't been sent already.
          if (!sentHeaders) {
            observer.next(partialFromXhr());
            sentHeaders = true;
          } // Start building the download progress event to deliver on the response
          // event stream.


          var progressEvent = {
            type: HttpEventType.DownloadProgress,
            loaded: event.loaded
          }; // Set the total number of bytes in the event if it's available.

          if (event.lengthComputable) {
            progressEvent.total = event.total;
          } // If the request was for text content and a partial response is
          // available on XMLHttpRequest, include it in the progress event
          // to allow for streaming reads.


          if (req.responseType === 'text' && !!xhr.responseText) {
            progressEvent.partialText = xhr.responseText;
          } // Finally, fire the event.


          observer.next(progressEvent);
        }; // The upload progress event handler, which is only registered if
        // progress events are enabled.


        var onUpProgress = function onUpProgress(event) {
          // Upload progress events are simpler. Begin building the progress
          // event.
          var progress = {
            type: HttpEventType.UploadProgress,
            loaded: event.loaded
          }; // If the total number of bytes being uploaded is available, include
          // it.

          if (event.lengthComputable) {
            progress.total = event.total;
          } // Send the event.


          observer.next(progress);
        }; // By default, register for load and error events.


        xhr.addEventListener('load', onLoad);
        xhr.addEventListener('error', onError); // Progress events are only enabled if requested.

        if (req.reportProgress) {
          // Download progress is always enabled if requested.
          xhr.addEventListener('progress', onDownProgress); // Upload progress depends on whether there is a body to upload.

          if (reqBody !== null && xhr.upload) {
            xhr.upload.addEventListener('progress', onUpProgress);
          }
        } // Fire the request, and notify the event stream that it was fired.


        xhr.send(reqBody);
        observer.next({
          type: HttpEventType.Sent
        }); // This is the return from the Observable function, which is the
        // request cancellation handler.

        return function () {
          // On a cancellation, remove all registered event listeners.
          xhr.removeEventListener('error', onError);
          xhr.removeEventListener('load', onLoad);

          if (req.reportProgress) {
            xhr.removeEventListener('progress', onDownProgress);

            if (reqBody !== null && xhr.upload) {
              xhr.upload.removeEventListener('progress', onUpProgress);
            }
          } // Finally, abort the in-flight request.


          if (xhr.readyState !== xhr.DONE) {
            xhr.abort();
          }
        };
      });
    }
  }]);

  return HttpXhrBackend;
}();

HttpXhrBackend.ɵfac = function HttpXhrBackend_Factory(t) {
  return new (t || HttpXhrBackend)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](XhrFactory));
};

HttpXhrBackend.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: HttpXhrBackend,
  factory: HttpXhrBackend.ɵfac
});

HttpXhrBackend.ctorParameters = function () {
  return [{
    type: XhrFactory
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpXhrBackend, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: XhrFactory
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var XSRF_COOKIE_NAME = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('XSRF_COOKIE_NAME');
var XSRF_HEADER_NAME = new _angular_core__WEBPACK_IMPORTED_MODULE_6__["InjectionToken"]('XSRF_HEADER_NAME');
/**
 * Retrieves the current XSRF token to use with the next outgoing request.
 *
 * @publicApi
 */

var HttpXsrfTokenExtractor = function HttpXsrfTokenExtractor() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpXsrfTokenExtractor);
};
/**
 * `HttpXsrfTokenExtractor` which retrieves the token from a cookie.
 */


var HttpXsrfCookieExtractor = /*#__PURE__*/function () {
  function HttpXsrfCookieExtractor(doc, platform, cookieName) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpXsrfCookieExtractor);

    this.doc = doc;
    this.platform = platform;
    this.cookieName = cookieName;
    this.lastCookieString = '';
    this.lastToken = null;
    /**
     * @internal for testing
     */

    this.parseCount = 0;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpXsrfCookieExtractor, [{
    key: "getToken",
    value: function getToken() {
      if (this.platform === 'server') {
        return null;
      }

      var cookieString = this.doc.cookie || '';

      if (cookieString !== this.lastCookieString) {
        this.parseCount++;
        this.lastToken = Object(_angular_common__WEBPACK_IMPORTED_MODULE_9__["ɵparseCookieValue"])(cookieString, this.cookieName);
        this.lastCookieString = cookieString;
      }

      return this.lastToken;
    }
  }]);

  return HttpXsrfCookieExtractor;
}();

HttpXsrfCookieExtractor.ɵfac = function HttpXsrfCookieExtractor_Factory(t) {
  return new (t || HttpXsrfCookieExtractor)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_9__["DOCUMENT"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["PLATFORM_ID"]), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](XSRF_COOKIE_NAME));
};

HttpXsrfCookieExtractor.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: HttpXsrfCookieExtractor,
  factory: HttpXsrfCookieExtractor.ɵfac
});

HttpXsrfCookieExtractor.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_common__WEBPACK_IMPORTED_MODULE_9__["DOCUMENT"]]
    }]
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["PLATFORM_ID"]]
    }]
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [XSRF_COOKIE_NAME]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpXsrfCookieExtractor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_common__WEBPACK_IMPORTED_MODULE_9__["DOCUMENT"]]
      }]
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [_angular_core__WEBPACK_IMPORTED_MODULE_6__["PLATFORM_ID"]]
      }]
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [XSRF_COOKIE_NAME]
      }]
    }];
  }, null);
})();
/**
 * `HttpInterceptor` which adds an XSRF token to eligible outgoing requests.
 */


var HttpXsrfInterceptor = /*#__PURE__*/function () {
  function HttpXsrfInterceptor(tokenService, headerName) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpXsrfInterceptor);

    this.tokenService = tokenService;
    this.headerName = headerName;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpXsrfInterceptor, [{
    key: "intercept",
    value: function intercept(req, next) {
      var lcUrl = req.url.toLowerCase(); // Skip both non-mutating requests and absolute URLs.
      // Non-mutating requests don't require a token, and absolute URLs require special handling
      // anyway as the cookie set
      // on our origin is not the same as the token expected by another origin.

      if (req.method === 'GET' || req.method === 'HEAD' || lcUrl.startsWith('http://') || lcUrl.startsWith('https://')) {
        return next.handle(req);
      }

      var token = this.tokenService.getToken(); // Be careful not to overwrite an existing header of the same name.

      if (token !== null && !req.headers.has(this.headerName)) {
        req = req.clone({
          headers: req.headers.set(this.headerName, token)
        });
      }

      return next.handle(req);
    }
  }]);

  return HttpXsrfInterceptor;
}();

HttpXsrfInterceptor.ɵfac = function HttpXsrfInterceptor_Factory(t) {
  return new (t || HttpXsrfInterceptor)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](HttpXsrfTokenExtractor), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](XSRF_HEADER_NAME));
};

HttpXsrfInterceptor.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: HttpXsrfInterceptor,
  factory: HttpXsrfInterceptor.ɵfac
});

HttpXsrfInterceptor.ctorParameters = function () {
  return [{
    type: HttpXsrfTokenExtractor
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
      args: [XSRF_HEADER_NAME]
    }]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpXsrfInterceptor, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: HttpXsrfTokenExtractor
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Inject"],
        args: [XSRF_HEADER_NAME]
      }]
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * An injectable `HttpHandler` that applies multiple interceptors
 * to a request before passing it to the given `HttpBackend`.
 *
 * The interceptors are loaded lazily from the injector, to allow
 * interceptors to themselves inject classes depending indirectly
 * on `HttpInterceptingHandler` itself.
 * @see `HttpInterceptor`
 */


var HttpInterceptingHandler = /*#__PURE__*/function () {
  function HttpInterceptingHandler(backend, injector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpInterceptingHandler);

    this.backend = backend;
    this.injector = injector;
    this.chain = null;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpInterceptingHandler, [{
    key: "handle",
    value: function handle(req) {
      if (this.chain === null) {
        var interceptors = this.injector.get(HTTP_INTERCEPTORS, []);
        this.chain = interceptors.reduceRight(function (next, interceptor) {
          return new HttpInterceptorHandler(next, interceptor);
        }, this.backend);
      }

      return this.chain.handle(req);
    }
  }]);

  return HttpInterceptingHandler;
}();

HttpInterceptingHandler.ɵfac = function HttpInterceptingHandler_Factory(t) {
  return new (t || HttpInterceptingHandler)(_angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](HttpBackend), _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_6__["Injector"]));
};

HttpInterceptingHandler.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjectable"]({
  token: HttpInterceptingHandler,
  factory: HttpInterceptingHandler.ɵfac
});

HttpInterceptingHandler.ctorParameters = function () {
  return [{
    type: HttpBackend
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injector"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpInterceptingHandler, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injectable"]
  }], function () {
    return [{
      type: HttpBackend
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["Injector"]
    }];
  }, null);
})();
/**
 * Constructs an `HttpHandler` that applies interceptors
 * to a request before passing it to the given `HttpBackend`.
 *
 * Use as a factory function within `HttpClientModule`.
 *
 *
 */


function interceptingHandler(backend) {
  var interceptors = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  if (!interceptors) {
    return backend;
  }

  return interceptors.reduceRight(function (next, interceptor) {
    return new HttpInterceptorHandler(next, interceptor);
  }, backend);
}
/**
 * Factory function that determines where to store JSONP callbacks.
 *
 * Ordinarily JSONP callbacks are stored on the `window` object, but this may not exist
 * in test environments. In that case, callbacks are stored on an anonymous object instead.
 *
 *
 */


function jsonpCallbackContext() {
  if (typeof window === 'object') {
    return window;
  }

  return {};
}
/**
 * Configures XSRF protection support for outgoing requests.
 *
 * For a server that supports a cookie-based XSRF protection system,
 * use directly to configure XSRF protection with the correct
 * cookie and header names.
 *
 * If no names are supplied, the default cookie name is `XSRF-TOKEN`
 * and the default header name is `X-XSRF-TOKEN`.
 *
 * @publicApi
 */


var HttpClientXsrfModule = /*#__PURE__*/function () {
  function HttpClientXsrfModule() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpClientXsrfModule);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(HttpClientXsrfModule, null, [{
    key: "disable",

    /**
     * Disable the default XSRF protection.
     */
    value: function disable() {
      return {
        ngModule: HttpClientXsrfModule,
        providers: [{
          provide: HttpXsrfInterceptor,
          useClass: NoopInterceptor
        }]
      };
    }
    /**
     * Configure XSRF protection.
     * @param options An object that can specify either or both
     * cookie name or header name.
     * - Cookie name default is `XSRF-TOKEN`.
     * - Header name default is `X-XSRF-TOKEN`.
     *
     */

  }, {
    key: "withOptions",
    value: function withOptions() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return {
        ngModule: HttpClientXsrfModule,
        providers: [options.cookieName ? {
          provide: XSRF_COOKIE_NAME,
          useValue: options.cookieName
        } : [], options.headerName ? {
          provide: XSRF_HEADER_NAME,
          useValue: options.headerName
        } : []]
      };
    }
  }]);

  return HttpClientXsrfModule;
}();

HttpClientXsrfModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineNgModule"]({
  type: HttpClientXsrfModule
});
HttpClientXsrfModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjector"]({
  factory: function HttpClientXsrfModule_Factory(t) {
    return new (t || HttpClientXsrfModule)();
  },
  providers: [HttpXsrfInterceptor, {
    provide: HTTP_INTERCEPTORS,
    useExisting: HttpXsrfInterceptor,
    multi: true
  }, {
    provide: HttpXsrfTokenExtractor,
    useClass: HttpXsrfCookieExtractor
  }, {
    provide: XSRF_COOKIE_NAME,
    useValue: 'XSRF-TOKEN'
  }, {
    provide: XSRF_HEADER_NAME,
    useValue: 'X-XSRF-TOKEN'
  }]
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpClientXsrfModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModule"],
    args: [{
      providers: [HttpXsrfInterceptor, {
        provide: HTTP_INTERCEPTORS,
        useExisting: HttpXsrfInterceptor,
        multi: true
      }, {
        provide: HttpXsrfTokenExtractor,
        useClass: HttpXsrfCookieExtractor
      }, {
        provide: XSRF_COOKIE_NAME,
        useValue: 'XSRF-TOKEN'
      }, {
        provide: XSRF_HEADER_NAME,
        useValue: 'X-XSRF-TOKEN'
      }]
    }]
  }], null, null);
})();
/**
 * Configures the [dependency injector](guide/glossary#injector) for `HttpClient`
 * with supporting services for XSRF. Automatically imported by `HttpClientModule`.
 *
 * You can add interceptors to the chain behind `HttpClient` by binding them to the
 * multiprovider for built-in [DI token](guide/glossary#di-token) `HTTP_INTERCEPTORS`.
 *
 * @publicApi
 */


var HttpClientModule = function HttpClientModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpClientModule);
};

HttpClientModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineNgModule"]({
  type: HttpClientModule
});
HttpClientModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjector"]({
  factory: function HttpClientModule_Factory(t) {
    return new (t || HttpClientModule)();
  },
  providers: [HttpClient, {
    provide: HttpHandler,
    useClass: HttpInterceptingHandler
  }, HttpXhrBackend, {
    provide: HttpBackend,
    useExisting: HttpXhrBackend
  }, BrowserXhr, {
    provide: XhrFactory,
    useExisting: BrowserXhr
  }],
  imports: [[HttpClientXsrfModule.withOptions({
    cookieName: 'XSRF-TOKEN',
    headerName: 'X-XSRF-TOKEN'
  })]]
});

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵsetNgModuleScope"](HttpClientModule, {
    imports: [HttpClientXsrfModule]
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpClientModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModule"],
    args: [{
      /**
       * Optional configuration for XSRF protection.
       */
      imports: [HttpClientXsrfModule.withOptions({
        cookieName: 'XSRF-TOKEN',
        headerName: 'X-XSRF-TOKEN'
      })],

      /**
       * Configures the [dependency injector](guide/glossary#injector) where it is imported
       * with supporting services for HTTP communications.
       */
      providers: [HttpClient, {
        provide: HttpHandler,
        useClass: HttpInterceptingHandler
      }, HttpXhrBackend, {
        provide: HttpBackend,
        useExisting: HttpXhrBackend
      }, BrowserXhr, {
        provide: XhrFactory,
        useExisting: BrowserXhr
      }]
    }]
  }], null, null);
})();
/**
 * Configures the [dependency injector](guide/glossary#injector) for `HttpClient`
 * with supporting services for JSONP.
 * Without this module, Jsonp requests reach the backend
 * with method JSONP, where they are rejected.
 *
 * You can add interceptors to the chain behind `HttpClient` by binding them to the
 * multiprovider for built-in [DI token](guide/glossary#di-token) `HTTP_INTERCEPTORS`.
 *
 * @publicApi
 */


var HttpClientJsonpModule = function HttpClientJsonpModule() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, HttpClientJsonpModule);
};

HttpClientJsonpModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineNgModule"]({
  type: HttpClientJsonpModule
});
HttpClientJsonpModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵɵdefineInjector"]({
  factory: function HttpClientJsonpModule_Factory(t) {
    return new (t || HttpClientJsonpModule)();
  },
  providers: [JsonpClientBackend, {
    provide: JsonpCallbackContext,
    useFactory: jsonpCallbackContext
  }, {
    provide: HTTP_INTERCEPTORS,
    useClass: JsonpInterceptor,
    multi: true
  }]
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_6__["ɵsetClassMetadata"](HttpClientJsonpModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_6__["NgModule"],
    args: [{
      providers: [JsonpClientBackend, {
        provide: JsonpCallbackContext,
        useFactory: jsonpCallbackContext
      }, {
        provide: HTTP_INTERCEPTORS,
        useClass: JsonpInterceptor,
        multi: true
      }]
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */




/***/ }),

/***/ "tnsW":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/audit.js ***!
  \****************************************************************/
/*! exports provided: audit */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "audit", function() { return audit; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





function audit(durationSelector) {
  return function auditOperatorFunction(source) {
    return source.lift(new AuditOperator(durationSelector));
  };
}

var AuditOperator = /*#__PURE__*/function () {
  function AuditOperator(durationSelector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, AuditOperator);

    this.durationSelector = durationSelector;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(AuditOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new AuditSubscriber(subscriber, this.durationSelector));
    }
  }]);

  return AuditOperator;
}();

var AuditSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(AuditSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(AuditSubscriber);

  function AuditSubscriber(destination, durationSelector) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, AuditSubscriber);

    _this = _super.call(this, destination);
    _this.durationSelector = durationSelector;
    _this.hasValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(AuditSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.value = value;
      this.hasValue = true;

      if (!this.throttled) {
        var duration;

        try {
          var durationSelector = this.durationSelector;
          duration = durationSelector(value);
        } catch (err) {
          return this.destination.error(err);
        }

        var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(duration, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](this));

        if (!innerSubscription || innerSubscription.closed) {
          this.clearThrottle();
        } else {
          this.add(this.throttled = innerSubscription);
        }
      }
    }
  }, {
    key: "clearThrottle",
    value: function clearThrottle() {
      var value = this.value,
          hasValue = this.hasValue,
          throttled = this.throttled;

      if (throttled) {
        this.remove(throttled);
        this.throttled = undefined;
        throttled.unsubscribe();
      }

      if (hasValue) {
        this.value = undefined;
        this.hasValue = false;
        this.destination.next(value);
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      this.clearThrottle();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.clearThrottle();
    }
  }]);

  return AuditSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "tyNb":
/*!**********************************************************************!*\
  !*** ./node_modules/@angular/router/__ivy_ngcc__/fesm2015/router.js ***!
  \**********************************************************************/
/*! exports provided: ActivatedRoute, ActivatedRouteSnapshot, ActivationEnd, ActivationStart, BaseRouteReuseStrategy, ChildActivationEnd, ChildActivationStart, ChildrenOutletContexts, DefaultUrlSerializer, GuardsCheckEnd, GuardsCheckStart, NavigationCancel, NavigationEnd, NavigationError, NavigationStart, NoPreloading, OutletContext, PRIMARY_OUTLET, PreloadAllModules, PreloadingStrategy, ROUTER_CONFIGURATION, ROUTER_INITIALIZER, ROUTES, ResolveEnd, ResolveStart, RouteConfigLoadEnd, RouteConfigLoadStart, RouteReuseStrategy, Router, RouterEvent, RouterLink, RouterLinkActive, RouterLinkWithHref, RouterModule, RouterOutlet, RouterPreloader, RouterState, RouterStateSnapshot, RoutesRecognized, Scroll, UrlHandlingStrategy, UrlSegment, UrlSegmentGroup, UrlSerializer, UrlTree, VERSION, convertToParamMap, provideRoutes, ɵEmptyOutletComponent, ɵROUTER_PROVIDERS, ɵangular_packages_router_router_a, ɵangular_packages_router_router_b, ɵangular_packages_router_router_c, ɵangular_packages_router_router_d, ɵangular_packages_router_router_e, ɵangular_packages_router_router_f, ɵangular_packages_router_router_g, ɵangular_packages_router_router_h, ɵangular_packages_router_router_i, ɵangular_packages_router_router_j, ɵangular_packages_router_router_k, ɵangular_packages_router_router_l, ɵangular_packages_router_router_m, ɵangular_packages_router_router_n, ɵangular_packages_router_router_o, ɵflatten */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ActivatedRoute", function() { return ActivatedRoute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ActivatedRouteSnapshot", function() { return ActivatedRouteSnapshot; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ActivationEnd", function() { return ActivationEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ActivationStart", function() { return ActivationStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "BaseRouteReuseStrategy", function() { return BaseRouteReuseStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ChildActivationEnd", function() { return ChildActivationEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ChildActivationStart", function() { return ChildActivationStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ChildrenOutletContexts", function() { return ChildrenOutletContexts; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "DefaultUrlSerializer", function() { return DefaultUrlSerializer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "GuardsCheckEnd", function() { return GuardsCheckEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "GuardsCheckStart", function() { return GuardsCheckStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NavigationCancel", function() { return NavigationCancel; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NavigationEnd", function() { return NavigationEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NavigationError", function() { return NavigationError; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NavigationStart", function() { return NavigationStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "NoPreloading", function() { return NoPreloading; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "OutletContext", function() { return OutletContext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PRIMARY_OUTLET", function() { return PRIMARY_OUTLET; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PreloadAllModules", function() { return PreloadAllModules; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "PreloadingStrategy", function() { return PreloadingStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ROUTER_CONFIGURATION", function() { return ROUTER_CONFIGURATION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ROUTER_INITIALIZER", function() { return ROUTER_INITIALIZER; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ROUTES", function() { return ROUTES; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ResolveEnd", function() { return ResolveEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ResolveStart", function() { return ResolveStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouteConfigLoadEnd", function() { return RouteConfigLoadEnd; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouteConfigLoadStart", function() { return RouteConfigLoadStart; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouteReuseStrategy", function() { return RouteReuseStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Router", function() { return Router; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterEvent", function() { return RouterEvent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterLink", function() { return RouterLink; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterLinkActive", function() { return RouterLinkActive; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterLinkWithHref", function() { return RouterLinkWithHref; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterModule", function() { return RouterModule; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterOutlet", function() { return RouterOutlet; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterPreloader", function() { return RouterPreloader; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterState", function() { return RouterState; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RouterStateSnapshot", function() { return RouterStateSnapshot; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "RoutesRecognized", function() { return RoutesRecognized; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "Scroll", function() { return Scroll; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UrlHandlingStrategy", function() { return UrlHandlingStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UrlSegment", function() { return UrlSegment; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UrlSegmentGroup", function() { return UrlSegmentGroup; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UrlSerializer", function() { return UrlSerializer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "UrlTree", function() { return UrlTree; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "VERSION", function() { return VERSION; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "convertToParamMap", function() { return convertToParamMap; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "provideRoutes", function() { return provideRoutes; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵEmptyOutletComponent", function() { return ɵEmptyOutletComponent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵROUTER_PROVIDERS", function() { return ROUTER_PROVIDERS; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_a", function() { return ROUTER_FORROOT_GUARD; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_b", function() { return routerNgProbeToken; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_c", function() { return createRouterScroller; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_d", function() { return provideLocationStrategy; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_e", function() { return provideForRootGuard; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_f", function() { return setupRouter; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_g", function() { return rootRoute; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_h", function() { return RouterInitializer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_i", function() { return getAppInitializer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_j", function() { return getBootstrapListener; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_k", function() { return provideRouterInitializer; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_l", function() { return ɵEmptyOutletComponent; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_m", function() { return Tree; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_n", function() { return TreeNode; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵangular_packages_router_router_o", function() { return RouterScroller; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ɵflatten", function() { return flatten; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/defineProperty */ "rePB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createForOfIteratorHelper */ "uFwe");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _angular_common__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! @angular/common */ "ofXK");
/* harmony import */ var _angular_core__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! @angular/core */ "fXoL");
/* harmony import */ var rxjs__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! rxjs */ "qCKp");
/* harmony import */ var rxjs_operators__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! rxjs/operators */ "kU1M");









/**
 * @license Angular v10.1.4
 * (c) 2010-2020 Google LLC. https://angular.io/
 * License: MIT
 */




/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Base for events the router goes through, as opposed to events tied to a specific
 * route. Fired one time for any given navigation.
 *
 * The following code shows how a class subscribes to router events.
 *
 * ```ts
 * class MyService {
 *   constructor(public router: Router, logger: Logger) {
 *     router.events.pipe(
 *        filter((e: Event): e is RouterEvent => e instanceof RouterEvent)
 *     ).subscribe((e: RouterEvent) => {
 *       logger.log(e.id, e.url);
 *     });
 *   }
 * }
 * ```
 *
 * @see `Event`
 * @see [Router events summary](guide/router#router-events)
 * @publicApi
 */




var RouterEvent = function RouterEvent(
/** A unique ID that the router assigns to every router navigation. */
id,
/** The URL that is the destination for this navigation. */
url) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterEvent);

  this.id = id;
  this.url = url;
};
/**
 * An event triggered when a navigation starts.
 *
 * @publicApi
 */


var NavigationStart = /*#__PURE__*/function (_RouterEvent) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(NavigationStart, _RouterEvent);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(NavigationStart);

  function NavigationStart(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url) {
    var _this;

    var navigationTrigger = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'imperative';
    var restoredState = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NavigationStart);

    _this = _super.call(this, id, url);
    _this.navigationTrigger = navigationTrigger;
    _this.restoredState = restoredState;
    return _this;
  }
  /** @docsNotRequired */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(NavigationStart, [{
    key: "toString",
    value: function toString() {
      return "NavigationStart(id: ".concat(this.id, ", url: '").concat(this.url, "')");
    }
  }]);

  return NavigationStart;
}(RouterEvent);
/**
 * An event triggered when a navigation ends successfully.
 *
 * @see `NavigationStart`
 * @see `NavigationCancel`
 * @see `NavigationError`
 *
 * @publicApi
 */


var NavigationEnd = /*#__PURE__*/function (_RouterEvent2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(NavigationEnd, _RouterEvent2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(NavigationEnd);

  function NavigationEnd(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  urlAfterRedirects) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NavigationEnd);

    _this2 = _super2.call(this, id, url);
    _this2.urlAfterRedirects = urlAfterRedirects;
    return _this2;
  }
  /** @docsNotRequired */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(NavigationEnd, [{
    key: "toString",
    value: function toString() {
      return "NavigationEnd(id: ".concat(this.id, ", url: '").concat(this.url, "', urlAfterRedirects: '").concat(this.urlAfterRedirects, "')");
    }
  }]);

  return NavigationEnd;
}(RouterEvent);
/**
 * An event triggered when a navigation is canceled, directly or indirectly.
 * This can happen when a route guard
 * returns `false` or initiates a redirect by returning a `UrlTree`.
 *
 * @see `NavigationStart`
 * @see `NavigationEnd`
 * @see `NavigationError`
 *
 * @publicApi
 */


var NavigationCancel = /*#__PURE__*/function (_RouterEvent3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(NavigationCancel, _RouterEvent3);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(NavigationCancel);

  function NavigationCancel(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  reason) {
    var _this3;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NavigationCancel);

    _this3 = _super3.call(this, id, url);
    _this3.reason = reason;
    return _this3;
  }
  /** @docsNotRequired */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(NavigationCancel, [{
    key: "toString",
    value: function toString() {
      return "NavigationCancel(id: ".concat(this.id, ", url: '").concat(this.url, "')");
    }
  }]);

  return NavigationCancel;
}(RouterEvent);
/**
 * An event triggered when a navigation fails due to an unexpected error.
 *
 * @see `NavigationStart`
 * @see `NavigationEnd`
 * @see `NavigationCancel`
 *
 * @publicApi
 */


var NavigationError = /*#__PURE__*/function (_RouterEvent4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(NavigationError, _RouterEvent4);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(NavigationError);

  function NavigationError(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  error) {
    var _this4;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NavigationError);

    _this4 = _super4.call(this, id, url);
    _this4.error = error;
    return _this4;
  }
  /** @docsNotRequired */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(NavigationError, [{
    key: "toString",
    value: function toString() {
      return "NavigationError(id: ".concat(this.id, ", url: '").concat(this.url, "', error: ").concat(this.error, ")");
    }
  }]);

  return NavigationError;
}(RouterEvent);
/**
 * An event triggered when routes are recognized.
 *
 * @publicApi
 */


var RoutesRecognized = /*#__PURE__*/function (_RouterEvent5) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(RoutesRecognized, _RouterEvent5);

  var _super5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(RoutesRecognized);

  function RoutesRecognized(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  urlAfterRedirects,
  /** @docsNotRequired */
  state) {
    var _this5;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RoutesRecognized);

    _this5 = _super5.call(this, id, url);
    _this5.urlAfterRedirects = urlAfterRedirects;
    _this5.state = state;
    return _this5;
  }
  /** @docsNotRequired */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RoutesRecognized, [{
    key: "toString",
    value: function toString() {
      return "RoutesRecognized(id: ".concat(this.id, ", url: '").concat(this.url, "', urlAfterRedirects: '").concat(this.urlAfterRedirects, "', state: ").concat(this.state, ")");
    }
  }]);

  return RoutesRecognized;
}(RouterEvent);
/**
 * An event triggered at the start of the Guard phase of routing.
 *
 * @see `GuardsCheckEnd`
 *
 * @publicApi
 */


var GuardsCheckStart = /*#__PURE__*/function (_RouterEvent6) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(GuardsCheckStart, _RouterEvent6);

  var _super6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(GuardsCheckStart);

  function GuardsCheckStart(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  urlAfterRedirects,
  /** @docsNotRequired */
  state) {
    var _this6;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, GuardsCheckStart);

    _this6 = _super6.call(this, id, url);
    _this6.urlAfterRedirects = urlAfterRedirects;
    _this6.state = state;
    return _this6;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(GuardsCheckStart, [{
    key: "toString",
    value: function toString() {
      return "GuardsCheckStart(id: ".concat(this.id, ", url: '").concat(this.url, "', urlAfterRedirects: '").concat(this.urlAfterRedirects, "', state: ").concat(this.state, ")");
    }
  }]);

  return GuardsCheckStart;
}(RouterEvent);
/**
 * An event triggered at the end of the Guard phase of routing.
 *
 * @see `GuardsCheckStart`
 *
 * @publicApi
 */


var GuardsCheckEnd = /*#__PURE__*/function (_RouterEvent7) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(GuardsCheckEnd, _RouterEvent7);

  var _super7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(GuardsCheckEnd);

  function GuardsCheckEnd(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  urlAfterRedirects,
  /** @docsNotRequired */
  state,
  /** @docsNotRequired */
  shouldActivate) {
    var _this7;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, GuardsCheckEnd);

    _this7 = _super7.call(this, id, url);
    _this7.urlAfterRedirects = urlAfterRedirects;
    _this7.state = state;
    _this7.shouldActivate = shouldActivate;
    return _this7;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(GuardsCheckEnd, [{
    key: "toString",
    value: function toString() {
      return "GuardsCheckEnd(id: ".concat(this.id, ", url: '").concat(this.url, "', urlAfterRedirects: '").concat(this.urlAfterRedirects, "', state: ").concat(this.state, ", shouldActivate: ").concat(this.shouldActivate, ")");
    }
  }]);

  return GuardsCheckEnd;
}(RouterEvent);
/**
 * An event triggered at the the start of the Resolve phase of routing.
 *
 * Runs in the "resolve" phase whether or not there is anything to resolve.
 * In future, may change to only run when there are things to be resolved.
 *
 * @see `ResolveEnd`
 *
 * @publicApi
 */


var ResolveStart = /*#__PURE__*/function (_RouterEvent8) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(ResolveStart, _RouterEvent8);

  var _super8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(ResolveStart);

  function ResolveStart(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  urlAfterRedirects,
  /** @docsNotRequired */
  state) {
    var _this8;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ResolveStart);

    _this8 = _super8.call(this, id, url);
    _this8.urlAfterRedirects = urlAfterRedirects;
    _this8.state = state;
    return _this8;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ResolveStart, [{
    key: "toString",
    value: function toString() {
      return "ResolveStart(id: ".concat(this.id, ", url: '").concat(this.url, "', urlAfterRedirects: '").concat(this.urlAfterRedirects, "', state: ").concat(this.state, ")");
    }
  }]);

  return ResolveStart;
}(RouterEvent);
/**
 * An event triggered at the end of the Resolve phase of routing.
 * @see `ResolveStart`.
 *
 * @publicApi
 */


var ResolveEnd = /*#__PURE__*/function (_RouterEvent9) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(ResolveEnd, _RouterEvent9);

  var _super9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(ResolveEnd);

  function ResolveEnd(
  /** @docsNotRequired */
  id,
  /** @docsNotRequired */
  url,
  /** @docsNotRequired */
  urlAfterRedirects,
  /** @docsNotRequired */
  state) {
    var _this9;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ResolveEnd);

    _this9 = _super9.call(this, id, url);
    _this9.urlAfterRedirects = urlAfterRedirects;
    _this9.state = state;
    return _this9;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ResolveEnd, [{
    key: "toString",
    value: function toString() {
      return "ResolveEnd(id: ".concat(this.id, ", url: '").concat(this.url, "', urlAfterRedirects: '").concat(this.urlAfterRedirects, "', state: ").concat(this.state, ")");
    }
  }]);

  return ResolveEnd;
}(RouterEvent);
/**
 * An event triggered before lazy loading a route configuration.
 *
 * @see `RouteConfigLoadEnd`
 *
 * @publicApi
 */


var RouteConfigLoadStart = /*#__PURE__*/function () {
  function RouteConfigLoadStart(
  /** @docsNotRequired */
  route) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouteConfigLoadStart);

    this.route = route;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouteConfigLoadStart, [{
    key: "toString",
    value: function toString() {
      return "RouteConfigLoadStart(path: ".concat(this.route.path, ")");
    }
  }]);

  return RouteConfigLoadStart;
}();
/**
 * An event triggered when a route has been lazy loaded.
 *
 * @see `RouteConfigLoadStart`
 *
 * @publicApi
 */


var RouteConfigLoadEnd = /*#__PURE__*/function () {
  function RouteConfigLoadEnd(
  /** @docsNotRequired */
  route) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouteConfigLoadEnd);

    this.route = route;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouteConfigLoadEnd, [{
    key: "toString",
    value: function toString() {
      return "RouteConfigLoadEnd(path: ".concat(this.route.path, ")");
    }
  }]);

  return RouteConfigLoadEnd;
}();
/**
 * An event triggered at the start of the child-activation
 * part of the Resolve phase of routing.
 * @see  `ChildActivationEnd`
 * @see `ResolveStart`
 *
 * @publicApi
 */


var ChildActivationStart = /*#__PURE__*/function () {
  function ChildActivationStart(
  /** @docsNotRequired */
  snapshot) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ChildActivationStart);

    this.snapshot = snapshot;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ChildActivationStart, [{
    key: "toString",
    value: function toString() {
      var path = this.snapshot.routeConfig && this.snapshot.routeConfig.path || '';
      return "ChildActivationStart(path: '".concat(path, "')");
    }
  }]);

  return ChildActivationStart;
}();
/**
 * An event triggered at the end of the child-activation part
 * of the Resolve phase of routing.
 * @see `ChildActivationStart`
 * @see `ResolveStart`
 * @publicApi
 */


var ChildActivationEnd = /*#__PURE__*/function () {
  function ChildActivationEnd(
  /** @docsNotRequired */
  snapshot) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ChildActivationEnd);

    this.snapshot = snapshot;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ChildActivationEnd, [{
    key: "toString",
    value: function toString() {
      var path = this.snapshot.routeConfig && this.snapshot.routeConfig.path || '';
      return "ChildActivationEnd(path: '".concat(path, "')");
    }
  }]);

  return ChildActivationEnd;
}();
/**
 * An event triggered at the start of the activation part
 * of the Resolve phase of routing.
 * @see `ActivationEnd`
 * @see `ResolveStart`
 *
 * @publicApi
 */


var ActivationStart = /*#__PURE__*/function () {
  function ActivationStart(
  /** @docsNotRequired */
  snapshot) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ActivationStart);

    this.snapshot = snapshot;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ActivationStart, [{
    key: "toString",
    value: function toString() {
      var path = this.snapshot.routeConfig && this.snapshot.routeConfig.path || '';
      return "ActivationStart(path: '".concat(path, "')");
    }
  }]);

  return ActivationStart;
}();
/**
 * An event triggered at the end of the activation part
 * of the Resolve phase of routing.
 * @see `ActivationStart`
 * @see `ResolveStart`
 *
 * @publicApi
 */


var ActivationEnd = /*#__PURE__*/function () {
  function ActivationEnd(
  /** @docsNotRequired */
  snapshot) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ActivationEnd);

    this.snapshot = snapshot;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ActivationEnd, [{
    key: "toString",
    value: function toString() {
      var path = this.snapshot.routeConfig && this.snapshot.routeConfig.path || '';
      return "ActivationEnd(path: '".concat(path, "')");
    }
  }]);

  return ActivationEnd;
}();
/**
 * An event triggered by scrolling.
 *
 * @publicApi
 */


var Scroll = /*#__PURE__*/function () {
  function Scroll(
  /** @docsNotRequired */
  routerEvent,
  /** @docsNotRequired */
  position,
  /** @docsNotRequired */
  anchor) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, Scroll);

    this.routerEvent = routerEvent;
    this.position = position;
    this.anchor = anchor;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(Scroll, [{
    key: "toString",
    value: function toString() {
      var pos = this.position ? "".concat(this.position[0], ", ").concat(this.position[1]) : null;
      return "Scroll(anchor: '".concat(this.anchor, "', position: '").concat(pos, "')");
    }
  }]);

  return Scroll;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The primary routing outlet.
 *
 * @publicApi
 */


var PRIMARY_OUTLET = 'primary';

var ParamsAsMap = /*#__PURE__*/function () {
  function ParamsAsMap(params) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ParamsAsMap);

    this.params = params || {};
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ParamsAsMap, [{
    key: "has",
    value: function has(name) {
      return Object.prototype.hasOwnProperty.call(this.params, name);
    }
  }, {
    key: "get",
    value: function get(name) {
      if (this.has(name)) {
        var v = this.params[name];
        return Array.isArray(v) ? v[0] : v;
      }

      return null;
    }
  }, {
    key: "getAll",
    value: function getAll(name) {
      if (this.has(name)) {
        var v = this.params[name];
        return Array.isArray(v) ? v : [v];
      }

      return [];
    }
  }, {
    key: "keys",
    get: function get() {
      return Object.keys(this.params);
    }
  }]);

  return ParamsAsMap;
}();
/**
 * Converts a `Params` instance to a `ParamMap`.
 * @param params The instance to convert.
 * @returns The new map instance.
 *
 * @publicApi
 */


function convertToParamMap(params) {
  return new ParamsAsMap(params);
}

var NAVIGATION_CANCELING_ERROR = 'ngNavigationCancelingError';

function navigationCancelingError(message) {
  var error = Error('NavigationCancelingError: ' + message);
  error[NAVIGATION_CANCELING_ERROR] = true;
  return error;
}

function isNavigationCancelingError(error) {
  return error && error[NAVIGATION_CANCELING_ERROR];
} // Matches the route configuration (`route`) against the actual URL (`segments`).


function defaultUrlMatcher(segments, segmentGroup, route) {
  var parts = route.path.split('/');

  if (parts.length > segments.length) {
    // The actual URL is shorter than the config, no match
    return null;
  }

  if (route.pathMatch === 'full' && (segmentGroup.hasChildren() || parts.length < segments.length)) {
    // The config is longer than the actual URL but we are looking for a full match, return null
    return null;
  }

  var posParams = {}; // Check each config part against the actual URL

  for (var index = 0; index < parts.length; index++) {
    var part = parts[index];
    var segment = segments[index];
    var isParameter = part.startsWith(':');

    if (isParameter) {
      posParams[part.substring(1)] = segment;
    } else if (part !== segment.path) {
      // The actual URL part does not match the config, no match
      return null;
    }
  }

  return {
    consumed: segments.slice(0, parts.length),
    posParams: posParams
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function shallowEqualArrays(a, b) {
  if (a.length !== b.length) return false;

  for (var i = 0; i < a.length; ++i) {
    if (!shallowEqual(a[i], b[i])) return false;
  }

  return true;
}

function shallowEqual(a, b) {
  // Casting Object.keys return values to include `undefined` as there are some cases
  // in IE 11 where this can happen. Cannot provide a test because the behavior only
  // exists in certain circumstances in IE 11, therefore doing this cast ensures the
  // logic is correct for when this edge case is hit.
  var k1 = Object.keys(a);
  var k2 = Object.keys(b);

  if (!k1 || !k2 || k1.length != k2.length) {
    return false;
  }

  var key;

  for (var i = 0; i < k1.length; i++) {
    key = k1[i];

    if (!equalArraysOrString(a[key], b[key])) {
      return false;
    }
  }

  return true;
}
/**
 * Test equality for arrays of strings or a string.
 */


function equalArraysOrString(a, b) {
  if (Array.isArray(a) && Array.isArray(b)) {
    if (a.length !== b.length) return false;

    var aSorted = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(a).sort();

    var bSorted = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(b).sort();

    return aSorted.every(function (val, index) {
      return bSorted[index] === val;
    });
  } else {
    return a === b;
  }
}
/**
 * Flattens single-level nested arrays.
 */


function flatten(arr) {
  return Array.prototype.concat.apply([], arr);
}
/**
 * Return the last element of an array.
 */


function last(a) {
  return a.length > 0 ? a[a.length - 1] : null;
}
/**
 * Verifys all booleans in an array are `true`.
 */


function and(bools) {
  return !bools.some(function (v) {
    return !v;
  });
}

function forEach(map, callback) {
  for (var prop in map) {
    if (map.hasOwnProperty(prop)) {
      callback(map[prop], prop);
    }
  }
}

function waitForMap(obj, fn) {
  if (Object.keys(obj).length === 0) {
    return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])({});
  }

  var waitHead = [];
  var waitTail = [];
  var res = {};
  forEach(obj, function (a, k) {
    var mapped = fn(k, a).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (r) {
      return res[k] = r;
    }));

    if (k === PRIMARY_OUTLET) {
      waitHead.push(mapped);
    } else {
      waitTail.push(mapped);
    }
  }); // Closure compiler has problem with using spread operator here. So we use "Array.concat".
  // Note that we also need to cast the new promise because TypeScript cannot infer the type
  // when calling the "of" function through "Function.apply"

  return rxjs__WEBPACK_IMPORTED_MODULE_10__["of"].apply(null, waitHead.concat(waitTail)).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["concatAll"])(), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["last"])(), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function () {
    return res;
  }));
}

function wrapIntoObservable(value) {
  if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵisObservable"])(value)) {
    return value;
  }

  if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵisPromise"])(value)) {
    // Use `Promise.resolve()` to wrap promise-like instances.
    // Required ie when a Resolver returns a AngularJS `$q` promise to correctly trigger the
    // change detection.
    return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(Promise.resolve(value));
  }

  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(value);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function createEmptyUrlTree() {
  return new UrlTree(new UrlSegmentGroup([], {}), {}, null);
}

function containsTree(container, containee, exact) {
  if (exact) {
    return equalQueryParams(container.queryParams, containee.queryParams) && equalSegmentGroups(container.root, containee.root);
  }

  return containsQueryParams(container.queryParams, containee.queryParams) && containsSegmentGroup(container.root, containee.root);
}

function equalQueryParams(container, containee) {
  // TODO: This does not handle array params correctly.
  return shallowEqual(container, containee);
}

function equalSegmentGroups(container, containee) {
  if (!equalPath(container.segments, containee.segments)) return false;
  if (container.numberOfChildren !== containee.numberOfChildren) return false;

  for (var c in containee.children) {
    if (!container.children[c]) return false;
    if (!equalSegmentGroups(container.children[c], containee.children[c])) return false;
  }

  return true;
}

function containsQueryParams(container, containee) {
  return Object.keys(containee).length <= Object.keys(container).length && Object.keys(containee).every(function (key) {
    return equalArraysOrString(container[key], containee[key]);
  });
}

function containsSegmentGroup(container, containee) {
  return containsSegmentGroupHelper(container, containee, containee.segments);
}

function containsSegmentGroupHelper(container, containee, containeePaths) {
  if (container.segments.length > containeePaths.length) {
    var current = container.segments.slice(0, containeePaths.length);
    if (!equalPath(current, containeePaths)) return false;
    if (containee.hasChildren()) return false;
    return true;
  } else if (container.segments.length === containeePaths.length) {
    if (!equalPath(container.segments, containeePaths)) return false;

    for (var c in containee.children) {
      if (!container.children[c]) return false;
      if (!containsSegmentGroup(container.children[c], containee.children[c])) return false;
    }

    return true;
  } else {
    var _current = containeePaths.slice(0, container.segments.length);

    var next = containeePaths.slice(container.segments.length);
    if (!equalPath(container.segments, _current)) return false;
    if (!container.children[PRIMARY_OUTLET]) return false;
    return containsSegmentGroupHelper(container.children[PRIMARY_OUTLET], containee, next);
  }
}
/**
 * @description
 *
 * Represents the parsed URL.
 *
 * Since a router state is a tree, and the URL is nothing but a serialized state, the URL is a
 * serialized tree.
 * UrlTree is a data structure that provides a lot of affordances in dealing with URLs
 *
 * @usageNotes
 * ### Example
 *
 * ```
 * @Component({templateUrl:'template.html'})
 * class MyComponent {
 *   constructor(router: Router) {
 *     const tree: UrlTree =
 *       router.parseUrl('/team/33/(user/victor//support:help)?debug=true#fragment');
 *     const f = tree.fragment; // return 'fragment'
 *     const q = tree.queryParams; // returns {debug: 'true'}
 *     const g: UrlSegmentGroup = tree.root.children[PRIMARY_OUTLET];
 *     const s: UrlSegment[] = g.segments; // returns 2 segments 'team' and '33'
 *     g.children[PRIMARY_OUTLET].segments; // returns 2 segments 'user' and 'victor'
 *     g.children['support'].segments; // return 1 segment 'help'
 *   }
 * }
 * ```
 *
 * @publicApi
 */


var UrlTree = /*#__PURE__*/function () {
  /** @internal */
  function UrlTree(
  /** The root segment group of the URL tree */
  root,
  /** The query params of the URL */
  queryParams,
  /** The fragment of the URL */
  fragment) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, UrlTree);

    this.root = root;
    this.queryParams = queryParams;
    this.fragment = fragment;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(UrlTree, [{
    key: "toString",

    /** @docsNotRequired */
    value: function toString() {
      return DEFAULT_SERIALIZER.serialize(this);
    }
  }, {
    key: "queryParamMap",
    get: function get() {
      if (!this._queryParamMap) {
        this._queryParamMap = convertToParamMap(this.queryParams);
      }

      return this._queryParamMap;
    }
  }]);

  return UrlTree;
}();
/**
 * @description
 *
 * Represents the parsed URL segment group.
 *
 * See `UrlTree` for more information.
 *
 * @publicApi
 */


var UrlSegmentGroup = /*#__PURE__*/function () {
  function UrlSegmentGroup(
  /** The URL segments of this group. See `UrlSegment` for more information */
  segments,
  /** The list of children of this group */
  children) {
    var _this10 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, UrlSegmentGroup);

    this.segments = segments;
    this.children = children;
    /** The parent node in the url tree */

    this.parent = null;
    forEach(children, function (v, k) {
      return v.parent = _this10;
    });
  }
  /** Whether the segment has child segments */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(UrlSegmentGroup, [{
    key: "hasChildren",
    value: function hasChildren() {
      return this.numberOfChildren > 0;
    }
    /** Number of child segments */

  }, {
    key: "toString",

    /** @docsNotRequired */
    value: function toString() {
      return serializePaths(this);
    }
  }, {
    key: "numberOfChildren",
    get: function get() {
      return Object.keys(this.children).length;
    }
  }]);

  return UrlSegmentGroup;
}();
/**
 * @description
 *
 * Represents a single URL segment.
 *
 * A UrlSegment is a part of a URL between the two slashes. It contains a path and the matrix
 * parameters associated with the segment.
 *
 * @usageNotes
 * ### Example
 *
 * ```
 * @Component({templateUrl:'template.html'})
 * class MyComponent {
 *   constructor(router: Router) {
 *     const tree: UrlTree = router.parseUrl('/team;id=33');
 *     const g: UrlSegmentGroup = tree.root.children[PRIMARY_OUTLET];
 *     const s: UrlSegment[] = g.segments;
 *     s[0].path; // returns 'team'
 *     s[0].parameters; // returns {id: 33}
 *   }
 * }
 * ```
 *
 * @publicApi
 */


var UrlSegment = /*#__PURE__*/function () {
  function UrlSegment(
  /** The path part of a URL segment */
  path,
  /** The matrix parameters associated with a segment */
  parameters) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, UrlSegment);

    this.path = path;
    this.parameters = parameters;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(UrlSegment, [{
    key: "toString",

    /** @docsNotRequired */
    value: function toString() {
      return serializePath(this);
    }
  }, {
    key: "parameterMap",
    get: function get() {
      if (!this._parameterMap) {
        this._parameterMap = convertToParamMap(this.parameters);
      }

      return this._parameterMap;
    }
  }]);

  return UrlSegment;
}();

function equalSegments(as, bs) {
  return equalPath(as, bs) && as.every(function (a, i) {
    return shallowEqual(a.parameters, bs[i].parameters);
  });
}

function equalPath(as, bs) {
  if (as.length !== bs.length) return false;
  return as.every(function (a, i) {
    return a.path === bs[i].path;
  });
}

function mapChildrenIntoArray(segment, fn) {
  var res = [];
  forEach(segment.children, function (child, childOutlet) {
    if (childOutlet === PRIMARY_OUTLET) {
      res = res.concat(fn(child, childOutlet));
    }
  });
  forEach(segment.children, function (child, childOutlet) {
    if (childOutlet !== PRIMARY_OUTLET) {
      res = res.concat(fn(child, childOutlet));
    }
  });
  return res;
}
/**
 * @description
 *
 * Serializes and deserializes a URL string into a URL tree.
 *
 * The url serialization strategy is customizable. You can
 * make all URLs case insensitive by providing a custom UrlSerializer.
 *
 * See `DefaultUrlSerializer` for an example of a URL serializer.
 *
 * @publicApi
 */


var UrlSerializer = function UrlSerializer() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, UrlSerializer);
};
/**
 * @description
 *
 * A default implementation of the `UrlSerializer`.
 *
 * Example URLs:
 *
 * ```
 * /inbox/33(popup:compose)
 * /inbox/33;open=true/messages/44
 * ```
 *
 * DefaultUrlSerializer uses parentheses to serialize secondary segments (e.g., popup:compose), the
 * colon syntax to specify the outlet, and the ';parameter=value' syntax (e.g., open=true) to
 * specify route specific parameters.
 *
 * @publicApi
 */


var DefaultUrlSerializer = /*#__PURE__*/function () {
  function DefaultUrlSerializer() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, DefaultUrlSerializer);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(DefaultUrlSerializer, [{
    key: "parse",

    /** Parses a url into a `UrlTree` */
    value: function parse(url) {
      var p = new UrlParser(url);
      return new UrlTree(p.parseRootSegment(), p.parseQueryParams(), p.parseFragment());
    }
    /** Converts a `UrlTree` into a url */

  }, {
    key: "serialize",
    value: function serialize(tree) {
      var segment = "/".concat(serializeSegment(tree.root, true));
      var query = serializeQueryParams(tree.queryParams);
      var fragment = typeof tree.fragment === "string" ? "#".concat(encodeUriFragment(tree.fragment)) : '';
      return "".concat(segment).concat(query).concat(fragment);
    }
  }]);

  return DefaultUrlSerializer;
}();

var DEFAULT_SERIALIZER = new DefaultUrlSerializer();

function serializePaths(segment) {
  return segment.segments.map(function (p) {
    return serializePath(p);
  }).join('/');
}

function serializeSegment(segment, root) {
  if (!segment.hasChildren()) {
    return serializePaths(segment);
  }

  if (root) {
    var primary = segment.children[PRIMARY_OUTLET] ? serializeSegment(segment.children[PRIMARY_OUTLET], false) : '';
    var children = [];
    forEach(segment.children, function (v, k) {
      if (k !== PRIMARY_OUTLET) {
        children.push("".concat(k, ":").concat(serializeSegment(v, false)));
      }
    });
    return children.length > 0 ? "".concat(primary, "(").concat(children.join('//'), ")") : primary;
  } else {
    var _children = mapChildrenIntoArray(segment, function (v, k) {
      if (k === PRIMARY_OUTLET) {
        return [serializeSegment(segment.children[PRIMARY_OUTLET], false)];
      }

      return ["".concat(k, ":").concat(serializeSegment(v, false))];
    }); // use no parenthesis if the only child is a primary outlet route


    if (Object.keys(segment.children).length === 1 && segment.children[PRIMARY_OUTLET] != null) {
      return "".concat(serializePaths(segment), "/").concat(_children[0]);
    }

    return "".concat(serializePaths(segment), "/(").concat(_children.join('//'), ")");
  }
}
/**
 * Encodes a URI string with the default encoding. This function will only ever be called from
 * `encodeUriQuery` or `encodeUriSegment` as it's the base set of encodings to be used. We need
 * a custom encoding because encodeURIComponent is too aggressive and encodes stuff that doesn't
 * have to be encoded per https://url.spec.whatwg.org.
 */


function encodeUriString(s) {
  return encodeURIComponent(s).replace(/%40/g, '@').replace(/%3A/gi, ':').replace(/%24/g, '$').replace(/%2C/gi, ',');
}
/**
 * This function should be used to encode both keys and values in a query string key/value. In
 * the following URL, you need to call encodeUriQuery on "k" and "v":
 *
 * http://www.site.org/html;mk=mv?k=v#f
 */


function encodeUriQuery(s) {
  return encodeUriString(s).replace(/%3B/gi, ';');
}
/**
 * This function should be used to encode a URL fragment. In the following URL, you need to call
 * encodeUriFragment on "f":
 *
 * http://www.site.org/html;mk=mv?k=v#f
 */


function encodeUriFragment(s) {
  return encodeURI(s);
}
/**
 * This function should be run on any URI segment as well as the key and value in a key/value
 * pair for matrix params. In the following URL, you need to call encodeUriSegment on "html",
 * "mk", and "mv":
 *
 * http://www.site.org/html;mk=mv?k=v#f
 */


function encodeUriSegment(s) {
  return encodeUriString(s).replace(/\(/g, '%28').replace(/\)/g, '%29').replace(/%26/gi, '&');
}

function decode(s) {
  return decodeURIComponent(s);
} // Query keys/values should have the "+" replaced first, as "+" in a query string is " ".
// decodeURIComponent function will not decode "+" as a space.


function decodeQuery(s) {
  return decode(s.replace(/\+/g, '%20'));
}

function serializePath(path) {
  return "".concat(encodeUriSegment(path.path)).concat(serializeMatrixParams(path.parameters));
}

function serializeMatrixParams(params) {
  return Object.keys(params).map(function (key) {
    return ";".concat(encodeUriSegment(key), "=").concat(encodeUriSegment(params[key]));
  }).join('');
}

function serializeQueryParams(params) {
  var strParams = Object.keys(params).map(function (name) {
    var value = params[name];
    return Array.isArray(value) ? value.map(function (v) {
      return "".concat(encodeUriQuery(name), "=").concat(encodeUriQuery(v));
    }).join('&') : "".concat(encodeUriQuery(name), "=").concat(encodeUriQuery(value));
  });
  return strParams.length ? "?".concat(strParams.join('&')) : '';
}

var SEGMENT_RE = /^[^\/()?;=#]+/;

function matchSegments(str) {
  var match = str.match(SEGMENT_RE);
  return match ? match[0] : '';
}

var QUERY_PARAM_RE = /^[^=?&#]+/; // Return the name of the query param at the start of the string or an empty string

function matchQueryParams(str) {
  var match = str.match(QUERY_PARAM_RE);
  return match ? match[0] : '';
}

var QUERY_PARAM_VALUE_RE = /^[^?&#]+/; // Return the value of the query param at the start of the string or an empty string

function matchUrlQueryParamValue(str) {
  var match = str.match(QUERY_PARAM_VALUE_RE);
  return match ? match[0] : '';
}

var UrlParser = /*#__PURE__*/function () {
  function UrlParser(url) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, UrlParser);

    this.url = url;
    this.remaining = url;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(UrlParser, [{
    key: "parseRootSegment",
    value: function parseRootSegment() {
      this.consumeOptional('/');

      if (this.remaining === '' || this.peekStartsWith('?') || this.peekStartsWith('#')) {
        return new UrlSegmentGroup([], {});
      } // The root segment group never has segments


      return new UrlSegmentGroup([], this.parseChildren());
    }
  }, {
    key: "parseQueryParams",
    value: function parseQueryParams() {
      var params = {};

      if (this.consumeOptional('?')) {
        do {
          this.parseQueryParam(params);
        } while (this.consumeOptional('&'));
      }

      return params;
    }
  }, {
    key: "parseFragment",
    value: function parseFragment() {
      return this.consumeOptional('#') ? decodeURIComponent(this.remaining) : null;
    }
  }, {
    key: "parseChildren",
    value: function parseChildren() {
      if (this.remaining === '') {
        return {};
      }

      this.consumeOptional('/');
      var segments = [];

      if (!this.peekStartsWith('(')) {
        segments.push(this.parseSegment());
      }

      while (this.peekStartsWith('/') && !this.peekStartsWith('//') && !this.peekStartsWith('/(')) {
        this.capture('/');
        segments.push(this.parseSegment());
      }

      var children = {};

      if (this.peekStartsWith('/(')) {
        this.capture('/');
        children = this.parseParens(true);
      }

      var res = {};

      if (this.peekStartsWith('(')) {
        res = this.parseParens(false);
      }

      if (segments.length > 0 || Object.keys(children).length > 0) {
        res[PRIMARY_OUTLET] = new UrlSegmentGroup(segments, children);
      }

      return res;
    } // parse a segment with its matrix parameters
    // ie `name;k1=v1;k2`

  }, {
    key: "parseSegment",
    value: function parseSegment() {
      var path = matchSegments(this.remaining);

      if (path === '' && this.peekStartsWith(';')) {
        throw new Error("Empty path url segment cannot have parameters: '".concat(this.remaining, "'."));
      }

      this.capture(path);
      return new UrlSegment(decode(path), this.parseMatrixParams());
    }
  }, {
    key: "parseMatrixParams",
    value: function parseMatrixParams() {
      var params = {};

      while (this.consumeOptional(';')) {
        this.parseParam(params);
      }

      return params;
    }
  }, {
    key: "parseParam",
    value: function parseParam(params) {
      var key = matchSegments(this.remaining);

      if (!key) {
        return;
      }

      this.capture(key);
      var value = '';

      if (this.consumeOptional('=')) {
        var valueMatch = matchSegments(this.remaining);

        if (valueMatch) {
          value = valueMatch;
          this.capture(value);
        }
      }

      params[decode(key)] = decode(value);
    } // Parse a single query parameter `name[=value]`

  }, {
    key: "parseQueryParam",
    value: function parseQueryParam(params) {
      var key = matchQueryParams(this.remaining);

      if (!key) {
        return;
      }

      this.capture(key);
      var value = '';

      if (this.consumeOptional('=')) {
        var valueMatch = matchUrlQueryParamValue(this.remaining);

        if (valueMatch) {
          value = valueMatch;
          this.capture(value);
        }
      }

      var decodedKey = decodeQuery(key);
      var decodedVal = decodeQuery(value);

      if (params.hasOwnProperty(decodedKey)) {
        // Append to existing values
        var currentVal = params[decodedKey];

        if (!Array.isArray(currentVal)) {
          currentVal = [currentVal];
          params[decodedKey] = currentVal;
        }

        currentVal.push(decodedVal);
      } else {
        // Create a new value
        params[decodedKey] = decodedVal;
      }
    } // parse `(a/b//outlet_name:c/d)`

  }, {
    key: "parseParens",
    value: function parseParens(allowPrimary) {
      var segments = {};
      this.capture('(');

      while (!this.consumeOptional(')') && this.remaining.length > 0) {
        var path = matchSegments(this.remaining);
        var next = this.remaining[path.length]; // if is is not one of these characters, then the segment was unescaped
        // or the group was not closed

        if (next !== '/' && next !== ')' && next !== ';') {
          throw new Error("Cannot parse url '".concat(this.url, "'"));
        }

        var outletName = undefined;

        if (path.indexOf(':') > -1) {
          outletName = path.substr(0, path.indexOf(':'));
          this.capture(outletName);
          this.capture(':');
        } else if (allowPrimary) {
          outletName = PRIMARY_OUTLET;
        }

        var children = this.parseChildren();
        segments[outletName] = Object.keys(children).length === 1 ? children[PRIMARY_OUTLET] : new UrlSegmentGroup([], children);
        this.consumeOptional('//');
      }

      return segments;
    }
  }, {
    key: "peekStartsWith",
    value: function peekStartsWith(str) {
      return this.remaining.startsWith(str);
    } // Consumes the prefix when it is present and returns whether it has been consumed

  }, {
    key: "consumeOptional",
    value: function consumeOptional(str) {
      if (this.peekStartsWith(str)) {
        this.remaining = this.remaining.substring(str.length);
        return true;
      }

      return false;
    }
  }, {
    key: "capture",
    value: function capture(str) {
      if (!this.consumeOptional(str)) {
        throw new Error("Expected \"".concat(str, "\"."));
      }
    }
  }]);

  return UrlParser;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var Tree = /*#__PURE__*/function () {
  function Tree(root) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, Tree);

    this._root = root;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(Tree, [{
    key: "parent",

    /**
     * @internal
     */
    value: function parent(t) {
      var p = this.pathFromRoot(t);
      return p.length > 1 ? p[p.length - 2] : null;
    }
    /**
     * @internal
     */

  }, {
    key: "children",
    value: function children(t) {
      var n = findNode(t, this._root);
      return n ? n.children.map(function (t) {
        return t.value;
      }) : [];
    }
    /**
     * @internal
     */

  }, {
    key: "firstChild",
    value: function firstChild(t) {
      var n = findNode(t, this._root);
      return n && n.children.length > 0 ? n.children[0].value : null;
    }
    /**
     * @internal
     */

  }, {
    key: "siblings",
    value: function siblings(t) {
      var p = findPath(t, this._root);
      if (p.length < 2) return [];
      var c = p[p.length - 2].children.map(function (c) {
        return c.value;
      });
      return c.filter(function (cc) {
        return cc !== t;
      });
    }
    /**
     * @internal
     */

  }, {
    key: "pathFromRoot",
    value: function pathFromRoot(t) {
      return findPath(t, this._root).map(function (s) {
        return s.value;
      });
    }
  }, {
    key: "root",
    get: function get() {
      return this._root.value;
    }
  }]);

  return Tree;
}(); // DFS for the node matching the value


function findNode(value, node) {
  if (value === node.value) return node;

  var _iterator = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(node.children),
      _step;

  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var child = _step.value;

      var _node = findNode(value, child);

      if (_node) return _node;
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }

  return null;
} // Return the path to the node with the given value using DFS


function findPath(value, node) {
  if (value === node.value) return [node];

  var _iterator2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(node.children),
      _step2;

  try {
    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
      var child = _step2.value;
      var path = findPath(value, child);

      if (path.length) {
        path.unshift(node);
        return path;
      }
    }
  } catch (err) {
    _iterator2.e(err);
  } finally {
    _iterator2.f();
  }

  return [];
}

var TreeNode = /*#__PURE__*/function () {
  function TreeNode(value, children) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, TreeNode);

    this.value = value;
    this.children = children;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(TreeNode, [{
    key: "toString",
    value: function toString() {
      return "TreeNode(".concat(this.value, ")");
    }
  }]);

  return TreeNode;
}(); // Return the list of T indexed by outlet name


function nodeChildrenAsMap(node) {
  var map = {};

  if (node) {
    node.children.forEach(function (child) {
      return map[child.value.outlet] = child;
    });
  }

  return map;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Represents the state of the router as a tree of activated routes.
 *
 * @usageNotes
 *
 * Every node in the route tree is an `ActivatedRoute` instance
 * that knows about the "consumed" URL segments, the extracted parameters,
 * and the resolved data.
 * Use the `ActivatedRoute` properties to traverse the tree from any node.
 *
 * The following fragment shows how a component gets the root node
 * of the current state to establish its own route tree:
 *
 * ```
 * @Component({templateUrl:'template.html'})
 * class MyComponent {
 *   constructor(router: Router) {
 *     const state: RouterState = router.routerState;
 *     const root: ActivatedRoute = state.root;
 *     const child = root.firstChild;
 *     const id: Observable<string> = child.params.map(p => p.id);
 *     //...
 *   }
 * }
 * ```
 *
 * @see `ActivatedRoute`
 * @see [Getting route information](guide/router#getting-route-information)
 *
 * @publicApi
 */


var RouterState = /*#__PURE__*/function (_Tree) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(RouterState, _Tree);

  var _super10 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(RouterState);

  /** @internal */
  function RouterState(root,
  /** The current snapshot of the router state */
  snapshot) {
    var _this11;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterState);

    _this11 = _super10.call(this, root);
    _this11.snapshot = snapshot;
    setRouterState(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__["default"])(_this11), root);
    return _this11;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterState, [{
    key: "toString",
    value: function toString() {
      return this.snapshot.toString();
    }
  }]);

  return RouterState;
}(Tree);

function createEmptyState(urlTree, rootComponent) {
  var snapshot = createEmptyStateSnapshot(urlTree, rootComponent);
  var emptyUrl = new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"]([new UrlSegment('', {})]);
  var emptyParams = new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"]({});
  var emptyData = new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"]({});
  var emptyQueryParams = new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"]({});
  var fragment = new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"]('');
  var activated = new ActivatedRoute(emptyUrl, emptyParams, emptyQueryParams, fragment, emptyData, PRIMARY_OUTLET, rootComponent, snapshot.root);
  activated.snapshot = snapshot.root;
  return new RouterState(new TreeNode(activated, []), snapshot);
}

function createEmptyStateSnapshot(urlTree, rootComponent) {
  var emptyParams = {};
  var emptyData = {};
  var emptyQueryParams = {};
  var fragment = '';
  var activated = new ActivatedRouteSnapshot([], emptyParams, emptyQueryParams, fragment, emptyData, PRIMARY_OUTLET, rootComponent, null, urlTree.root, -1, {});
  return new RouterStateSnapshot('', new TreeNode(activated, []));
}
/**
 * Provides access to information about a route associated with a component
 * that is loaded in an outlet.
 * Use to traverse the `RouterState` tree and extract information from nodes.
 *
 * The following example shows how to construct a component using information from a
 * currently activated route.
 *
 * {@example router/activated-route/module.ts region="activated-route"
 *     header="activated-route.component.ts"}
 *
 * @see [Getting route information](guide/router#getting-route-information)
 *
 * @publicApi
 */


var ActivatedRoute = /*#__PURE__*/function () {
  /** @internal */
  function ActivatedRoute(
  /** An observable of the URL segments matched by this route. */
  url,
  /** An observable of the matrix parameters scoped to this route. */
  params,
  /** An observable of the query parameters shared by all the routes. */
  queryParams,
  /** An observable of the URL fragment shared by all the routes. */
  fragment,
  /** An observable of the static and resolved data of this route. */
  data,
  /** The outlet name of the route, a constant. */
  outlet,
  /** The component of the route, a constant. */
  // TODO(vsavkin): remove |string
  component, futureSnapshot) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ActivatedRoute);

    this.url = url;
    this.params = params;
    this.queryParams = queryParams;
    this.fragment = fragment;
    this.data = data;
    this.outlet = outlet;
    this.component = component;
    this._futureSnapshot = futureSnapshot;
  }
  /** The configuration used to match this route. */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ActivatedRoute, [{
    key: "toString",
    value: function toString() {
      return this.snapshot ? this.snapshot.toString() : "Future(".concat(this._futureSnapshot, ")");
    }
  }, {
    key: "routeConfig",
    get: function get() {
      return this._futureSnapshot.routeConfig;
    }
    /** The root of the router state. */

  }, {
    key: "root",
    get: function get() {
      return this._routerState.root;
    }
    /** The parent of this route in the router state tree. */

  }, {
    key: "parent",
    get: function get() {
      return this._routerState.parent(this);
    }
    /** The first child of this route in the router state tree. */

  }, {
    key: "firstChild",
    get: function get() {
      return this._routerState.firstChild(this);
    }
    /** The children of this route in the router state tree. */

  }, {
    key: "children",
    get: function get() {
      return this._routerState.children(this);
    }
    /** The path from the root of the router state tree to this route. */

  }, {
    key: "pathFromRoot",
    get: function get() {
      return this._routerState.pathFromRoot(this);
    }
    /**
     * An Observable that contains a map of the required and optional parameters
     * specific to the route.
     * The map supports retrieving single and multiple values from the same parameter.
     */

  }, {
    key: "paramMap",
    get: function get() {
      if (!this._paramMap) {
        this._paramMap = this.params.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (p) {
          return convertToParamMap(p);
        }));
      }

      return this._paramMap;
    }
    /**
     * An Observable that contains a map of the query parameters available to all routes.
     * The map supports retrieving single and multiple values from the query parameter.
     */

  }, {
    key: "queryParamMap",
    get: function get() {
      if (!this._queryParamMap) {
        this._queryParamMap = this.queryParams.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (p) {
          return convertToParamMap(p);
        }));
      }

      return this._queryParamMap;
    }
  }]);

  return ActivatedRoute;
}();
/**
 * Returns the inherited params, data, and resolve for a given route.
 * By default, this only inherits values up to the nearest path-less or component-less route.
 * @internal
 */


function inheritedParamsDataResolve(route) {
  var paramsInheritanceStrategy = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'emptyOnly';
  var pathFromRoot = route.pathFromRoot;
  var inheritingStartingFrom = 0;

  if (paramsInheritanceStrategy !== 'always') {
    inheritingStartingFrom = pathFromRoot.length - 1;

    while (inheritingStartingFrom >= 1) {
      var current = pathFromRoot[inheritingStartingFrom];
      var parent = pathFromRoot[inheritingStartingFrom - 1]; // current route is an empty path => inherits its parent's params and data

      if (current.routeConfig && current.routeConfig.path === '') {
        inheritingStartingFrom--; // parent is componentless => current route should inherit its params and data
      } else if (!parent.component) {
        inheritingStartingFrom--;
      } else {
        break;
      }
    }
  }

  return flattenInherited(pathFromRoot.slice(inheritingStartingFrom));
}
/** @internal */


function flattenInherited(pathFromRoot) {
  return pathFromRoot.reduce(function (res, curr) {
    var params = Object.assign(Object.assign({}, res.params), curr.params);
    var data = Object.assign(Object.assign({}, res.data), curr.data);
    var resolve = Object.assign(Object.assign({}, res.resolve), curr._resolvedData);
    return {
      params: params,
      data: data,
      resolve: resolve
    };
  }, {
    params: {},
    data: {},
    resolve: {}
  });
}
/**
 * @description
 *
 * Contains the information about a route associated with a component loaded in an
 * outlet at a particular moment in time. ActivatedRouteSnapshot can also be used to
 * traverse the router state tree.
 *
 * The following example initializes a component with route information extracted
 * from the snapshot of the root node at the time of creation.
 *
 * ```
 * @Component({templateUrl:'./my-component.html'})
 * class MyComponent {
 *   constructor(route: ActivatedRoute) {
 *     const id: string = route.snapshot.params.id;
 *     const url: string = route.snapshot.url.join('');
 *     const user = route.snapshot.data.user;
 *   }
 * }
 * ```
 *
 * @publicApi
 */


var ActivatedRouteSnapshot = /*#__PURE__*/function () {
  /** @internal */
  function ActivatedRouteSnapshot(
  /** The URL segments matched by this route */
  url,
  /** The matrix parameters scoped to this route */
  params,
  /** The query parameters shared by all the routes */
  queryParams,
  /** The URL fragment shared by all the routes */
  fragment,
  /** The static and resolved data of this route */
  data,
  /** The outlet name of the route */
  outlet,
  /** The component of the route */
  component, routeConfig, urlSegment, lastPathIndex, resolve) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ActivatedRouteSnapshot);

    this.url = url;
    this.params = params;
    this.queryParams = queryParams;
    this.fragment = fragment;
    this.data = data;
    this.outlet = outlet;
    this.component = component;
    this.routeConfig = routeConfig;
    this._urlSegment = urlSegment;
    this._lastPathIndex = lastPathIndex;
    this._resolve = resolve;
  }
  /** The root of the router state */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ActivatedRouteSnapshot, [{
    key: "toString",
    value: function toString() {
      var url = this.url.map(function (segment) {
        return segment.toString();
      }).join('/');
      var matched = this.routeConfig ? this.routeConfig.path : '';
      return "Route(url:'".concat(url, "', path:'").concat(matched, "')");
    }
  }, {
    key: "root",
    get: function get() {
      return this._routerState.root;
    }
    /** The parent of this route in the router state tree */

  }, {
    key: "parent",
    get: function get() {
      return this._routerState.parent(this);
    }
    /** The first child of this route in the router state tree */

  }, {
    key: "firstChild",
    get: function get() {
      return this._routerState.firstChild(this);
    }
    /** The children of this route in the router state tree */

  }, {
    key: "children",
    get: function get() {
      return this._routerState.children(this);
    }
    /** The path from the root of the router state tree to this route */

  }, {
    key: "pathFromRoot",
    get: function get() {
      return this._routerState.pathFromRoot(this);
    }
  }, {
    key: "paramMap",
    get: function get() {
      if (!this._paramMap) {
        this._paramMap = convertToParamMap(this.params);
      }

      return this._paramMap;
    }
  }, {
    key: "queryParamMap",
    get: function get() {
      if (!this._queryParamMap) {
        this._queryParamMap = convertToParamMap(this.queryParams);
      }

      return this._queryParamMap;
    }
  }]);

  return ActivatedRouteSnapshot;
}();
/**
 * @description
 *
 * Represents the state of the router at a moment in time.
 *
 * This is a tree of activated route snapshots. Every node in this tree knows about
 * the "consumed" URL segments, the extracted parameters, and the resolved data.
 *
 * The following example shows how a component is initialized with information
 * from the snapshot of the root node's state at the time of creation.
 *
 * ```
 * @Component({templateUrl:'template.html'})
 * class MyComponent {
 *   constructor(router: Router) {
 *     const state: RouterState = router.routerState;
 *     const snapshot: RouterStateSnapshot = state.snapshot;
 *     const root: ActivatedRouteSnapshot = snapshot.root;
 *     const child = root.firstChild;
 *     const id: Observable<string> = child.params.map(p => p.id);
 *     //...
 *   }
 * }
 * ```
 *
 * @publicApi
 */


var RouterStateSnapshot = /*#__PURE__*/function (_Tree2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(RouterStateSnapshot, _Tree2);

  var _super11 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(RouterStateSnapshot);

  /** @internal */
  function RouterStateSnapshot(
  /** The url from which this snapshot was created */
  url, root) {
    var _this12;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterStateSnapshot);

    _this12 = _super11.call(this, root);
    _this12.url = url;
    setRouterState(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__["default"])(_this12), root);
    return _this12;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterStateSnapshot, [{
    key: "toString",
    value: function toString() {
      return serializeNode(this._root);
    }
  }]);

  return RouterStateSnapshot;
}(Tree);

function setRouterState(state, node) {
  node.value._routerState = state;
  node.children.forEach(function (c) {
    return setRouterState(state, c);
  });
}

function serializeNode(node) {
  var c = node.children.length > 0 ? " { ".concat(node.children.map(serializeNode).join(', '), " } ") : '';
  return "".concat(node.value).concat(c);
}
/**
 * The expectation is that the activate route is created with the right set of parameters.
 * So we push new values into the observables only when they are not the initial values.
 * And we detect that by checking if the snapshot field is set.
 */


function advanceActivatedRoute(route) {
  if (route.snapshot) {
    var currentSnapshot = route.snapshot;
    var nextSnapshot = route._futureSnapshot;
    route.snapshot = nextSnapshot;

    if (!shallowEqual(currentSnapshot.queryParams, nextSnapshot.queryParams)) {
      route.queryParams.next(nextSnapshot.queryParams);
    }

    if (currentSnapshot.fragment !== nextSnapshot.fragment) {
      route.fragment.next(nextSnapshot.fragment);
    }

    if (!shallowEqual(currentSnapshot.params, nextSnapshot.params)) {
      route.params.next(nextSnapshot.params);
    }

    if (!shallowEqualArrays(currentSnapshot.url, nextSnapshot.url)) {
      route.url.next(nextSnapshot.url);
    }

    if (!shallowEqual(currentSnapshot.data, nextSnapshot.data)) {
      route.data.next(nextSnapshot.data);
    }
  } else {
    route.snapshot = route._futureSnapshot; // this is for resolved data

    route.data.next(route._futureSnapshot.data);
  }
}

function equalParamsAndUrlSegments(a, b) {
  var equalUrlParams = shallowEqual(a.params, b.params) && equalSegments(a.url, b.url);
  var parentsMismatch = !a.parent !== !b.parent;
  return equalUrlParams && !parentsMismatch && (!a.parent || equalParamsAndUrlSegments(a.parent, b.parent));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function createRouterState(routeReuseStrategy, curr, prevState) {
  var root = createNode(routeReuseStrategy, curr._root, prevState ? prevState._root : undefined);
  return new RouterState(root, curr);
}

function createNode(routeReuseStrategy, curr, prevState) {
  // reuse an activated route that is currently displayed on the screen
  if (prevState && routeReuseStrategy.shouldReuseRoute(curr.value, prevState.value.snapshot)) {
    var value = prevState.value;
    value._futureSnapshot = curr.value;
    var children = createOrReuseChildren(routeReuseStrategy, curr, prevState);
    return new TreeNode(value, children); // retrieve an activated route that is used to be displayed, but is not currently displayed
  } else {
    var detachedRouteHandle = routeReuseStrategy.retrieve(curr.value);

    if (detachedRouteHandle) {
      var _tree = detachedRouteHandle.route;
      setFutureSnapshotsOfActivatedRoutes(curr, _tree);
      return _tree;
    } else {
      var _value = createActivatedRoute(curr.value);

      var _children2 = curr.children.map(function (c) {
        return createNode(routeReuseStrategy, c);
      });

      return new TreeNode(_value, _children2);
    }
  }
}

function setFutureSnapshotsOfActivatedRoutes(curr, result) {
  if (curr.value.routeConfig !== result.value.routeConfig) {
    throw new Error('Cannot reattach ActivatedRouteSnapshot created from a different route');
  }

  if (curr.children.length !== result.children.length) {
    throw new Error('Cannot reattach ActivatedRouteSnapshot with a different number of children');
  }

  result.value._futureSnapshot = curr.value;

  for (var i = 0; i < curr.children.length; ++i) {
    setFutureSnapshotsOfActivatedRoutes(curr.children[i], result.children[i]);
  }
}

function createOrReuseChildren(routeReuseStrategy, curr, prevState) {
  return curr.children.map(function (child) {
    var _iterator3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(prevState.children),
        _step3;

    try {
      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
        var p = _step3.value;

        if (routeReuseStrategy.shouldReuseRoute(p.value.snapshot, child.value)) {
          return createNode(routeReuseStrategy, child, p);
        }
      }
    } catch (err) {
      _iterator3.e(err);
    } finally {
      _iterator3.f();
    }

    return createNode(routeReuseStrategy, child);
  });
}

function createActivatedRoute(c) {
  return new ActivatedRoute(new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"](c.url), new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"](c.params), new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"](c.queryParams), new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"](c.fragment), new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"](c.data), c.outlet, c.component, c);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function _createUrlTree(route, urlTree, commands, queryParams, fragment) {
  if (commands.length === 0) {
    return tree(urlTree.root, urlTree.root, urlTree, queryParams, fragment);
  }

  var nav = computeNavigation(commands);

  if (nav.toRoot()) {
    return tree(urlTree.root, new UrlSegmentGroup([], {}), urlTree, queryParams, fragment);
  }

  var startingPosition = findStartingPosition(nav, urlTree, route);
  var segmentGroup = startingPosition.processChildren ? updateSegmentGroupChildren(startingPosition.segmentGroup, startingPosition.index, nav.commands) : updateSegmentGroup(startingPosition.segmentGroup, startingPosition.index, nav.commands);
  return tree(startingPosition.segmentGroup, segmentGroup, urlTree, queryParams, fragment);
}

function isMatrixParams(command) {
  return typeof command === 'object' && command != null && !command.outlets && !command.segmentPath;
}

function tree(oldSegmentGroup, newSegmentGroup, urlTree, queryParams, fragment) {
  var qp = {};

  if (queryParams) {
    forEach(queryParams, function (value, name) {
      qp[name] = Array.isArray(value) ? value.map(function (v) {
        return "".concat(v);
      }) : "".concat(value);
    });
  }

  if (urlTree.root === oldSegmentGroup) {
    return new UrlTree(newSegmentGroup, qp, fragment);
  }

  return new UrlTree(replaceSegment(urlTree.root, oldSegmentGroup, newSegmentGroup), qp, fragment);
}

function replaceSegment(current, oldSegment, newSegment) {
  var children = {};
  forEach(current.children, function (c, outletName) {
    if (c === oldSegment) {
      children[outletName] = newSegment;
    } else {
      children[outletName] = replaceSegment(c, oldSegment, newSegment);
    }
  });
  return new UrlSegmentGroup(current.segments, children);
}

var Navigation = /*#__PURE__*/function () {
  function Navigation(isAbsolute, numberOfDoubleDots, commands) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, Navigation);

    this.isAbsolute = isAbsolute;
    this.numberOfDoubleDots = numberOfDoubleDots;
    this.commands = commands;

    if (isAbsolute && commands.length > 0 && isMatrixParams(commands[0])) {
      throw new Error('Root segment cannot have matrix parameters');
    }

    var cmdWithOutlet = commands.find(function (c) {
      return typeof c === 'object' && c != null && c.outlets;
    });

    if (cmdWithOutlet && cmdWithOutlet !== last(commands)) {
      throw new Error('{outlets:{}} has to be the last command');
    }
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(Navigation, [{
    key: "toRoot",
    value: function toRoot() {
      return this.isAbsolute && this.commands.length === 1 && this.commands[0] == '/';
    }
  }]);

  return Navigation;
}();
/** Transforms commands to a normalized `Navigation` */


function computeNavigation(commands) {
  if (typeof commands[0] === 'string' && commands.length === 1 && commands[0] === '/') {
    return new Navigation(true, 0, commands);
  }

  var numberOfDoubleDots = 0;
  var isAbsolute = false;
  var res = commands.reduce(function (res, cmd, cmdIdx) {
    if (typeof cmd === 'object' && cmd != null) {
      if (cmd.outlets) {
        var outlets = {};
        forEach(cmd.outlets, function (commands, name) {
          outlets[name] = typeof commands === 'string' ? commands.split('/') : commands;
        });
        return [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(res), [{
          outlets: outlets
        }]);
      }

      if (cmd.segmentPath) {
        return [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(res), [cmd.segmentPath]);
      }
    }

    if (!(typeof cmd === 'string')) {
      return [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(res), [cmd]);
    }

    if (cmdIdx === 0) {
      cmd.split('/').forEach(function (urlPart, partIndex) {
        if (partIndex == 0 && urlPart === '.') {// skip './a'
        } else if (partIndex == 0 && urlPart === '') {
          //  '/a'
          isAbsolute = true;
        } else if (urlPart === '..') {
          //  '../a'
          numberOfDoubleDots++;
        } else if (urlPart != '') {
          res.push(urlPart);
        }
      });
      return res;
    }

    return [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(res), [cmd]);
  }, []);
  return new Navigation(isAbsolute, numberOfDoubleDots, res);
}

var Position = function Position(segmentGroup, processChildren, index) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, Position);

  this.segmentGroup = segmentGroup;
  this.processChildren = processChildren;
  this.index = index;
};

function findStartingPosition(nav, tree, route) {
  if (nav.isAbsolute) {
    return new Position(tree.root, true, 0);
  }

  if (route.snapshot._lastPathIndex === -1) {
    var segmentGroup = route.snapshot._urlSegment; // Pathless ActivatedRoute has _lastPathIndex === -1 but should not process children
    // see issue #26224, #13011, #35687
    // However, if the ActivatedRoute is the root we should process children like above.

    var processChildren = segmentGroup === tree.root;
    return new Position(segmentGroup, processChildren, 0);
  }

  var modifier = isMatrixParams(nav.commands[0]) ? 0 : 1;
  var index = route.snapshot._lastPathIndex + modifier;
  return createPositionApplyingDoubleDots(route.snapshot._urlSegment, index, nav.numberOfDoubleDots);
}

function createPositionApplyingDoubleDots(group, index, numberOfDoubleDots) {
  var g = group;
  var ci = index;
  var dd = numberOfDoubleDots;

  while (dd > ci) {
    dd -= ci;
    g = g.parent;

    if (!g) {
      throw new Error('Invalid number of \'../\'');
    }

    ci = g.segments.length;
  }

  return new Position(g, false, ci - dd);
}

function getPath(command) {
  if (typeof command === 'object' && command != null && command.outlets) {
    return command.outlets[PRIMARY_OUTLET];
  }

  return "".concat(command);
}

function getOutlets(commands) {
  if (typeof commands[0] === 'object' && commands[0] !== null && commands[0].outlets) {
    return commands[0].outlets;
  }

  return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, PRIMARY_OUTLET, commands);
}

function updateSegmentGroup(segmentGroup, startIndex, commands) {
  if (!segmentGroup) {
    segmentGroup = new UrlSegmentGroup([], {});
  }

  if (segmentGroup.segments.length === 0 && segmentGroup.hasChildren()) {
    return updateSegmentGroupChildren(segmentGroup, startIndex, commands);
  }

  var m = prefixedWith(segmentGroup, startIndex, commands);
  var slicedCommands = commands.slice(m.commandIndex);

  if (m.match && m.pathIndex < segmentGroup.segments.length) {
    var g = new UrlSegmentGroup(segmentGroup.segments.slice(0, m.pathIndex), {});
    g.children[PRIMARY_OUTLET] = new UrlSegmentGroup(segmentGroup.segments.slice(m.pathIndex), segmentGroup.children);
    return updateSegmentGroupChildren(g, 0, slicedCommands);
  } else if (m.match && slicedCommands.length === 0) {
    return new UrlSegmentGroup(segmentGroup.segments, {});
  } else if (m.match && !segmentGroup.hasChildren()) {
    return createNewSegmentGroup(segmentGroup, startIndex, commands);
  } else if (m.match) {
    return updateSegmentGroupChildren(segmentGroup, 0, slicedCommands);
  } else {
    return createNewSegmentGroup(segmentGroup, startIndex, commands);
  }
}

function updateSegmentGroupChildren(segmentGroup, startIndex, commands) {
  if (commands.length === 0) {
    return new UrlSegmentGroup(segmentGroup.segments, {});
  } else {
    var outlets = getOutlets(commands);
    var children = {};
    forEach(outlets, function (commands, outlet) {
      if (commands !== null) {
        children[outlet] = updateSegmentGroup(segmentGroup.children[outlet], startIndex, commands);
      }
    });
    forEach(segmentGroup.children, function (child, childOutlet) {
      if (outlets[childOutlet] === undefined) {
        children[childOutlet] = child;
      }
    });
    return new UrlSegmentGroup(segmentGroup.segments, children);
  }
}

function prefixedWith(segmentGroup, startIndex, commands) {
  var currentCommandIndex = 0;
  var currentPathIndex = startIndex;
  var noMatch = {
    match: false,
    pathIndex: 0,
    commandIndex: 0
  };

  while (currentPathIndex < segmentGroup.segments.length) {
    if (currentCommandIndex >= commands.length) return noMatch;
    var path = segmentGroup.segments[currentPathIndex];
    var curr = getPath(commands[currentCommandIndex]);
    var next = currentCommandIndex < commands.length - 1 ? commands[currentCommandIndex + 1] : null;
    if (currentPathIndex > 0 && curr === undefined) break;

    if (curr && next && typeof next === 'object' && next.outlets === undefined) {
      if (!compare(curr, next, path)) return noMatch;
      currentCommandIndex += 2;
    } else {
      if (!compare(curr, {}, path)) return noMatch;
      currentCommandIndex++;
    }

    currentPathIndex++;
  }

  return {
    match: true,
    pathIndex: currentPathIndex,
    commandIndex: currentCommandIndex
  };
}

function createNewSegmentGroup(segmentGroup, startIndex, commands) {
  var paths = segmentGroup.segments.slice(0, startIndex);
  var i = 0;

  while (i < commands.length) {
    if (typeof commands[i] === 'object' && commands[i] !== null && commands[i].outlets !== undefined) {
      var children = createNewSegmentChildren(commands[i].outlets);
      return new UrlSegmentGroup(paths, children);
    } // if we start with an object literal, we need to reuse the path part from the segment


    if (i === 0 && isMatrixParams(commands[0])) {
      var p = segmentGroup.segments[startIndex];
      paths.push(new UrlSegment(p.path, commands[0]));
      i++;
      continue;
    }

    var curr = getPath(commands[i]);
    var next = i < commands.length - 1 ? commands[i + 1] : null;

    if (curr && next && isMatrixParams(next)) {
      paths.push(new UrlSegment(curr, stringify(next)));
      i += 2;
    } else {
      paths.push(new UrlSegment(curr, {}));
      i++;
    }
  }

  return new UrlSegmentGroup(paths, {});
}

function createNewSegmentChildren(outlets) {
  var children = {};
  forEach(outlets, function (commands, outlet) {
    if (commands !== null) {
      children[outlet] = createNewSegmentGroup(new UrlSegmentGroup([], {}), 0, commands);
    }
  });
  return children;
}

function stringify(params) {
  var res = {};
  forEach(params, function (v, k) {
    return res[k] = "".concat(v);
  });
  return res;
}

function compare(path, params, segment) {
  return path == segment.path && shallowEqual(params, segment.parameters);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var activateRoutes = function activateRoutes(rootContexts, routeReuseStrategy, forwardEvent) {
  return Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (t) {
    new ActivateRoutes(routeReuseStrategy, t.targetRouterState, t.currentRouterState, forwardEvent).activate(rootContexts);
    return t;
  });
};

var ActivateRoutes = /*#__PURE__*/function () {
  function ActivateRoutes(routeReuseStrategy, futureState, currState, forwardEvent) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ActivateRoutes);

    this.routeReuseStrategy = routeReuseStrategy;
    this.futureState = futureState;
    this.currState = currState;
    this.forwardEvent = forwardEvent;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ActivateRoutes, [{
    key: "activate",
    value: function activate(parentContexts) {
      var futureRoot = this.futureState._root;
      var currRoot = this.currState ? this.currState._root : null;
      this.deactivateChildRoutes(futureRoot, currRoot, parentContexts);
      advanceActivatedRoute(this.futureState.root);
      this.activateChildRoutes(futureRoot, currRoot, parentContexts);
    } // De-activate the child route that are not re-used for the future state

  }, {
    key: "deactivateChildRoutes",
    value: function deactivateChildRoutes(futureNode, currNode, contexts) {
      var _this13 = this;

      var children = nodeChildrenAsMap(currNode); // Recurse on the routes active in the future state to de-activate deeper children

      futureNode.children.forEach(function (futureChild) {
        var childOutletName = futureChild.value.outlet;

        _this13.deactivateRoutes(futureChild, children[childOutletName], contexts);

        delete children[childOutletName];
      }); // De-activate the routes that will not be re-used

      forEach(children, function (v, childName) {
        _this13.deactivateRouteAndItsChildren(v, contexts);
      });
    }
  }, {
    key: "deactivateRoutes",
    value: function deactivateRoutes(futureNode, currNode, parentContext) {
      var future = futureNode.value;
      var curr = currNode ? currNode.value : null;

      if (future === curr) {
        // Reusing the node, check to see if the children need to be de-activated
        if (future.component) {
          // If we have a normal route, we need to go through an outlet.
          var context = parentContext.getContext(future.outlet);

          if (context) {
            this.deactivateChildRoutes(futureNode, currNode, context.children);
          }
        } else {
          // if we have a componentless route, we recurse but keep the same outlet map.
          this.deactivateChildRoutes(futureNode, currNode, parentContext);
        }
      } else {
        if (curr) {
          // Deactivate the current route which will not be re-used
          this.deactivateRouteAndItsChildren(currNode, parentContext);
        }
      }
    }
  }, {
    key: "deactivateRouteAndItsChildren",
    value: function deactivateRouteAndItsChildren(route, parentContexts) {
      if (this.routeReuseStrategy.shouldDetach(route.value.snapshot)) {
        this.detachAndStoreRouteSubtree(route, parentContexts);
      } else {
        this.deactivateRouteAndOutlet(route, parentContexts);
      }
    }
  }, {
    key: "detachAndStoreRouteSubtree",
    value: function detachAndStoreRouteSubtree(route, parentContexts) {
      var context = parentContexts.getContext(route.value.outlet);

      if (context && context.outlet) {
        var componentRef = context.outlet.detach();
        var contexts = context.children.onOutletDeactivated();
        this.routeReuseStrategy.store(route.value.snapshot, {
          componentRef: componentRef,
          route: route,
          contexts: contexts
        });
      }
    }
  }, {
    key: "deactivateRouteAndOutlet",
    value: function deactivateRouteAndOutlet(route, parentContexts) {
      var _this14 = this;

      var context = parentContexts.getContext(route.value.outlet);

      if (context) {
        var children = nodeChildrenAsMap(route);
        var contexts = route.value.component ? context.children : parentContexts;
        forEach(children, function (v, k) {
          return _this14.deactivateRouteAndItsChildren(v, contexts);
        });

        if (context.outlet) {
          // Destroy the component
          context.outlet.deactivate(); // Destroy the contexts for all the outlets that were in the component

          context.children.onOutletDeactivated();
        }
      }
    }
  }, {
    key: "activateChildRoutes",
    value: function activateChildRoutes(futureNode, currNode, contexts) {
      var _this15 = this;

      var children = nodeChildrenAsMap(currNode);
      futureNode.children.forEach(function (c) {
        _this15.activateRoutes(c, children[c.value.outlet], contexts);

        _this15.forwardEvent(new ActivationEnd(c.value.snapshot));
      });

      if (futureNode.children.length) {
        this.forwardEvent(new ChildActivationEnd(futureNode.value.snapshot));
      }
    }
  }, {
    key: "activateRoutes",
    value: function activateRoutes(futureNode, currNode, parentContexts) {
      var future = futureNode.value;
      var curr = currNode ? currNode.value : null;
      advanceActivatedRoute(future); // reusing the node

      if (future === curr) {
        if (future.component) {
          // If we have a normal route, we need to go through an outlet.
          var context = parentContexts.getOrCreateContext(future.outlet);
          this.activateChildRoutes(futureNode, currNode, context.children);
        } else {
          // if we have a componentless route, we recurse but keep the same outlet map.
          this.activateChildRoutes(futureNode, currNode, parentContexts);
        }
      } else {
        if (future.component) {
          // if we have a normal route, we need to place the component into the outlet and recurse.
          var _context = parentContexts.getOrCreateContext(future.outlet);

          if (this.routeReuseStrategy.shouldAttach(future.snapshot)) {
            var stored = this.routeReuseStrategy.retrieve(future.snapshot);
            this.routeReuseStrategy.store(future.snapshot, null);

            _context.children.onOutletReAttached(stored.contexts);

            _context.attachRef = stored.componentRef;
            _context.route = stored.route.value;

            if (_context.outlet) {
              // Attach right away when the outlet has already been instantiated
              // Otherwise attach from `RouterOutlet.ngOnInit` when it is instantiated
              _context.outlet.attach(stored.componentRef, stored.route.value);
            }

            advanceActivatedRouteNodeAndItsChildren(stored.route);
          } else {
            var config = parentLoadedConfig(future.snapshot);
            var cmpFactoryResolver = config ? config.module.componentFactoryResolver : null;
            _context.attachRef = null;
            _context.route = future;
            _context.resolver = cmpFactoryResolver;

            if (_context.outlet) {
              // Activate the outlet when it has already been instantiated
              // Otherwise it will get activated from its `ngOnInit` when instantiated
              _context.outlet.activateWith(future, cmpFactoryResolver);
            }

            this.activateChildRoutes(futureNode, null, _context.children);
          }
        } else {
          // if we have a componentless route, we recurse but keep the same outlet map.
          this.activateChildRoutes(futureNode, null, parentContexts);
        }
      }
    }
  }]);

  return ActivateRoutes;
}();

function advanceActivatedRouteNodeAndItsChildren(node) {
  advanceActivatedRoute(node.value);
  node.children.forEach(advanceActivatedRouteNodeAndItsChildren);
}

function parentLoadedConfig(snapshot) {
  for (var s = snapshot.parent; s; s = s.parent) {
    var route = s.routeConfig;
    if (route && route._loadedConfig) return route._loadedConfig;
    if (route && route.component) return null;
  }

  return null;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var LoadedRouterConfig = function LoadedRouterConfig(routes, module) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, LoadedRouterConfig);

  this.routes = routes;
  this.module = module;
};
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Simple function check, but generic so type inference will flow. Example:
 *
 * function product(a: number, b: number) {
 *   return a * b;
 * }
 *
 * if (isFunction<product>(fn)) {
 *   return fn(1, 2);
 * } else {
 *   throw "Must provide the `product` function";
 * }
 */


function isFunction(v) {
  return typeof v === 'function';
}

function isBoolean(v) {
  return typeof v === 'boolean';
}

function isUrlTree(v) {
  return v instanceof UrlTree;
}

function isCanLoad(guard) {
  return guard && isFunction(guard.canLoad);
}

function isCanActivate(guard) {
  return guard && isFunction(guard.canActivate);
}

function isCanActivateChild(guard) {
  return guard && isFunction(guard.canActivateChild);
}

function isCanDeactivate(guard) {
  return guard && isFunction(guard.canDeactivate);
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var INITIAL_VALUE = Symbol('INITIAL_VALUE');

function prioritizedGuardValue() {
  return Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (obs) {
    return rxjs__WEBPACK_IMPORTED_MODULE_10__["combineLatest"].apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(obs.map(function (o) {
      return o.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["take"])(1), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["startWith"])(INITIAL_VALUE));
    }))).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["scan"])(function (acc, list) {
      var isPending = false;
      return list.reduce(function (innerAcc, val, i) {
        if (innerAcc !== INITIAL_VALUE) return innerAcc; // Toggle pending flag if any values haven't been set yet

        if (val === INITIAL_VALUE) isPending = true; // Any other return values are only valid if we haven't yet hit a pending
        // call. This guarantees that in the case of a guard at the bottom of the
        // tree that returns a redirect, we will wait for the higher priority
        // guard at the top to finish before performing the redirect.

        if (!isPending) {
          // Early return when we hit a `false` value as that should always
          // cancel navigation
          if (val === false) return val;

          if (i === list.length - 1 || isUrlTree(val)) {
            return val;
          }
        }

        return innerAcc;
      }, acc);
    }, INITIAL_VALUE), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["filter"])(function (item) {
      return item !== INITIAL_VALUE;
    }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (item) {
      return isUrlTree(item) ? item : item === true;
    }), //
    Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["take"])(1));
  });
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NoMatch = function NoMatch(segmentGroup) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NoMatch);

  this.segmentGroup = segmentGroup || null;
};

var AbsoluteRedirect = function AbsoluteRedirect(urlTree) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, AbsoluteRedirect);

  this.urlTree = urlTree;
};

function noMatch(segmentGroup) {
  return new rxjs__WEBPACK_IMPORTED_MODULE_10__["Observable"](function (obs) {
    return obs.error(new NoMatch(segmentGroup));
  });
}

function absoluteRedirect(newTree) {
  return new rxjs__WEBPACK_IMPORTED_MODULE_10__["Observable"](function (obs) {
    return obs.error(new AbsoluteRedirect(newTree));
  });
}

function namedOutletsRedirect(redirectTo) {
  return new rxjs__WEBPACK_IMPORTED_MODULE_10__["Observable"](function (obs) {
    return obs.error(new Error("Only absolute redirects can have named outlets. redirectTo: '".concat(redirectTo, "'")));
  });
}

function canLoadFails(route) {
  return new rxjs__WEBPACK_IMPORTED_MODULE_10__["Observable"](function (obs) {
    return obs.error(navigationCancelingError("Cannot load children because the guard of the route \"path: '".concat(route.path, "'\" returned false")));
  });
}
/**
 * Returns the `UrlTree` with the redirection applied.
 *
 * Lazy modules are loaded along the way.
 */


function applyRedirects(moduleInjector, configLoader, urlSerializer, urlTree, config) {
  return new ApplyRedirects(moduleInjector, configLoader, urlSerializer, urlTree, config).apply();
}

var ApplyRedirects = /*#__PURE__*/function () {
  function ApplyRedirects(moduleInjector, configLoader, urlSerializer, urlTree, config) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ApplyRedirects);

    this.configLoader = configLoader;
    this.urlSerializer = urlSerializer;
    this.urlTree = urlTree;
    this.config = config;
    this.allowRedirects = true;
    this.ngModule = moduleInjector.get(_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleRef"]);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ApplyRedirects, [{
    key: "apply",
    value: function apply() {
      var _this16 = this;

      var expanded$ = this.expandSegmentGroup(this.ngModule, this.config, this.urlTree.root, PRIMARY_OUTLET);
      var urlTrees$ = expanded$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (rootSegmentGroup) {
        return _this16.createUrlTree(rootSegmentGroup, _this16.urlTree.queryParams, _this16.urlTree.fragment);
      }));
      return urlTrees$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["catchError"])(function (e) {
        if (e instanceof AbsoluteRedirect) {
          // after an absolute redirect we do not apply any more redirects!
          _this16.allowRedirects = false; // we need to run matching, so we can fetch all lazy-loaded modules

          return _this16.match(e.urlTree);
        }

        if (e instanceof NoMatch) {
          throw _this16.noMatchError(e);
        }

        throw e;
      }));
    }
  }, {
    key: "match",
    value: function match(tree) {
      var _this17 = this;

      var expanded$ = this.expandSegmentGroup(this.ngModule, this.config, tree.root, PRIMARY_OUTLET);
      var mapped$ = expanded$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (rootSegmentGroup) {
        return _this17.createUrlTree(rootSegmentGroup, tree.queryParams, tree.fragment);
      }));
      return mapped$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["catchError"])(function (e) {
        if (e instanceof NoMatch) {
          throw _this17.noMatchError(e);
        }

        throw e;
      }));
    }
  }, {
    key: "noMatchError",
    value: function noMatchError(e) {
      return new Error("Cannot match any routes. URL Segment: '".concat(e.segmentGroup, "'"));
    }
  }, {
    key: "createUrlTree",
    value: function createUrlTree(rootCandidate, queryParams, fragment) {
      var root = rootCandidate.segments.length > 0 ? new UrlSegmentGroup([], Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_defineProperty__WEBPACK_IMPORTED_MODULE_0__["default"])({}, PRIMARY_OUTLET, rootCandidate)) : rootCandidate;
      return new UrlTree(root, queryParams, fragment);
    }
  }, {
    key: "expandSegmentGroup",
    value: function expandSegmentGroup(ngModule, routes, segmentGroup, outlet) {
      if (segmentGroup.segments.length === 0 && segmentGroup.hasChildren()) {
        return this.expandChildren(ngModule, routes, segmentGroup).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (children) {
          return new UrlSegmentGroup([], children);
        }));
      }

      return this.expandSegment(ngModule, segmentGroup, routes, segmentGroup.segments, outlet, true);
    } // Recursively expand segment groups for all the child outlets

  }, {
    key: "expandChildren",
    value: function expandChildren(ngModule, routes, segmentGroup) {
      var _this18 = this;

      return waitForMap(segmentGroup.children, function (childOutlet, child) {
        return _this18.expandSegmentGroup(ngModule, routes, child, childOutlet);
      });
    }
  }, {
    key: "expandSegment",
    value: function expandSegment(ngModule, segmentGroup, routes, segments, outlet, allowRedirects) {
      var _this19 = this;

      return rxjs__WEBPACK_IMPORTED_MODULE_10__["of"].apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(routes)).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["concatMap"])(function (r) {
        var expanded$ = _this19.expandSegmentAgainstRoute(ngModule, segmentGroup, routes, r, segments, outlet, allowRedirects);

        return expanded$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["catchError"])(function (e) {
          if (e instanceof NoMatch) {
            // TODO(i): this return type doesn't match the declared Observable<UrlSegmentGroup> -
            // talk to Jason
            return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(null);
          }

          throw e;
        }));
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])(function (s) {
        return !!s;
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["catchError"])(function (e, _) {
        if (e instanceof rxjs__WEBPACK_IMPORTED_MODULE_10__["EmptyError"] || e.name === 'EmptyError') {
          if (_this19.noLeftoversInUrl(segmentGroup, segments, outlet)) {
            return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(new UrlSegmentGroup([], {}));
          }

          throw new NoMatch(segmentGroup);
        }

        throw e;
      }));
    }
  }, {
    key: "noLeftoversInUrl",
    value: function noLeftoversInUrl(segmentGroup, segments, outlet) {
      return segments.length === 0 && !segmentGroup.children[outlet];
    }
  }, {
    key: "expandSegmentAgainstRoute",
    value: function expandSegmentAgainstRoute(ngModule, segmentGroup, routes, route, paths, outlet, allowRedirects) {
      if (getOutlet(route) !== outlet) {
        return noMatch(segmentGroup);
      }

      if (route.redirectTo === undefined) {
        return this.matchSegmentAgainstRoute(ngModule, segmentGroup, route, paths);
      }

      if (allowRedirects && this.allowRedirects) {
        return this.expandSegmentAgainstRouteUsingRedirect(ngModule, segmentGroup, routes, route, paths, outlet);
      }

      return noMatch(segmentGroup);
    }
  }, {
    key: "expandSegmentAgainstRouteUsingRedirect",
    value: function expandSegmentAgainstRouteUsingRedirect(ngModule, segmentGroup, routes, route, segments, outlet) {
      if (route.path === '**') {
        return this.expandWildCardWithParamsAgainstRouteUsingRedirect(ngModule, routes, route, outlet);
      }

      return this.expandRegularSegmentAgainstRouteUsingRedirect(ngModule, segmentGroup, routes, route, segments, outlet);
    }
  }, {
    key: "expandWildCardWithParamsAgainstRouteUsingRedirect",
    value: function expandWildCardWithParamsAgainstRouteUsingRedirect(ngModule, routes, route, outlet) {
      var _this20 = this;

      var newTree = this.applyRedirectCommands([], route.redirectTo, {});

      if (route.redirectTo.startsWith('/')) {
        return absoluteRedirect(newTree);
      }

      return this.lineralizeSegments(route, newTree).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (newSegments) {
        var group = new UrlSegmentGroup(newSegments, {});
        return _this20.expandSegment(ngModule, group, routes, newSegments, outlet, false);
      }));
    }
  }, {
    key: "expandRegularSegmentAgainstRouteUsingRedirect",
    value: function expandRegularSegmentAgainstRouteUsingRedirect(ngModule, segmentGroup, routes, route, segments, outlet) {
      var _this21 = this;

      var _match = match(segmentGroup, route, segments),
          matched = _match.matched,
          consumedSegments = _match.consumedSegments,
          lastChild = _match.lastChild,
          positionalParamSegments = _match.positionalParamSegments;

      if (!matched) return noMatch(segmentGroup);
      var newTree = this.applyRedirectCommands(consumedSegments, route.redirectTo, positionalParamSegments);

      if (route.redirectTo.startsWith('/')) {
        return absoluteRedirect(newTree);
      }

      return this.lineralizeSegments(route, newTree).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (newSegments) {
        return _this21.expandSegment(ngModule, segmentGroup, routes, newSegments.concat(segments.slice(lastChild)), outlet, false);
      }));
    }
  }, {
    key: "matchSegmentAgainstRoute",
    value: function matchSegmentAgainstRoute(ngModule, rawSegmentGroup, route, segments) {
      var _this22 = this;

      if (route.path === '**') {
        if (route.loadChildren) {
          return this.configLoader.load(ngModule.injector, route).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (cfg) {
            route._loadedConfig = cfg;
            return new UrlSegmentGroup(segments, {});
          }));
        }

        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(new UrlSegmentGroup(segments, {}));
      }

      var _match2 = match(rawSegmentGroup, route, segments),
          matched = _match2.matched,
          consumedSegments = _match2.consumedSegments,
          lastChild = _match2.lastChild;

      if (!matched) return noMatch(rawSegmentGroup);
      var rawSlicedSegments = segments.slice(lastChild);
      var childConfig$ = this.getChildConfig(ngModule, route, segments);
      return childConfig$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (routerConfig) {
        var childModule = routerConfig.module;
        var childConfig = routerConfig.routes;

        var _split = split(rawSegmentGroup, consumedSegments, rawSlicedSegments, childConfig),
            segmentGroup = _split.segmentGroup,
            slicedSegments = _split.slicedSegments;

        if (slicedSegments.length === 0 && segmentGroup.hasChildren()) {
          var _expanded$ = _this22.expandChildren(childModule, childConfig, segmentGroup);

          return _expanded$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (children) {
            return new UrlSegmentGroup(consumedSegments, children);
          }));
        }

        if (childConfig.length === 0 && slicedSegments.length === 0) {
          return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(new UrlSegmentGroup(consumedSegments, {}));
        }

        var expanded$ = _this22.expandSegment(childModule, segmentGroup, childConfig, slicedSegments, PRIMARY_OUTLET, true);

        return expanded$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (cs) {
          return new UrlSegmentGroup(consumedSegments.concat(cs.segments), cs.children);
        }));
      }));
    }
  }, {
    key: "getChildConfig",
    value: function getChildConfig(ngModule, route, segments) {
      var _this23 = this;

      if (route.children) {
        // The children belong to the same module
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(new LoadedRouterConfig(route.children, ngModule));
      }

      if (route.loadChildren) {
        // lazy children belong to the loaded module
        if (route._loadedConfig !== undefined) {
          return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(route._loadedConfig);
        }

        return this.runCanLoadGuards(ngModule.injector, route, segments).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (shouldLoadResult) {
          if (shouldLoadResult) {
            return _this23.configLoader.load(ngModule.injector, route).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (cfg) {
              route._loadedConfig = cfg;
              return cfg;
            }));
          }

          return canLoadFails(route);
        }));
      }

      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(new LoadedRouterConfig([], ngModule));
    }
  }, {
    key: "runCanLoadGuards",
    value: function runCanLoadGuards(moduleInjector, route, segments) {
      var _this24 = this;

      var canLoad = route.canLoad;
      if (!canLoad || canLoad.length === 0) return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(true);
      var canLoadObservables = canLoad.map(function (injectionToken) {
        var guard = moduleInjector.get(injectionToken);
        var guardVal;

        if (isCanLoad(guard)) {
          guardVal = guard.canLoad(route, segments);
        } else if (isFunction(guard)) {
          guardVal = guard(route, segments);
        } else {
          throw new Error('Invalid CanLoad guard');
        }

        return wrapIntoObservable(guardVal);
      });
      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(canLoadObservables).pipe(prioritizedGuardValue(), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (result) {
        if (!isUrlTree(result)) return;
        var error = navigationCancelingError("Redirecting to \"".concat(_this24.urlSerializer.serialize(result), "\""));
        error.url = result;
        throw error;
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (result) {
        return result === true;
      }));
    }
  }, {
    key: "lineralizeSegments",
    value: function lineralizeSegments(route, urlTree) {
      var res = [];
      var c = urlTree.root;

      while (true) {
        res = res.concat(c.segments);

        if (c.numberOfChildren === 0) {
          return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(res);
        }

        if (c.numberOfChildren > 1 || !c.children[PRIMARY_OUTLET]) {
          return namedOutletsRedirect(route.redirectTo);
        }

        c = c.children[PRIMARY_OUTLET];
      }
    }
  }, {
    key: "applyRedirectCommands",
    value: function applyRedirectCommands(segments, redirectTo, posParams) {
      return this.applyRedirectCreatreUrlTree(redirectTo, this.urlSerializer.parse(redirectTo), segments, posParams);
    }
  }, {
    key: "applyRedirectCreatreUrlTree",
    value: function applyRedirectCreatreUrlTree(redirectTo, urlTree, segments, posParams) {
      var newRoot = this.createSegmentGroup(redirectTo, urlTree.root, segments, posParams);
      return new UrlTree(newRoot, this.createQueryParams(urlTree.queryParams, this.urlTree.queryParams), urlTree.fragment);
    }
  }, {
    key: "createQueryParams",
    value: function createQueryParams(redirectToParams, actualParams) {
      var res = {};
      forEach(redirectToParams, function (v, k) {
        var copySourceValue = typeof v === 'string' && v.startsWith(':');

        if (copySourceValue) {
          var sourceName = v.substring(1);
          res[k] = actualParams[sourceName];
        } else {
          res[k] = v;
        }
      });
      return res;
    }
  }, {
    key: "createSegmentGroup",
    value: function createSegmentGroup(redirectTo, group, segments, posParams) {
      var _this25 = this;

      var updatedSegments = this.createSegments(redirectTo, group.segments, segments, posParams);
      var children = {};
      forEach(group.children, function (child, name) {
        children[name] = _this25.createSegmentGroup(redirectTo, child, segments, posParams);
      });
      return new UrlSegmentGroup(updatedSegments, children);
    }
  }, {
    key: "createSegments",
    value: function createSegments(redirectTo, redirectToSegments, actualSegments, posParams) {
      var _this26 = this;

      return redirectToSegments.map(function (s) {
        return s.path.startsWith(':') ? _this26.findPosParam(redirectTo, s, posParams) : _this26.findOrReturn(s, actualSegments);
      });
    }
  }, {
    key: "findPosParam",
    value: function findPosParam(redirectTo, redirectToUrlSegment, posParams) {
      var pos = posParams[redirectToUrlSegment.path.substring(1)];
      if (!pos) throw new Error("Cannot redirect to '".concat(redirectTo, "'. Cannot find '").concat(redirectToUrlSegment.path, "'."));
      return pos;
    }
  }, {
    key: "findOrReturn",
    value: function findOrReturn(redirectToUrlSegment, actualSegments) {
      var idx = 0;

      var _iterator4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(actualSegments),
          _step4;

      try {
        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
          var s = _step4.value;

          if (s.path === redirectToUrlSegment.path) {
            actualSegments.splice(idx);
            return s;
          }

          idx++;
        }
      } catch (err) {
        _iterator4.e(err);
      } finally {
        _iterator4.f();
      }

      return redirectToUrlSegment;
    }
  }]);

  return ApplyRedirects;
}();

function match(segmentGroup, route, segments) {
  if (route.path === '') {
    if (route.pathMatch === 'full' && (segmentGroup.hasChildren() || segments.length > 0)) {
      return {
        matched: false,
        consumedSegments: [],
        lastChild: 0,
        positionalParamSegments: {}
      };
    }

    return {
      matched: true,
      consumedSegments: [],
      lastChild: 0,
      positionalParamSegments: {}
    };
  }

  var matcher = route.matcher || defaultUrlMatcher;
  var res = matcher(segments, segmentGroup, route);

  if (!res) {
    return {
      matched: false,
      consumedSegments: [],
      lastChild: 0,
      positionalParamSegments: {}
    };
  }

  return {
    matched: true,
    consumedSegments: res.consumed,
    lastChild: res.consumed.length,
    positionalParamSegments: res.posParams
  };
}

function split(segmentGroup, consumedSegments, slicedSegments, config) {
  if (slicedSegments.length > 0 && containsEmptyPathRedirectsWithNamedOutlets(segmentGroup, slicedSegments, config)) {
    var s = new UrlSegmentGroup(consumedSegments, createChildrenForEmptySegments(config, new UrlSegmentGroup(slicedSegments, segmentGroup.children)));
    return {
      segmentGroup: mergeTrivialChildren(s),
      slicedSegments: []
    };
  }

  if (slicedSegments.length === 0 && containsEmptyPathRedirects(segmentGroup, slicedSegments, config)) {
    var _s = new UrlSegmentGroup(segmentGroup.segments, addEmptySegmentsToChildrenIfNeeded(segmentGroup, slicedSegments, config, segmentGroup.children));

    return {
      segmentGroup: mergeTrivialChildren(_s),
      slicedSegments: slicedSegments
    };
  }

  return {
    segmentGroup: segmentGroup,
    slicedSegments: slicedSegments
  };
}

function mergeTrivialChildren(s) {
  if (s.numberOfChildren === 1 && s.children[PRIMARY_OUTLET]) {
    var c = s.children[PRIMARY_OUTLET];
    return new UrlSegmentGroup(s.segments.concat(c.segments), c.children);
  }

  return s;
}

function addEmptySegmentsToChildrenIfNeeded(segmentGroup, slicedSegments, routes, children) {
  var res = {};

  var _iterator5 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(routes),
      _step5;

  try {
    for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
      var r = _step5.value;

      if (isEmptyPathRedirect(segmentGroup, slicedSegments, r) && !children[getOutlet(r)]) {
        res[getOutlet(r)] = new UrlSegmentGroup([], {});
      }
    }
  } catch (err) {
    _iterator5.e(err);
  } finally {
    _iterator5.f();
  }

  return Object.assign(Object.assign({}, children), res);
}

function createChildrenForEmptySegments(routes, primarySegmentGroup) {
  var res = {};
  res[PRIMARY_OUTLET] = primarySegmentGroup;

  var _iterator6 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(routes),
      _step6;

  try {
    for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
      var r = _step6.value;

      if (r.path === '' && getOutlet(r) !== PRIMARY_OUTLET) {
        res[getOutlet(r)] = new UrlSegmentGroup([], {});
      }
    }
  } catch (err) {
    _iterator6.e(err);
  } finally {
    _iterator6.f();
  }

  return res;
}

function containsEmptyPathRedirectsWithNamedOutlets(segmentGroup, segments, routes) {
  return routes.some(function (r) {
    return isEmptyPathRedirect(segmentGroup, segments, r) && getOutlet(r) !== PRIMARY_OUTLET;
  });
}

function containsEmptyPathRedirects(segmentGroup, segments, routes) {
  return routes.some(function (r) {
    return isEmptyPathRedirect(segmentGroup, segments, r);
  });
}

function isEmptyPathRedirect(segmentGroup, segments, r) {
  if ((segmentGroup.hasChildren() || segments.length > 0) && r.pathMatch === 'full') {
    return false;
  }

  return r.path === '' && r.redirectTo !== undefined;
}

function getOutlet(route) {
  return route.outlet || PRIMARY_OUTLET;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function applyRedirects$1(moduleInjector, configLoader, urlSerializer, config) {
  return function (source) {
    return source.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (t) {
      return applyRedirects(moduleInjector, configLoader, urlSerializer, t.extractedUrl, config).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (urlAfterRedirects) {
        return Object.assign(Object.assign({}, t), {
          urlAfterRedirects: urlAfterRedirects
        });
      }));
    }));
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var CanActivate = function CanActivate(path) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, CanActivate);

  this.path = path;
  this.route = this.path[this.path.length - 1];
};

var CanDeactivate = function CanDeactivate(component, route) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, CanDeactivate);

  this.component = component;
  this.route = route;
};

function getAllRouteGuards(future, curr, parentContexts) {
  var futureRoot = future._root;
  var currRoot = curr ? curr._root : null;
  return getChildRouteGuards(futureRoot, currRoot, parentContexts, [futureRoot.value]);
}

function getCanActivateChild(p) {
  var canActivateChild = p.routeConfig ? p.routeConfig.canActivateChild : null;
  if (!canActivateChild || canActivateChild.length === 0) return null;
  return {
    node: p,
    guards: canActivateChild
  };
}

function getToken(token, snapshot, moduleInjector) {
  var config = getClosestLoadedConfig(snapshot);
  var injector = config ? config.module.injector : moduleInjector;
  return injector.get(token);
}

function getClosestLoadedConfig(snapshot) {
  if (!snapshot) return null;

  for (var s = snapshot.parent; s; s = s.parent) {
    var route = s.routeConfig;
    if (route && route._loadedConfig) return route._loadedConfig;
  }

  return null;
}

function getChildRouteGuards(futureNode, currNode, contexts, futurePath) {
  var checks = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {
    canDeactivateChecks: [],
    canActivateChecks: []
  };
  var prevChildren = nodeChildrenAsMap(currNode); // Process the children of the future route

  futureNode.children.forEach(function (c) {
    getRouteGuards(c, prevChildren[c.value.outlet], contexts, futurePath.concat([c.value]), checks);
    delete prevChildren[c.value.outlet];
  }); // Process any children left from the current route (not active for the future route)

  forEach(prevChildren, function (v, k) {
    return deactivateRouteAndItsChildren(v, contexts.getContext(k), checks);
  });
  return checks;
}

function getRouteGuards(futureNode, currNode, parentContexts, futurePath) {
  var checks = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {
    canDeactivateChecks: [],
    canActivateChecks: []
  };
  var future = futureNode.value;
  var curr = currNode ? currNode.value : null;
  var context = parentContexts ? parentContexts.getContext(futureNode.value.outlet) : null; // reusing the node

  if (curr && future.routeConfig === curr.routeConfig) {
    var shouldRun = shouldRunGuardsAndResolvers(curr, future, future.routeConfig.runGuardsAndResolvers);

    if (shouldRun) {
      checks.canActivateChecks.push(new CanActivate(futurePath));
    } else {
      // we need to set the data
      future.data = curr.data;
      future._resolvedData = curr._resolvedData;
    } // If we have a component, we need to go through an outlet.


    if (future.component) {
      getChildRouteGuards(futureNode, currNode, context ? context.children : null, futurePath, checks); // if we have a componentless route, we recurse but keep the same outlet map.
    } else {
      getChildRouteGuards(futureNode, currNode, parentContexts, futurePath, checks);
    }

    if (shouldRun) {
      var component = context && context.outlet && context.outlet.component || null;
      checks.canDeactivateChecks.push(new CanDeactivate(component, curr));
    }
  } else {
    if (curr) {
      deactivateRouteAndItsChildren(currNode, context, checks);
    }

    checks.canActivateChecks.push(new CanActivate(futurePath)); // If we have a component, we need to go through an outlet.

    if (future.component) {
      getChildRouteGuards(futureNode, null, context ? context.children : null, futurePath, checks); // if we have a componentless route, we recurse but keep the same outlet map.
    } else {
      getChildRouteGuards(futureNode, null, parentContexts, futurePath, checks);
    }
  }

  return checks;
}

function shouldRunGuardsAndResolvers(curr, future, mode) {
  if (typeof mode === 'function') {
    return mode(curr, future);
  }

  switch (mode) {
    case 'pathParamsChange':
      return !equalPath(curr.url, future.url);

    case 'pathParamsOrQueryParamsChange':
      return !equalPath(curr.url, future.url) || !shallowEqual(curr.queryParams, future.queryParams);

    case 'always':
      return true;

    case 'paramsOrQueryParamsChange':
      return !equalParamsAndUrlSegments(curr, future) || !shallowEqual(curr.queryParams, future.queryParams);

    case 'paramsChange':
    default:
      return !equalParamsAndUrlSegments(curr, future);
  }
}

function deactivateRouteAndItsChildren(route, context, checks) {
  var children = nodeChildrenAsMap(route);
  var r = route.value;
  forEach(children, function (node, childName) {
    if (!r.component) {
      deactivateRouteAndItsChildren(node, context, checks);
    } else if (context) {
      deactivateRouteAndItsChildren(node, context.children.getContext(childName), checks);
    } else {
      deactivateRouteAndItsChildren(node, null, checks);
    }
  });

  if (!r.component) {
    checks.canDeactivateChecks.push(new CanDeactivate(null, r));
  } else if (context && context.outlet && context.outlet.isActivated) {
    checks.canDeactivateChecks.push(new CanDeactivate(context.outlet.component, r));
  } else {
    checks.canDeactivateChecks.push(new CanDeactivate(null, r));
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function checkGuards(moduleInjector, forwardEvent) {
  return function (source) {
    return source.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (t) {
      var targetSnapshot = t.targetSnapshot,
          currentSnapshot = t.currentSnapshot,
          _t$guards = t.guards,
          canActivateChecks = _t$guards.canActivateChecks,
          canDeactivateChecks = _t$guards.canDeactivateChecks;

      if (canDeactivateChecks.length === 0 && canActivateChecks.length === 0) {
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(Object.assign(Object.assign({}, t), {
          guardsResult: true
        }));
      }

      return runCanDeactivateChecks(canDeactivateChecks, targetSnapshot, currentSnapshot, moduleInjector).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (canDeactivate) {
        return canDeactivate && isBoolean(canDeactivate) ? runCanActivateChecks(targetSnapshot, canActivateChecks, moduleInjector, forwardEvent) : Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(canDeactivate);
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (guardsResult) {
        return Object.assign(Object.assign({}, t), {
          guardsResult: guardsResult
        });
      }));
    }));
  };
}

function runCanDeactivateChecks(checks, futureRSS, currRSS, moduleInjector) {
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(checks).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (check) {
    return runCanDeactivate(check.component, check.route, currRSS, futureRSS, moduleInjector);
  }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])(function (result) {
    return result !== true;
  }, true));
}

function runCanActivateChecks(futureSnapshot, checks, moduleInjector, forwardEvent) {
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(checks).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["concatMap"])(function (check) {
    return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])([fireChildActivationStart(check.route.parent, forwardEvent), fireActivationStart(check.route, forwardEvent), runCanActivateChild(futureSnapshot, check.path, moduleInjector), runCanActivate(futureSnapshot, check.route, moduleInjector)]).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["concatAll"])(), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])(function (result) {
      return result !== true;
    }, true));
  }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])(function (result) {
    return result !== true;
  }, true));
}
/**
 * This should fire off `ActivationStart` events for each route being activated at this
 * level.
 * In other words, if you're activating `a` and `b` below, `path` will contain the
 * `ActivatedRouteSnapshot`s for both and we will fire `ActivationStart` for both. Always
 * return
 * `true` so checks continue to run.
 */


function fireActivationStart(snapshot, forwardEvent) {
  if (snapshot !== null && forwardEvent) {
    forwardEvent(new ActivationStart(snapshot));
  }

  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(true);
}
/**
 * This should fire off `ChildActivationStart` events for each route being activated at this
 * level.
 * In other words, if you're activating `a` and `b` below, `path` will contain the
 * `ActivatedRouteSnapshot`s for both and we will fire `ChildActivationStart` for both. Always
 * return
 * `true` so checks continue to run.
 */


function fireChildActivationStart(snapshot, forwardEvent) {
  if (snapshot !== null && forwardEvent) {
    forwardEvent(new ChildActivationStart(snapshot));
  }

  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(true);
}

function runCanActivate(futureRSS, futureARS, moduleInjector) {
  var canActivate = futureARS.routeConfig ? futureARS.routeConfig.canActivate : null;
  if (!canActivate || canActivate.length === 0) return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(true);
  var canActivateObservables = canActivate.map(function (c) {
    return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["defer"])(function () {
      var guard = getToken(c, futureARS, moduleInjector);
      var observable;

      if (isCanActivate(guard)) {
        observable = wrapIntoObservable(guard.canActivate(futureARS, futureRSS));
      } else if (isFunction(guard)) {
        observable = wrapIntoObservable(guard(futureARS, futureRSS));
      } else {
        throw new Error('Invalid CanActivate guard');
      }

      return observable.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])());
    });
  });
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(canActivateObservables).pipe(prioritizedGuardValue());
}

function runCanActivateChild(futureRSS, path, moduleInjector) {
  var futureARS = path[path.length - 1];
  var canActivateChildGuards = path.slice(0, path.length - 1).reverse().map(function (p) {
    return getCanActivateChild(p);
  }).filter(function (_) {
    return _ !== null;
  });
  var canActivateChildGuardsMapped = canActivateChildGuards.map(function (d) {
    return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["defer"])(function () {
      var guardsMapped = d.guards.map(function (c) {
        var guard = getToken(c, d.node, moduleInjector);
        var observable;

        if (isCanActivateChild(guard)) {
          observable = wrapIntoObservable(guard.canActivateChild(futureARS, futureRSS));
        } else if (isFunction(guard)) {
          observable = wrapIntoObservable(guard(futureARS, futureRSS));
        } else {
          throw new Error('Invalid CanActivateChild guard');
        }

        return observable.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])());
      });
      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(guardsMapped).pipe(prioritizedGuardValue());
    });
  });
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(canActivateChildGuardsMapped).pipe(prioritizedGuardValue());
}

function runCanDeactivate(component, currARS, currRSS, futureRSS, moduleInjector) {
  var canDeactivate = currARS && currARS.routeConfig ? currARS.routeConfig.canDeactivate : null;
  if (!canDeactivate || canDeactivate.length === 0) return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(true);
  var canDeactivateObservables = canDeactivate.map(function (c) {
    var guard = getToken(c, currARS, moduleInjector);
    var observable;

    if (isCanDeactivate(guard)) {
      observable = wrapIntoObservable(guard.canDeactivate(component, currARS, currRSS, futureRSS));
    } else if (isFunction(guard)) {
      observable = wrapIntoObservable(guard(component, currARS, currRSS, futureRSS));
    } else {
      throw new Error('Invalid CanDeactivate guard');
    }

    return observable.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["first"])());
  });
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(canDeactivateObservables).pipe(prioritizedGuardValue());
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var NoMatch$1 = function NoMatch$1() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NoMatch$1);
};

function recognize(rootComponentType, config, urlTree, url) {
  var paramsInheritanceStrategy = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'emptyOnly';
  var relativeLinkResolution = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'legacy';
  return new Recognizer(rootComponentType, config, urlTree, url, paramsInheritanceStrategy, relativeLinkResolution).recognize();
}

var Recognizer = /*#__PURE__*/function () {
  function Recognizer(rootComponentType, config, urlTree, url, paramsInheritanceStrategy, relativeLinkResolution) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, Recognizer);

    this.rootComponentType = rootComponentType;
    this.config = config;
    this.urlTree = urlTree;
    this.url = url;
    this.paramsInheritanceStrategy = paramsInheritanceStrategy;
    this.relativeLinkResolution = relativeLinkResolution;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(Recognizer, [{
    key: "recognize",
    value: function recognize() {
      try {
        var rootSegmentGroup = split$1(this.urlTree.root, [], [], this.config, this.relativeLinkResolution).segmentGroup;
        var children = this.processSegmentGroup(this.config, rootSegmentGroup, PRIMARY_OUTLET);
        var root = new ActivatedRouteSnapshot([], Object.freeze({}), Object.freeze(Object.assign({}, this.urlTree.queryParams)), this.urlTree.fragment, {}, PRIMARY_OUTLET, this.rootComponentType, null, this.urlTree.root, -1, {});
        var rootNode = new TreeNode(root, children);
        var routeState = new RouterStateSnapshot(this.url, rootNode);
        this.inheritParamsAndData(routeState._root);
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(routeState);
      } catch (e) {
        return new rxjs__WEBPACK_IMPORTED_MODULE_10__["Observable"](function (obs) {
          return obs.error(e);
        });
      }
    }
  }, {
    key: "inheritParamsAndData",
    value: function inheritParamsAndData(routeNode) {
      var _this27 = this;

      var route = routeNode.value;
      var i = inheritedParamsDataResolve(route, this.paramsInheritanceStrategy);
      route.params = Object.freeze(i.params);
      route.data = Object.freeze(i.data);
      routeNode.children.forEach(function (n) {
        return _this27.inheritParamsAndData(n);
      });
    }
  }, {
    key: "processSegmentGroup",
    value: function processSegmentGroup(config, segmentGroup, outlet) {
      if (segmentGroup.segments.length === 0 && segmentGroup.hasChildren()) {
        return this.processChildren(config, segmentGroup);
      }

      return this.processSegment(config, segmentGroup, segmentGroup.segments, outlet);
    }
  }, {
    key: "processChildren",
    value: function processChildren(config, segmentGroup) {
      var _this28 = this;

      var children = mapChildrenIntoArray(segmentGroup, function (child, childOutlet) {
        return _this28.processSegmentGroup(config, child, childOutlet);
      });
      checkOutletNameUniqueness(children);
      sortActivatedRouteSnapshots(children);
      return children;
    }
  }, {
    key: "processSegment",
    value: function processSegment(config, segmentGroup, segments, outlet) {
      var _iterator7 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(config),
          _step7;

      try {
        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
          var r = _step7.value;

          try {
            return this.processSegmentAgainstRoute(r, segmentGroup, segments, outlet);
          } catch (e) {
            if (!(e instanceof NoMatch$1)) throw e;
          }
        }
      } catch (err) {
        _iterator7.e(err);
      } finally {
        _iterator7.f();
      }

      if (this.noLeftoversInUrl(segmentGroup, segments, outlet)) {
        return [];
      }

      throw new NoMatch$1();
    }
  }, {
    key: "noLeftoversInUrl",
    value: function noLeftoversInUrl(segmentGroup, segments, outlet) {
      return segments.length === 0 && !segmentGroup.children[outlet];
    }
  }, {
    key: "processSegmentAgainstRoute",
    value: function processSegmentAgainstRoute(route, rawSegment, segments, outlet) {
      if (route.redirectTo) throw new NoMatch$1();
      if ((route.outlet || PRIMARY_OUTLET) !== outlet) throw new NoMatch$1();
      var snapshot;
      var consumedSegments = [];
      var rawSlicedSegments = [];

      if (route.path === '**') {
        var params = segments.length > 0 ? last(segments).parameters : {};
        snapshot = new ActivatedRouteSnapshot(segments, params, Object.freeze(Object.assign({}, this.urlTree.queryParams)), this.urlTree.fragment, getData(route), outlet, route.component, route, getSourceSegmentGroup(rawSegment), getPathIndexShift(rawSegment) + segments.length, getResolve(route));
      } else {
        var result = match$1(rawSegment, route, segments);
        consumedSegments = result.consumedSegments;
        rawSlicedSegments = segments.slice(result.lastChild);
        snapshot = new ActivatedRouteSnapshot(consumedSegments, result.parameters, Object.freeze(Object.assign({}, this.urlTree.queryParams)), this.urlTree.fragment, getData(route), outlet, route.component, route, getSourceSegmentGroup(rawSegment), getPathIndexShift(rawSegment) + consumedSegments.length, getResolve(route));
      }

      var childConfig = getChildConfig(route);

      var _split$ = split$1(rawSegment, consumedSegments, rawSlicedSegments, childConfig, this.relativeLinkResolution),
          segmentGroup = _split$.segmentGroup,
          slicedSegments = _split$.slicedSegments;

      if (slicedSegments.length === 0 && segmentGroup.hasChildren()) {
        var _children3 = this.processChildren(childConfig, segmentGroup);

        return [new TreeNode(snapshot, _children3)];
      }

      if (childConfig.length === 0 && slicedSegments.length === 0) {
        return [new TreeNode(snapshot, [])];
      }

      var children = this.processSegment(childConfig, segmentGroup, slicedSegments, PRIMARY_OUTLET);
      return [new TreeNode(snapshot, children)];
    }
  }]);

  return Recognizer;
}();

function sortActivatedRouteSnapshots(nodes) {
  nodes.sort(function (a, b) {
    if (a.value.outlet === PRIMARY_OUTLET) return -1;
    if (b.value.outlet === PRIMARY_OUTLET) return 1;
    return a.value.outlet.localeCompare(b.value.outlet);
  });
}

function getChildConfig(route) {
  if (route.children) {
    return route.children;
  }

  if (route.loadChildren) {
    return route._loadedConfig.routes;
  }

  return [];
}

function match$1(segmentGroup, route, segments) {
  if (route.path === '') {
    if (route.pathMatch === 'full' && (segmentGroup.hasChildren() || segments.length > 0)) {
      throw new NoMatch$1();
    }

    return {
      consumedSegments: [],
      lastChild: 0,
      parameters: {}
    };
  }

  var matcher = route.matcher || defaultUrlMatcher;
  var res = matcher(segments, segmentGroup, route);
  if (!res) throw new NoMatch$1();
  var posParams = {};
  forEach(res.posParams, function (v, k) {
    posParams[k] = v.path;
  });
  var parameters = res.consumed.length > 0 ? Object.assign(Object.assign({}, posParams), res.consumed[res.consumed.length - 1].parameters) : posParams;
  return {
    consumedSegments: res.consumed,
    lastChild: res.consumed.length,
    parameters: parameters
  };
}

function checkOutletNameUniqueness(nodes) {
  var names = {};
  nodes.forEach(function (n) {
    var routeWithSameOutletName = names[n.value.outlet];

    if (routeWithSameOutletName) {
      var p = routeWithSameOutletName.url.map(function (s) {
        return s.toString();
      }).join('/');
      var c = n.value.url.map(function (s) {
        return s.toString();
      }).join('/');
      throw new Error("Two segments cannot have the same outlet name: '".concat(p, "' and '").concat(c, "'."));
    }

    names[n.value.outlet] = n.value;
  });
}

function getSourceSegmentGroup(segmentGroup) {
  var s = segmentGroup;

  while (s._sourceSegment) {
    s = s._sourceSegment;
  }

  return s;
}

function getPathIndexShift(segmentGroup) {
  var s = segmentGroup;
  var res = s._segmentIndexShift ? s._segmentIndexShift : 0;

  while (s._sourceSegment) {
    s = s._sourceSegment;
    res += s._segmentIndexShift ? s._segmentIndexShift : 0;
  }

  return res - 1;
}

function split$1(segmentGroup, consumedSegments, slicedSegments, config, relativeLinkResolution) {
  if (slicedSegments.length > 0 && containsEmptyPathMatchesWithNamedOutlets(segmentGroup, slicedSegments, config)) {
    var _s2 = new UrlSegmentGroup(consumedSegments, createChildrenForEmptyPaths(segmentGroup, consumedSegments, config, new UrlSegmentGroup(slicedSegments, segmentGroup.children)));

    _s2._sourceSegment = segmentGroup;
    _s2._segmentIndexShift = consumedSegments.length;
    return {
      segmentGroup: _s2,
      slicedSegments: []
    };
  }

  if (slicedSegments.length === 0 && containsEmptyPathMatches(segmentGroup, slicedSegments, config)) {
    var _s3 = new UrlSegmentGroup(segmentGroup.segments, addEmptyPathsToChildrenIfNeeded(segmentGroup, consumedSegments, slicedSegments, config, segmentGroup.children, relativeLinkResolution));

    _s3._sourceSegment = segmentGroup;
    _s3._segmentIndexShift = consumedSegments.length;
    return {
      segmentGroup: _s3,
      slicedSegments: slicedSegments
    };
  }

  var s = new UrlSegmentGroup(segmentGroup.segments, segmentGroup.children);
  s._sourceSegment = segmentGroup;
  s._segmentIndexShift = consumedSegments.length;
  return {
    segmentGroup: s,
    slicedSegments: slicedSegments
  };
}

function addEmptyPathsToChildrenIfNeeded(segmentGroup, consumedSegments, slicedSegments, routes, children, relativeLinkResolution) {
  var res = {};

  var _iterator8 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(routes),
      _step8;

  try {
    for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
      var r = _step8.value;

      if (emptyPathMatch(segmentGroup, slicedSegments, r) && !children[getOutlet$1(r)]) {
        var s = new UrlSegmentGroup([], {});
        s._sourceSegment = segmentGroup;

        if (relativeLinkResolution === 'legacy') {
          s._segmentIndexShift = segmentGroup.segments.length;
        } else {
          s._segmentIndexShift = consumedSegments.length;
        }

        res[getOutlet$1(r)] = s;
      }
    }
  } catch (err) {
    _iterator8.e(err);
  } finally {
    _iterator8.f();
  }

  return Object.assign(Object.assign({}, children), res);
}

function createChildrenForEmptyPaths(segmentGroup, consumedSegments, routes, primarySegment) {
  var res = {};
  res[PRIMARY_OUTLET] = primarySegment;
  primarySegment._sourceSegment = segmentGroup;
  primarySegment._segmentIndexShift = consumedSegments.length;

  var _iterator9 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(routes),
      _step9;

  try {
    for (_iterator9.s(); !(_step9 = _iterator9.n()).done;) {
      var r = _step9.value;

      if (r.path === '' && getOutlet$1(r) !== PRIMARY_OUTLET) {
        var s = new UrlSegmentGroup([], {});
        s._sourceSegment = segmentGroup;
        s._segmentIndexShift = consumedSegments.length;
        res[getOutlet$1(r)] = s;
      }
    }
  } catch (err) {
    _iterator9.e(err);
  } finally {
    _iterator9.f();
  }

  return res;
}

function containsEmptyPathMatchesWithNamedOutlets(segmentGroup, slicedSegments, routes) {
  return routes.some(function (r) {
    return emptyPathMatch(segmentGroup, slicedSegments, r) && getOutlet$1(r) !== PRIMARY_OUTLET;
  });
}

function containsEmptyPathMatches(segmentGroup, slicedSegments, routes) {
  return routes.some(function (r) {
    return emptyPathMatch(segmentGroup, slicedSegments, r);
  });
}

function emptyPathMatch(segmentGroup, slicedSegments, r) {
  if ((segmentGroup.hasChildren() || slicedSegments.length > 0) && r.pathMatch === 'full') {
    return false;
  }

  return r.path === '' && r.redirectTo === undefined;
}

function getOutlet$1(route) {
  return route.outlet || PRIMARY_OUTLET;
}

function getData(route) {
  return route.data || {};
}

function getResolve(route) {
  return route.resolve || {};
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function recognize$1(rootComponentType, config, serializer, paramsInheritanceStrategy, relativeLinkResolution) {
  return function (source) {
    return source.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (t) {
      return recognize(rootComponentType, config, t.urlAfterRedirects, serializer(t.urlAfterRedirects), paramsInheritanceStrategy, relativeLinkResolution).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (targetSnapshot) {
        return Object.assign(Object.assign({}, t), {
          targetSnapshot: targetSnapshot
        });
      }));
    }));
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function resolveData(paramsInheritanceStrategy, moduleInjector) {
  return function (source) {
    return source.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (t) {
      var targetSnapshot = t.targetSnapshot,
          canActivateChecks = t.guards.canActivateChecks;

      if (!canActivateChecks.length) {
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t);
      }

      var canActivateChecksResolved = 0;
      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(canActivateChecks).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["concatMap"])(function (check) {
        return runResolve(check.route, targetSnapshot, paramsInheritanceStrategy, moduleInjector);
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function () {
        return canActivateChecksResolved++;
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["takeLast"])(1), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (_) {
        return canActivateChecksResolved === canActivateChecks.length ? Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t) : rxjs__WEBPACK_IMPORTED_MODULE_10__["EMPTY"];
      }));
    }));
  };
}

function runResolve(futureARS, futureRSS, paramsInheritanceStrategy, moduleInjector) {
  var resolve = futureARS._resolve;
  return resolveNode(resolve, futureARS, futureRSS, moduleInjector).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (resolvedData) {
    futureARS._resolvedData = resolvedData;
    futureARS.data = Object.assign(Object.assign({}, futureARS.data), inheritedParamsDataResolve(futureARS, paramsInheritanceStrategy).resolve);
    return null;
  }));
}

function resolveNode(resolve, futureARS, futureRSS, moduleInjector) {
  var keys = Object.keys(resolve);

  if (keys.length === 0) {
    return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])({});
  }

  var data = {};
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(keys).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (key) {
    return getResolver(resolve[key], futureARS, futureRSS, moduleInjector).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (value) {
      data[key] = value;
    }));
  }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["takeLast"])(1), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function () {
    // Ensure all resolvers returned values, otherwise don't emit any "next" and just complete
    // the chain which will cancel navigation
    if (Object.keys(data).length === keys.length) {
      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(data);
    }

    return rxjs__WEBPACK_IMPORTED_MODULE_10__["EMPTY"];
  }));
}

function getResolver(injectionToken, futureARS, futureRSS, moduleInjector) {
  var resolver = getToken(injectionToken, futureARS, moduleInjector);
  return resolver.resolve ? wrapIntoObservable(resolver.resolve(futureARS, futureRSS)) : wrapIntoObservable(resolver(futureARS, futureRSS));
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Perform a side effect through a switchMap for every emission on the source Observable,
 * but return an Observable that is identical to the source. It's essentially the same as
 * the `tap` operator, but if the side effectful `next` function returns an ObservableInput,
 * it will wait before continuing with the original value.
 */


function switchTap(next) {
  return function (source) {
    return source.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (v) {
      var nextResult = next(v);

      if (nextResult) {
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(nextResult).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function () {
          return v;
        }));
      }

      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])([v]);
    }));
  };
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * Provides a way to customize when activated routes get reused.
 *
 * @publicApi
 */


var RouteReuseStrategy = function RouteReuseStrategy() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouteReuseStrategy);
};
/**
 * @description
 *
 * This base route reuse strategy only reuses routes when the matched router configs are
 * identical. This prevents components from being destroyed and recreated
 * when just the fragment or query parameters change
 * (that is, the existing component is _reused_).
 *
 * This strategy does not store any routes for later reuse.
 *
 * Angular uses this strategy by default.
 *
 *
 * It can be used as a base class for custom route reuse strategies, i.e. you can create your own
 * class that extends the `BaseRouteReuseStrategy` one.
 * @publicApi
 */


var BaseRouteReuseStrategy = /*#__PURE__*/function () {
  function BaseRouteReuseStrategy() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, BaseRouteReuseStrategy);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(BaseRouteReuseStrategy, [{
    key: "shouldDetach",

    /**
     * Whether the given route should detach for later reuse.
     * Always returns false for `BaseRouteReuseStrategy`.
     * */
    value: function shouldDetach(route) {
      return false;
    }
    /**
     * A no-op; the route is never stored since this strategy never detaches routes for later re-use.
     */

  }, {
    key: "store",
    value: function store(route, detachedTree) {}
    /** Returns `false`, meaning the route (and its subtree) is never reattached */

  }, {
    key: "shouldAttach",
    value: function shouldAttach(route) {
      return false;
    }
    /** Returns `null` because this strategy does not store routes for later re-use. */

  }, {
    key: "retrieve",
    value: function retrieve(route) {
      return null;
    }
    /**
     * Determines if a route should be reused.
     * This strategy returns `true` when the future route config and current route config are
     * identical.
     */

  }, {
    key: "shouldReuseRoute",
    value: function shouldReuseRoute(future, curr) {
      return future.routeConfig === curr.routeConfig;
    }
  }]);

  return BaseRouteReuseStrategy;
}();

var DefaultRouteReuseStrategy = /*#__PURE__*/function (_BaseRouteReuseStrate) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_5__["default"])(DefaultRouteReuseStrategy, _BaseRouteReuseStrate);

  var _super12 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_6__["default"])(DefaultRouteReuseStrategy);

  function DefaultRouteReuseStrategy() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, DefaultRouteReuseStrategy);

    return _super12.apply(this, arguments);
  }

  return DefaultRouteReuseStrategy;
}(BaseRouteReuseStrategy);
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * This component is used internally within the router to be a placeholder when an empty
 * router-outlet is needed. For example, with a config such as:
 *
 * `{path: 'parent', outlet: 'nav', children: [...]}`
 *
 * In order to render, there needs to be a component on this config, which will default
 * to this `EmptyOutletComponent`.
 */


var ɵEmptyOutletComponent = function ɵEmptyOutletComponent() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ɵEmptyOutletComponent);
};

ɵEmptyOutletComponent.ɵfac = function ɵEmptyOutletComponent_Factory(t) {
  return new (t || ɵEmptyOutletComponent)();
};

ɵEmptyOutletComponent.ɵcmp = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineComponent"]({
  type: ɵEmptyOutletComponent,
  selectors: [["ng-component"]],
  decls: 1,
  vars: 0,
  template: function ɵEmptyOutletComponent_Template(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵelement"](0, "router-outlet");
    }
  },
  directives: function directives() {
    return [RouterOutlet];
  },
  encapsulation: 2
});
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](ɵEmptyOutletComponent, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Component"],
    args: [{
      template: "<router-outlet></router-outlet>"
    }]
  }], null, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function validateConfig(config) {
  var parentPath = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';

  // forEach doesn't iterate undefined values
  for (var i = 0; i < config.length; i++) {
    var route = config[i];
    var fullPath = getFullPath(parentPath, route);
    validateNode(route, fullPath);
  }
}

function validateNode(route, fullPath) {
  if (!route) {
    throw new Error("\n      Invalid configuration of route '".concat(fullPath, "': Encountered undefined route.\n      The reason might be an extra comma.\n\n      Example:\n      const routes: Routes = [\n        { path: '', redirectTo: '/dashboard', pathMatch: 'full' },\n        { path: 'dashboard',  component: DashboardComponent },, << two commas\n        { path: 'detail/:id', component: HeroDetailComponent }\n      ];\n    "));
  }

  if (Array.isArray(route)) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': Array cannot be specified"));
  }

  if (!route.component && !route.children && !route.loadChildren && route.outlet && route.outlet !== PRIMARY_OUTLET) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': a componentless route without children or loadChildren cannot have a named outlet set"));
  }

  if (route.redirectTo && route.children) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': redirectTo and children cannot be used together"));
  }

  if (route.redirectTo && route.loadChildren) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': redirectTo and loadChildren cannot be used together"));
  }

  if (route.children && route.loadChildren) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': children and loadChildren cannot be used together"));
  }

  if (route.redirectTo && route.component) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': redirectTo and component cannot be used together"));
  }

  if (route.path && route.matcher) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': path and matcher cannot be used together"));
  }

  if (route.redirectTo === void 0 && !route.component && !route.children && !route.loadChildren) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "'. One of the following must be provided: component, redirectTo, children or loadChildren"));
  }

  if (route.path === void 0 && route.matcher === void 0) {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': routes must have either a path or a matcher specified"));
  }

  if (typeof route.path === 'string' && route.path.charAt(0) === '/') {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': path cannot start with a slash"));
  }

  if (route.path === '' && route.redirectTo !== void 0 && route.pathMatch === void 0) {
    var exp = "The default value of 'pathMatch' is 'prefix', but often the intent is to use 'full'.";
    throw new Error("Invalid configuration of route '{path: \"".concat(fullPath, "\", redirectTo: \"").concat(route.redirectTo, "\"}': please provide 'pathMatch'. ").concat(exp));
  }

  if (route.pathMatch !== void 0 && route.pathMatch !== 'full' && route.pathMatch !== 'prefix') {
    throw new Error("Invalid configuration of route '".concat(fullPath, "': pathMatch can only be set to 'prefix' or 'full'"));
  }

  if (route.children) {
    validateConfig(route.children, fullPath);
  }
}

function getFullPath(parentPath, currentRoute) {
  if (!currentRoute) {
    return parentPath;
  }

  if (!parentPath && !currentRoute.path) {
    return '';
  } else if (parentPath && !currentRoute.path) {
    return "".concat(parentPath, "/");
  } else if (!parentPath && currentRoute.path) {
    return currentRoute.path;
  } else {
    return "".concat(parentPath, "/").concat(currentRoute.path);
  }
}
/**
 * Makes a copy of the config and adds any default required properties.
 */


function standardizeConfig(r) {
  var children = r.children && r.children.map(standardizeConfig);
  var c = children ? Object.assign(Object.assign({}, r), {
    children: children
  }) : Object.assign({}, r);

  if (!c.component && (children || c.loadChildren) && c.outlet && c.outlet !== PRIMARY_OUTLET) {
    c.component = ɵEmptyOutletComponent;
  }

  return c;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The [DI token](guide/glossary/#di-token) for a router configuration.
 * @see `ROUTES`
 * @publicApi
 */


var ROUTES = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["InjectionToken"]('ROUTES');

var RouterConfigLoader = /*#__PURE__*/function () {
  function RouterConfigLoader(loader, compiler, onLoadStartListener, onLoadEndListener) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterConfigLoader);

    this.loader = loader;
    this.compiler = compiler;
    this.onLoadStartListener = onLoadStartListener;
    this.onLoadEndListener = onLoadEndListener;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterConfigLoader, [{
    key: "load",
    value: function load(parentInjector, route) {
      var _this29 = this;

      if (this.onLoadStartListener) {
        this.onLoadStartListener(route);
      }

      var moduleFactory$ = this.loadModuleFactory(route.loadChildren);
      return moduleFactory$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (factory) {
        if (_this29.onLoadEndListener) {
          _this29.onLoadEndListener(route);
        }

        var module = factory.create(parentInjector);
        return new LoadedRouterConfig(flatten(module.injector.get(ROUTES)).map(standardizeConfig), module);
      }));
    }
  }, {
    key: "loadModuleFactory",
    value: function loadModuleFactory(loadChildren) {
      var _this30 = this;

      if (typeof loadChildren === 'string') {
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(this.loader.load(loadChildren));
      } else {
        return wrapIntoObservable(loadChildren()).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (t) {
          if (t instanceof _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactory"]) {
            return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t);
          } else {
            return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(_this30.compiler.compileModuleAsync(t));
          }
        }));
      }
    }
  }]);

  return RouterConfigLoader;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Store contextual information about a `RouterOutlet`
 *
 * @publicApi
 */


var OutletContext = function OutletContext() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, OutletContext);

  this.outlet = null;
  this.route = null;
  this.resolver = null;
  this.children = new ChildrenOutletContexts();
  this.attachRef = null;
};
/**
 * Store contextual information about the children (= nested) `RouterOutlet`
 *
 * @publicApi
 */


var ChildrenOutletContexts = /*#__PURE__*/function () {
  function ChildrenOutletContexts() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, ChildrenOutletContexts);

    // contexts for child outlets, by name.
    this.contexts = new Map();
  }
  /** Called when a `RouterOutlet` directive is instantiated */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(ChildrenOutletContexts, [{
    key: "onChildOutletCreated",
    value: function onChildOutletCreated(childName, outlet) {
      var context = this.getOrCreateContext(childName);
      context.outlet = outlet;
      this.contexts.set(childName, context);
    }
    /**
     * Called when a `RouterOutlet` directive is destroyed.
     * We need to keep the context as the outlet could be destroyed inside a NgIf and might be
     * re-created later.
     */

  }, {
    key: "onChildOutletDestroyed",
    value: function onChildOutletDestroyed(childName) {
      var context = this.getContext(childName);

      if (context) {
        context.outlet = null;
      }
    }
    /**
     * Called when the corresponding route is deactivated during navigation.
     * Because the component get destroyed, all children outlet are destroyed.
     */

  }, {
    key: "onOutletDeactivated",
    value: function onOutletDeactivated() {
      var contexts = this.contexts;
      this.contexts = new Map();
      return contexts;
    }
  }, {
    key: "onOutletReAttached",
    value: function onOutletReAttached(contexts) {
      this.contexts = contexts;
    }
  }, {
    key: "getOrCreateContext",
    value: function getOrCreateContext(childName) {
      var context = this.getContext(childName);

      if (!context) {
        context = new OutletContext();
        this.contexts.set(childName, context);
      }

      return context;
    }
  }, {
    key: "getContext",
    value: function getContext(childName) {
      return this.contexts.get(childName) || null;
    }
  }]);

  return ChildrenOutletContexts;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * Provides a way to migrate AngularJS applications to Angular.
 *
 * @publicApi
 */


var UrlHandlingStrategy = function UrlHandlingStrategy() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, UrlHandlingStrategy);
};
/**
 * @publicApi
 */


var DefaultUrlHandlingStrategy = /*#__PURE__*/function () {
  function DefaultUrlHandlingStrategy() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, DefaultUrlHandlingStrategy);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(DefaultUrlHandlingStrategy, [{
    key: "shouldProcessUrl",
    value: function shouldProcessUrl(url) {
      return true;
    }
  }, {
    key: "extract",
    value: function extract(url) {
      return url;
    }
  }, {
    key: "merge",
    value: function merge(newUrlPart, wholeUrl) {
      return newUrlPart;
    }
  }]);

  return DefaultUrlHandlingStrategy;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


function defaultErrorHandler(error) {
  throw error;
}

function defaultMalformedUriErrorHandler(error, urlSerializer, url) {
  return urlSerializer.parse('/');
}
/**
 * @internal
 */


function defaultRouterHook(snapshot, runExtras) {
  return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(null);
}
/**
 * @description
 *
 * A service that provides navigation among views and URL manipulation capabilities.
 *
 * @see `Route`.
 * @see [Routing and Navigation Guide](guide/router).
 *
 * @ngModule RouterModule
 *
 * @publicApi
 */


var Router = /*#__PURE__*/function () {
  /**
   * Creates the router service.
   */
  // TODO: vsavkin make internal after the final is out.
  function Router(rootComponentType, urlSerializer, rootContexts, location, injector, loader, compiler, config) {
    var _this31 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, Router);

    this.rootComponentType = rootComponentType;
    this.urlSerializer = urlSerializer;
    this.rootContexts = rootContexts;
    this.location = location;
    this.config = config;
    this.lastSuccessfulNavigation = null;
    this.currentNavigation = null;
    /**
     * Tracks the previously seen location change from the location subscription so we can compare
     * the two latest to see if they are duplicates. See setUpLocationChangeListener.
     */

    this.lastLocationChangeInfo = null;
    this.navigationId = 0;
    this.isNgZoneEnabled = false;
    /**
     * An event stream for routing events in this NgModule.
     */

    this.events = new rxjs__WEBPACK_IMPORTED_MODULE_10__["Subject"]();
    /**
     * A handler for navigation errors in this NgModule.
     */

    this.errorHandler = defaultErrorHandler;
    /**
     * A handler for errors thrown by `Router.parseUrl(url)`
     * when `url` contains an invalid character.
     * The most common case is a `%` sign
     * that's not encoded and is not part of a percent encoded sequence.
     */

    this.malformedUriErrorHandler = defaultMalformedUriErrorHandler;
    /**
     * True if at least one navigation event has occurred,
     * false otherwise.
     */

    this.navigated = false;
    this.lastSuccessfulId = -1;
    /**
     * Hooks that enable you to pause navigation,
     * either before or after the preactivation phase.
     * Used by `RouterModule`.
     *
     * @internal
     */

    this.hooks = {
      beforePreactivation: defaultRouterHook,
      afterPreactivation: defaultRouterHook
    };
    /**
     * A strategy for extracting and merging URLs.
     * Used for AngularJS to Angular migrations.
     */

    this.urlHandlingStrategy = new DefaultUrlHandlingStrategy();
    /**
     * A strategy for re-using routes.
     */

    this.routeReuseStrategy = new DefaultRouteReuseStrategy();
    /**
     * How to handle a navigation request to the current URL. One of:
     * - `'ignore'` :  The router ignores the request.
     * - `'reload'` : The router reloads the URL. Use to implement a "refresh" feature.
     */

    this.onSameUrlNavigation = 'ignore';
    /**
     * How to merge parameters, data, and resolved data from parent to child
     * routes. One of:
     *
     * - `'emptyOnly'` : Inherit parent parameters, data, and resolved data
     * for path-less or component-less routes.
     * - `'always'` : Inherit parent parameters, data, and resolved data
     * for all child routes.
     */

    this.paramsInheritanceStrategy = 'emptyOnly';
    /**
     * Determines when the router updates the browser URL.
     * By default (`"deferred"`), updates the browser URL after navigation has finished.
     * Set to `'eager'` to update the browser URL at the beginning of navigation.
     * You can choose to update early so that, if navigation fails,
     * you can show an error message with the URL that failed.
     */

    this.urlUpdateStrategy = 'deferred';
    /**
     * Enables a bug fix that corrects relative link resolution in components with empty paths.
     * @see `RouterModule`
     */

    this.relativeLinkResolution = 'legacy';

    var onLoadStart = function onLoadStart(r) {
      return _this31.triggerEvent(new RouteConfigLoadStart(r));
    };

    var onLoadEnd = function onLoadEnd(r) {
      return _this31.triggerEvent(new RouteConfigLoadEnd(r));
    };

    this.ngModule = injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleRef"]);
    this.console = injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵConsole"]);
    var ngZone = injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgZone"]);
    this.isNgZoneEnabled = ngZone instanceof _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgZone"];
    this.resetConfig(config);
    this.currentUrlTree = createEmptyUrlTree();
    this.rawUrlTree = this.currentUrlTree;
    this.browserUrlTree = this.currentUrlTree;
    this.configLoader = new RouterConfigLoader(loader, compiler, onLoadStart, onLoadEnd);
    this.routerState = createEmptyState(this.currentUrlTree, this.rootComponentType);
    this.transitions = new rxjs__WEBPACK_IMPORTED_MODULE_10__["BehaviorSubject"]({
      id: 0,
      currentUrlTree: this.currentUrlTree,
      currentRawUrl: this.currentUrlTree,
      extractedUrl: this.urlHandlingStrategy.extract(this.currentUrlTree),
      urlAfterRedirects: this.urlHandlingStrategy.extract(this.currentUrlTree),
      rawUrl: this.currentUrlTree,
      extras: {},
      resolve: null,
      reject: null,
      promise: Promise.resolve(true),
      source: 'imperative',
      restoredState: null,
      currentSnapshot: this.routerState.snapshot,
      targetSnapshot: null,
      currentRouterState: this.routerState,
      targetRouterState: null,
      guards: {
        canActivateChecks: [],
        canDeactivateChecks: []
      },
      guardsResult: null
    });
    this.navigations = this.setupNavigations(this.transitions);
    this.processNavigations();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(Router, [{
    key: "setupNavigations",
    value: function setupNavigations(transitions) {
      var _this32 = this;

      var eventsSubject = this.events;
      return transitions.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["filter"])(function (t) {
        return t.id !== 0;
      }), // Extract URL
      Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (t) {
        return Object.assign(Object.assign({}, t), {
          extractedUrl: _this32.urlHandlingStrategy.extract(t.rawUrl)
        });
      }), // Using switchMap so we cancel executing navigations when a new one comes in
      Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (t) {
        var completed = false;
        var errored = false;
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t).pipe( // Store the Navigation object
        Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
          _this32.currentNavigation = {
            id: t.id,
            initialUrl: t.currentRawUrl,
            extractedUrl: t.extractedUrl,
            trigger: t.source,
            extras: t.extras,
            previousNavigation: _this32.lastSuccessfulNavigation ? Object.assign(Object.assign({}, _this32.lastSuccessfulNavigation), {
              previousNavigation: null
            }) : null
          };
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (t) {
          var urlTransition = !_this32.navigated || t.extractedUrl.toString() !== _this32.browserUrlTree.toString();

          var processCurrentUrl = (_this32.onSameUrlNavigation === 'reload' ? true : urlTransition) && _this32.urlHandlingStrategy.shouldProcessUrl(t.rawUrl);

          if (processCurrentUrl) {
            return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t).pipe( // Fire NavigationStart event
            Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (t) {
              var transition = _this32.transitions.getValue();

              eventsSubject.next(new NavigationStart(t.id, _this32.serializeUrl(t.extractedUrl), t.source, t.restoredState));

              if (transition !== _this32.transitions.getValue()) {
                return rxjs__WEBPACK_IMPORTED_MODULE_10__["EMPTY"];
              }

              return [t];
            }), // This delay is required to match old behavior that forced navigation
            // to always be async
            Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (t) {
              return Promise.resolve(t);
            }), // ApplyRedirects
            applyRedirects$1(_this32.ngModule.injector, _this32.configLoader, _this32.urlSerializer, _this32.config), // Update the currentNavigation
            Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
              _this32.currentNavigation = Object.assign(Object.assign({}, _this32.currentNavigation), {
                finalUrl: t.urlAfterRedirects
              });
            }), // Recognize
            recognize$1(_this32.rootComponentType, _this32.config, function (url) {
              return _this32.serializeUrl(url);
            }, _this32.paramsInheritanceStrategy, _this32.relativeLinkResolution), // Update URL if in `eager` update mode
            Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
              if (_this32.urlUpdateStrategy === 'eager') {
                if (!t.extras.skipLocationChange) {
                  _this32.setBrowserUrl(t.urlAfterRedirects, !!t.extras.replaceUrl, t.id, t.extras.state);
                }

                _this32.browserUrlTree = t.urlAfterRedirects;
              }
            }), // Fire RoutesRecognized
            Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
              var routesRecognized = new RoutesRecognized(t.id, _this32.serializeUrl(t.extractedUrl), _this32.serializeUrl(t.urlAfterRedirects), t.targetSnapshot);
              eventsSubject.next(routesRecognized);
            }));
          } else {
            var processPreviousUrl = urlTransition && _this32.rawUrlTree && _this32.urlHandlingStrategy.shouldProcessUrl(_this32.rawUrlTree);
            /* When the current URL shouldn't be processed, but the previous one was,
             * we handle this "error condition" by navigating to the previously
             * successful URL, but leaving the URL intact.*/


            if (processPreviousUrl) {
              var id = t.id,
                  extractedUrl = t.extractedUrl,
                  source = t.source,
                  restoredState = t.restoredState,
                  extras = t.extras;
              var navStart = new NavigationStart(id, _this32.serializeUrl(extractedUrl), source, restoredState);
              eventsSubject.next(navStart);
              var targetSnapshot = createEmptyState(extractedUrl, _this32.rootComponentType).snapshot;
              return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(Object.assign(Object.assign({}, t), {
                targetSnapshot: targetSnapshot,
                urlAfterRedirects: extractedUrl,
                extras: Object.assign(Object.assign({}, extras), {
                  skipLocationChange: false,
                  replaceUrl: false
                })
              }));
            } else {
              /* When neither the current or previous URL can be processed, do nothing
               * other than update router's internal reference to the current "settled"
               * URL. This way the next navigation will be coming from the current URL
               * in the browser.
               */
              _this32.rawUrlTree = t.rawUrl;
              _this32.browserUrlTree = t.urlAfterRedirects;
              t.resolve(null);
              return rxjs__WEBPACK_IMPORTED_MODULE_10__["EMPTY"];
            }
          }
        }), // Before Preactivation
        switchTap(function (t) {
          var targetSnapshot = t.targetSnapshot,
              navigationId = t.id,
              appliedUrlTree = t.extractedUrl,
              rawUrlTree = t.rawUrl,
              _t$extras = t.extras,
              skipLocationChange = _t$extras.skipLocationChange,
              replaceUrl = _t$extras.replaceUrl;
          return _this32.hooks.beforePreactivation(targetSnapshot, {
            navigationId: navigationId,
            appliedUrlTree: appliedUrlTree,
            rawUrlTree: rawUrlTree,
            skipLocationChange: !!skipLocationChange,
            replaceUrl: !!replaceUrl
          });
        }), // --- GUARDS ---
        Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
          var guardsStart = new GuardsCheckStart(t.id, _this32.serializeUrl(t.extractedUrl), _this32.serializeUrl(t.urlAfterRedirects), t.targetSnapshot);

          _this32.triggerEvent(guardsStart);
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (t) {
          return Object.assign(Object.assign({}, t), {
            guards: getAllRouteGuards(t.targetSnapshot, t.currentSnapshot, _this32.rootContexts)
          });
        }), checkGuards(_this32.ngModule.injector, function (evt) {
          return _this32.triggerEvent(evt);
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
          if (isUrlTree(t.guardsResult)) {
            var error = navigationCancelingError("Redirecting to \"".concat(_this32.serializeUrl(t.guardsResult), "\""));
            error.url = t.guardsResult;
            throw error;
          }
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
          var guardsEnd = new GuardsCheckEnd(t.id, _this32.serializeUrl(t.extractedUrl), _this32.serializeUrl(t.urlAfterRedirects), t.targetSnapshot, !!t.guardsResult);

          _this32.triggerEvent(guardsEnd);
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["filter"])(function (t) {
          if (!t.guardsResult) {
            _this32.resetUrlToCurrentUrlTree();

            var navCancel = new NavigationCancel(t.id, _this32.serializeUrl(t.extractedUrl), '');
            eventsSubject.next(navCancel);
            t.resolve(false);
            return false;
          }

          return true;
        }), // --- RESOLVE ---
        switchTap(function (t) {
          if (t.guards.canActivateChecks.length) {
            return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
              var resolveStart = new ResolveStart(t.id, _this32.serializeUrl(t.extractedUrl), _this32.serializeUrl(t.urlAfterRedirects), t.targetSnapshot);

              _this32.triggerEvent(resolveStart);
            }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["switchMap"])(function (t) {
              var dataResolved = false;
              return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(t).pipe(resolveData(_this32.paramsInheritanceStrategy, _this32.ngModule.injector), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])({
                next: function next() {
                  return dataResolved = true;
                },
                complete: function complete() {
                  if (!dataResolved) {
                    var navCancel = new NavigationCancel(t.id, _this32.serializeUrl(t.extractedUrl), "At least one route resolver didn't emit any value.");
                    eventsSubject.next(navCancel);
                    t.resolve(false);
                  }
                }
              }));
            }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
              var resolveEnd = new ResolveEnd(t.id, _this32.serializeUrl(t.extractedUrl), _this32.serializeUrl(t.urlAfterRedirects), t.targetSnapshot);

              _this32.triggerEvent(resolveEnd);
            }));
          }

          return undefined;
        }), // --- AFTER PREACTIVATION ---
        switchTap(function (t) {
          var targetSnapshot = t.targetSnapshot,
              navigationId = t.id,
              appliedUrlTree = t.extractedUrl,
              rawUrlTree = t.rawUrl,
              _t$extras2 = t.extras,
              skipLocationChange = _t$extras2.skipLocationChange,
              replaceUrl = _t$extras2.replaceUrl;
          return _this32.hooks.afterPreactivation(targetSnapshot, {
            navigationId: navigationId,
            appliedUrlTree: appliedUrlTree,
            rawUrlTree: rawUrlTree,
            skipLocationChange: !!skipLocationChange,
            replaceUrl: !!replaceUrl
          });
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (t) {
          var targetRouterState = createRouterState(_this32.routeReuseStrategy, t.targetSnapshot, t.currentRouterState);
          return Object.assign(Object.assign({}, t), {
            targetRouterState: targetRouterState
          });
        }),
        /* Once here, we are about to activate syncronously. The assumption is this
           will succeed, and user code may read from the Router service. Therefore
           before activation, we need to update router properties storing the current
           URL and the RouterState, as well as updated the browser URL. All this should
           happen *before* activating. */
        Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])(function (t) {
          _this32.currentUrlTree = t.urlAfterRedirects;
          _this32.rawUrlTree = _this32.urlHandlingStrategy.merge(_this32.currentUrlTree, t.rawUrl);
          _this32.routerState = t.targetRouterState;

          if (_this32.urlUpdateStrategy === 'deferred') {
            if (!t.extras.skipLocationChange) {
              _this32.setBrowserUrl(_this32.rawUrlTree, !!t.extras.replaceUrl, t.id, t.extras.state);
            }

            _this32.browserUrlTree = t.urlAfterRedirects;
          }
        }), activateRoutes(_this32.rootContexts, _this32.routeReuseStrategy, function (evt) {
          return _this32.triggerEvent(evt);
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["tap"])({
          next: function next() {
            completed = true;
          },
          complete: function complete() {
            completed = true;
          }
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["finalize"])(function () {
          /* When the navigation stream finishes either through error or success, we
           * set the `completed` or `errored` flag. However, there are some situations
           * where we could get here without either of those being set. For instance, a
           * redirect during NavigationStart. Therefore, this is a catch-all to make
           * sure the NavigationCancel
           * event is fired when a navigation gets cancelled but not caught by other
           * means. */
          if (!completed && !errored) {
            // Must reset to current URL tree here to ensure history.state is set. On a
            // fresh page load, if a new navigation comes in before a successful
            // navigation completes, there will be nothing in
            // history.state.navigationId. This can cause sync problems with AngularJS
            // sync code which looks for a value here in order to determine whether or
            // not to handle a given popstate event or to leave it to the Angualr
            // router.
            _this32.resetUrlToCurrentUrlTree();

            var navCancel = new NavigationCancel(t.id, _this32.serializeUrl(t.extractedUrl), "Navigation ID ".concat(t.id, " is not equal to the current navigation id ").concat(_this32.navigationId));
            eventsSubject.next(navCancel);
            t.resolve(false);
          } // currentNavigation should always be reset to null here. If navigation was
          // successful, lastSuccessfulTransition will have already been set. Therefore
          // we can safely set currentNavigation to null here.


          _this32.currentNavigation = null;
        }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["catchError"])(function (e) {
          errored = true;
          /* This error type is issued during Redirect, and is handled as a
           * cancellation rather than an error. */

          if (isNavigationCancelingError(e)) {
            var redirecting = isUrlTree(e.url);

            if (!redirecting) {
              // Set property only if we're not redirecting. If we landed on a page and
              // redirect to `/` route, the new navigation is going to see the `/`
              // isn't a change from the default currentUrlTree and won't navigate.
              // This is only applicable with initial navigation, so setting
              // `navigated` only when not redirecting resolves this scenario.
              _this32.navigated = true;

              _this32.resetStateAndUrl(t.currentRouterState, t.currentUrlTree, t.rawUrl);
            }

            var navCancel = new NavigationCancel(t.id, _this32.serializeUrl(t.extractedUrl), e.message);
            eventsSubject.next(navCancel); // When redirecting, we need to delay resolving the navigation
            // promise and push it to the redirect navigation

            if (!redirecting) {
              t.resolve(false);
            } else {
              // setTimeout is required so this navigation finishes with
              // the return EMPTY below. If it isn't allowed to finish
              // processing, there can be multiple navigations to the same
              // URL.
              setTimeout(function () {
                var mergedTree = _this32.urlHandlingStrategy.merge(e.url, _this32.rawUrlTree);

                var extras = {
                  skipLocationChange: t.extras.skipLocationChange,
                  replaceUrl: _this32.urlUpdateStrategy === 'eager'
                };
                return _this32.scheduleNavigation(mergedTree, 'imperative', null, extras, {
                  resolve: t.resolve,
                  reject: t.reject,
                  promise: t.promise
                });
              }, 0);
            }
            /* All other errors should reset to the router's internal URL reference to
             * the pre-error state. */

          } else {
            _this32.resetStateAndUrl(t.currentRouterState, t.currentUrlTree, t.rawUrl);

            var navError = new NavigationError(t.id, _this32.serializeUrl(t.extractedUrl), e);
            eventsSubject.next(navError);

            try {
              t.resolve(_this32.errorHandler(e));
            } catch (ee) {
              t.reject(ee);
            }
          }

          return rxjs__WEBPACK_IMPORTED_MODULE_10__["EMPTY"];
        })); // TODO(jasonaden): remove cast once g3 is on updated TypeScript
      }));
    }
    /**
     * @internal
     * TODO: this should be removed once the constructor of the router made internal
     */

  }, {
    key: "resetRootComponentType",
    value: function resetRootComponentType(rootComponentType) {
      this.rootComponentType = rootComponentType; // TODO: vsavkin router 4.0 should make the root component set to null
      // this will simplify the lifecycle of the router.

      this.routerState.root.component = this.rootComponentType;
    }
  }, {
    key: "getTransition",
    value: function getTransition() {
      var transition = this.transitions.value; // This value needs to be set. Other values such as extractedUrl are set on initial navigation
      // but the urlAfterRedirects may not get set if we aren't processing the new URL *and* not
      // processing the previous URL.

      transition.urlAfterRedirects = this.browserUrlTree;
      return transition;
    }
  }, {
    key: "setTransition",
    value: function setTransition(t) {
      this.transitions.next(Object.assign(Object.assign({}, this.getTransition()), t));
    }
    /**
     * Sets up the location change listener and performs the initial navigation.
     */

  }, {
    key: "initialNavigation",
    value: function initialNavigation() {
      this.setUpLocationChangeListener();

      if (this.navigationId === 0) {
        this.navigateByUrl(this.location.path(true), {
          replaceUrl: true
        });
      }
    }
    /**
     * Sets up the location change listener. This listener detects navigations triggered from outside
     * the Router (the browser back/forward buttons, for example) and schedules a corresponding Router
     * navigation so that the correct events, guards, etc. are triggered.
     */

  }, {
    key: "setUpLocationChangeListener",
    value: function setUpLocationChangeListener() {
      var _this33 = this;

      // Don't need to use Zone.wrap any more, because zone.js
      // already patch onPopState, so location change callback will
      // run into ngZone
      if (!this.locationSubscription) {
        this.locationSubscription = this.location.subscribe(function (event) {
          var currentChange = _this33.extractLocationChangeInfoFromEvent(event);

          if (_this33.shouldScheduleNavigation(_this33.lastLocationChangeInfo, currentChange)) {
            // The `setTimeout` was added in #12160 and is likely to support Angular/AngularJS
            // hybrid apps.
            setTimeout(function () {
              var source = currentChange.source,
                  state = currentChange.state,
                  urlTree = currentChange.urlTree;
              var extras = {
                replaceUrl: true
              };

              if (state) {
                var stateCopy = Object.assign({}, state);
                delete stateCopy.navigationId;

                if (Object.keys(stateCopy).length !== 0) {
                  extras.state = stateCopy;
                }
              }

              _this33.scheduleNavigation(urlTree, source, state, extras);
            }, 0);
          }

          _this33.lastLocationChangeInfo = currentChange;
        });
      }
    }
    /** Extracts router-related information from a `PopStateEvent`. */

  }, {
    key: "extractLocationChangeInfoFromEvent",
    value: function extractLocationChangeInfoFromEvent(change) {
      var _a;

      return {
        source: change['type'] === 'popstate' ? 'popstate' : 'hashchange',
        urlTree: this.parseUrl(change['url']),
        // Navigations coming from Angular router have a navigationId state
        // property. When this exists, restore the state.
        state: ((_a = change.state) === null || _a === void 0 ? void 0 : _a.navigationId) ? change.state : null,
        transitionId: this.getTransition().id
      };
    }
    /**
     * Determines whether two events triggered by the Location subscription are due to the same
     * navigation. The location subscription can fire two events (popstate and hashchange) for a
     * single navigation. The second one should be ignored, that is, we should not schedule another
     * navigation in the Router.
     */

  }, {
    key: "shouldScheduleNavigation",
    value: function shouldScheduleNavigation(previous, current) {
      if (!previous) return true;
      var sameDestination = current.urlTree.toString() === previous.urlTree.toString();
      var eventsOccurredAtSameTime = current.transitionId === previous.transitionId;

      if (!eventsOccurredAtSameTime || !sameDestination) {
        return true;
      }

      if (current.source === 'hashchange' && previous.source === 'popstate' || current.source === 'popstate' && previous.source === 'hashchange') {
        return false;
      }

      return true;
    }
    /** The current URL. */

  }, {
    key: "getCurrentNavigation",

    /** The current Navigation object if one exists */
    value: function getCurrentNavigation() {
      return this.currentNavigation;
    }
    /** @internal */

  }, {
    key: "triggerEvent",
    value: function triggerEvent(event) {
      this.events.next(event);
    }
    /**
     * Resets the route configuration used for navigation and generating links.
     *
     * @param config The route array for the new configuration.
     *
     * @usageNotes
     *
     * ```
     * router.resetConfig([
     *  { path: 'team/:id', component: TeamCmp, children: [
     *    { path: 'simple', component: SimpleCmp },
     *    { path: 'user/:name', component: UserCmp }
     *  ]}
     * ]);
     * ```
     */

  }, {
    key: "resetConfig",
    value: function resetConfig(config) {
      validateConfig(config);
      this.config = config.map(standardizeConfig);
      this.navigated = false;
      this.lastSuccessfulId = -1;
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      this.dispose();
    }
    /** Disposes of the router. */

  }, {
    key: "dispose",
    value: function dispose() {
      if (this.locationSubscription) {
        this.locationSubscription.unsubscribe();
        this.locationSubscription = undefined;
      }
    }
    /**
     * Appends URL segments to the current URL tree to create a new URL tree.
     *
     * @param commands An array of URL fragments with which to construct the new URL tree.
     * If the path is static, can be the literal URL string. For a dynamic path, pass an array of path
     * segments, followed by the parameters for each segment.
     * The fragments are applied to the current URL tree or the one provided  in the `relativeTo`
     * property of the options object, if supplied.
     * @param navigationExtras Options that control the navigation strategy. This function
     * only uses properties in `NavigationExtras` that would change the provided URL.
     * @returns The new URL tree.
     *
     * @usageNotes
     *
     * ```
     * // create /team/33/user/11
     * router.createUrlTree(['/team', 33, 'user', 11]);
     *
     * // create /team/33;expand=true/user/11
     * router.createUrlTree(['/team', 33, {expand: true}, 'user', 11]);
     *
     * // you can collapse static segments like this (this works only with the first passed-in value):
     * router.createUrlTree(['/team/33/user', userId]);
     *
     * // If the first segment can contain slashes, and you do not want the router to split it,
     * // you can do the following:
     * router.createUrlTree([{segmentPath: '/one/two'}]);
     *
     * // create /team/33/(user/11//right:chat)
     * router.createUrlTree(['/team', 33, {outlets: {primary: 'user/11', right: 'chat'}}]);
     *
     * // remove the right secondary node
     * router.createUrlTree(['/team', 33, {outlets: {primary: 'user/11', right: null}}]);
     *
     * // assuming the current url is `/team/33/user/11` and the route points to `user/11`
     *
     * // navigate to /team/33/user/11/details
     * router.createUrlTree(['details'], {relativeTo: route});
     *
     * // navigate to /team/33/user/22
     * router.createUrlTree(['../22'], {relativeTo: route});
     *
     * // navigate to /team/44/user/22
     * router.createUrlTree(['../../team/44/user/22'], {relativeTo: route});
     * ```
     */

  }, {
    key: "createUrlTree",
    value: function createUrlTree(commands) {
      var navigationExtras = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var relativeTo = navigationExtras.relativeTo,
          queryParams = navigationExtras.queryParams,
          fragment = navigationExtras.fragment,
          preserveQueryParams = navigationExtras.preserveQueryParams,
          queryParamsHandling = navigationExtras.queryParamsHandling,
          preserveFragment = navigationExtras.preserveFragment;

      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_9__["isDevMode"])() && preserveQueryParams && console && console.warn) {
        console.warn('preserveQueryParams is deprecated, use queryParamsHandling instead.');
      }

      var a = relativeTo || this.routerState.root;
      var f = preserveFragment ? this.currentUrlTree.fragment : fragment;
      var q = null;

      if (queryParamsHandling) {
        switch (queryParamsHandling) {
          case 'merge':
            q = Object.assign(Object.assign({}, this.currentUrlTree.queryParams), queryParams);
            break;

          case 'preserve':
            q = this.currentUrlTree.queryParams;
            break;

          default:
            q = queryParams || null;
        }
      } else {
        q = preserveQueryParams ? this.currentUrlTree.queryParams : queryParams || null;
      }

      if (q !== null) {
        q = this.removeEmptyProps(q);
      }

      return _createUrlTree(a, this.currentUrlTree, commands, q, f);
    }
    /**
     * Navigates to a view using an absolute route path.
     *
     * @param url An absolute path for a defined route. The function does not apply any delta to the
     *     current URL.
     * @param extras An object containing properties that modify the navigation strategy.
     * The function ignores any properties in the `NavigationExtras` that would change the
     * provided URL.
     *
     * @returns A Promise that resolves to 'true' when navigation succeeds,
     * to 'false' when navigation fails, or is rejected on error.
     *
     * @usageNotes
     *
     * The following calls request navigation to an absolute path.
     *
     * ```
     * router.navigateByUrl("/team/33/user/11");
     *
     * // Navigate without updating the URL
     * router.navigateByUrl("/team/33/user/11", { skipLocationChange: true });
     * ```
     *
     * @see [Routing and Navigation guide](guide/router)
     *
     */

  }, {
    key: "navigateByUrl",
    value: function navigateByUrl(url) {
      var extras = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
        skipLocationChange: false
      };

      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_9__["isDevMode"])() && this.isNgZoneEnabled && !_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgZone"].isInAngularZone()) {
        this.console.warn("Navigation triggered outside Angular zone, did you forget to call 'ngZone.run()'?");
      }

      var urlTree = isUrlTree(url) ? url : this.parseUrl(url);
      var mergedTree = this.urlHandlingStrategy.merge(urlTree, this.rawUrlTree);
      return this.scheduleNavigation(mergedTree, 'imperative', null, extras);
    }
    /**
     * Navigate based on the provided array of commands and a starting point.
     * If no starting route is provided, the navigation is absolute.
     *
     * @param commands An array of URL fragments with which to construct the target URL.
     * If the path is static, can be the literal URL string. For a dynamic path, pass an array of path
     * segments, followed by the parameters for each segment.
     * The fragments are applied to the current URL or the one provided  in the `relativeTo` property
     * of the options object, if supplied.
     * @param extras An options object that determines how the URL should be constructed or
     *     interpreted.
     *
     * @returns A Promise that resolves to `true` when navigation succeeds, to `false` when navigation
     *     fails,
     * or is rejected on error.
     *
     * @usageNotes
     *
     * The following calls request navigation to a dynamic route path relative to the current URL.
     *
     * ```
     * router.navigate(['team', 33, 'user', 11], {relativeTo: route});
     *
     * // Navigate without updating the URL, overriding the default behavior
     * router.navigate(['team', 33, 'user', 11], {relativeTo: route, skipLocationChange: true});
     * ```
     *
     * @see [Routing and Navigation guide](guide/router)
     *
     */

  }, {
    key: "navigate",
    value: function navigate(commands) {
      var extras = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
        skipLocationChange: false
      };
      validateCommands(commands);
      return this.navigateByUrl(this.createUrlTree(commands, extras), extras);
    }
    /** Serializes a `UrlTree` into a string */

  }, {
    key: "serializeUrl",
    value: function serializeUrl(url) {
      return this.urlSerializer.serialize(url);
    }
    /** Parses a string into a `UrlTree` */

  }, {
    key: "parseUrl",
    value: function parseUrl(url) {
      var urlTree;

      try {
        urlTree = this.urlSerializer.parse(url);
      } catch (e) {
        urlTree = this.malformedUriErrorHandler(e, this.urlSerializer, url);
      }

      return urlTree;
    }
    /** Returns whether the url is activated */

  }, {
    key: "isActive",
    value: function isActive(url, exact) {
      if (isUrlTree(url)) {
        return containsTree(this.currentUrlTree, url, exact);
      }

      var urlTree = this.parseUrl(url);
      return containsTree(this.currentUrlTree, urlTree, exact);
    }
  }, {
    key: "removeEmptyProps",
    value: function removeEmptyProps(params) {
      return Object.keys(params).reduce(function (result, key) {
        var value = params[key];

        if (value !== null && value !== undefined) {
          result[key] = value;
        }

        return result;
      }, {});
    }
  }, {
    key: "processNavigations",
    value: function processNavigations() {
      var _this34 = this;

      this.navigations.subscribe(function (t) {
        _this34.navigated = true;
        _this34.lastSuccessfulId = t.id;

        _this34.events.next(new NavigationEnd(t.id, _this34.serializeUrl(t.extractedUrl), _this34.serializeUrl(_this34.currentUrlTree)));

        _this34.lastSuccessfulNavigation = _this34.currentNavigation;
        _this34.currentNavigation = null;
        t.resolve(true);
      }, function (e) {
        _this34.console.warn("Unhandled Navigation Error: ");
      });
    }
  }, {
    key: "scheduleNavigation",
    value: function scheduleNavigation(rawUrl, source, restoredState, extras, priorPromise) {
      // * Imperative navigations (router.navigate) might trigger additional navigations to the same
      //   URL via a popstate event and the locationChangeListener. We should skip these duplicate
      //   navs. Duplicates may also be triggered by attempts to sync AngularJS and Angular router
      //   states.
      // * Imperative navigations can be cancelled by router guards, meaning the URL won't change. If
      //   the user follows that with a navigation using the back/forward button or manual URL change,
      //   the destination may be the same as the previous imperative attempt. We should not skip
      //   these navigations because it's a separate case from the one above -- it's not a duplicate
      //   navigation.
      var lastNavigation = this.getTransition(); // We don't want to skip duplicate successful navs if they're imperative because
      // onSameUrlNavigation could be 'reload' (so the duplicate is intended).

      var browserNavPrecededByRouterNav = source !== 'imperative' && (lastNavigation === null || lastNavigation === void 0 ? void 0 : lastNavigation.source) === 'imperative';
      var lastNavigationSucceeded = this.lastSuccessfulId === lastNavigation.id; // If the last navigation succeeded or is in flight, we can use the rawUrl as the comparison.
      // However, if it failed, we should compare to the final result (urlAfterRedirects).

      var lastNavigationUrl = lastNavigationSucceeded || this.currentNavigation ? lastNavigation.rawUrl : lastNavigation.urlAfterRedirects;
      var duplicateNav = lastNavigationUrl.toString() === rawUrl.toString();

      if (browserNavPrecededByRouterNav && duplicateNav) {
        return Promise.resolve(true); // return value is not used
      }

      var resolve;
      var reject;
      var promise;

      if (priorPromise) {
        resolve = priorPromise.resolve;
        reject = priorPromise.reject;
        promise = priorPromise.promise;
      } else {
        promise = new Promise(function (res, rej) {
          resolve = res;
          reject = rej;
        });
      }

      var id = ++this.navigationId;
      this.setTransition({
        id: id,
        source: source,
        restoredState: restoredState,
        currentUrlTree: this.currentUrlTree,
        currentRawUrl: this.rawUrlTree,
        rawUrl: rawUrl,
        extras: extras,
        resolve: resolve,
        reject: reject,
        promise: promise,
        currentSnapshot: this.routerState.snapshot,
        currentRouterState: this.routerState
      }); // Make sure that the error is propagated even though `processNavigations` catch
      // handler does not rethrow

      return promise.catch(function (e) {
        return Promise.reject(e);
      });
    }
  }, {
    key: "setBrowserUrl",
    value: function setBrowserUrl(url, replaceUrl, id, state) {
      var path = this.urlSerializer.serialize(url);
      state = state || {};

      if (this.location.isCurrentPathEqualTo(path) || replaceUrl) {
        // TODO(jasonaden): Remove first `navigationId` and rely on `ng` namespace.
        this.location.replaceState(path, '', Object.assign(Object.assign({}, state), {
          navigationId: id
        }));
      } else {
        this.location.go(path, '', Object.assign(Object.assign({}, state), {
          navigationId: id
        }));
      }
    }
  }, {
    key: "resetStateAndUrl",
    value: function resetStateAndUrl(storedState, storedUrl, rawUrl) {
      this.routerState = storedState;
      this.currentUrlTree = storedUrl;
      this.rawUrlTree = this.urlHandlingStrategy.merge(this.currentUrlTree, rawUrl);
      this.resetUrlToCurrentUrlTree();
    }
  }, {
    key: "resetUrlToCurrentUrlTree",
    value: function resetUrlToCurrentUrlTree() {
      this.location.replaceState(this.urlSerializer.serialize(this.rawUrlTree), '', {
        navigationId: this.lastSuccessfulId
      });
    }
  }, {
    key: "url",
    get: function get() {
      return this.serializeUrl(this.currentUrlTree);
    }
  }]);

  return Router;
}();

Router.ɵfac = function Router_Factory(t) {
  return new (t || Router)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Type"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](UrlSerializer), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](ChildrenOutletContexts), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_8__["Location"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](undefined));
};

Router.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineInjectable"]({
  token: Router,
  factory: Router.ɵfac
});

Router.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Type"]
  }, {
    type: UrlSerializer
  }, {
    type: ChildrenOutletContexts
  }, {
    type: _angular_common__WEBPACK_IMPORTED_MODULE_8__["Location"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"]
  }, {
    type: undefined
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](Router, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injectable"]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Type"]
    }, {
      type: UrlSerializer
    }, {
      type: ChildrenOutletContexts
    }, {
      type: _angular_common__WEBPACK_IMPORTED_MODULE_8__["Location"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"]
    }, {
      type: undefined
    }];
  }, null);
})();

function validateCommands(commands) {
  for (var i = 0; i < commands.length; i++) {
    var cmd = commands[i];

    if (cmd == null) {
      throw new Error("The requested path contains ".concat(cmd, " segment at index ").concat(i));
    }
  }
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * When applied to an element in a template, makes that element a link
 * that initiates navigation to a route. Navigation opens one or more routed components
 * in one or more `<router-outlet>` locations on the page.
 *
 * Given a route configuration `[{ path: 'user/:name', component: UserCmp }]`,
 * the following creates a static link to the route:
 * `<a routerLink="/user/bob">link to user component</a>`
 *
 * You can use dynamic values to generate the link.
 * For a dynamic link, pass an array of path segments,
 * followed by the params for each segment.
 * For example, `['/team', teamId, 'user', userName, {details: true}]`
 * generates a link to `/team/11/user/bob;details=true`.
 *
 * Multiple static segments can be merged into one term and combined with dynamic segements.
 * For example, `['/team/11/user', userName, {details: true}]`
 *
 * The input that you provide to the link is treated as a delta to the current URL.
 * For instance, suppose the current URL is `/user/(box//aux:team)`.
 * The link `<a [routerLink]="['/user/jim']">Jim</a>` creates the URL
 * `/user/(jim//aux:team)`.
 * See {@link Router#createUrlTree createUrlTree} for more information.
 *
 * @usageNotes
 *
 * You can use absolute or relative paths in a link, set query parameters,
 * control how parameters are handled, and keep a history of navigation states.
 *
 * ### Relative link paths
 *
 * The first segment name can be prepended with `/`, `./`, or `../`.
 * * If the first segment begins with `/`, the router looks up the route from the root of the
 *   app.
 * * If the first segment begins with `./`, or doesn't begin with a slash, the router
 *   looks in the children of the current activated route.
 * * If the first segment begins with `../`, the router goes up one level in the route tree.
 *
 * ### Setting and handling query params and fragments
 *
 * The following link adds a query parameter and a fragment to the generated URL:
 *
 * ```
 * <a [routerLink]="['/user/bob']" [queryParams]="{debug: true}" fragment="education">
 *   link to user component
 * </a>
 * ```
 * By default, the directive constructs the new URL using the given query parameters.
 * The example generates the link: `/user/bob?debug=true#education`.
 *
 * You can instruct the directive to handle query parameters differently
 * by specifying the `queryParamsHandling` option in the link.
 * Allowed values are:
 *
 *  - `'merge'`: Merge the given `queryParams` into the current query params.
 *  - `'preserve'`: Preserve the current query params.
 *
 * For example:
 *
 * ```
 * <a [routerLink]="['/user/bob']" [queryParams]="{debug: true}" queryParamsHandling="merge">
 *   link to user component
 * </a>
 * ```
 *
 * See {@link NavigationExtras.queryParamsHandling NavigationExtras#queryParamsHandling}.
 *
 * ### Preserving navigation history
 *
 * You can provide a `state` value to be persisted to the browser's
 * [`History.state` property](https://developer.mozilla.org/en-US/docs/Web/API/History#Properties).
 * For example:
 *
 * ```
 * <a [routerLink]="['/user/bob']" [state]="{tracingId: 123}">
 *   link to user component
 * </a>
 * ```
 *
 * Use {@link Router.getCurrentNavigation() Router#getCurrentNavigation} to retrieve a saved
 * navigation-state value. For example, to capture the `tracingId` during the `NavigationStart`
 * event:
 *
 * ```
 * // Get NavigationStart events
 * router.events.pipe(filter(e => e instanceof NavigationStart)).subscribe(e => {
 *   const navigation = router.getCurrentNavigation();
 *   tracingService.trace({id: navigation.extras.state.tracingId});
 * });
 * ```
 *
 * @ngModule RouterModule
 *
 * @publicApi
 */


var RouterLink = /*#__PURE__*/function () {
  function RouterLink(router, route, tabIndex, renderer, el) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterLink);

    this.router = router;
    this.route = route;
    this.commands = [];
    /** @internal */

    this.onChanges = new rxjs__WEBPACK_IMPORTED_MODULE_10__["Subject"]();

    if (tabIndex == null) {
      renderer.setAttribute(el.nativeElement, 'tabindex', '0');
    }
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterLink, [{
    key: "ngOnChanges",
    value: function ngOnChanges(changes) {
      // This is subscribed to by `RouterLinkActive` so that it knows to update when there are changes
      // to the RouterLinks it's tracking.
      this.onChanges.next(this);
    }
    /**
     * Commands to pass to {@link Router#createUrlTree Router#createUrlTree}.
     *   - **array**: commands to pass to {@link Router#createUrlTree Router#createUrlTree}.
     *   - **string**: shorthand for array of commands with just the string, i.e. `['/route']`
     *   - **null|undefined**: shorthand for an empty array of commands, i.e. `[]`
     * @see {@link Router#createUrlTree Router#createUrlTree}
     */

  }, {
    key: "onClick",

    /** @nodoc */
    value: function onClick() {
      var extras = {
        skipLocationChange: attrBoolValue(this.skipLocationChange),
        replaceUrl: attrBoolValue(this.replaceUrl),
        state: this.state
      };
      this.router.navigateByUrl(this.urlTree, extras);
      return true;
    }
  }, {
    key: "routerLink",
    set: function set(commands) {
      if (commands != null) {
        this.commands = Array.isArray(commands) ? commands : [commands];
      } else {
        this.commands = [];
      }
    }
    /**
     * @deprecated As of Angular v4.0 use `queryParamsHandling` instead.
     */

  }, {
    key: "preserveQueryParams",
    set: function set(value) {
      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_9__["isDevMode"])() && console && console.warn) {
        console.warn('preserveQueryParams is deprecated!, use queryParamsHandling instead.');
      }

      this.preserve = value;
    }
  }, {
    key: "urlTree",
    get: function get() {
      return this.router.createUrlTree(this.commands, {
        relativeTo: this.route,
        queryParams: this.queryParams,
        fragment: this.fragment,
        preserveQueryParams: attrBoolValue(this.preserve),
        queryParamsHandling: this.queryParamsHandling,
        preserveFragment: attrBoolValue(this.preserveFragment)
      });
    }
  }]);

  return RouterLink;
}();

RouterLink.ɵfac = function RouterLink_Factory(t) {
  return new (t || RouterLink)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](Router), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](ActivatedRoute), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinjectAttribute"]('tabindex'), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["ElementRef"]));
};

RouterLink.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineDirective"]({
  type: RouterLink,
  selectors: [["", "routerLink", "", 5, "a", 5, "area"]],
  hostBindings: function RouterLink_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵlistener"]("click", function RouterLink_click_HostBindingHandler() {
        return ctx.onClick();
      });
    }
  },
  inputs: {
    routerLink: "routerLink",
    preserveQueryParams: "preserveQueryParams",
    queryParams: "queryParams",
    fragment: "fragment",
    queryParamsHandling: "queryParamsHandling",
    preserveFragment: "preserveFragment",
    skipLocationChange: "skipLocationChange",
    replaceUrl: "replaceUrl",
    state: "state"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵNgOnChangesFeature"]]
});

RouterLink.ctorParameters = function () {
  return [{
    type: Router
  }, {
    type: ActivatedRoute
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Attribute"],
      args: ['tabindex']
    }]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ElementRef"]
  }];
};

RouterLink.propDecorators = {
  queryParams: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  fragment: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  queryParamsHandling: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  preserveFragment: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  skipLocationChange: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  replaceUrl: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  state: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  routerLink: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  preserveQueryParams: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  onClick: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostListener"],
    args: ['click']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterLink, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Directive"],
    args: [{
      selector: ':not(a):not(area)[routerLink]'
    }]
  }], function () {
    return [{
      type: Router
    }, {
      type: ActivatedRoute
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Attribute"],
        args: ['tabindex']
      }]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ElementRef"]
    }];
  }, {
    routerLink: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    preserveQueryParams: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],

    /** @nodoc */
    onClick: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostListener"],
      args: ['click']
    }],
    queryParams: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    fragment: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    queryParamsHandling: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    preserveFragment: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    skipLocationChange: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    replaceUrl: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    state: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }]
  });
})();
/**
 * @description
 *
 * Lets you link to specific routes in your app.
 *
 * See `RouterLink` for more information.
 *
 * @ngModule RouterModule
 *
 * @publicApi
 */


var RouterLinkWithHref = /*#__PURE__*/function () {
  function RouterLinkWithHref(router, route, locationStrategy) {
    var _this35 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterLinkWithHref);

    this.router = router;
    this.route = route;
    this.locationStrategy = locationStrategy;
    this.commands = [];
    /** @internal */

    this.onChanges = new rxjs__WEBPACK_IMPORTED_MODULE_10__["Subject"]();
    this.subscription = router.events.subscribe(function (s) {
      if (s instanceof NavigationEnd) {
        _this35.updateTargetUrlAndHref();
      }
    });
  }
  /**
   * Commands to pass to {@link Router#createUrlTree Router#createUrlTree}.
   *   - **array**: commands to pass to {@link Router#createUrlTree Router#createUrlTree}.
   *   - **string**: shorthand for array of commands with just the string, i.e. `['/route']`
   *   - **null|undefined**: shorthand for an empty array of commands, i.e. `[]`
   * @see {@link Router#createUrlTree Router#createUrlTree}
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterLinkWithHref, [{
    key: "ngOnChanges",

    /** @nodoc */
    value: function ngOnChanges(changes) {
      this.updateTargetUrlAndHref();
      this.onChanges.next(this);
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      this.subscription.unsubscribe();
    }
    /** @nodoc */

  }, {
    key: "onClick",
    value: function onClick(button, ctrlKey, shiftKey, altKey, metaKey) {
      if (button !== 0 || ctrlKey || shiftKey || altKey || metaKey) {
        return true;
      }

      if (typeof this.target === 'string' && this.target != '_self') {
        return true;
      }

      var extras = {
        skipLocationChange: attrBoolValue(this.skipLocationChange),
        replaceUrl: attrBoolValue(this.replaceUrl),
        state: this.state
      };
      this.router.navigateByUrl(this.urlTree, extras);
      return false;
    }
  }, {
    key: "updateTargetUrlAndHref",
    value: function updateTargetUrlAndHref() {
      this.href = this.locationStrategy.prepareExternalUrl(this.router.serializeUrl(this.urlTree));
    }
  }, {
    key: "routerLink",
    set: function set(commands) {
      if (commands != null) {
        this.commands = Array.isArray(commands) ? commands : [commands];
      } else {
        this.commands = [];
      }
    }
    /**
     * @deprecated As of Angular v4.0 use `queryParamsHandling` instead.
     */

  }, {
    key: "preserveQueryParams",
    set: function set(value) {
      if (Object(_angular_core__WEBPACK_IMPORTED_MODULE_9__["isDevMode"])() && console && console.warn) {
        console.warn('preserveQueryParams is deprecated, use queryParamsHandling instead.');
      }

      this.preserve = value;
    }
  }, {
    key: "urlTree",
    get: function get() {
      return this.router.createUrlTree(this.commands, {
        relativeTo: this.route,
        queryParams: this.queryParams,
        fragment: this.fragment,
        preserveQueryParams: attrBoolValue(this.preserve),
        queryParamsHandling: this.queryParamsHandling,
        preserveFragment: attrBoolValue(this.preserveFragment)
      });
    }
  }]);

  return RouterLinkWithHref;
}();

RouterLinkWithHref.ɵfac = function RouterLinkWithHref_Factory(t) {
  return new (t || RouterLinkWithHref)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](Router), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](ActivatedRoute), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_common__WEBPACK_IMPORTED_MODULE_8__["LocationStrategy"]));
};

RouterLinkWithHref.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineDirective"]({
  type: RouterLinkWithHref,
  selectors: [["a", "routerLink", ""], ["area", "routerLink", ""]],
  hostVars: 2,
  hostBindings: function RouterLinkWithHref_HostBindings(rf, ctx) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵlistener"]("click", function RouterLinkWithHref_click_HostBindingHandler($event) {
        return ctx.onClick($event.button, $event.ctrlKey, $event.shiftKey, $event.altKey, $event.metaKey);
      });
    }

    if (rf & 2) {
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵhostProperty"]("href", ctx.href, _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵsanitizeUrl"]);
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵattribute"]("target", ctx.target);
    }
  },
  inputs: {
    routerLink: "routerLink",
    preserveQueryParams: "preserveQueryParams",
    target: "target",
    queryParams: "queryParams",
    fragment: "fragment",
    queryParamsHandling: "queryParamsHandling",
    preserveFragment: "preserveFragment",
    skipLocationChange: "skipLocationChange",
    replaceUrl: "replaceUrl",
    state: "state"
  },
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵNgOnChangesFeature"]]
});

RouterLinkWithHref.ctorParameters = function () {
  return [{
    type: Router
  }, {
    type: ActivatedRoute
  }, {
    type: _angular_common__WEBPACK_IMPORTED_MODULE_8__["LocationStrategy"]
  }];
};

RouterLinkWithHref.propDecorators = {
  target: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostBinding"],
    args: ['attr.target']
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  queryParams: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  fragment: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  queryParamsHandling: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  preserveFragment: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  skipLocationChange: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  replaceUrl: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  state: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  href: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostBinding"]
  }],
  routerLink: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  preserveQueryParams: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  onClick: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostListener"],
    args: ['click', ['$event.button', '$event.ctrlKey', '$event.shiftKey', '$event.altKey', '$event.metaKey']]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterLinkWithHref, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Directive"],
    args: [{
      selector: 'a[routerLink],area[routerLink]'
    }]
  }], function () {
    return [{
      type: Router
    }, {
      type: ActivatedRoute
    }, {
      type: _angular_common__WEBPACK_IMPORTED_MODULE_8__["LocationStrategy"]
    }];
  }, {
    routerLink: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    preserveQueryParams: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],

    /** @nodoc */
    onClick: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostListener"],
      args: ['click', ['$event.button', '$event.ctrlKey', '$event.shiftKey', '$event.altKey', '$event.metaKey']]
    }],
    href: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostBinding"]
    }],
    target: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["HostBinding"],
      args: ['attr.target']
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    queryParams: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    fragment: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    queryParamsHandling: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    preserveFragment: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    skipLocationChange: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    replaceUrl: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    state: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }]
  });
})();

function attrBoolValue(s) {
  return s === '' || !!s;
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 *
 * @description
 *
 * Tracks whether the linked route of an element is currently active, and allows you
 * to specify one or more CSS classes to add to the element when the linked route
 * is active.
 *
 * Use this directive to create a visual distinction for elements associated with an active route.
 * For example, the following code highlights the word "Bob" when the the router
 * activates the associated route:
 *
 * ```
 * <a routerLink="/user/bob" routerLinkActive="active-link">Bob</a>
 * ```
 *
 * Whenever the URL is either '/user' or '/user/bob', the "active-link" class is
 * added to the anchor tag. If the URL changes, the class is removed.
 *
 * You can set more than one class using a space-separated string or an array.
 * For example:
 *
 * ```
 * <a routerLink="/user/bob" routerLinkActive="class1 class2">Bob</a>
 * <a routerLink="/user/bob" [routerLinkActive]="['class1', 'class2']">Bob</a>
 * ```
 *
 * To add the classes only when the URL matches the link exactly, add the option `exact: true`:
 *
 * ```
 * <a routerLink="/user/bob" routerLinkActive="active-link" [routerLinkActiveOptions]="{exact:
 * true}">Bob</a>
 * ```
 *
 * To directly check the `isActive` status of the link, assign the `RouterLinkActive`
 * instance to a template variable.
 * For example, the following checks the status without assigning any CSS classes:
 *
 * ```
 * <a routerLink="/user/bob" routerLinkActive #rla="routerLinkActive">
 *   Bob {{ rla.isActive ? '(already open)' : ''}}
 * </a>
 * ```
 *
 * You can apply the `RouterLinkActive` directive to an ancestor of linked elements.
 * For example, the following sets the active-link class on the `<div>`  parent tag
 * when the URL is either '/user/jim' or '/user/bob'.
 *
 * ```
 * <div routerLinkActive="active-link" [routerLinkActiveOptions]="{exact: true}">
 *   <a routerLink="/user/jim">Jim</a>
 *   <a routerLink="/user/bob">Bob</a>
 * </div>
 * ```
 *
 * @ngModule RouterModule
 *
 * @publicApi
 */


var RouterLinkActive = /*#__PURE__*/function () {
  function RouterLinkActive(router, element, renderer, cdr, link, linkWithHref) {
    var _this36 = this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterLinkActive);

    this.router = router;
    this.element = element;
    this.renderer = renderer;
    this.cdr = cdr;
    this.link = link;
    this.linkWithHref = linkWithHref;
    this.classes = [];
    this.isActive = false;
    this.routerLinkActiveOptions = {
      exact: false
    };
    this.routerEventsSubscription = router.events.subscribe(function (s) {
      if (s instanceof NavigationEnd) {
        _this36.update();
      }
    });
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterLinkActive, [{
    key: "ngAfterContentInit",
    value: function ngAfterContentInit() {
      var _this37 = this;

      // `of(null)` is used to force subscribe body to execute once immediately (like `startWith`).
      Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])([this.links.changes, this.linksWithHrefs.changes, Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(null)]).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeAll"])()).subscribe(function (_) {
        _this37.update();

        _this37.subscribeToEachLinkOnChanges();
      });
    }
  }, {
    key: "subscribeToEachLinkOnChanges",
    value: function subscribeToEachLinkOnChanges() {
      var _this38 = this;

      var _a;

      (_a = this.linkInputChangesSubscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
      var allLinkChanges = [].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(this.links.toArray()), Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_3__["default"])(this.linksWithHrefs.toArray()), [this.link, this.linkWithHref]).filter(function (link) {
        return !!link;
      }).map(function (link) {
        return link.onChanges;
      });
      this.linkInputChangesSubscription = Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(allLinkChanges).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeAll"])()).subscribe(function (link) {
        if (_this38.isActive !== _this38.isLinkActive(_this38.router)(link)) {
          _this38.update();
        }
      });
    }
  }, {
    key: "ngOnChanges",

    /** @nodoc */
    value: function ngOnChanges(changes) {
      this.update();
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      var _a;

      this.routerEventsSubscription.unsubscribe();
      (_a = this.linkInputChangesSubscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
  }, {
    key: "update",
    value: function update() {
      var _this39 = this;

      if (!this.links || !this.linksWithHrefs || !this.router.navigated) return;
      Promise.resolve().then(function () {
        var hasActiveLinks = _this39.hasActiveLinks();

        if (_this39.isActive !== hasActiveLinks) {
          _this39.isActive = hasActiveLinks;

          _this39.cdr.markForCheck();

          _this39.classes.forEach(function (c) {
            if (hasActiveLinks) {
              _this39.renderer.addClass(_this39.element.nativeElement, c);
            } else {
              _this39.renderer.removeClass(_this39.element.nativeElement, c);
            }
          });
        }
      });
    }
  }, {
    key: "isLinkActive",
    value: function isLinkActive(router) {
      var _this40 = this;

      return function (link) {
        return router.isActive(link.urlTree, _this40.routerLinkActiveOptions.exact);
      };
    }
  }, {
    key: "hasActiveLinks",
    value: function hasActiveLinks() {
      var isActiveCheckFn = this.isLinkActive(this.router);
      return this.link && isActiveCheckFn(this.link) || this.linkWithHref && isActiveCheckFn(this.linkWithHref) || this.links.some(isActiveCheckFn) || this.linksWithHrefs.some(isActiveCheckFn);
    }
  }, {
    key: "routerLinkActive",
    set: function set(data) {
      var classes = Array.isArray(data) ? data : data.split(' ');
      this.classes = classes.filter(function (c) {
        return !!c;
      });
    }
  }]);

  return RouterLinkActive;
}();

RouterLinkActive.ɵfac = function RouterLinkActive_Factory(t) {
  return new (t || RouterLinkActive)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](Router), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["ElementRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Renderer2"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["ChangeDetectorRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](RouterLink, 8), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](RouterLinkWithHref, 8));
};

RouterLinkActive.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineDirective"]({
  type: RouterLinkActive,
  selectors: [["", "routerLinkActive", ""]],
  contentQueries: function RouterLinkActive_ContentQueries(rf, ctx, dirIndex) {
    if (rf & 1) {
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵcontentQuery"](dirIndex, RouterLink, true);
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵcontentQuery"](dirIndex, RouterLinkWithHref, true);
    }

    if (rf & 2) {
      var _t;

      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵqueryRefresh"](_t = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵloadQuery"]()) && (ctx.links = _t);
      _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵqueryRefresh"](_t = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵloadQuery"]()) && (ctx.linksWithHrefs = _t);
    }
  },
  inputs: {
    routerLinkActiveOptions: "routerLinkActiveOptions",
    routerLinkActive: "routerLinkActive"
  },
  exportAs: ["routerLinkActive"],
  features: [_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵNgOnChangesFeature"]]
});

RouterLinkActive.ctorParameters = function () {
  return [{
    type: Router
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ElementRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Renderer2"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ChangeDetectorRef"]
  }, {
    type: RouterLink,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
    }]
  }, {
    type: RouterLinkWithHref,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
    }]
  }];
};

RouterLinkActive.propDecorators = {
  links: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ContentChildren"],
    args: [RouterLink, {
      descendants: true
    }]
  }],
  linksWithHrefs: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ContentChildren"],
    args: [RouterLinkWithHref, {
      descendants: true
    }]
  }],
  routerLinkActiveOptions: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }],
  routerLinkActive: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterLinkActive, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Directive"],
    args: [{
      selector: '[routerLinkActive]',
      exportAs: 'routerLinkActive'
    }]
  }], function () {
    return [{
      type: Router
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ElementRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Renderer2"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ChangeDetectorRef"]
    }, {
      type: RouterLink,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
      }]
    }, {
      type: RouterLinkWithHref,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
      }]
    }];
  }, {
    routerLinkActiveOptions: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    routerLinkActive: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Input"]
    }],
    links: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ContentChildren"],
      args: [RouterLink, {
        descendants: true
      }]
    }],
    linksWithHrefs: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ContentChildren"],
      args: [RouterLinkWithHref, {
        descendants: true
      }]
    }]
  });
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * Acts as a placeholder that Angular dynamically fills based on the current router state.
 *
 * Each outlet can have a unique name, determined by the optional `name` attribute.
 * The name cannot be set or changed dynamically. If not set, default value is "primary".
 *
 * ```
 * <router-outlet></router-outlet>
 * <router-outlet name='left'></router-outlet>
 * <router-outlet name='right'></router-outlet>
 * ```
 *
 * Named outlets can be the targets of secondary routes.
 * The `Route` object for a secondary route has an `outlet` property to identify the target outlet:
 *
 * `{path: <base-path>, component: <component>, outlet: <target_outlet_name>}`
 *
 * Using named outlets and secondary routes, you can target multiple outlets in
 * the same `RouterLink` directive.
 *
 * The router keeps track of separate branches in a navigation tree for each named outlet and
 * generates a representation of that tree in the URL.
 * The URL for a secondary route uses the following syntax to specify both the primary and secondary
 * routes at the same time:
 *
 * `http://base-path/primary-route-path(outlet-name:route-path)`
 *
 * A router outlet emits an activate event when a new component is instantiated,
 * and a deactivate event when a component is destroyed.
 *
 * ```
 * <router-outlet
 *   (activate)='onActivate($event)'
 *   (deactivate)='onDeactivate($event)'></router-outlet>
 * ```
 *
 * @see [Routing tutorial](guide/router-tutorial-toh#named-outlets "Example of a named
 * outlet and secondary route configuration").
 * @see `RouterLink`
 * @see `Route`
 * @ngModule RouterModule
 *
 * @publicApi
 */


var RouterOutlet = /*#__PURE__*/function () {
  function RouterOutlet(parentContexts, location, resolver, name, changeDetector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterOutlet);

    this.parentContexts = parentContexts;
    this.location = location;
    this.resolver = resolver;
    this.changeDetector = changeDetector;
    this.activated = null;
    this._activatedRoute = null;
    this.activateEvents = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["EventEmitter"]();
    this.deactivateEvents = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["EventEmitter"]();
    this.name = name || PRIMARY_OUTLET;
    parentContexts.onChildOutletCreated(this.name, this);
  }
  /** @nodoc */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterOutlet, [{
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      this.parentContexts.onChildOutletDestroyed(this.name);
    }
    /** @nodoc */

  }, {
    key: "ngOnInit",
    value: function ngOnInit() {
      if (!this.activated) {
        // If the outlet was not instantiated at the time the route got activated we need to populate
        // the outlet when it is initialized (ie inside a NgIf)
        var context = this.parentContexts.getContext(this.name);

        if (context && context.route) {
          if (context.attachRef) {
            // `attachRef` is populated when there is an existing component to mount
            this.attach(context.attachRef, context.route);
          } else {
            // otherwise the component defined in the configuration is created
            this.activateWith(context.route, context.resolver || null);
          }
        }
      }
    }
  }, {
    key: "detach",

    /**
     * Called when the `RouteReuseStrategy` instructs to detach the subtree
     */
    value: function detach() {
      if (!this.activated) throw new Error('Outlet is not activated');
      this.location.detach();
      var cmp = this.activated;
      this.activated = null;
      this._activatedRoute = null;
      return cmp;
    }
    /**
     * Called when the `RouteReuseStrategy` instructs to re-attach a previously detached subtree
     */

  }, {
    key: "attach",
    value: function attach(ref, activatedRoute) {
      this.activated = ref;
      this._activatedRoute = activatedRoute;
      this.location.insert(ref.hostView);
    }
  }, {
    key: "deactivate",
    value: function deactivate() {
      if (this.activated) {
        var c = this.component;
        this.activated.destroy();
        this.activated = null;
        this._activatedRoute = null;
        this.deactivateEvents.emit(c);
      }
    }
  }, {
    key: "activateWith",
    value: function activateWith(activatedRoute, resolver) {
      if (this.isActivated) {
        throw new Error('Cannot activate an already activated outlet');
      }

      this._activatedRoute = activatedRoute;
      var snapshot = activatedRoute._futureSnapshot;
      var component = snapshot.routeConfig.component;
      resolver = resolver || this.resolver;
      var factory = resolver.resolveComponentFactory(component);
      var childContexts = this.parentContexts.getOrCreateContext(this.name).children;
      var injector = new OutletInjector(activatedRoute, childContexts, this.location.injector);
      this.activated = this.location.createComponent(factory, this.location.length, injector); // Calling `markForCheck` to make sure we will run the change detection when the
      // `RouterOutlet` is inside a `ChangeDetectionStrategy.OnPush` component.

      this.changeDetector.markForCheck();
      this.activateEvents.emit(this.activated.instance);
    }
  }, {
    key: "isActivated",
    get: function get() {
      return !!this.activated;
    }
  }, {
    key: "component",
    get: function get() {
      if (!this.activated) throw new Error('Outlet is not activated');
      return this.activated.instance;
    }
  }, {
    key: "activatedRoute",
    get: function get() {
      if (!this.activated) throw new Error('Outlet is not activated');
      return this._activatedRoute;
    }
  }, {
    key: "activatedRouteData",
    get: function get() {
      if (this._activatedRoute) {
        return this._activatedRoute.snapshot.data;
      }

      return {};
    }
  }]);

  return RouterOutlet;
}();

RouterOutlet.ɵfac = function RouterOutlet_Factory(t) {
  return new (t || RouterOutlet)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](ChildrenOutletContexts), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["ViewContainerRef"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["ComponentFactoryResolver"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinjectAttribute"]('name'), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdirectiveInject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["ChangeDetectorRef"]));
};

RouterOutlet.ɵdir = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineDirective"]({
  type: RouterOutlet,
  selectors: [["router-outlet"]],
  outputs: {
    activateEvents: "activate",
    deactivateEvents: "deactivate"
  },
  exportAs: ["outlet"]
});

RouterOutlet.ctorParameters = function () {
  return [{
    type: ChildrenOutletContexts
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ViewContainerRef"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ComponentFactoryResolver"]
  }, {
    type: String,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Attribute"],
      args: ['name']
    }]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ChangeDetectorRef"]
  }];
};

RouterOutlet.propDecorators = {
  activateEvents: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Output"],
    args: ['activate']
  }],
  deactivateEvents: [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Output"],
    args: ['deactivate']
  }]
};
/*@__PURE__*/

(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterOutlet, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Directive"],
    args: [{
      selector: 'router-outlet',
      exportAs: 'outlet'
    }]
  }], function () {
    return [{
      type: ChildrenOutletContexts
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ViewContainerRef"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ComponentFactoryResolver"]
    }, {
      type: String,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Attribute"],
        args: ['name']
      }]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ChangeDetectorRef"]
    }];
  }, {
    activateEvents: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Output"],
      args: ['activate']
    }],
    deactivateEvents: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Output"],
      args: ['deactivate']
    }]
  });
})();

var OutletInjector = /*#__PURE__*/function () {
  function OutletInjector(route, childContexts, parent) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, OutletInjector);

    this.route = route;
    this.childContexts = childContexts;
    this.parent = parent;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(OutletInjector, [{
    key: "get",
    value: function get(token, notFoundValue) {
      if (token === ActivatedRoute) {
        return this.route;
      }

      if (token === ChildrenOutletContexts) {
        return this.childContexts;
      }

      return this.parent.get(token, notFoundValue);
    }
  }]);

  return OutletInjector;
}();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @description
 *
 * Provides a preloading strategy.
 *
 * @publicApi
 */


var PreloadingStrategy = function PreloadingStrategy() {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, PreloadingStrategy);
};
/**
 * @description
 *
 * Provides a preloading strategy that preloads all modules as quickly as possible.
 *
 * ```
 * RouterModule.forRoot(ROUTES, {preloadingStrategy: PreloadAllModules})
 * ```
 *
 * @publicApi
 */


var PreloadAllModules = /*#__PURE__*/function () {
  function PreloadAllModules() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, PreloadAllModules);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(PreloadAllModules, [{
    key: "preload",
    value: function preload(route, fn) {
      return fn().pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["catchError"])(function () {
        return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(null);
      }));
    }
  }]);

  return PreloadAllModules;
}();
/**
 * @description
 *
 * Provides a preloading strategy that does not preload any modules.
 *
 * This strategy is enabled by default.
 *
 * @publicApi
 */


var NoPreloading = /*#__PURE__*/function () {
  function NoPreloading() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, NoPreloading);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(NoPreloading, [{
    key: "preload",
    value: function preload(route, fn) {
      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(null);
    }
  }]);

  return NoPreloading;
}();
/**
 * The preloader optimistically loads all router configurations to
 * make navigations into lazily-loaded sections of the application faster.
 *
 * The preloader runs in the background. When the router bootstraps, the preloader
 * starts listening to all navigation events. After every such event, the preloader
 * will check if any configurations can be loaded lazily.
 *
 * If a route is protected by `canLoad` guards, the preloaded will not load it.
 *
 * @publicApi
 */


var RouterPreloader = /*#__PURE__*/function () {
  function RouterPreloader(router, moduleLoader, compiler, injector, preloadingStrategy) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterPreloader);

    this.router = router;
    this.injector = injector;
    this.preloadingStrategy = preloadingStrategy;

    var onStartLoad = function onStartLoad(r) {
      return router.triggerEvent(new RouteConfigLoadStart(r));
    };

    var onEndLoad = function onEndLoad(r) {
      return router.triggerEvent(new RouteConfigLoadEnd(r));
    };

    this.loader = new RouterConfigLoader(moduleLoader, compiler, onStartLoad, onEndLoad);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterPreloader, [{
    key: "setUpPreloading",
    value: function setUpPreloading() {
      var _this41 = this;

      this.subscription = this.router.events.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["filter"])(function (e) {
        return e instanceof NavigationEnd;
      }), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["concatMap"])(function () {
        return _this41.preload();
      })).subscribe(function () {});
    }
  }, {
    key: "preload",
    value: function preload() {
      var ngModule = this.injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleRef"]);
      return this.processRoutes(ngModule, this.router.config);
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this.subscription) {
        this.subscription.unsubscribe();
      }
    }
  }, {
    key: "processRoutes",
    value: function processRoutes(ngModule, routes) {
      var res = [];

      var _iterator10 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createForOfIteratorHelper__WEBPACK_IMPORTED_MODULE_2__["default"])(routes),
          _step10;

      try {
        for (_iterator10.s(); !(_step10 = _iterator10.n()).done;) {
          var route = _step10.value;

          // we already have the config loaded, just recurse
          if (route.loadChildren && !route.canLoad && route._loadedConfig) {
            var childConfig = route._loadedConfig;
            res.push(this.processRoutes(childConfig.module, childConfig.routes)); // no config loaded, fetch the config
          } else if (route.loadChildren && !route.canLoad) {
            res.push(this.preloadConfig(ngModule, route)); // recurse into children
          } else if (route.children) {
            res.push(this.processRoutes(ngModule, route.children));
          }
        }
      } catch (err) {
        _iterator10.e(err);
      } finally {
        _iterator10.f();
      }

      return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["from"])(res).pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeAll"])(), Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["map"])(function (_) {
        return void 0;
      }));
    }
  }, {
    key: "preloadConfig",
    value: function preloadConfig(ngModule, route) {
      var _this42 = this;

      return this.preloadingStrategy.preload(route, function () {
        var loaded$ = _this42.loader.load(ngModule.injector, route);

        return loaded$.pipe(Object(rxjs_operators__WEBPACK_IMPORTED_MODULE_11__["mergeMap"])(function (config) {
          route._loadedConfig = config;
          return _this42.processRoutes(config.module, config.routes);
        }));
      });
    }
  }]);

  return RouterPreloader;
}();

RouterPreloader.ɵfac = function RouterPreloader_Factory(t) {
  return new (t || RouterPreloader)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](Router), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](PreloadingStrategy));
};

RouterPreloader.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineInjectable"]({
  token: RouterPreloader,
  factory: RouterPreloader.ɵfac
});

RouterPreloader.ctorParameters = function () {
  return [{
    type: Router
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"]
  }, {
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]
  }, {
    type: PreloadingStrategy
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterPreloader, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injectable"]
  }], function () {
    return [{
      type: Router
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]
    }, {
      type: PreloadingStrategy
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */


var RouterScroller = /*#__PURE__*/function () {
  function RouterScroller(router,
  /** @docsNotRequired */
  viewportScroller) {
    var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterScroller);

    this.router = router;
    this.viewportScroller = viewportScroller;
    this.options = options;
    this.lastId = 0;
    this.lastSource = 'imperative';
    this.restoredId = 0;
    this.store = {}; // Default both options to 'disabled'

    options.scrollPositionRestoration = options.scrollPositionRestoration || 'disabled';
    options.anchorScrolling = options.anchorScrolling || 'disabled';
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterScroller, [{
    key: "init",
    value: function init() {
      // we want to disable the automatic scrolling because having two places
      // responsible for scrolling results race conditions, especially given
      // that browser don't implement this behavior consistently
      if (this.options.scrollPositionRestoration !== 'disabled') {
        this.viewportScroller.setHistoryScrollRestoration('manual');
      }

      this.routerEventsSubscription = this.createScrollEvents();
      this.scrollEventsSubscription = this.consumeScrollEvents();
    }
  }, {
    key: "createScrollEvents",
    value: function createScrollEvents() {
      var _this43 = this;

      return this.router.events.subscribe(function (e) {
        if (e instanceof NavigationStart) {
          // store the scroll position of the current stable navigations.
          _this43.store[_this43.lastId] = _this43.viewportScroller.getScrollPosition();
          _this43.lastSource = e.navigationTrigger;
          _this43.restoredId = e.restoredState ? e.restoredState.navigationId : 0;
        } else if (e instanceof NavigationEnd) {
          _this43.lastId = e.id;

          _this43.scheduleScrollEvent(e, _this43.router.parseUrl(e.urlAfterRedirects).fragment);
        }
      });
    }
  }, {
    key: "consumeScrollEvents",
    value: function consumeScrollEvents() {
      var _this44 = this;

      return this.router.events.subscribe(function (e) {
        if (!(e instanceof Scroll)) return; // a popstate event. The pop state event will always ignore anchor scrolling.

        if (e.position) {
          if (_this44.options.scrollPositionRestoration === 'top') {
            _this44.viewportScroller.scrollToPosition([0, 0]);
          } else if (_this44.options.scrollPositionRestoration === 'enabled') {
            _this44.viewportScroller.scrollToPosition(e.position);
          } // imperative navigation "forward"

        } else {
          if (e.anchor && _this44.options.anchorScrolling === 'enabled') {
            _this44.viewportScroller.scrollToAnchor(e.anchor);
          } else if (_this44.options.scrollPositionRestoration !== 'disabled') {
            _this44.viewportScroller.scrollToPosition([0, 0]);
          }
        }
      });
    }
  }, {
    key: "scheduleScrollEvent",
    value: function scheduleScrollEvent(routerEvent, anchor) {
      this.router.triggerEvent(new Scroll(routerEvent, this.lastSource === 'popstate' ? this.store[this.restoredId] : null, anchor));
    }
    /** @nodoc */

  }, {
    key: "ngOnDestroy",
    value: function ngOnDestroy() {
      if (this.routerEventsSubscription) {
        this.routerEventsSubscription.unsubscribe();
      }

      if (this.scrollEventsSubscription) {
        this.scrollEventsSubscription.unsubscribe();
      }
    }
  }]);

  return RouterScroller;
}();

RouterScroller.ɵfac = function RouterScroller_Factory(t) {
  return new (t || RouterScroller)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](Router), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_common__WEBPACK_IMPORTED_MODULE_8__["ViewportScroller"]), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](undefined));
};

RouterScroller.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineInjectable"]({
  token: RouterScroller,
  factory: RouterScroller.ɵfac
});

RouterScroller.ctorParameters = function () {
  return [{
    type: Router
  }, {
    type: _angular_common__WEBPACK_IMPORTED_MODULE_8__["ViewportScroller"]
  }, {
    type: undefined
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterScroller, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injectable"]
  }], function () {
    return [{
      type: Router
    }, {
      type: _angular_common__WEBPACK_IMPORTED_MODULE_8__["ViewportScroller"]
    }, {
      type: undefined
    }];
  }, null);
})();
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * The directives defined in the `RouterModule`.
 */


var ROUTER_DIRECTIVES = [RouterOutlet, RouterLink, RouterLinkWithHref, RouterLinkActive, ɵEmptyOutletComponent];
/**
 * A [DI token](guide/glossary/#di-token) for the router service.
 *
 * @publicApi
 */

var ROUTER_CONFIGURATION = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["InjectionToken"]('ROUTER_CONFIGURATION');
/**
 * @docsNotRequired
 */

var ROUTER_FORROOT_GUARD = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["InjectionToken"]('ROUTER_FORROOT_GUARD');
var ɵ0 = {
  enableTracing: false
};
var ROUTER_PROVIDERS = [_angular_common__WEBPACK_IMPORTED_MODULE_8__["Location"], {
  provide: UrlSerializer,
  useClass: DefaultUrlSerializer
}, {
  provide: Router,
  useFactory: setupRouter,
  deps: [UrlSerializer, ChildrenOutletContexts, _angular_common__WEBPACK_IMPORTED_MODULE_8__["Location"], _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"], _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"], _angular_core__WEBPACK_IMPORTED_MODULE_9__["Compiler"], ROUTES, ROUTER_CONFIGURATION, [UrlHandlingStrategy, new _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]()], [RouteReuseStrategy, new _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]()]]
}, ChildrenOutletContexts, {
  provide: ActivatedRoute,
  useFactory: rootRoute,
  deps: [Router]
}, {
  provide: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModuleFactoryLoader"],
  useClass: _angular_core__WEBPACK_IMPORTED_MODULE_9__["SystemJsNgModuleLoader"]
}, RouterPreloader, NoPreloading, PreloadAllModules, {
  provide: ROUTER_CONFIGURATION,
  useValue: ɵ0
}];

function routerNgProbeToken() {
  return new _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgProbeToken"]('Router', Router);
}
/**
 * @description
 *
 * Adds directives and providers for in-app navigation among views defined in an application.
 * Use the Angular `Router` service to declaratively specify application states and manage state
 * transitions.
 *
 * You can import this NgModule multiple times, once for each lazy-loaded bundle.
 * However, only one `Router` service can be active.
 * To ensure this, there are two ways to register routes when importing this module:
 *
 * * The `forRoot()` method creates an `NgModule` that contains all the directives, the given
 * routes, and the `Router` service itself.
 * * The `forChild()` method creates an `NgModule` that contains all the directives and the given
 * routes, but does not include the `Router` service.
 *
 * @see [Routing and Navigation guide](guide/router) for an
 * overview of how the `Router` service should be used.
 *
 * @publicApi
 */


var RouterModule = /*#__PURE__*/function () {
  // Note: We are injecting the Router so it gets created eagerly...
  function RouterModule(guard, router) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterModule);
  }
  /**
   * Creates and configures a module with all the router providers and directives.
   * Optionally sets up an application listener to perform an initial navigation.
   *
   * When registering the NgModule at the root, import as follows:
   *
   * ```
   * @NgModule({
   *   imports: [RouterModule.forRoot(ROUTES)]
   * })
   * class MyNgModule {}
   * ```
   *
   * @param routes An array of `Route` objects that define the navigation paths for the application.
   * @param config An `ExtraOptions` configuration object that controls how navigation is performed.
   * @return The new `NgModule`.
   *
   */


  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterModule, null, [{
    key: "forRoot",
    value: function forRoot(routes, config) {
      return {
        ngModule: RouterModule,
        providers: [ROUTER_PROVIDERS, provideRoutes(routes), {
          provide: ROUTER_FORROOT_GUARD,
          useFactory: provideForRootGuard,
          deps: [[Router, new _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"](), new _angular_core__WEBPACK_IMPORTED_MODULE_9__["SkipSelf"]()]]
        }, {
          provide: ROUTER_CONFIGURATION,
          useValue: config ? config : {}
        }, {
          provide: _angular_common__WEBPACK_IMPORTED_MODULE_8__["LocationStrategy"],
          useFactory: provideLocationStrategy,
          deps: [_angular_common__WEBPACK_IMPORTED_MODULE_8__["PlatformLocation"], [new _angular_core__WEBPACK_IMPORTED_MODULE_9__["Inject"](_angular_common__WEBPACK_IMPORTED_MODULE_8__["APP_BASE_HREF"]), new _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]()], ROUTER_CONFIGURATION]
        }, {
          provide: RouterScroller,
          useFactory: createRouterScroller,
          deps: [Router, _angular_common__WEBPACK_IMPORTED_MODULE_8__["ViewportScroller"], ROUTER_CONFIGURATION]
        }, {
          provide: PreloadingStrategy,
          useExisting: config && config.preloadingStrategy ? config.preloadingStrategy : NoPreloading
        }, {
          provide: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgProbeToken"],
          multi: true,
          useFactory: routerNgProbeToken
        }, provideRouterInitializer()]
      };
    }
    /**
     * Creates a module with all the router directives and a provider registering routes,
     * without creating a new Router service.
     * When registering for submodules and lazy-loaded submodules, create the NgModule as follows:
     *
     * ```
     * @NgModule({
     *   imports: [RouterModule.forChild(ROUTES)]
     * })
     * class MyNgModule {}
     * ```
     *
     * @param routes An array of `Route` objects that define the navigation paths for the submodule.
     * @return The new NgModule.
     *
     */

  }, {
    key: "forChild",
    value: function forChild(routes) {
      return {
        ngModule: RouterModule,
        providers: [provideRoutes(routes)]
      };
    }
  }]);

  return RouterModule;
}();

RouterModule.ɵmod = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineNgModule"]({
  type: RouterModule
});
RouterModule.ɵinj = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineInjector"]({
  factory: function RouterModule_Factory(t) {
    return new (t || RouterModule)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](ROUTER_FORROOT_GUARD, 8), _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](Router, 8));
  }
});

RouterModule.ctorParameters = function () {
  return [{
    type: undefined,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
    }, {
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Inject"],
      args: [ROUTER_FORROOT_GUARD]
    }]
  }, {
    type: Router,
    decorators: [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
    }]
  }];
};

(function () {
  (typeof ngJitMode === "undefined" || ngJitMode) && _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵsetNgModuleScope"](RouterModule, {
    declarations: [RouterOutlet, RouterLink, RouterLinkWithHref, RouterLinkActive, ɵEmptyOutletComponent],
    exports: [RouterOutlet, RouterLink, RouterLinkWithHref, RouterLinkActive, ɵEmptyOutletComponent]
  });
})();
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterModule, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["NgModule"],
    args: [{
      declarations: ROUTER_DIRECTIVES,
      exports: ROUTER_DIRECTIVES,
      entryComponents: [ɵEmptyOutletComponent]
    }]
  }], function () {
    return [{
      type: undefined,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
      }, {
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Inject"],
        args: [ROUTER_FORROOT_GUARD]
      }]
    }, {
      type: Router,
      decorators: [{
        type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Optional"]
      }]
    }];
  }, null);
})();

function createRouterScroller(router, viewportScroller, config) {
  if (config.scrollOffset) {
    viewportScroller.setOffset(config.scrollOffset);
  }

  return new RouterScroller(router, viewportScroller, config);
}

function provideLocationStrategy(platformLocationStrategy, baseHref) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  return options.useHash ? new _angular_common__WEBPACK_IMPORTED_MODULE_8__["HashLocationStrategy"](platformLocationStrategy, baseHref) : new _angular_common__WEBPACK_IMPORTED_MODULE_8__["PathLocationStrategy"](platformLocationStrategy, baseHref);
}

function provideForRootGuard(router) {
  if (router) {
    throw new Error("RouterModule.forRoot() called twice. Lazy loaded modules should use RouterModule.forChild() instead.");
  }

  return 'guarded';
}
/**
 * Registers a [DI provider](guide/glossary#provider) for a set of routes.
 * @param routes The route configuration to provide.
 *
 * @usageNotes
 *
 * ```
 * @NgModule({
 *   imports: [RouterModule.forChild(ROUTES)],
 *   providers: [provideRoutes(EXTRA_ROUTES)]
 * })
 * class MyNgModule {}
 * ```
 *
 * @publicApi
 */


function provideRoutes(routes) {
  return [{
    provide: _angular_core__WEBPACK_IMPORTED_MODULE_9__["ANALYZE_FOR_ENTRY_COMPONENTS"],
    multi: true,
    useValue: routes
  }, {
    provide: ROUTES,
    multi: true,
    useValue: routes
  }];
}

function setupRouter(urlSerializer, contexts, location, injector, loader, compiler, config) {
  var opts = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : {};
  var urlHandlingStrategy = arguments.length > 8 ? arguments[8] : undefined;
  var routeReuseStrategy = arguments.length > 9 ? arguments[9] : undefined;
  var router = new Router(null, urlSerializer, contexts, location, injector, loader, compiler, flatten(config));

  if (urlHandlingStrategy) {
    router.urlHandlingStrategy = urlHandlingStrategy;
  }

  if (routeReuseStrategy) {
    router.routeReuseStrategy = routeReuseStrategy;
  }

  if (opts.errorHandler) {
    router.errorHandler = opts.errorHandler;
  }

  if (opts.malformedUriErrorHandler) {
    router.malformedUriErrorHandler = opts.malformedUriErrorHandler;
  }

  if (opts.enableTracing) {
    var dom = Object(_angular_common__WEBPACK_IMPORTED_MODULE_8__["ɵgetDOM"])();
    router.events.subscribe(function (e) {
      dom.logGroup("Router Event: ".concat(e.constructor.name));
      dom.log(e.toString());
      dom.log(e);
      dom.logGroupEnd();
    });
  }

  if (opts.onSameUrlNavigation) {
    router.onSameUrlNavigation = opts.onSameUrlNavigation;
  }

  if (opts.paramsInheritanceStrategy) {
    router.paramsInheritanceStrategy = opts.paramsInheritanceStrategy;
  }

  if (opts.urlUpdateStrategy) {
    router.urlUpdateStrategy = opts.urlUpdateStrategy;
  }

  if (opts.relativeLinkResolution) {
    router.relativeLinkResolution = opts.relativeLinkResolution;
  }

  return router;
}

function rootRoute(router) {
  return router.routerState.root;
}
/**
 * Router initialization requires two steps:
 *
 * First, we start the navigation in a `APP_INITIALIZER` to block the bootstrap if
 * a resolver or a guard executes asynchronously.
 *
 * Next, we actually run activation in a `BOOTSTRAP_LISTENER`, using the
 * `afterPreactivation` hook provided by the router.
 * The router navigation starts, reaches the point when preactivation is done, and then
 * pauses. It waits for the hook to be resolved. We then resolve it only in a bootstrap listener.
 */


var RouterInitializer = /*#__PURE__*/function () {
  function RouterInitializer(injector) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_7__["default"])(this, RouterInitializer);

    this.injector = injector;
    this.initNavigation = false;
    this.resultOfPreactivationDone = new rxjs__WEBPACK_IMPORTED_MODULE_10__["Subject"]();
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(RouterInitializer, [{
    key: "appInitializer",
    value: function appInitializer() {
      var _this45 = this;

      var p = this.injector.get(_angular_common__WEBPACK_IMPORTED_MODULE_8__["LOCATION_INITIALIZED"], Promise.resolve(null));
      return p.then(function () {
        var resolve = null;
        var res = new Promise(function (r) {
          return resolve = r;
        });

        var router = _this45.injector.get(Router);

        var opts = _this45.injector.get(ROUTER_CONFIGURATION);

        if (_this45.isLegacyDisabled(opts) || _this45.isLegacyEnabled(opts)) {
          resolve(true);
        } else if (opts.initialNavigation === 'disabled') {
          router.setUpLocationChangeListener();
          resolve(true);
        } else if (opts.initialNavigation === 'enabled') {
          router.hooks.afterPreactivation = function () {
            // only the initial navigation should be delayed
            if (!_this45.initNavigation) {
              _this45.initNavigation = true;
              resolve(true);
              return _this45.resultOfPreactivationDone; // subsequent navigations should not be delayed
            } else {
              return Object(rxjs__WEBPACK_IMPORTED_MODULE_10__["of"])(null);
            }
          };

          router.initialNavigation();
        } else {
          throw new Error("Invalid initialNavigation options: '".concat(opts.initialNavigation, "'"));
        }

        return res;
      });
    }
  }, {
    key: "bootstrapListener",
    value: function bootstrapListener(bootstrappedComponentRef) {
      var opts = this.injector.get(ROUTER_CONFIGURATION);
      var preloader = this.injector.get(RouterPreloader);
      var routerScroller = this.injector.get(RouterScroller);
      var router = this.injector.get(Router);
      var ref = this.injector.get(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ApplicationRef"]);

      if (bootstrappedComponentRef !== ref.components[0]) {
        return;
      }

      if (this.isLegacyEnabled(opts)) {
        router.initialNavigation();
      } else if (this.isLegacyDisabled(opts)) {
        router.setUpLocationChangeListener();
      }

      preloader.setUpPreloading();
      routerScroller.init();
      router.resetRootComponentType(ref.componentTypes[0]);
      this.resultOfPreactivationDone.next(null);
      this.resultOfPreactivationDone.complete();
    }
  }, {
    key: "isLegacyEnabled",
    value: function isLegacyEnabled(opts) {
      return opts.initialNavigation === 'legacy_enabled' || opts.initialNavigation === true || opts.initialNavigation === undefined;
    }
  }, {
    key: "isLegacyDisabled",
    value: function isLegacyDisabled(opts) {
      return opts.initialNavigation === 'legacy_disabled' || opts.initialNavigation === false;
    }
  }]);

  return RouterInitializer;
}();

RouterInitializer.ɵfac = function RouterInitializer_Factory(t) {
  return new (t || RouterInitializer)(_angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵinject"](_angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]));
};

RouterInitializer.ɵprov = _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵɵdefineInjectable"]({
  token: RouterInitializer,
  factory: RouterInitializer.ɵfac
});

RouterInitializer.ctorParameters = function () {
  return [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]
  }];
};
/*@__PURE__*/


(function () {
  _angular_core__WEBPACK_IMPORTED_MODULE_9__["ɵsetClassMetadata"](RouterInitializer, [{
    type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injectable"]
  }], function () {
    return [{
      type: _angular_core__WEBPACK_IMPORTED_MODULE_9__["Injector"]
    }];
  }, null);
})();

function getAppInitializer(r) {
  return r.appInitializer.bind(r);
}

function getBootstrapListener(r) {
  return r.bootstrapListener.bind(r);
}
/**
 * A [DI token](guide/glossary/#di-token) for the router initializer that
 * is called after the app is bootstrapped.
 *
 * @publicApi
 */


var ROUTER_INITIALIZER = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["InjectionToken"]('Router Initializer');

function provideRouterInitializer() {
  return [RouterInitializer, {
    provide: _angular_core__WEBPACK_IMPORTED_MODULE_9__["APP_INITIALIZER"],
    multi: true,
    useFactory: getAppInitializer,
    deps: [RouterInitializer]
  }, {
    provide: ROUTER_INITIALIZER,
    useFactory: getBootstrapListener,
    deps: [RouterInitializer]
  }, {
    provide: _angular_core__WEBPACK_IMPORTED_MODULE_9__["APP_BOOTSTRAP_LISTENER"],
    multi: true,
    useExisting: ROUTER_INITIALIZER
  }];
}
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @publicApi
 */


var VERSION = new _angular_core__WEBPACK_IMPORTED_MODULE_9__["Version"]('10.1.4');
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * Generated bundle index. Do not edit.
 */



/***/ }),

/***/ "u3GI":
/*!*********************************************!*\
  !*** ./node_modules/moment/locale/de-ch.js ***!
  \*********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : German (Switzerland) [de-ch]
//! author : sschueller : https://github.com/sschueller
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      m: ['eine Minute', 'einer Minute'],
      h: ['eine Stunde', 'einer Stunde'],
      d: ['ein Tag', 'einem Tag'],
      dd: [number + ' Tage', number + ' Tagen'],
      w: ['eine Woche', 'einer Woche'],
      M: ['ein Monat', 'einem Monat'],
      MM: [number + ' Monate', number + ' Monaten'],
      y: ['ein Jahr', 'einem Jahr'],
      yy: [number + ' Jahre', number + ' Jahren']
    };
    return withoutSuffix ? format[key][0] : format[key][1];
  }

  var deCh = moment.defineLocale('de-ch', {
    months: 'Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember'.split('_'),
    monthsShort: 'Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.'.split('_'),
    monthsParseExact: true,
    weekdays: 'Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag'.split('_'),
    weekdaysShort: 'So_Mo_Di_Mi_Do_Fr_Sa'.split('_'),
    weekdaysMin: 'So_Mo_Di_Mi_Do_Fr_Sa'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY HH:mm',
      LLLL: 'dddd, D. MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[heute um] LT [Uhr]',
      sameElse: 'L',
      nextDay: '[morgen um] LT [Uhr]',
      nextWeek: 'dddd [um] LT [Uhr]',
      lastDay: '[gestern um] LT [Uhr]',
      lastWeek: '[letzten] dddd [um] LT [Uhr]'
    },
    relativeTime: {
      future: 'in %s',
      past: 'vor %s',
      s: 'ein paar Sekunden',
      ss: '%d Sekunden',
      m: processRelativeTime,
      mm: '%d Minuten',
      h: processRelativeTime,
      hh: '%d Stunden',
      d: processRelativeTime,
      dd: processRelativeTime,
      w: processRelativeTime,
      ww: '%d Wochen',
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return deCh;
});

/***/ }),

/***/ "uEye":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/nn.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Nynorsk [nn]
//! authors : https://github.com/mechuwind
//!           Stephen Ramthun : https://github.com/stephenramthun
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var nn = moment.defineLocale('nn', {
    months: 'januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember'.split('_'),
    monthsShort: 'jan._feb._mars_apr._mai_juni_juli_aug._sep._okt._nov._des.'.split('_'),
    monthsParseExact: true,
    weekdays: 'sundag_måndag_tysdag_onsdag_torsdag_fredag_laurdag'.split('_'),
    weekdaysShort: 'su._må._ty._on._to._fr._lau.'.split('_'),
    weekdaysMin: 'su_må_ty_on_to_fr_la'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM YYYY',
      LLL: 'D. MMMM YYYY [kl.] H:mm',
      LLLL: 'dddd D. MMMM YYYY [kl.] HH:mm'
    },
    calendar: {
      sameDay: '[I dag klokka] LT',
      nextDay: '[I morgon klokka] LT',
      nextWeek: 'dddd [klokka] LT',
      lastDay: '[I går klokka] LT',
      lastWeek: '[Føregåande] dddd [klokka] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'om %s',
      past: '%s sidan',
      s: 'nokre sekund',
      ss: '%d sekund',
      m: 'eit minutt',
      mm: '%d minutt',
      h: 'ein time',
      hh: '%d timar',
      d: 'ein dag',
      dd: '%d dagar',
      w: 'ei veke',
      ww: '%d veker',
      M: 'ein månad',
      MM: '%d månader',
      y: 'eit år',
      yy: '%d år'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return nn;
});

/***/ }),

/***/ "uFwe":
/*!******************************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/createForOfIteratorHelper.js ***!
  \******************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _createForOfIteratorHelper; });
/* harmony import */ var _unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./unsupportedIterableToArray */ "BsWD");

function _createForOfIteratorHelper(o, allowArrayLike) {
  var it;

  if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) {
    if (Array.isArray(o) || (it = Object(_unsupportedIterableToArray__WEBPACK_IMPORTED_MODULE_0__["default"])(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;

      var F = function F() {};

      return {
        s: F,
        n: function n() {
          if (i >= o.length) return {
            done: true
          };
          return {
            done: false,
            value: o[i++]
          };
        },
        e: function e(_e) {
          throw _e;
        },
        f: F
      };
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var normalCompletion = true,
      didErr = false,
      err;
  return {
    s: function s() {
      it = o[Symbol.iterator]();
    },
    n: function n() {
      var step = it.next();
      normalCompletion = step.done;
      return step;
    },
    e: function e(_e2) {
      didErr = true;
      err = _e2;
    },
    f: function f() {
      try {
        if (!normalCompletion && it["return"] != null) it["return"]();
      } finally {
        if (didErr) throw err;
      }
    }
  };
}

/***/ }),

/***/ "uTdr":
/*!****************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/onErrorResumeNext.js ***!
  \****************************************************************************/
/*! exports provided: onErrorResumeNext, onErrorResumeNextStatic */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "onErrorResumeNext", function() { return onErrorResumeNext; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "onErrorResumeNextStatic", function() { return onErrorResumeNextStatic; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _observable_from__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../observable/from */ "Cfvw");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");







function onErrorResumeNext() {
  for (var _len = arguments.length, nextSources = new Array(_len), _key = 0; _key < _len; _key++) {
    nextSources[_key] = arguments[_key];
  }

  if (nextSources.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_5__["isArray"])(nextSources[0])) {
    nextSources = nextSources[0];
  }

  return function (source) {
    return source.lift(new OnErrorResumeNextOperator(nextSources));
  };
}
function onErrorResumeNextStatic() {
  for (var _len2 = arguments.length, nextSources = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    nextSources[_key2] = arguments[_key2];
  }

  var source = undefined;

  if (nextSources.length === 1 && Object(_util_isArray__WEBPACK_IMPORTED_MODULE_5__["isArray"])(nextSources[0])) {
    nextSources = nextSources[0];
  }

  source = nextSources.shift();
  return Object(_observable_from__WEBPACK_IMPORTED_MODULE_4__["from"])(source).lift(new OnErrorResumeNextOperator(nextSources));
}

var OnErrorResumeNextOperator = /*#__PURE__*/function () {
  function OnErrorResumeNextOperator(nextSources) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, OnErrorResumeNextOperator);

    this.nextSources = nextSources;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(OnErrorResumeNextOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new OnErrorResumeNextSubscriber(subscriber, this.nextSources));
    }
  }]);

  return OnErrorResumeNextOperator;
}();

var OnErrorResumeNextSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(OnErrorResumeNextSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(OnErrorResumeNextSubscriber);

  function OnErrorResumeNextSubscriber(destination, nextSources) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, OnErrorResumeNextSubscriber);

    _this = _super.call(this, destination);
    _this.destination = destination;
    _this.nextSources = nextSources;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(OnErrorResumeNextSubscriber, [{
    key: "notifyError",
    value: function notifyError() {
      this.subscribeToNextSource();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.subscribeToNextSource();
    }
  }, {
    key: "_error",
    value: function _error(err) {
      this.subscribeToNextSource();
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.subscribeToNextSource();
      this.unsubscribe();
    }
  }, {
    key: "subscribeToNextSource",
    value: function subscribeToNextSource() {
      var next = this.nextSources.shift();

      if (!!next) {
        var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleInnerSubscriber"](this);
        var destination = this.destination;
        destination.add(innerSubscriber);
        var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["innerSubscribe"])(next, innerSubscriber);

        if (innerSubscription !== innerSubscriber) {
          destination.add(innerSubscription);
        }
      } else {
        this.destination.complete();
      }
    }
  }]);

  return OnErrorResumeNextSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_6__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "uXwI":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/lv.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Latvian [lv]
//! author : Kristaps Karlsons : https://github.com/skakri
//! author : Jānis Elmeris : https://github.com/JanisE
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var units = {
    ss: 'sekundes_sekundēm_sekunde_sekundes'.split('_'),
    m: 'minūtes_minūtēm_minūte_minūtes'.split('_'),
    mm: 'minūtes_minūtēm_minūte_minūtes'.split('_'),
    h: 'stundas_stundām_stunda_stundas'.split('_'),
    hh: 'stundas_stundām_stunda_stundas'.split('_'),
    d: 'dienas_dienām_diena_dienas'.split('_'),
    dd: 'dienas_dienām_diena_dienas'.split('_'),
    M: 'mēneša_mēnešiem_mēnesis_mēneši'.split('_'),
    MM: 'mēneša_mēnešiem_mēnesis_mēneši'.split('_'),
    y: 'gada_gadiem_gads_gadi'.split('_'),
    yy: 'gada_gadiem_gads_gadi'.split('_')
  };
  /**
   * @param withoutSuffix boolean true = a length of time; false = before/after a period of time.
   */

  function format(forms, number, withoutSuffix) {
    if (withoutSuffix) {
      // E.g. "21 minūte", "3 minūtes".
      return number % 10 === 1 && number % 100 !== 11 ? forms[2] : forms[3];
    } else {
      // E.g. "21 minūtes" as in "pēc 21 minūtes".
      // E.g. "3 minūtēm" as in "pēc 3 minūtēm".
      return number % 10 === 1 && number % 100 !== 11 ? forms[0] : forms[1];
    }
  }

  function relativeTimeWithPlural(number, withoutSuffix, key) {
    return number + ' ' + format(units[key], number, withoutSuffix);
  }

  function relativeTimeWithSingular(number, withoutSuffix, key) {
    return format(units[key], number, withoutSuffix);
  }

  function relativeSeconds(number, withoutSuffix) {
    return withoutSuffix ? 'dažas sekundes' : 'dažām sekundēm';
  }

  var lv = moment.defineLocale('lv', {
    months: 'janvāris_februāris_marts_aprīlis_maijs_jūnijs_jūlijs_augusts_septembris_oktobris_novembris_decembris'.split('_'),
    monthsShort: 'jan_feb_mar_apr_mai_jūn_jūl_aug_sep_okt_nov_dec'.split('_'),
    weekdays: 'svētdiena_pirmdiena_otrdiena_trešdiena_ceturtdiena_piektdiena_sestdiena'.split('_'),
    weekdaysShort: 'Sv_P_O_T_C_Pk_S'.split('_'),
    weekdaysMin: 'Sv_P_O_T_C_Pk_S'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY.',
      LL: 'YYYY. [gada] D. MMMM',
      LLL: 'YYYY. [gada] D. MMMM, HH:mm',
      LLLL: 'YYYY. [gada] D. MMMM, dddd, HH:mm'
    },
    calendar: {
      sameDay: '[Šodien pulksten] LT',
      nextDay: '[Rīt pulksten] LT',
      nextWeek: 'dddd [pulksten] LT',
      lastDay: '[Vakar pulksten] LT',
      lastWeek: '[Pagājušā] dddd [pulksten] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'pēc %s',
      past: 'pirms %s',
      s: relativeSeconds,
      ss: relativeTimeWithPlural,
      m: relativeTimeWithSingular,
      mm: relativeTimeWithPlural,
      h: relativeTimeWithSingular,
      hh: relativeTimeWithPlural,
      d: relativeTimeWithSingular,
      dd: relativeTimeWithPlural,
      M: relativeTimeWithSingular,
      MM: relativeTimeWithPlural,
      y: relativeTimeWithSingular,
      yy: relativeTimeWithPlural
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return lv;
});

/***/ }),

/***/ "un/a":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/retry.js ***!
  \****************************************************************/
/*! exports provided: retry */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "retry", function() { return retry; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");







function retry() {
  var count = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : -1;
  return function (source) {
    return source.lift(new RetryOperator(count, source));
  };
}

var RetryOperator = /*#__PURE__*/function () {
  function RetryOperator(count, source) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RetryOperator);

    this.count = count;
    this.source = source;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RetryOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new RetrySubscriber(subscriber, this.count, this.source));
    }
  }]);

  return RetryOperator;
}();

var RetrySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(RetrySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(RetrySubscriber);

  function RetrySubscriber(destination, count, source) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, RetrySubscriber);

    _this = _super.call(this, destination);
    _this.count = count;
    _this.source = source;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(RetrySubscriber, [{
    key: "error",
    value: function error(err) {
      if (!this.isStopped) {
        var source = this.source,
            count = this.count;

        if (count === 0) {
          return Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_0__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_1__["default"])(RetrySubscriber.prototype), "error", this).call(this, err);
        } else if (count > -1) {
          this.count = count - 1;
        }

        source.subscribe(this._unsubscribeAndRecycle());
      }
    }
  }]);

  return RetrySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_6__["Subscriber"]);

/***/ }),

/***/ "vkgz":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/tap.js ***!
  \**************************************************************/
/*! exports provided: tap */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "tap", function() { return tap; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");
/* harmony import */ var _util_noop__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/noop */ "KqfI");
/* harmony import */ var _util_isFunction__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/isFunction */ "n6bG");








function tap(nextOrObserver, error, complete) {
  return function tapOperatorFunction(source) {
    return source.lift(new DoOperator(nextOrObserver, error, complete));
  };
}

var DoOperator = /*#__PURE__*/function () {
  function DoOperator(nextOrObserver, error, complete) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, DoOperator);

    this.nextOrObserver = nextOrObserver;
    this.error = error;
    this.complete = complete;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(DoOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new TapSubscriber(subscriber, this.nextOrObserver, this.error, this.complete));
    }
  }]);

  return DoOperator;
}();

var TapSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_1__["default"])(TapSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_2__["default"])(TapSubscriber);

  function TapSubscriber(destination, observerOrNext, error, complete) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_3__["default"])(this, TapSubscriber);

    _this = _super.call(this, destination);
    _this._tapNext = _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
    _this._tapError = _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
    _this._tapComplete = _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
    _this._tapError = error || _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
    _this._tapComplete = complete || _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];

    if (Object(_util_isFunction__WEBPACK_IMPORTED_MODULE_7__["isFunction"])(observerOrNext)) {
      _this._context = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this);
      _this._tapNext = observerOrNext;
    } else if (observerOrNext) {
      _this._context = observerOrNext;
      _this._tapNext = observerOrNext.next || _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
      _this._tapError = observerOrNext.error || _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
      _this._tapComplete = observerOrNext.complete || _util_noop__WEBPACK_IMPORTED_MODULE_6__["noop"];
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_4__["default"])(TapSubscriber, [{
    key: "_next",
    value: function _next(value) {
      try {
        this._tapNext.call(this._context, value);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.destination.next(value);
    }
  }, {
    key: "_error",
    value: function _error(err) {
      try {
        this._tapError.call(this._context, err);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.destination.error(err);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      try {
        this._tapComplete.call(this._context);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      return this.destination.complete();
    }
  }]);

  return TapSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_5__["Subscriber"]);

/***/ }),

/***/ "vqkR":
/*!********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/skipUntil.js ***!
  \********************************************************************/
/*! exports provided: skipUntil */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "skipUntil", function() { return skipUntil; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/get */ "ReuC");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/getPrototypeOf */ "foSv");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");








function skipUntil(notifier) {
  return function (source) {
    return source.lift(new SkipUntilOperator(notifier));
  };
}

var SkipUntilOperator = /*#__PURE__*/function () {
  function SkipUntilOperator(notifier) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, SkipUntilOperator);

    this.notifier = notifier;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(SkipUntilOperator, [{
    key: "call",
    value: function call(destination, source) {
      return source.subscribe(new SkipUntilSubscriber(destination, this.notifier));
    }
  }]);

  return SkipUntilOperator;
}();

var SkipUntilSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipUntilSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_4__["default"])(SkipUntilSubscriber);

  function SkipUntilSubscriber(destination, notifier) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_5__["default"])(this, SkipUntilSubscriber);

    _this = _super.call(this, destination);
    _this.hasValue = false;
    var innerSubscriber = new _innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleInnerSubscriber"](Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_0__["default"])(_this));

    _this.add(innerSubscriber);

    _this.innerSubscription = innerSubscriber;
    var innerSubscription = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["innerSubscribe"])(notifier, innerSubscriber);

    if (innerSubscription !== innerSubscriber) {
      _this.add(innerSubscription);

      _this.innerSubscription = innerSubscription;
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_6__["default"])(SkipUntilSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (this.hasValue) {
        Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_get__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_getPrototypeOf__WEBPACK_IMPORTED_MODULE_2__["default"])(SkipUntilSubscriber.prototype), "_next", this).call(this, value);
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      this.hasValue = true;

      if (this.innerSubscription) {
        this.innerSubscription.unsubscribe();
      }
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {}
  }]);

  return SkipUntilSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_7__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "vuIU":
/*!****************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/esm/createClass.js ***!
  \****************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _createClass; });
function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

/***/ }),

/***/ "w1tV":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/share.js ***!
  \****************************************************************/
/*! exports provided: share */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "share", function() { return share; });
/* harmony import */ var _multicast__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./multicast */ "oB13");
/* harmony import */ var _refCount__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./refCount */ "x+ZX");
/* harmony import */ var _Subject__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../Subject */ "XNiG");




function shareSubjectFactory() {
  return new _Subject__WEBPACK_IMPORTED_MODULE_2__["Subject"]();
}

function share() {
  return function (source) {
    return Object(_refCount__WEBPACK_IMPORTED_MODULE_1__["refCount"])()(Object(_multicast__WEBPACK_IMPORTED_MODULE_0__["multicast"])(shareSubjectFactory)(source));
  };
}

/***/ }),

/***/ "wO+i":
/*!****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/pluck.js ***!
  \****************************************************************/
/*! exports provided: pluck */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "pluck", function() { return pluck; });
/* harmony import */ var _map__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./map */ "lJxs");

function pluck() {
  for (var _len = arguments.length, properties = new Array(_len), _key = 0; _key < _len; _key++) {
    properties[_key] = arguments[_key];
  }

  var length = properties.length;

  if (length === 0) {
    throw new Error('list of properties cannot be empty.');
  }

  return function (source) {
    return Object(_map__WEBPACK_IMPORTED_MODULE_0__["map"])(plucker(properties, length))(source);
  };
}

function plucker(props, length) {
  var mapper = function mapper(x) {
    var currentProp = x;

    for (var i = 0; i < length; i++) {
      var p = currentProp != null ? currentProp[props[i]] : undefined;

      if (p !== void 0) {
        currentProp = p;
      } else {
        return undefined;
      }
    }

    return currentProp;
  };

  return mapper;
}

/***/ }),

/***/ "wQk9":
/*!*******************************************!*\
  !*** ./node_modules/moment/locale/tzm.js ***!
  \*******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Central Atlas Tamazight [tzm]
//! author : Abdel Said : https://github.com/abdelsaid
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var tzm = moment.defineLocale('tzm', {
    months: 'ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ'.split('_'),
    monthsShort: 'ⵉⵏⵏⴰⵢⵔ_ⴱⵕⴰⵢⵕ_ⵎⴰⵕⵚ_ⵉⴱⵔⵉⵔ_ⵎⴰⵢⵢⵓ_ⵢⵓⵏⵢⵓ_ⵢⵓⵍⵢⵓⵣ_ⵖⵓⵛⵜ_ⵛⵓⵜⴰⵏⴱⵉⵔ_ⴽⵟⵓⴱⵕ_ⵏⵓⵡⴰⵏⴱⵉⵔ_ⴷⵓⵊⵏⴱⵉⵔ'.split('_'),
    weekdays: 'ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ'.split('_'),
    weekdaysShort: 'ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ'.split('_'),
    weekdaysMin: 'ⴰⵙⴰⵎⴰⵙ_ⴰⵢⵏⴰⵙ_ⴰⵙⵉⵏⴰⵙ_ⴰⴽⵔⴰⵙ_ⴰⴽⵡⴰⵙ_ⴰⵙⵉⵎⵡⴰⵙ_ⴰⵙⵉⴹⵢⴰⵙ'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[ⴰⵙⴷⵅ ⴴ] LT',
      nextDay: '[ⴰⵙⴽⴰ ⴴ] LT',
      nextWeek: 'dddd [ⴴ] LT',
      lastDay: '[ⴰⵚⴰⵏⵜ ⴴ] LT',
      lastWeek: 'dddd [ⴴ] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'ⴷⴰⴷⵅ ⵙ ⵢⴰⵏ %s',
      past: 'ⵢⴰⵏ %s',
      s: 'ⵉⵎⵉⴽ',
      ss: '%d ⵉⵎⵉⴽ',
      m: 'ⵎⵉⵏⵓⴺ',
      mm: '%d ⵎⵉⵏⵓⴺ',
      h: 'ⵙⴰⵄⴰ',
      hh: '%d ⵜⴰⵙⵙⴰⵄⵉⵏ',
      d: 'ⴰⵙⵙ',
      dd: '%d oⵙⵙⴰⵏ',
      M: 'ⴰⵢoⵓⵔ',
      MM: '%d ⵉⵢⵢⵉⵔⵏ',
      y: 'ⴰⵙⴳⴰⵙ',
      yy: '%d ⵉⵙⴳⴰⵙⵏ'
    },
    week: {
      dow: 6,
      // Saturday is the first day of the week.
      doy: 12 // The week that contains Jan 12th is the first week of the year.

    }
  });
  return tzm;
});

/***/ }),

/***/ "wd/R":
/*!***************************************!*\
  !*** ./node_modules/moment/moment.js ***!
  \***************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

/* WEBPACK VAR INJECTION */(function(module) {var require;//! moment.js
//! version : 2.29.0
//! authors : Tim Wood, Iskren Chernev, Moment.js contributors
//! license : MIT
//! momentjs.com
;

(function (global, factory) {
   true ? module.exports = factory() : undefined;
})(this, function () {
  'use strict';

  var hookCallback;

  function hooks() {
    return hookCallback.apply(null, arguments);
  } // This is done to register the method called with moment()
  // without creating circular dependencies.


  function setHookCallback(callback) {
    hookCallback = callback;
  }

  function isArray(input) {
    return input instanceof Array || Object.prototype.toString.call(input) === '[object Array]';
  }

  function isObject(input) {
    // IE8 will treat undefined and null as object if it wasn't for
    // input != null
    return input != null && Object.prototype.toString.call(input) === '[object Object]';
  }

  function hasOwnProp(a, b) {
    return Object.prototype.hasOwnProperty.call(a, b);
  }

  function isObjectEmpty(obj) {
    if (Object.getOwnPropertyNames) {
      return Object.getOwnPropertyNames(obj).length === 0;
    } else {
      var k;

      for (k in obj) {
        if (hasOwnProp(obj, k)) {
          return false;
        }
      }

      return true;
    }
  }

  function isUndefined(input) {
    return input === void 0;
  }

  function isNumber(input) {
    return typeof input === 'number' || Object.prototype.toString.call(input) === '[object Number]';
  }

  function isDate(input) {
    return input instanceof Date || Object.prototype.toString.call(input) === '[object Date]';
  }

  function map(arr, fn) {
    var res = [],
        i;

    for (i = 0; i < arr.length; ++i) {
      res.push(fn(arr[i], i));
    }

    return res;
  }

  function extend(a, b) {
    for (var i in b) {
      if (hasOwnProp(b, i)) {
        a[i] = b[i];
      }
    }

    if (hasOwnProp(b, 'toString')) {
      a.toString = b.toString;
    }

    if (hasOwnProp(b, 'valueOf')) {
      a.valueOf = b.valueOf;
    }

    return a;
  }

  function createUTC(input, format, locale, strict) {
    return createLocalOrUTC(input, format, locale, strict, true).utc();
  }

  function defaultParsingFlags() {
    // We need to deep clone this object.
    return {
      empty: false,
      unusedTokens: [],
      unusedInput: [],
      overflow: -2,
      charsLeftOver: 0,
      nullInput: false,
      invalidEra: null,
      invalidMonth: null,
      invalidFormat: false,
      userInvalidated: false,
      iso: false,
      parsedDateParts: [],
      era: null,
      meridiem: null,
      rfc2822: false,
      weekdayMismatch: false
    };
  }

  function getParsingFlags(m) {
    if (m._pf == null) {
      m._pf = defaultParsingFlags();
    }

    return m._pf;
  }

  var some;

  if (Array.prototype.some) {
    some = Array.prototype.some;
  } else {
    some = function some(fun) {
      var t = Object(this),
          len = t.length >>> 0,
          i;

      for (i = 0; i < len; i++) {
        if (i in t && fun.call(this, t[i], i, t)) {
          return true;
        }
      }

      return false;
    };
  }

  function isValid(m) {
    if (m._isValid == null) {
      var flags = getParsingFlags(m),
          parsedParts = some.call(flags.parsedDateParts, function (i) {
        return i != null;
      }),
          isNowValid = !isNaN(m._d.getTime()) && flags.overflow < 0 && !flags.empty && !flags.invalidEra && !flags.invalidMonth && !flags.invalidWeekday && !flags.weekdayMismatch && !flags.nullInput && !flags.invalidFormat && !flags.userInvalidated && (!flags.meridiem || flags.meridiem && parsedParts);

      if (m._strict) {
        isNowValid = isNowValid && flags.charsLeftOver === 0 && flags.unusedTokens.length === 0 && flags.bigHour === undefined;
      }

      if (Object.isFrozen == null || !Object.isFrozen(m)) {
        m._isValid = isNowValid;
      } else {
        return isNowValid;
      }
    }

    return m._isValid;
  }

  function createInvalid(flags) {
    var m = createUTC(NaN);

    if (flags != null) {
      extend(getParsingFlags(m), flags);
    } else {
      getParsingFlags(m).userInvalidated = true;
    }

    return m;
  } // Plugins that add properties should also add the key here (null value),
  // so we can properly clone ourselves.


  var momentProperties = hooks.momentProperties = [],
      updateInProgress = false;

  function copyConfig(to, from) {
    var i, prop, val;

    if (!isUndefined(from._isAMomentObject)) {
      to._isAMomentObject = from._isAMomentObject;
    }

    if (!isUndefined(from._i)) {
      to._i = from._i;
    }

    if (!isUndefined(from._f)) {
      to._f = from._f;
    }

    if (!isUndefined(from._l)) {
      to._l = from._l;
    }

    if (!isUndefined(from._strict)) {
      to._strict = from._strict;
    }

    if (!isUndefined(from._tzm)) {
      to._tzm = from._tzm;
    }

    if (!isUndefined(from._isUTC)) {
      to._isUTC = from._isUTC;
    }

    if (!isUndefined(from._offset)) {
      to._offset = from._offset;
    }

    if (!isUndefined(from._pf)) {
      to._pf = getParsingFlags(from);
    }

    if (!isUndefined(from._locale)) {
      to._locale = from._locale;
    }

    if (momentProperties.length > 0) {
      for (i = 0; i < momentProperties.length; i++) {
        prop = momentProperties[i];
        val = from[prop];

        if (!isUndefined(val)) {
          to[prop] = val;
        }
      }
    }

    return to;
  } // Moment prototype object


  function Moment(config) {
    copyConfig(this, config);
    this._d = new Date(config._d != null ? config._d.getTime() : NaN);

    if (!this.isValid()) {
      this._d = new Date(NaN);
    } // Prevent infinite loop in case updateOffset creates new moment
    // objects.


    if (updateInProgress === false) {
      updateInProgress = true;
      hooks.updateOffset(this);
      updateInProgress = false;
    }
  }

  function isMoment(obj) {
    return obj instanceof Moment || obj != null && obj._isAMomentObject != null;
  }

  function warn(msg) {
    if (hooks.suppressDeprecationWarnings === false && typeof console !== 'undefined' && console.warn) {
      console.warn('Deprecation warning: ' + msg);
    }
  }

  function deprecate(msg, fn) {
    var firstTime = true;
    return extend(function () {
      if (hooks.deprecationHandler != null) {
        hooks.deprecationHandler(null, msg);
      }

      if (firstTime) {
        var args = [],
            arg,
            i,
            key;

        for (i = 0; i < arguments.length; i++) {
          arg = '';

          if (typeof arguments[i] === 'object') {
            arg += '\n[' + i + '] ';

            for (key in arguments[0]) {
              if (hasOwnProp(arguments[0], key)) {
                arg += key + ': ' + arguments[0][key] + ', ';
              }
            }

            arg = arg.slice(0, -2); // Remove trailing comma and space
          } else {
            arg = arguments[i];
          }

          args.push(arg);
        }

        warn(msg + '\nArguments: ' + Array.prototype.slice.call(args).join('') + '\n' + new Error().stack);
        firstTime = false;
      }

      return fn.apply(this, arguments);
    }, fn);
  }

  var deprecations = {};

  function deprecateSimple(name, msg) {
    if (hooks.deprecationHandler != null) {
      hooks.deprecationHandler(name, msg);
    }

    if (!deprecations[name]) {
      warn(msg);
      deprecations[name] = true;
    }
  }

  hooks.suppressDeprecationWarnings = false;
  hooks.deprecationHandler = null;

  function isFunction(input) {
    return typeof Function !== 'undefined' && input instanceof Function || Object.prototype.toString.call(input) === '[object Function]';
  }

  function set(config) {
    var prop, i;

    for (i in config) {
      if (hasOwnProp(config, i)) {
        prop = config[i];

        if (isFunction(prop)) {
          this[i] = prop;
        } else {
          this['_' + i] = prop;
        }
      }
    }

    this._config = config; // Lenient ordinal parsing accepts just a number in addition to
    // number + (possibly) stuff coming from _dayOfMonthOrdinalParse.
    // TODO: Remove "ordinalParse" fallback in next major release.

    this._dayOfMonthOrdinalParseLenient = new RegExp((this._dayOfMonthOrdinalParse.source || this._ordinalParse.source) + '|' + /\d{1,2}/.source);
  }

  function mergeConfigs(parentConfig, childConfig) {
    var res = extend({}, parentConfig),
        prop;

    for (prop in childConfig) {
      if (hasOwnProp(childConfig, prop)) {
        if (isObject(parentConfig[prop]) && isObject(childConfig[prop])) {
          res[prop] = {};
          extend(res[prop], parentConfig[prop]);
          extend(res[prop], childConfig[prop]);
        } else if (childConfig[prop] != null) {
          res[prop] = childConfig[prop];
        } else {
          delete res[prop];
        }
      }
    }

    for (prop in parentConfig) {
      if (hasOwnProp(parentConfig, prop) && !hasOwnProp(childConfig, prop) && isObject(parentConfig[prop])) {
        // make sure changes to properties don't modify parent config
        res[prop] = extend({}, res[prop]);
      }
    }

    return res;
  }

  function Locale(config) {
    if (config != null) {
      this.set(config);
    }
  }

  var keys;

  if (Object.keys) {
    keys = Object.keys;
  } else {
    keys = function keys(obj) {
      var i,
          res = [];

      for (i in obj) {
        if (hasOwnProp(obj, i)) {
          res.push(i);
        }
      }

      return res;
    };
  }

  var defaultCalendar = {
    sameDay: '[Today at] LT',
    nextDay: '[Tomorrow at] LT',
    nextWeek: 'dddd [at] LT',
    lastDay: '[Yesterday at] LT',
    lastWeek: '[Last] dddd [at] LT',
    sameElse: 'L'
  };

  function calendar(key, mom, now) {
    var output = this._calendar[key] || this._calendar['sameElse'];
    return isFunction(output) ? output.call(mom, now) : output;
  }

  function zeroFill(number, targetLength, forceSign) {
    var absNumber = '' + Math.abs(number),
        zerosToFill = targetLength - absNumber.length,
        sign = number >= 0;
    return (sign ? forceSign ? '+' : '' : '-') + Math.pow(10, Math.max(0, zerosToFill)).toString().substr(1) + absNumber;
  }

  var formattingTokens = /(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|N{1,5}|YYYYYY|YYYYY|YYYY|YY|y{2,4}|yo?|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g,
      localFormattingTokens = /(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g,
      formatFunctions = {},
      formatTokenFunctions = {}; // token:    'M'
  // padded:   ['MM', 2]
  // ordinal:  'Mo'
  // callback: function () { this.month() + 1 }

  function addFormatToken(token, padded, ordinal, callback) {
    var func = callback;

    if (typeof callback === 'string') {
      func = function func() {
        return this[callback]();
      };
    }

    if (token) {
      formatTokenFunctions[token] = func;
    }

    if (padded) {
      formatTokenFunctions[padded[0]] = function () {
        return zeroFill(func.apply(this, arguments), padded[1], padded[2]);
      };
    }

    if (ordinal) {
      formatTokenFunctions[ordinal] = function () {
        return this.localeData().ordinal(func.apply(this, arguments), token);
      };
    }
  }

  function removeFormattingTokens(input) {
    if (input.match(/\[[\s\S]/)) {
      return input.replace(/^\[|\]$/g, '');
    }

    return input.replace(/\\/g, '');
  }

  function makeFormatFunction(format) {
    var array = format.match(formattingTokens),
        i,
        length;

    for (i = 0, length = array.length; i < length; i++) {
      if (formatTokenFunctions[array[i]]) {
        array[i] = formatTokenFunctions[array[i]];
      } else {
        array[i] = removeFormattingTokens(array[i]);
      }
    }

    return function (mom) {
      var output = '',
          i;

      for (i = 0; i < length; i++) {
        output += isFunction(array[i]) ? array[i].call(mom, format) : array[i];
      }

      return output;
    };
  } // format date using native date object


  function formatMoment(m, format) {
    if (!m.isValid()) {
      return m.localeData().invalidDate();
    }

    format = expandFormat(format, m.localeData());
    formatFunctions[format] = formatFunctions[format] || makeFormatFunction(format);
    return formatFunctions[format](m);
  }

  function expandFormat(format, locale) {
    var i = 5;

    function replaceLongDateFormatTokens(input) {
      return locale.longDateFormat(input) || input;
    }

    localFormattingTokens.lastIndex = 0;

    while (i >= 0 && localFormattingTokens.test(format)) {
      format = format.replace(localFormattingTokens, replaceLongDateFormatTokens);
      localFormattingTokens.lastIndex = 0;
      i -= 1;
    }

    return format;
  }

  var defaultLongDateFormat = {
    LTS: 'h:mm:ss A',
    LT: 'h:mm A',
    L: 'MM/DD/YYYY',
    LL: 'MMMM D, YYYY',
    LLL: 'MMMM D, YYYY h:mm A',
    LLLL: 'dddd, MMMM D, YYYY h:mm A'
  };

  function longDateFormat(key) {
    var format = this._longDateFormat[key],
        formatUpper = this._longDateFormat[key.toUpperCase()];

    if (format || !formatUpper) {
      return format;
    }

    this._longDateFormat[key] = formatUpper.match(formattingTokens).map(function (tok) {
      if (tok === 'MMMM' || tok === 'MM' || tok === 'DD' || tok === 'dddd') {
        return tok.slice(1);
      }

      return tok;
    }).join('');
    return this._longDateFormat[key];
  }

  var defaultInvalidDate = 'Invalid date';

  function invalidDate() {
    return this._invalidDate;
  }

  var defaultOrdinal = '%d',
      defaultDayOfMonthOrdinalParse = /\d{1,2}/;

  function ordinal(number) {
    return this._ordinal.replace('%d', number);
  }

  var defaultRelativeTime = {
    future: 'in %s',
    past: '%s ago',
    s: 'a few seconds',
    ss: '%d seconds',
    m: 'a minute',
    mm: '%d minutes',
    h: 'an hour',
    hh: '%d hours',
    d: 'a day',
    dd: '%d days',
    w: 'a week',
    ww: '%d weeks',
    M: 'a month',
    MM: '%d months',
    y: 'a year',
    yy: '%d years'
  };

  function relativeTime(number, withoutSuffix, string, isFuture) {
    var output = this._relativeTime[string];
    return isFunction(output) ? output(number, withoutSuffix, string, isFuture) : output.replace(/%d/i, number);
  }

  function pastFuture(diff, output) {
    var format = this._relativeTime[diff > 0 ? 'future' : 'past'];
    return isFunction(format) ? format(output) : format.replace(/%s/i, output);
  }

  var aliases = {};

  function addUnitAlias(unit, shorthand) {
    var lowerCase = unit.toLowerCase();
    aliases[lowerCase] = aliases[lowerCase + 's'] = aliases[shorthand] = unit;
  }

  function normalizeUnits(units) {
    return typeof units === 'string' ? aliases[units] || aliases[units.toLowerCase()] : undefined;
  }

  function normalizeObjectUnits(inputObject) {
    var normalizedInput = {},
        normalizedProp,
        prop;

    for (prop in inputObject) {
      if (hasOwnProp(inputObject, prop)) {
        normalizedProp = normalizeUnits(prop);

        if (normalizedProp) {
          normalizedInput[normalizedProp] = inputObject[prop];
        }
      }
    }

    return normalizedInput;
  }

  var priorities = {};

  function addUnitPriority(unit, priority) {
    priorities[unit] = priority;
  }

  function getPrioritizedUnits(unitsObj) {
    var units = [],
        u;

    for (u in unitsObj) {
      if (hasOwnProp(unitsObj, u)) {
        units.push({
          unit: u,
          priority: priorities[u]
        });
      }
    }

    units.sort(function (a, b) {
      return a.priority - b.priority;
    });
    return units;
  }

  function isLeapYear(year) {
    return year % 4 === 0 && year % 100 !== 0 || year % 400 === 0;
  }

  function absFloor(number) {
    if (number < 0) {
      // -0 -> 0
      return Math.ceil(number) || 0;
    } else {
      return Math.floor(number);
    }
  }

  function toInt(argumentForCoercion) {
    var coercedNumber = +argumentForCoercion,
        value = 0;

    if (coercedNumber !== 0 && isFinite(coercedNumber)) {
      value = absFloor(coercedNumber);
    }

    return value;
  }

  function makeGetSet(unit, keepTime) {
    return function (value) {
      if (value != null) {
        set$1(this, unit, value);
        hooks.updateOffset(this, keepTime);
        return this;
      } else {
        return get(this, unit);
      }
    };
  }

  function get(mom, unit) {
    return mom.isValid() ? mom._d['get' + (mom._isUTC ? 'UTC' : '') + unit]() : NaN;
  }

  function set$1(mom, unit, value) {
    if (mom.isValid() && !isNaN(value)) {
      if (unit === 'FullYear' && isLeapYear(mom.year()) && mom.month() === 1 && mom.date() === 29) {
        value = toInt(value);

        mom._d['set' + (mom._isUTC ? 'UTC' : '') + unit](value, mom.month(), daysInMonth(value, mom.month()));
      } else {
        mom._d['set' + (mom._isUTC ? 'UTC' : '') + unit](value);
      }
    }
  } // MOMENTS


  function stringGet(units) {
    units = normalizeUnits(units);

    if (isFunction(this[units])) {
      return this[units]();
    }

    return this;
  }

  function stringSet(units, value) {
    if (typeof units === 'object') {
      units = normalizeObjectUnits(units);
      var prioritized = getPrioritizedUnits(units),
          i;

      for (i = 0; i < prioritized.length; i++) {
        this[prioritized[i].unit](units[prioritized[i].unit]);
      }
    } else {
      units = normalizeUnits(units);

      if (isFunction(this[units])) {
        return this[units](value);
      }
    }

    return this;
  }

  var match1 = /\d/,
      //       0 - 9
  match2 = /\d\d/,
      //      00 - 99
  match3 = /\d{3}/,
      //     000 - 999
  match4 = /\d{4}/,
      //    0000 - 9999
  match6 = /[+-]?\d{6}/,
      // -999999 - 999999
  match1to2 = /\d\d?/,
      //       0 - 99
  match3to4 = /\d\d\d\d?/,
      //     999 - 9999
  match5to6 = /\d\d\d\d\d\d?/,
      //   99999 - 999999
  match1to3 = /\d{1,3}/,
      //       0 - 999
  match1to4 = /\d{1,4}/,
      //       0 - 9999
  match1to6 = /[+-]?\d{1,6}/,
      // -999999 - 999999
  matchUnsigned = /\d+/,
      //       0 - inf
  matchSigned = /[+-]?\d+/,
      //    -inf - inf
  matchOffset = /Z|[+-]\d\d:?\d\d/gi,
      // +00:00 -00:00 +0000 -0000 or Z
  matchShortOffset = /Z|[+-]\d\d(?::?\d\d)?/gi,
      // +00 -00 +00:00 -00:00 +0000 -0000 or Z
  matchTimestamp = /[+-]?\d+(\.\d{1,3})?/,
      // 123456789 123456789.123
  // any word (or two) characters or numbers including two/three word month in arabic.
  // includes scottish gaelic two word and hyphenated months
  matchWord = /[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i,
      regexes;
  regexes = {};

  function addRegexToken(token, regex, strictRegex) {
    regexes[token] = isFunction(regex) ? regex : function (isStrict, localeData) {
      return isStrict && strictRegex ? strictRegex : regex;
    };
  }

  function getParseRegexForToken(token, config) {
    if (!hasOwnProp(regexes, token)) {
      return new RegExp(unescapeFormat(token));
    }

    return regexes[token](config._strict, config._locale);
  } // Code from http://stackoverflow.com/questions/3561493/is-there-a-regexp-escape-function-in-javascript


  function unescapeFormat(s) {
    return regexEscape(s.replace('\\', '').replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g, function (matched, p1, p2, p3, p4) {
      return p1 || p2 || p3 || p4;
    }));
  }

  function regexEscape(s) {
    return s.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
  }

  var tokens = {};

  function addParseToken(token, callback) {
    var i,
        func = callback;

    if (typeof token === 'string') {
      token = [token];
    }

    if (isNumber(callback)) {
      func = function func(input, array) {
        array[callback] = toInt(input);
      };
    }

    for (i = 0; i < token.length; i++) {
      tokens[token[i]] = func;
    }
  }

  function addWeekParseToken(token, callback) {
    addParseToken(token, function (input, array, config, token) {
      config._w = config._w || {};
      callback(input, config._w, config, token);
    });
  }

  function addTimeToArrayFromToken(token, input, config) {
    if (input != null && hasOwnProp(tokens, token)) {
      tokens[token](input, config._a, config, token);
    }
  }

  var YEAR = 0,
      MONTH = 1,
      DATE = 2,
      HOUR = 3,
      MINUTE = 4,
      SECOND = 5,
      MILLISECOND = 6,
      WEEK = 7,
      WEEKDAY = 8;

  function mod(n, x) {
    return (n % x + x) % x;
  }

  var indexOf;

  if (Array.prototype.indexOf) {
    indexOf = Array.prototype.indexOf;
  } else {
    indexOf = function indexOf(o) {
      // I know
      var i;

      for (i = 0; i < this.length; ++i) {
        if (this[i] === o) {
          return i;
        }
      }

      return -1;
    };
  }

  function daysInMonth(year, month) {
    if (isNaN(year) || isNaN(month)) {
      return NaN;
    }

    var modMonth = mod(month, 12);
    year += (month - modMonth) / 12;
    return modMonth === 1 ? isLeapYear(year) ? 29 : 28 : 31 - modMonth % 7 % 2;
  } // FORMATTING


  addFormatToken('M', ['MM', 2], 'Mo', function () {
    return this.month() + 1;
  });
  addFormatToken('MMM', 0, 0, function (format) {
    return this.localeData().monthsShort(this, format);
  });
  addFormatToken('MMMM', 0, 0, function (format) {
    return this.localeData().months(this, format);
  }); // ALIASES

  addUnitAlias('month', 'M'); // PRIORITY

  addUnitPriority('month', 8); // PARSING

  addRegexToken('M', match1to2);
  addRegexToken('MM', match1to2, match2);
  addRegexToken('MMM', function (isStrict, locale) {
    return locale.monthsShortRegex(isStrict);
  });
  addRegexToken('MMMM', function (isStrict, locale) {
    return locale.monthsRegex(isStrict);
  });
  addParseToken(['M', 'MM'], function (input, array) {
    array[MONTH] = toInt(input) - 1;
  });
  addParseToken(['MMM', 'MMMM'], function (input, array, config, token) {
    var month = config._locale.monthsParse(input, token, config._strict); // if we didn't find a month name, mark the date as invalid.


    if (month != null) {
      array[MONTH] = month;
    } else {
      getParsingFlags(config).invalidMonth = input;
    }
  }); // LOCALES

  var defaultLocaleMonths = 'January_February_March_April_May_June_July_August_September_October_November_December'.split('_'),
      defaultLocaleMonthsShort = 'Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec'.split('_'),
      MONTHS_IN_FORMAT = /D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/,
      defaultMonthsShortRegex = matchWord,
      defaultMonthsRegex = matchWord;

  function localeMonths(m, format) {
    if (!m) {
      return isArray(this._months) ? this._months : this._months['standalone'];
    }

    return isArray(this._months) ? this._months[m.month()] : this._months[(this._months.isFormat || MONTHS_IN_FORMAT).test(format) ? 'format' : 'standalone'][m.month()];
  }

  function localeMonthsShort(m, format) {
    if (!m) {
      return isArray(this._monthsShort) ? this._monthsShort : this._monthsShort['standalone'];
    }

    return isArray(this._monthsShort) ? this._monthsShort[m.month()] : this._monthsShort[MONTHS_IN_FORMAT.test(format) ? 'format' : 'standalone'][m.month()];
  }

  function handleStrictParse(monthName, format, strict) {
    var i,
        ii,
        mom,
        llc = monthName.toLocaleLowerCase();

    if (!this._monthsParse) {
      // this is not used
      this._monthsParse = [];
      this._longMonthsParse = [];
      this._shortMonthsParse = [];

      for (i = 0; i < 12; ++i) {
        mom = createUTC([2000, i]);
        this._shortMonthsParse[i] = this.monthsShort(mom, '').toLocaleLowerCase();
        this._longMonthsParse[i] = this.months(mom, '').toLocaleLowerCase();
      }
    }

    if (strict) {
      if (format === 'MMM') {
        ii = indexOf.call(this._shortMonthsParse, llc);
        return ii !== -1 ? ii : null;
      } else {
        ii = indexOf.call(this._longMonthsParse, llc);
        return ii !== -1 ? ii : null;
      }
    } else {
      if (format === 'MMM') {
        ii = indexOf.call(this._shortMonthsParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._longMonthsParse, llc);
        return ii !== -1 ? ii : null;
      } else {
        ii = indexOf.call(this._longMonthsParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._shortMonthsParse, llc);
        return ii !== -1 ? ii : null;
      }
    }
  }

  function localeMonthsParse(monthName, format, strict) {
    var i, mom, regex;

    if (this._monthsParseExact) {
      return handleStrictParse.call(this, monthName, format, strict);
    }

    if (!this._monthsParse) {
      this._monthsParse = [];
      this._longMonthsParse = [];
      this._shortMonthsParse = [];
    } // TODO: add sorting
    // Sorting makes sure if one month (or abbr) is a prefix of another
    // see sorting in computeMonthsParse


    for (i = 0; i < 12; i++) {
      // make the regex if we don't have it already
      mom = createUTC([2000, i]);

      if (strict && !this._longMonthsParse[i]) {
        this._longMonthsParse[i] = new RegExp('^' + this.months(mom, '').replace('.', '') + '$', 'i');
        this._shortMonthsParse[i] = new RegExp('^' + this.monthsShort(mom, '').replace('.', '') + '$', 'i');
      }

      if (!strict && !this._monthsParse[i]) {
        regex = '^' + this.months(mom, '') + '|^' + this.monthsShort(mom, '');
        this._monthsParse[i] = new RegExp(regex.replace('.', ''), 'i');
      } // test the regex


      if (strict && format === 'MMMM' && this._longMonthsParse[i].test(monthName)) {
        return i;
      } else if (strict && format === 'MMM' && this._shortMonthsParse[i].test(monthName)) {
        return i;
      } else if (!strict && this._monthsParse[i].test(monthName)) {
        return i;
      }
    }
  } // MOMENTS


  function setMonth(mom, value) {
    var dayOfMonth;

    if (!mom.isValid()) {
      // No op
      return mom;
    }

    if (typeof value === 'string') {
      if (/^\d+$/.test(value)) {
        value = toInt(value);
      } else {
        value = mom.localeData().monthsParse(value); // TODO: Another silent failure?

        if (!isNumber(value)) {
          return mom;
        }
      }
    }

    dayOfMonth = Math.min(mom.date(), daysInMonth(mom.year(), value));

    mom._d['set' + (mom._isUTC ? 'UTC' : '') + 'Month'](value, dayOfMonth);

    return mom;
  }

  function getSetMonth(value) {
    if (value != null) {
      setMonth(this, value);
      hooks.updateOffset(this, true);
      return this;
    } else {
      return get(this, 'Month');
    }
  }

  function getDaysInMonth() {
    return daysInMonth(this.year(), this.month());
  }

  function monthsShortRegex(isStrict) {
    if (this._monthsParseExact) {
      if (!hasOwnProp(this, '_monthsRegex')) {
        computeMonthsParse.call(this);
      }

      if (isStrict) {
        return this._monthsShortStrictRegex;
      } else {
        return this._monthsShortRegex;
      }
    } else {
      if (!hasOwnProp(this, '_monthsShortRegex')) {
        this._monthsShortRegex = defaultMonthsShortRegex;
      }

      return this._monthsShortStrictRegex && isStrict ? this._monthsShortStrictRegex : this._monthsShortRegex;
    }
  }

  function monthsRegex(isStrict) {
    if (this._monthsParseExact) {
      if (!hasOwnProp(this, '_monthsRegex')) {
        computeMonthsParse.call(this);
      }

      if (isStrict) {
        return this._monthsStrictRegex;
      } else {
        return this._monthsRegex;
      }
    } else {
      if (!hasOwnProp(this, '_monthsRegex')) {
        this._monthsRegex = defaultMonthsRegex;
      }

      return this._monthsStrictRegex && isStrict ? this._monthsStrictRegex : this._monthsRegex;
    }
  }

  function computeMonthsParse() {
    function cmpLenRev(a, b) {
      return b.length - a.length;
    }

    var shortPieces = [],
        longPieces = [],
        mixedPieces = [],
        i,
        mom;

    for (i = 0; i < 12; i++) {
      // make the regex if we don't have it already
      mom = createUTC([2000, i]);
      shortPieces.push(this.monthsShort(mom, ''));
      longPieces.push(this.months(mom, ''));
      mixedPieces.push(this.months(mom, ''));
      mixedPieces.push(this.monthsShort(mom, ''));
    } // Sorting makes sure if one month (or abbr) is a prefix of another it
    // will match the longer piece.


    shortPieces.sort(cmpLenRev);
    longPieces.sort(cmpLenRev);
    mixedPieces.sort(cmpLenRev);

    for (i = 0; i < 12; i++) {
      shortPieces[i] = regexEscape(shortPieces[i]);
      longPieces[i] = regexEscape(longPieces[i]);
    }

    for (i = 0; i < 24; i++) {
      mixedPieces[i] = regexEscape(mixedPieces[i]);
    }

    this._monthsRegex = new RegExp('^(' + mixedPieces.join('|') + ')', 'i');
    this._monthsShortRegex = this._monthsRegex;
    this._monthsStrictRegex = new RegExp('^(' + longPieces.join('|') + ')', 'i');
    this._monthsShortStrictRegex = new RegExp('^(' + shortPieces.join('|') + ')', 'i');
  } // FORMATTING


  addFormatToken('Y', 0, 0, function () {
    var y = this.year();
    return y <= 9999 ? zeroFill(y, 4) : '+' + y;
  });
  addFormatToken(0, ['YY', 2], 0, function () {
    return this.year() % 100;
  });
  addFormatToken(0, ['YYYY', 4], 0, 'year');
  addFormatToken(0, ['YYYYY', 5], 0, 'year');
  addFormatToken(0, ['YYYYYY', 6, true], 0, 'year'); // ALIASES

  addUnitAlias('year', 'y'); // PRIORITIES

  addUnitPriority('year', 1); // PARSING

  addRegexToken('Y', matchSigned);
  addRegexToken('YY', match1to2, match2);
  addRegexToken('YYYY', match1to4, match4);
  addRegexToken('YYYYY', match1to6, match6);
  addRegexToken('YYYYYY', match1to6, match6);
  addParseToken(['YYYYY', 'YYYYYY'], YEAR);
  addParseToken('YYYY', function (input, array) {
    array[YEAR] = input.length === 2 ? hooks.parseTwoDigitYear(input) : toInt(input);
  });
  addParseToken('YY', function (input, array) {
    array[YEAR] = hooks.parseTwoDigitYear(input);
  });
  addParseToken('Y', function (input, array) {
    array[YEAR] = parseInt(input, 10);
  }); // HELPERS

  function daysInYear(year) {
    return isLeapYear(year) ? 366 : 365;
  } // HOOKS


  hooks.parseTwoDigitYear = function (input) {
    return toInt(input) + (toInt(input) > 68 ? 1900 : 2000);
  }; // MOMENTS


  var getSetYear = makeGetSet('FullYear', true);

  function getIsLeapYear() {
    return isLeapYear(this.year());
  }

  function createDate(y, m, d, h, M, s, ms) {
    // can't just apply() to create a date:
    // https://stackoverflow.com/q/181348
    var date; // the date constructor remaps years 0-99 to 1900-1999

    if (y < 100 && y >= 0) {
      // preserve leap years using a full 400 year cycle, then reset
      date = new Date(y + 400, m, d, h, M, s, ms);

      if (isFinite(date.getFullYear())) {
        date.setFullYear(y);
      }
    } else {
      date = new Date(y, m, d, h, M, s, ms);
    }

    return date;
  }

  function createUTCDate(y) {
    var date, args; // the Date.UTC function remaps years 0-99 to 1900-1999

    if (y < 100 && y >= 0) {
      args = Array.prototype.slice.call(arguments); // preserve leap years using a full 400 year cycle, then reset

      args[0] = y + 400;
      date = new Date(Date.UTC.apply(null, args));

      if (isFinite(date.getUTCFullYear())) {
        date.setUTCFullYear(y);
      }
    } else {
      date = new Date(Date.UTC.apply(null, arguments));
    }

    return date;
  } // start-of-first-week - start-of-year


  function firstWeekOffset(year, dow, doy) {
    var // first-week day -- which january is always in the first week (4 for iso, 1 for other)
    fwd = 7 + dow - doy,
        // first-week day local weekday -- which local weekday is fwd
    fwdlw = (7 + createUTCDate(year, 0, fwd).getUTCDay() - dow) % 7;
    return -fwdlw + fwd - 1;
  } // https://en.wikipedia.org/wiki/ISO_week_date#Calculating_a_date_given_the_year.2C_week_number_and_weekday


  function dayOfYearFromWeeks(year, week, weekday, dow, doy) {
    var localWeekday = (7 + weekday - dow) % 7,
        weekOffset = firstWeekOffset(year, dow, doy),
        dayOfYear = 1 + 7 * (week - 1) + localWeekday + weekOffset,
        resYear,
        resDayOfYear;

    if (dayOfYear <= 0) {
      resYear = year - 1;
      resDayOfYear = daysInYear(resYear) + dayOfYear;
    } else if (dayOfYear > daysInYear(year)) {
      resYear = year + 1;
      resDayOfYear = dayOfYear - daysInYear(year);
    } else {
      resYear = year;
      resDayOfYear = dayOfYear;
    }

    return {
      year: resYear,
      dayOfYear: resDayOfYear
    };
  }

  function weekOfYear(mom, dow, doy) {
    var weekOffset = firstWeekOffset(mom.year(), dow, doy),
        week = Math.floor((mom.dayOfYear() - weekOffset - 1) / 7) + 1,
        resWeek,
        resYear;

    if (week < 1) {
      resYear = mom.year() - 1;
      resWeek = week + weeksInYear(resYear, dow, doy);
    } else if (week > weeksInYear(mom.year(), dow, doy)) {
      resWeek = week - weeksInYear(mom.year(), dow, doy);
      resYear = mom.year() + 1;
    } else {
      resYear = mom.year();
      resWeek = week;
    }

    return {
      week: resWeek,
      year: resYear
    };
  }

  function weeksInYear(year, dow, doy) {
    var weekOffset = firstWeekOffset(year, dow, doy),
        weekOffsetNext = firstWeekOffset(year + 1, dow, doy);
    return (daysInYear(year) - weekOffset + weekOffsetNext) / 7;
  } // FORMATTING


  addFormatToken('w', ['ww', 2], 'wo', 'week');
  addFormatToken('W', ['WW', 2], 'Wo', 'isoWeek'); // ALIASES

  addUnitAlias('week', 'w');
  addUnitAlias('isoWeek', 'W'); // PRIORITIES

  addUnitPriority('week', 5);
  addUnitPriority('isoWeek', 5); // PARSING

  addRegexToken('w', match1to2);
  addRegexToken('ww', match1to2, match2);
  addRegexToken('W', match1to2);
  addRegexToken('WW', match1to2, match2);
  addWeekParseToken(['w', 'ww', 'W', 'WW'], function (input, week, config, token) {
    week[token.substr(0, 1)] = toInt(input);
  }); // HELPERS
  // LOCALES

  function localeWeek(mom) {
    return weekOfYear(mom, this._week.dow, this._week.doy).week;
  }

  var defaultLocaleWeek = {
    dow: 0,
    // Sunday is the first day of the week.
    doy: 6 // The week that contains Jan 6th is the first week of the year.

  };

  function localeFirstDayOfWeek() {
    return this._week.dow;
  }

  function localeFirstDayOfYear() {
    return this._week.doy;
  } // MOMENTS


  function getSetWeek(input) {
    var week = this.localeData().week(this);
    return input == null ? week : this.add((input - week) * 7, 'd');
  }

  function getSetISOWeek(input) {
    var week = weekOfYear(this, 1, 4).week;
    return input == null ? week : this.add((input - week) * 7, 'd');
  } // FORMATTING


  addFormatToken('d', 0, 'do', 'day');
  addFormatToken('dd', 0, 0, function (format) {
    return this.localeData().weekdaysMin(this, format);
  });
  addFormatToken('ddd', 0, 0, function (format) {
    return this.localeData().weekdaysShort(this, format);
  });
  addFormatToken('dddd', 0, 0, function (format) {
    return this.localeData().weekdays(this, format);
  });
  addFormatToken('e', 0, 0, 'weekday');
  addFormatToken('E', 0, 0, 'isoWeekday'); // ALIASES

  addUnitAlias('day', 'd');
  addUnitAlias('weekday', 'e');
  addUnitAlias('isoWeekday', 'E'); // PRIORITY

  addUnitPriority('day', 11);
  addUnitPriority('weekday', 11);
  addUnitPriority('isoWeekday', 11); // PARSING

  addRegexToken('d', match1to2);
  addRegexToken('e', match1to2);
  addRegexToken('E', match1to2);
  addRegexToken('dd', function (isStrict, locale) {
    return locale.weekdaysMinRegex(isStrict);
  });
  addRegexToken('ddd', function (isStrict, locale) {
    return locale.weekdaysShortRegex(isStrict);
  });
  addRegexToken('dddd', function (isStrict, locale) {
    return locale.weekdaysRegex(isStrict);
  });
  addWeekParseToken(['dd', 'ddd', 'dddd'], function (input, week, config, token) {
    var weekday = config._locale.weekdaysParse(input, token, config._strict); // if we didn't get a weekday name, mark the date as invalid


    if (weekday != null) {
      week.d = weekday;
    } else {
      getParsingFlags(config).invalidWeekday = input;
    }
  });
  addWeekParseToken(['d', 'e', 'E'], function (input, week, config, token) {
    week[token] = toInt(input);
  }); // HELPERS

  function parseWeekday(input, locale) {
    if (typeof input !== 'string') {
      return input;
    }

    if (!isNaN(input)) {
      return parseInt(input, 10);
    }

    input = locale.weekdaysParse(input);

    if (typeof input === 'number') {
      return input;
    }

    return null;
  }

  function parseIsoWeekday(input, locale) {
    if (typeof input === 'string') {
      return locale.weekdaysParse(input) % 7 || 7;
    }

    return isNaN(input) ? null : input;
  } // LOCALES


  function shiftWeekdays(ws, n) {
    return ws.slice(n, 7).concat(ws.slice(0, n));
  }

  var defaultLocaleWeekdays = 'Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday'.split('_'),
      defaultLocaleWeekdaysShort = 'Sun_Mon_Tue_Wed_Thu_Fri_Sat'.split('_'),
      defaultLocaleWeekdaysMin = 'Su_Mo_Tu_We_Th_Fr_Sa'.split('_'),
      defaultWeekdaysRegex = matchWord,
      defaultWeekdaysShortRegex = matchWord,
      defaultWeekdaysMinRegex = matchWord;

  function localeWeekdays(m, format) {
    var weekdays = isArray(this._weekdays) ? this._weekdays : this._weekdays[m && m !== true && this._weekdays.isFormat.test(format) ? 'format' : 'standalone'];
    return m === true ? shiftWeekdays(weekdays, this._week.dow) : m ? weekdays[m.day()] : weekdays;
  }

  function localeWeekdaysShort(m) {
    return m === true ? shiftWeekdays(this._weekdaysShort, this._week.dow) : m ? this._weekdaysShort[m.day()] : this._weekdaysShort;
  }

  function localeWeekdaysMin(m) {
    return m === true ? shiftWeekdays(this._weekdaysMin, this._week.dow) : m ? this._weekdaysMin[m.day()] : this._weekdaysMin;
  }

  function handleStrictParse$1(weekdayName, format, strict) {
    var i,
        ii,
        mom,
        llc = weekdayName.toLocaleLowerCase();

    if (!this._weekdaysParse) {
      this._weekdaysParse = [];
      this._shortWeekdaysParse = [];
      this._minWeekdaysParse = [];

      for (i = 0; i < 7; ++i) {
        mom = createUTC([2000, 1]).day(i);
        this._minWeekdaysParse[i] = this.weekdaysMin(mom, '').toLocaleLowerCase();
        this._shortWeekdaysParse[i] = this.weekdaysShort(mom, '').toLocaleLowerCase();
        this._weekdaysParse[i] = this.weekdays(mom, '').toLocaleLowerCase();
      }
    }

    if (strict) {
      if (format === 'dddd') {
        ii = indexOf.call(this._weekdaysParse, llc);
        return ii !== -1 ? ii : null;
      } else if (format === 'ddd') {
        ii = indexOf.call(this._shortWeekdaysParse, llc);
        return ii !== -1 ? ii : null;
      } else {
        ii = indexOf.call(this._minWeekdaysParse, llc);
        return ii !== -1 ? ii : null;
      }
    } else {
      if (format === 'dddd') {
        ii = indexOf.call(this._weekdaysParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._shortWeekdaysParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._minWeekdaysParse, llc);
        return ii !== -1 ? ii : null;
      } else if (format === 'ddd') {
        ii = indexOf.call(this._shortWeekdaysParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._weekdaysParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._minWeekdaysParse, llc);
        return ii !== -1 ? ii : null;
      } else {
        ii = indexOf.call(this._minWeekdaysParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._weekdaysParse, llc);

        if (ii !== -1) {
          return ii;
        }

        ii = indexOf.call(this._shortWeekdaysParse, llc);
        return ii !== -1 ? ii : null;
      }
    }
  }

  function localeWeekdaysParse(weekdayName, format, strict) {
    var i, mom, regex;

    if (this._weekdaysParseExact) {
      return handleStrictParse$1.call(this, weekdayName, format, strict);
    }

    if (!this._weekdaysParse) {
      this._weekdaysParse = [];
      this._minWeekdaysParse = [];
      this._shortWeekdaysParse = [];
      this._fullWeekdaysParse = [];
    }

    for (i = 0; i < 7; i++) {
      // make the regex if we don't have it already
      mom = createUTC([2000, 1]).day(i);

      if (strict && !this._fullWeekdaysParse[i]) {
        this._fullWeekdaysParse[i] = new RegExp('^' + this.weekdays(mom, '').replace('.', '\\.?') + '$', 'i');
        this._shortWeekdaysParse[i] = new RegExp('^' + this.weekdaysShort(mom, '').replace('.', '\\.?') + '$', 'i');
        this._minWeekdaysParse[i] = new RegExp('^' + this.weekdaysMin(mom, '').replace('.', '\\.?') + '$', 'i');
      }

      if (!this._weekdaysParse[i]) {
        regex = '^' + this.weekdays(mom, '') + '|^' + this.weekdaysShort(mom, '') + '|^' + this.weekdaysMin(mom, '');
        this._weekdaysParse[i] = new RegExp(regex.replace('.', ''), 'i');
      } // test the regex


      if (strict && format === 'dddd' && this._fullWeekdaysParse[i].test(weekdayName)) {
        return i;
      } else if (strict && format === 'ddd' && this._shortWeekdaysParse[i].test(weekdayName)) {
        return i;
      } else if (strict && format === 'dd' && this._minWeekdaysParse[i].test(weekdayName)) {
        return i;
      } else if (!strict && this._weekdaysParse[i].test(weekdayName)) {
        return i;
      }
    }
  } // MOMENTS


  function getSetDayOfWeek(input) {
    if (!this.isValid()) {
      return input != null ? this : NaN;
    }

    var day = this._isUTC ? this._d.getUTCDay() : this._d.getDay();

    if (input != null) {
      input = parseWeekday(input, this.localeData());
      return this.add(input - day, 'd');
    } else {
      return day;
    }
  }

  function getSetLocaleDayOfWeek(input) {
    if (!this.isValid()) {
      return input != null ? this : NaN;
    }

    var weekday = (this.day() + 7 - this.localeData()._week.dow) % 7;
    return input == null ? weekday : this.add(input - weekday, 'd');
  }

  function getSetISODayOfWeek(input) {
    if (!this.isValid()) {
      return input != null ? this : NaN;
    } // behaves the same as moment#day except
    // as a getter, returns 7 instead of 0 (1-7 range instead of 0-6)
    // as a setter, sunday should belong to the previous week.


    if (input != null) {
      var weekday = parseIsoWeekday(input, this.localeData());
      return this.day(this.day() % 7 ? weekday : weekday - 7);
    } else {
      return this.day() || 7;
    }
  }

  function weekdaysRegex(isStrict) {
    if (this._weekdaysParseExact) {
      if (!hasOwnProp(this, '_weekdaysRegex')) {
        computeWeekdaysParse.call(this);
      }

      if (isStrict) {
        return this._weekdaysStrictRegex;
      } else {
        return this._weekdaysRegex;
      }
    } else {
      if (!hasOwnProp(this, '_weekdaysRegex')) {
        this._weekdaysRegex = defaultWeekdaysRegex;
      }

      return this._weekdaysStrictRegex && isStrict ? this._weekdaysStrictRegex : this._weekdaysRegex;
    }
  }

  function weekdaysShortRegex(isStrict) {
    if (this._weekdaysParseExact) {
      if (!hasOwnProp(this, '_weekdaysRegex')) {
        computeWeekdaysParse.call(this);
      }

      if (isStrict) {
        return this._weekdaysShortStrictRegex;
      } else {
        return this._weekdaysShortRegex;
      }
    } else {
      if (!hasOwnProp(this, '_weekdaysShortRegex')) {
        this._weekdaysShortRegex = defaultWeekdaysShortRegex;
      }

      return this._weekdaysShortStrictRegex && isStrict ? this._weekdaysShortStrictRegex : this._weekdaysShortRegex;
    }
  }

  function weekdaysMinRegex(isStrict) {
    if (this._weekdaysParseExact) {
      if (!hasOwnProp(this, '_weekdaysRegex')) {
        computeWeekdaysParse.call(this);
      }

      if (isStrict) {
        return this._weekdaysMinStrictRegex;
      } else {
        return this._weekdaysMinRegex;
      }
    } else {
      if (!hasOwnProp(this, '_weekdaysMinRegex')) {
        this._weekdaysMinRegex = defaultWeekdaysMinRegex;
      }

      return this._weekdaysMinStrictRegex && isStrict ? this._weekdaysMinStrictRegex : this._weekdaysMinRegex;
    }
  }

  function computeWeekdaysParse() {
    function cmpLenRev(a, b) {
      return b.length - a.length;
    }

    var minPieces = [],
        shortPieces = [],
        longPieces = [],
        mixedPieces = [],
        i,
        mom,
        minp,
        shortp,
        longp;

    for (i = 0; i < 7; i++) {
      // make the regex if we don't have it already
      mom = createUTC([2000, 1]).day(i);
      minp = regexEscape(this.weekdaysMin(mom, ''));
      shortp = regexEscape(this.weekdaysShort(mom, ''));
      longp = regexEscape(this.weekdays(mom, ''));
      minPieces.push(minp);
      shortPieces.push(shortp);
      longPieces.push(longp);
      mixedPieces.push(minp);
      mixedPieces.push(shortp);
      mixedPieces.push(longp);
    } // Sorting makes sure if one weekday (or abbr) is a prefix of another it
    // will match the longer piece.


    minPieces.sort(cmpLenRev);
    shortPieces.sort(cmpLenRev);
    longPieces.sort(cmpLenRev);
    mixedPieces.sort(cmpLenRev);
    this._weekdaysRegex = new RegExp('^(' + mixedPieces.join('|') + ')', 'i');
    this._weekdaysShortRegex = this._weekdaysRegex;
    this._weekdaysMinRegex = this._weekdaysRegex;
    this._weekdaysStrictRegex = new RegExp('^(' + longPieces.join('|') + ')', 'i');
    this._weekdaysShortStrictRegex = new RegExp('^(' + shortPieces.join('|') + ')', 'i');
    this._weekdaysMinStrictRegex = new RegExp('^(' + minPieces.join('|') + ')', 'i');
  } // FORMATTING


  function hFormat() {
    return this.hours() % 12 || 12;
  }

  function kFormat() {
    return this.hours() || 24;
  }

  addFormatToken('H', ['HH', 2], 0, 'hour');
  addFormatToken('h', ['hh', 2], 0, hFormat);
  addFormatToken('k', ['kk', 2], 0, kFormat);
  addFormatToken('hmm', 0, 0, function () {
    return '' + hFormat.apply(this) + zeroFill(this.minutes(), 2);
  });
  addFormatToken('hmmss', 0, 0, function () {
    return '' + hFormat.apply(this) + zeroFill(this.minutes(), 2) + zeroFill(this.seconds(), 2);
  });
  addFormatToken('Hmm', 0, 0, function () {
    return '' + this.hours() + zeroFill(this.minutes(), 2);
  });
  addFormatToken('Hmmss', 0, 0, function () {
    return '' + this.hours() + zeroFill(this.minutes(), 2) + zeroFill(this.seconds(), 2);
  });

  function meridiem(token, lowercase) {
    addFormatToken(token, 0, 0, function () {
      return this.localeData().meridiem(this.hours(), this.minutes(), lowercase);
    });
  }

  meridiem('a', true);
  meridiem('A', false); // ALIASES

  addUnitAlias('hour', 'h'); // PRIORITY

  addUnitPriority('hour', 13); // PARSING

  function matchMeridiem(isStrict, locale) {
    return locale._meridiemParse;
  }

  addRegexToken('a', matchMeridiem);
  addRegexToken('A', matchMeridiem);
  addRegexToken('H', match1to2);
  addRegexToken('h', match1to2);
  addRegexToken('k', match1to2);
  addRegexToken('HH', match1to2, match2);
  addRegexToken('hh', match1to2, match2);
  addRegexToken('kk', match1to2, match2);
  addRegexToken('hmm', match3to4);
  addRegexToken('hmmss', match5to6);
  addRegexToken('Hmm', match3to4);
  addRegexToken('Hmmss', match5to6);
  addParseToken(['H', 'HH'], HOUR);
  addParseToken(['k', 'kk'], function (input, array, config) {
    var kInput = toInt(input);
    array[HOUR] = kInput === 24 ? 0 : kInput;
  });
  addParseToken(['a', 'A'], function (input, array, config) {
    config._isPm = config._locale.isPM(input);
    config._meridiem = input;
  });
  addParseToken(['h', 'hh'], function (input, array, config) {
    array[HOUR] = toInt(input);
    getParsingFlags(config).bigHour = true;
  });
  addParseToken('hmm', function (input, array, config) {
    var pos = input.length - 2;
    array[HOUR] = toInt(input.substr(0, pos));
    array[MINUTE] = toInt(input.substr(pos));
    getParsingFlags(config).bigHour = true;
  });
  addParseToken('hmmss', function (input, array, config) {
    var pos1 = input.length - 4,
        pos2 = input.length - 2;
    array[HOUR] = toInt(input.substr(0, pos1));
    array[MINUTE] = toInt(input.substr(pos1, 2));
    array[SECOND] = toInt(input.substr(pos2));
    getParsingFlags(config).bigHour = true;
  });
  addParseToken('Hmm', function (input, array, config) {
    var pos = input.length - 2;
    array[HOUR] = toInt(input.substr(0, pos));
    array[MINUTE] = toInt(input.substr(pos));
  });
  addParseToken('Hmmss', function (input, array, config) {
    var pos1 = input.length - 4,
        pos2 = input.length - 2;
    array[HOUR] = toInt(input.substr(0, pos1));
    array[MINUTE] = toInt(input.substr(pos1, 2));
    array[SECOND] = toInt(input.substr(pos2));
  }); // LOCALES

  function localeIsPM(input) {
    // IE8 Quirks Mode & IE7 Standards Mode do not allow accessing strings like arrays
    // Using charAt should be more compatible.
    return (input + '').toLowerCase().charAt(0) === 'p';
  }

  var defaultLocaleMeridiemParse = /[ap]\.?m?\.?/i,
      // Setting the hour should keep the time, because the user explicitly
  // specified which hour they want. So trying to maintain the same hour (in
  // a new timezone) makes sense. Adding/subtracting hours does not follow
  // this rule.
  getSetHour = makeGetSet('Hours', true);

  function localeMeridiem(hours, minutes, isLower) {
    if (hours > 11) {
      return isLower ? 'pm' : 'PM';
    } else {
      return isLower ? 'am' : 'AM';
    }
  }

  var baseConfig = {
    calendar: defaultCalendar,
    longDateFormat: defaultLongDateFormat,
    invalidDate: defaultInvalidDate,
    ordinal: defaultOrdinal,
    dayOfMonthOrdinalParse: defaultDayOfMonthOrdinalParse,
    relativeTime: defaultRelativeTime,
    months: defaultLocaleMonths,
    monthsShort: defaultLocaleMonthsShort,
    week: defaultLocaleWeek,
    weekdays: defaultLocaleWeekdays,
    weekdaysMin: defaultLocaleWeekdaysMin,
    weekdaysShort: defaultLocaleWeekdaysShort,
    meridiemParse: defaultLocaleMeridiemParse
  }; // internal storage for locale config files

  var locales = {},
      localeFamilies = {},
      globalLocale;

  function commonPrefix(arr1, arr2) {
    var i,
        minl = Math.min(arr1.length, arr2.length);

    for (i = 0; i < minl; i += 1) {
      if (arr1[i] !== arr2[i]) {
        return i;
      }
    }

    return minl;
  }

  function normalizeLocale(key) {
    return key ? key.toLowerCase().replace('_', '-') : key;
  } // pick the locale from the array
  // try ['en-au', 'en-gb'] as 'en-au', 'en-gb', 'en', as in move through the list trying each
  // substring from most specific to least, but move to the next array item if it's a more specific variant than the current root


  function chooseLocale(names) {
    var i = 0,
        j,
        next,
        locale,
        split;

    while (i < names.length) {
      split = normalizeLocale(names[i]).split('-');
      j = split.length;
      next = normalizeLocale(names[i + 1]);
      next = next ? next.split('-') : null;

      while (j > 0) {
        locale = loadLocale(split.slice(0, j).join('-'));

        if (locale) {
          return locale;
        }

        if (next && next.length >= j && commonPrefix(split, next) >= j - 1) {
          //the next array item is better than a shallower substring of this one
          break;
        }

        j--;
      }

      i++;
    }

    return globalLocale;
  }

  function loadLocale(name) {
    var oldLocale = null,
        aliasedRequire; // TODO: Find a better way to register and load all the locales in Node

    if (locales[name] === undefined && typeof module !== 'undefined' && module && module.exports) {
      try {
        oldLocale = globalLocale._abbr;
        aliasedRequire = require;
        __webpack_require__("RnhZ")("./" + name);
        getSetGlobalLocale(oldLocale);
      } catch (e) {
        // mark as not found to avoid repeating expensive file require call causing high CPU
        // when trying to find en-US, en_US, en-us for every format call
        locales[name] = null; // null means not found
      }
    }

    return locales[name];
  } // This function will load locale and then set the global locale.  If
  // no arguments are passed in, it will simply return the current global
  // locale key.


  function getSetGlobalLocale(key, values) {
    var data;

    if (key) {
      if (isUndefined(values)) {
        data = getLocale(key);
      } else {
        data = defineLocale(key, values);
      }

      if (data) {
        // moment.duration._locale = moment._locale = data;
        globalLocale = data;
      } else {
        if (typeof console !== 'undefined' && console.warn) {
          //warn user if arguments are passed but the locale could not be set
          console.warn('Locale ' + key + ' not found. Did you forget to load it?');
        }
      }
    }

    return globalLocale._abbr;
  }

  function defineLocale(name, config) {
    if (config !== null) {
      var locale,
          parentConfig = baseConfig;
      config.abbr = name;

      if (locales[name] != null) {
        deprecateSimple('defineLocaleOverride', 'use moment.updateLocale(localeName, config) to change ' + 'an existing locale. moment.defineLocale(localeName, ' + 'config) should only be used for creating a new locale ' + 'See http://momentjs.com/guides/#/warnings/define-locale/ for more info.');
        parentConfig = locales[name]._config;
      } else if (config.parentLocale != null) {
        if (locales[config.parentLocale] != null) {
          parentConfig = locales[config.parentLocale]._config;
        } else {
          locale = loadLocale(config.parentLocale);

          if (locale != null) {
            parentConfig = locale._config;
          } else {
            if (!localeFamilies[config.parentLocale]) {
              localeFamilies[config.parentLocale] = [];
            }

            localeFamilies[config.parentLocale].push({
              name: name,
              config: config
            });
            return null;
          }
        }
      }

      locales[name] = new Locale(mergeConfigs(parentConfig, config));

      if (localeFamilies[name]) {
        localeFamilies[name].forEach(function (x) {
          defineLocale(x.name, x.config);
        });
      } // backwards compat for now: also set the locale
      // make sure we set the locale AFTER all child locales have been
      // created, so we won't end up with the child locale set.


      getSetGlobalLocale(name);
      return locales[name];
    } else {
      // useful for testing
      delete locales[name];
      return null;
    }
  }

  function updateLocale(name, config) {
    if (config != null) {
      var locale,
          tmpLocale,
          parentConfig = baseConfig;

      if (locales[name] != null && locales[name].parentLocale != null) {
        // Update existing child locale in-place to avoid memory-leaks
        locales[name].set(mergeConfigs(locales[name]._config, config));
      } else {
        // MERGE
        tmpLocale = loadLocale(name);

        if (tmpLocale != null) {
          parentConfig = tmpLocale._config;
        }

        config = mergeConfigs(parentConfig, config);

        if (tmpLocale == null) {
          // updateLocale is called for creating a new locale
          // Set abbr so it will have a name (getters return
          // undefined otherwise).
          config.abbr = name;
        }

        locale = new Locale(config);
        locale.parentLocale = locales[name];
        locales[name] = locale;
      } // backwards compat for now: also set the locale


      getSetGlobalLocale(name);
    } else {
      // pass null for config to unupdate, useful for tests
      if (locales[name] != null) {
        if (locales[name].parentLocale != null) {
          locales[name] = locales[name].parentLocale;

          if (name === getSetGlobalLocale()) {
            getSetGlobalLocale(name);
          }
        } else if (locales[name] != null) {
          delete locales[name];
        }
      }
    }

    return locales[name];
  } // returns locale data


  function getLocale(key) {
    var locale;

    if (key && key._locale && key._locale._abbr) {
      key = key._locale._abbr;
    }

    if (!key) {
      return globalLocale;
    }

    if (!isArray(key)) {
      //short-circuit everything else
      locale = loadLocale(key);

      if (locale) {
        return locale;
      }

      key = [key];
    }

    return chooseLocale(key);
  }

  function listLocales() {
    return keys(locales);
  }

  function checkOverflow(m) {
    var overflow,
        a = m._a;

    if (a && getParsingFlags(m).overflow === -2) {
      overflow = a[MONTH] < 0 || a[MONTH] > 11 ? MONTH : a[DATE] < 1 || a[DATE] > daysInMonth(a[YEAR], a[MONTH]) ? DATE : a[HOUR] < 0 || a[HOUR] > 24 || a[HOUR] === 24 && (a[MINUTE] !== 0 || a[SECOND] !== 0 || a[MILLISECOND] !== 0) ? HOUR : a[MINUTE] < 0 || a[MINUTE] > 59 ? MINUTE : a[SECOND] < 0 || a[SECOND] > 59 ? SECOND : a[MILLISECOND] < 0 || a[MILLISECOND] > 999 ? MILLISECOND : -1;

      if (getParsingFlags(m)._overflowDayOfYear && (overflow < YEAR || overflow > DATE)) {
        overflow = DATE;
      }

      if (getParsingFlags(m)._overflowWeeks && overflow === -1) {
        overflow = WEEK;
      }

      if (getParsingFlags(m)._overflowWeekday && overflow === -1) {
        overflow = WEEKDAY;
      }

      getParsingFlags(m).overflow = overflow;
    }

    return m;
  } // iso 8601 regex
  // 0000-00-00 0000-W00 or 0000-W00-0 + T + 00 or 00:00 or 00:00:00 or 00:00:00.000 + +00:00 or +0000 or +00)


  var extendedIsoRegex = /^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,
      basicIsoRegex = /^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d|))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,
      tzRegex = /Z|[+-]\d\d(?::?\d\d)?/,
      isoDates = [['YYYYYY-MM-DD', /[+-]\d{6}-\d\d-\d\d/], ['YYYY-MM-DD', /\d{4}-\d\d-\d\d/], ['GGGG-[W]WW-E', /\d{4}-W\d\d-\d/], ['GGGG-[W]WW', /\d{4}-W\d\d/, false], ['YYYY-DDD', /\d{4}-\d{3}/], ['YYYY-MM', /\d{4}-\d\d/, false], ['YYYYYYMMDD', /[+-]\d{10}/], ['YYYYMMDD', /\d{8}/], ['GGGG[W]WWE', /\d{4}W\d{3}/], ['GGGG[W]WW', /\d{4}W\d{2}/, false], ['YYYYDDD', /\d{7}/], ['YYYYMM', /\d{6}/, false], ['YYYY', /\d{4}/, false]],
      // iso time formats and regexes
  isoTimes = [['HH:mm:ss.SSSS', /\d\d:\d\d:\d\d\.\d+/], ['HH:mm:ss,SSSS', /\d\d:\d\d:\d\d,\d+/], ['HH:mm:ss', /\d\d:\d\d:\d\d/], ['HH:mm', /\d\d:\d\d/], ['HHmmss.SSSS', /\d\d\d\d\d\d\.\d+/], ['HHmmss,SSSS', /\d\d\d\d\d\d,\d+/], ['HHmmss', /\d\d\d\d\d\d/], ['HHmm', /\d\d\d\d/], ['HH', /\d\d/]],
      aspNetJsonRegex = /^\/?Date\((-?\d+)/i,
      // RFC 2822 regex: For details see https://tools.ietf.org/html/rfc2822#section-3.3
  rfc2822 = /^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/,
      obsOffsets = {
    UT: 0,
    GMT: 0,
    EDT: -4 * 60,
    EST: -5 * 60,
    CDT: -5 * 60,
    CST: -6 * 60,
    MDT: -6 * 60,
    MST: -7 * 60,
    PDT: -7 * 60,
    PST: -8 * 60
  }; // date from iso format

  function configFromISO(config) {
    var i,
        l,
        string = config._i,
        match = extendedIsoRegex.exec(string) || basicIsoRegex.exec(string),
        allowTime,
        dateFormat,
        timeFormat,
        tzFormat;

    if (match) {
      getParsingFlags(config).iso = true;

      for (i = 0, l = isoDates.length; i < l; i++) {
        if (isoDates[i][1].exec(match[1])) {
          dateFormat = isoDates[i][0];
          allowTime = isoDates[i][2] !== false;
          break;
        }
      }

      if (dateFormat == null) {
        config._isValid = false;
        return;
      }

      if (match[3]) {
        for (i = 0, l = isoTimes.length; i < l; i++) {
          if (isoTimes[i][1].exec(match[3])) {
            // match[2] should be 'T' or space
            timeFormat = (match[2] || ' ') + isoTimes[i][0];
            break;
          }
        }

        if (timeFormat == null) {
          config._isValid = false;
          return;
        }
      }

      if (!allowTime && timeFormat != null) {
        config._isValid = false;
        return;
      }

      if (match[4]) {
        if (tzRegex.exec(match[4])) {
          tzFormat = 'Z';
        } else {
          config._isValid = false;
          return;
        }
      }

      config._f = dateFormat + (timeFormat || '') + (tzFormat || '');
      configFromStringAndFormat(config);
    } else {
      config._isValid = false;
    }
  }

  function extractFromRFC2822Strings(yearStr, monthStr, dayStr, hourStr, minuteStr, secondStr) {
    var result = [untruncateYear(yearStr), defaultLocaleMonthsShort.indexOf(monthStr), parseInt(dayStr, 10), parseInt(hourStr, 10), parseInt(minuteStr, 10)];

    if (secondStr) {
      result.push(parseInt(secondStr, 10));
    }

    return result;
  }

  function untruncateYear(yearStr) {
    var year = parseInt(yearStr, 10);

    if (year <= 49) {
      return 2000 + year;
    } else if (year <= 999) {
      return 1900 + year;
    }

    return year;
  }

  function preprocessRFC2822(s) {
    // Remove comments and folding whitespace and replace multiple-spaces with a single space
    return s.replace(/\([^)]*\)|[\n\t]/g, ' ').replace(/(\s\s+)/g, ' ').replace(/^\s\s*/, '').replace(/\s\s*$/, '');
  }

  function checkWeekday(weekdayStr, parsedInput, config) {
    if (weekdayStr) {
      // TODO: Replace the vanilla JS Date object with an independent day-of-week check.
      var weekdayProvided = defaultLocaleWeekdaysShort.indexOf(weekdayStr),
          weekdayActual = new Date(parsedInput[0], parsedInput[1], parsedInput[2]).getDay();

      if (weekdayProvided !== weekdayActual) {
        getParsingFlags(config).weekdayMismatch = true;
        config._isValid = false;
        return false;
      }
    }

    return true;
  }

  function calculateOffset(obsOffset, militaryOffset, numOffset) {
    if (obsOffset) {
      return obsOffsets[obsOffset];
    } else if (militaryOffset) {
      // the only allowed military tz is Z
      return 0;
    } else {
      var hm = parseInt(numOffset, 10),
          m = hm % 100,
          h = (hm - m) / 100;
      return h * 60 + m;
    }
  } // date and time from ref 2822 format


  function configFromRFC2822(config) {
    var match = rfc2822.exec(preprocessRFC2822(config._i)),
        parsedArray;

    if (match) {
      parsedArray = extractFromRFC2822Strings(match[4], match[3], match[2], match[5], match[6], match[7]);

      if (!checkWeekday(match[1], parsedArray, config)) {
        return;
      }

      config._a = parsedArray;
      config._tzm = calculateOffset(match[8], match[9], match[10]);
      config._d = createUTCDate.apply(null, config._a);

      config._d.setUTCMinutes(config._d.getUTCMinutes() - config._tzm);

      getParsingFlags(config).rfc2822 = true;
    } else {
      config._isValid = false;
    }
  } // date from 1) ASP.NET, 2) ISO, 3) RFC 2822 formats, or 4) optional fallback if parsing isn't strict


  function configFromString(config) {
    var matched = aspNetJsonRegex.exec(config._i);

    if (matched !== null) {
      config._d = new Date(+matched[1]);
      return;
    }

    configFromISO(config);

    if (config._isValid === false) {
      delete config._isValid;
    } else {
      return;
    }

    configFromRFC2822(config);

    if (config._isValid === false) {
      delete config._isValid;
    } else {
      return;
    }

    if (config._strict) {
      config._isValid = false;
    } else {
      // Final attempt, use Input Fallback
      hooks.createFromInputFallback(config);
    }
  }

  hooks.createFromInputFallback = deprecate('value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), ' + 'which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are ' + 'discouraged and will be removed in an upcoming major release. Please refer to ' + 'http://momentjs.com/guides/#/warnings/js-date/ for more info.', function (config) {
    config._d = new Date(config._i + (config._useUTC ? ' UTC' : ''));
  }); // Pick the first defined of two or three arguments.

  function defaults(a, b, c) {
    if (a != null) {
      return a;
    }

    if (b != null) {
      return b;
    }

    return c;
  }

  function currentDateArray(config) {
    // hooks is actually the exported moment object
    var nowValue = new Date(hooks.now());

    if (config._useUTC) {
      return [nowValue.getUTCFullYear(), nowValue.getUTCMonth(), nowValue.getUTCDate()];
    }

    return [nowValue.getFullYear(), nowValue.getMonth(), nowValue.getDate()];
  } // convert an array to a date.
  // the array should mirror the parameters below
  // note: all values past the year are optional and will default to the lowest possible value.
  // [year, month, day , hour, minute, second, millisecond]


  function configFromArray(config) {
    var i,
        date,
        input = [],
        currentDate,
        expectedWeekday,
        yearToUse;

    if (config._d) {
      return;
    }

    currentDate = currentDateArray(config); //compute day of the year from weeks and weekdays

    if (config._w && config._a[DATE] == null && config._a[MONTH] == null) {
      dayOfYearFromWeekInfo(config);
    } //if the day of the year is set, figure out what it is


    if (config._dayOfYear != null) {
      yearToUse = defaults(config._a[YEAR], currentDate[YEAR]);

      if (config._dayOfYear > daysInYear(yearToUse) || config._dayOfYear === 0) {
        getParsingFlags(config)._overflowDayOfYear = true;
      }

      date = createUTCDate(yearToUse, 0, config._dayOfYear);
      config._a[MONTH] = date.getUTCMonth();
      config._a[DATE] = date.getUTCDate();
    } // Default to current date.
    // * if no year, month, day of month are given, default to today
    // * if day of month is given, default month and year
    // * if month is given, default only year
    // * if year is given, don't default anything


    for (i = 0; i < 3 && config._a[i] == null; ++i) {
      config._a[i] = input[i] = currentDate[i];
    } // Zero out whatever was not defaulted, including time


    for (; i < 7; i++) {
      config._a[i] = input[i] = config._a[i] == null ? i === 2 ? 1 : 0 : config._a[i];
    } // Check for 24:00:00.000


    if (config._a[HOUR] === 24 && config._a[MINUTE] === 0 && config._a[SECOND] === 0 && config._a[MILLISECOND] === 0) {
      config._nextDay = true;
      config._a[HOUR] = 0;
    }

    config._d = (config._useUTC ? createUTCDate : createDate).apply(null, input);
    expectedWeekday = config._useUTC ? config._d.getUTCDay() : config._d.getDay(); // Apply timezone offset from input. The actual utcOffset can be changed
    // with parseZone.

    if (config._tzm != null) {
      config._d.setUTCMinutes(config._d.getUTCMinutes() - config._tzm);
    }

    if (config._nextDay) {
      config._a[HOUR] = 24;
    } // check for mismatching day of week


    if (config._w && typeof config._w.d !== 'undefined' && config._w.d !== expectedWeekday) {
      getParsingFlags(config).weekdayMismatch = true;
    }
  }

  function dayOfYearFromWeekInfo(config) {
    var w, weekYear, week, weekday, dow, doy, temp, weekdayOverflow, curWeek;
    w = config._w;

    if (w.GG != null || w.W != null || w.E != null) {
      dow = 1;
      doy = 4; // TODO: We need to take the current isoWeekYear, but that depends on
      // how we interpret now (local, utc, fixed offset). So create
      // a now version of current config (take local/utc/offset flags, and
      // create now).

      weekYear = defaults(w.GG, config._a[YEAR], weekOfYear(createLocal(), 1, 4).year);
      week = defaults(w.W, 1);
      weekday = defaults(w.E, 1);

      if (weekday < 1 || weekday > 7) {
        weekdayOverflow = true;
      }
    } else {
      dow = config._locale._week.dow;
      doy = config._locale._week.doy;
      curWeek = weekOfYear(createLocal(), dow, doy);
      weekYear = defaults(w.gg, config._a[YEAR], curWeek.year); // Default to current week.

      week = defaults(w.w, curWeek.week);

      if (w.d != null) {
        // weekday -- low day numbers are considered next week
        weekday = w.d;

        if (weekday < 0 || weekday > 6) {
          weekdayOverflow = true;
        }
      } else if (w.e != null) {
        // local weekday -- counting starts from beginning of week
        weekday = w.e + dow;

        if (w.e < 0 || w.e > 6) {
          weekdayOverflow = true;
        }
      } else {
        // default to beginning of week
        weekday = dow;
      }
    }

    if (week < 1 || week > weeksInYear(weekYear, dow, doy)) {
      getParsingFlags(config)._overflowWeeks = true;
    } else if (weekdayOverflow != null) {
      getParsingFlags(config)._overflowWeekday = true;
    } else {
      temp = dayOfYearFromWeeks(weekYear, week, weekday, dow, doy);
      config._a[YEAR] = temp.year;
      config._dayOfYear = temp.dayOfYear;
    }
  } // constant that refers to the ISO standard


  hooks.ISO_8601 = function () {}; // constant that refers to the RFC 2822 form


  hooks.RFC_2822 = function () {}; // date from string and format string


  function configFromStringAndFormat(config) {
    // TODO: Move this to another part of the creation flow to prevent circular deps
    if (config._f === hooks.ISO_8601) {
      configFromISO(config);
      return;
    }

    if (config._f === hooks.RFC_2822) {
      configFromRFC2822(config);
      return;
    }

    config._a = [];
    getParsingFlags(config).empty = true; // This array is used to make a Date, either with `new Date` or `Date.UTC`

    var string = '' + config._i,
        i,
        parsedInput,
        tokens,
        token,
        skipped,
        stringLength = string.length,
        totalParsedInputLength = 0,
        era;
    tokens = expandFormat(config._f, config._locale).match(formattingTokens) || [];

    for (i = 0; i < tokens.length; i++) {
      token = tokens[i];
      parsedInput = (string.match(getParseRegexForToken(token, config)) || [])[0];

      if (parsedInput) {
        skipped = string.substr(0, string.indexOf(parsedInput));

        if (skipped.length > 0) {
          getParsingFlags(config).unusedInput.push(skipped);
        }

        string = string.slice(string.indexOf(parsedInput) + parsedInput.length);
        totalParsedInputLength += parsedInput.length;
      } // don't parse if it's not a known token


      if (formatTokenFunctions[token]) {
        if (parsedInput) {
          getParsingFlags(config).empty = false;
        } else {
          getParsingFlags(config).unusedTokens.push(token);
        }

        addTimeToArrayFromToken(token, parsedInput, config);
      } else if (config._strict && !parsedInput) {
        getParsingFlags(config).unusedTokens.push(token);
      }
    } // add remaining unparsed input length to the string


    getParsingFlags(config).charsLeftOver = stringLength - totalParsedInputLength;

    if (string.length > 0) {
      getParsingFlags(config).unusedInput.push(string);
    } // clear _12h flag if hour is <= 12


    if (config._a[HOUR] <= 12 && getParsingFlags(config).bigHour === true && config._a[HOUR] > 0) {
      getParsingFlags(config).bigHour = undefined;
    }

    getParsingFlags(config).parsedDateParts = config._a.slice(0);
    getParsingFlags(config).meridiem = config._meridiem; // handle meridiem

    config._a[HOUR] = meridiemFixWrap(config._locale, config._a[HOUR], config._meridiem); // handle era

    era = getParsingFlags(config).era;

    if (era !== null) {
      config._a[YEAR] = config._locale.erasConvertYear(era, config._a[YEAR]);
    }

    configFromArray(config);
    checkOverflow(config);
  }

  function meridiemFixWrap(locale, hour, meridiem) {
    var isPm;

    if (meridiem == null) {
      // nothing to do
      return hour;
    }

    if (locale.meridiemHour != null) {
      return locale.meridiemHour(hour, meridiem);
    } else if (locale.isPM != null) {
      // Fallback
      isPm = locale.isPM(meridiem);

      if (isPm && hour < 12) {
        hour += 12;
      }

      if (!isPm && hour === 12) {
        hour = 0;
      }

      return hour;
    } else {
      // this is not supposed to happen
      return hour;
    }
  } // date from string and array of format strings


  function configFromStringAndArray(config) {
    var tempConfig,
        bestMoment,
        scoreToBeat,
        i,
        currentScore,
        validFormatFound,
        bestFormatIsValid = false;

    if (config._f.length === 0) {
      getParsingFlags(config).invalidFormat = true;
      config._d = new Date(NaN);
      return;
    }

    for (i = 0; i < config._f.length; i++) {
      currentScore = 0;
      validFormatFound = false;
      tempConfig = copyConfig({}, config);

      if (config._useUTC != null) {
        tempConfig._useUTC = config._useUTC;
      }

      tempConfig._f = config._f[i];
      configFromStringAndFormat(tempConfig);

      if (isValid(tempConfig)) {
        validFormatFound = true;
      } // if there is any input that was not parsed add a penalty for that format


      currentScore += getParsingFlags(tempConfig).charsLeftOver; //or tokens

      currentScore += getParsingFlags(tempConfig).unusedTokens.length * 10;
      getParsingFlags(tempConfig).score = currentScore;

      if (!bestFormatIsValid) {
        if (scoreToBeat == null || currentScore < scoreToBeat || validFormatFound) {
          scoreToBeat = currentScore;
          bestMoment = tempConfig;

          if (validFormatFound) {
            bestFormatIsValid = true;
          }
        }
      } else {
        if (currentScore < scoreToBeat) {
          scoreToBeat = currentScore;
          bestMoment = tempConfig;
        }
      }
    }

    extend(config, bestMoment || tempConfig);
  }

  function configFromObject(config) {
    if (config._d) {
      return;
    }

    var i = normalizeObjectUnits(config._i),
        dayOrDate = i.day === undefined ? i.date : i.day;
    config._a = map([i.year, i.month, dayOrDate, i.hour, i.minute, i.second, i.millisecond], function (obj) {
      return obj && parseInt(obj, 10);
    });
    configFromArray(config);
  }

  function createFromConfig(config) {
    var res = new Moment(checkOverflow(prepareConfig(config)));

    if (res._nextDay) {
      // Adding is smart enough around DST
      res.add(1, 'd');
      res._nextDay = undefined;
    }

    return res;
  }

  function prepareConfig(config) {
    var input = config._i,
        format = config._f;
    config._locale = config._locale || getLocale(config._l);

    if (input === null || format === undefined && input === '') {
      return createInvalid({
        nullInput: true
      });
    }

    if (typeof input === 'string') {
      config._i = input = config._locale.preparse(input);
    }

    if (isMoment(input)) {
      return new Moment(checkOverflow(input));
    } else if (isDate(input)) {
      config._d = input;
    } else if (isArray(format)) {
      configFromStringAndArray(config);
    } else if (format) {
      configFromStringAndFormat(config);
    } else {
      configFromInput(config);
    }

    if (!isValid(config)) {
      config._d = null;
    }

    return config;
  }

  function configFromInput(config) {
    var input = config._i;

    if (isUndefined(input)) {
      config._d = new Date(hooks.now());
    } else if (isDate(input)) {
      config._d = new Date(input.valueOf());
    } else if (typeof input === 'string') {
      configFromString(config);
    } else if (isArray(input)) {
      config._a = map(input.slice(0), function (obj) {
        return parseInt(obj, 10);
      });
      configFromArray(config);
    } else if (isObject(input)) {
      configFromObject(config);
    } else if (isNumber(input)) {
      // from milliseconds
      config._d = new Date(input);
    } else {
      hooks.createFromInputFallback(config);
    }
  }

  function createLocalOrUTC(input, format, locale, strict, isUTC) {
    var c = {};

    if (format === true || format === false) {
      strict = format;
      format = undefined;
    }

    if (locale === true || locale === false) {
      strict = locale;
      locale = undefined;
    }

    if (isObject(input) && isObjectEmpty(input) || isArray(input) && input.length === 0) {
      input = undefined;
    } // object construction must be done this way.
    // https://github.com/moment/moment/issues/1423


    c._isAMomentObject = true;
    c._useUTC = c._isUTC = isUTC;
    c._l = locale;
    c._i = input;
    c._f = format;
    c._strict = strict;
    return createFromConfig(c);
  }

  function createLocal(input, format, locale, strict) {
    return createLocalOrUTC(input, format, locale, strict, false);
  }

  var prototypeMin = deprecate('moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/', function () {
    var other = createLocal.apply(null, arguments);

    if (this.isValid() && other.isValid()) {
      return other < this ? this : other;
    } else {
      return createInvalid();
    }
  }),
      prototypeMax = deprecate('moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/', function () {
    var other = createLocal.apply(null, arguments);

    if (this.isValid() && other.isValid()) {
      return other > this ? this : other;
    } else {
      return createInvalid();
    }
  }); // Pick a moment m from moments so that m[fn](other) is true for all
  // other. This relies on the function fn to be transitive.
  //
  // moments should either be an array of moment objects or an array, whose
  // first element is an array of moment objects.

  function pickBy(fn, moments) {
    var res, i;

    if (moments.length === 1 && isArray(moments[0])) {
      moments = moments[0];
    }

    if (!moments.length) {
      return createLocal();
    }

    res = moments[0];

    for (i = 1; i < moments.length; ++i) {
      if (!moments[i].isValid() || moments[i][fn](res)) {
        res = moments[i];
      }
    }

    return res;
  } // TODO: Use [].sort instead?


  function min() {
    var args = [].slice.call(arguments, 0);
    return pickBy('isBefore', args);
  }

  function max() {
    var args = [].slice.call(arguments, 0);
    return pickBy('isAfter', args);
  }

  var now = function now() {
    return Date.now ? Date.now() : +new Date();
  };

  var ordering = ['year', 'quarter', 'month', 'week', 'day', 'hour', 'minute', 'second', 'millisecond'];

  function isDurationValid(m) {
    var key,
        unitHasDecimal = false,
        i;

    for (key in m) {
      if (hasOwnProp(m, key) && !(indexOf.call(ordering, key) !== -1 && (m[key] == null || !isNaN(m[key])))) {
        return false;
      }
    }

    for (i = 0; i < ordering.length; ++i) {
      if (m[ordering[i]]) {
        if (unitHasDecimal) {
          return false; // only allow non-integers for smallest unit
        }

        if (parseFloat(m[ordering[i]]) !== toInt(m[ordering[i]])) {
          unitHasDecimal = true;
        }
      }
    }

    return true;
  }

  function isValid$1() {
    return this._isValid;
  }

  function createInvalid$1() {
    return createDuration(NaN);
  }

  function Duration(duration) {
    var normalizedInput = normalizeObjectUnits(duration),
        years = normalizedInput.year || 0,
        quarters = normalizedInput.quarter || 0,
        months = normalizedInput.month || 0,
        weeks = normalizedInput.week || normalizedInput.isoWeek || 0,
        days = normalizedInput.day || 0,
        hours = normalizedInput.hour || 0,
        minutes = normalizedInput.minute || 0,
        seconds = normalizedInput.second || 0,
        milliseconds = normalizedInput.millisecond || 0;
    this._isValid = isDurationValid(normalizedInput); // representation for dateAddRemove

    this._milliseconds = +milliseconds + seconds * 1e3 + // 1000
    minutes * 6e4 + // 1000 * 60
    hours * 1000 * 60 * 60; //using 1000 * 60 * 60 instead of 36e5 to avoid floating point rounding errors https://github.com/moment/moment/issues/2978
    // Because of dateAddRemove treats 24 hours as different from a
    // day when working around DST, we need to store them separately

    this._days = +days + weeks * 7; // It is impossible to translate months into days without knowing
    // which months you are are talking about, so we have to store
    // it separately.

    this._months = +months + quarters * 3 + years * 12;
    this._data = {};
    this._locale = getLocale();

    this._bubble();
  }

  function isDuration(obj) {
    return obj instanceof Duration;
  }

  function absRound(number) {
    if (number < 0) {
      return Math.round(-1 * number) * -1;
    } else {
      return Math.round(number);
    }
  } // compare two arrays, return the number of differences


  function compareArrays(array1, array2, dontConvert) {
    var len = Math.min(array1.length, array2.length),
        lengthDiff = Math.abs(array1.length - array2.length),
        diffs = 0,
        i;

    for (i = 0; i < len; i++) {
      if (dontConvert && array1[i] !== array2[i] || !dontConvert && toInt(array1[i]) !== toInt(array2[i])) {
        diffs++;
      }
    }

    return diffs + lengthDiff;
  } // FORMATTING


  function offset(token, separator) {
    addFormatToken(token, 0, 0, function () {
      var offset = this.utcOffset(),
          sign = '+';

      if (offset < 0) {
        offset = -offset;
        sign = '-';
      }

      return sign + zeroFill(~~(offset / 60), 2) + separator + zeroFill(~~offset % 60, 2);
    });
  }

  offset('Z', ':');
  offset('ZZ', ''); // PARSING

  addRegexToken('Z', matchShortOffset);
  addRegexToken('ZZ', matchShortOffset);
  addParseToken(['Z', 'ZZ'], function (input, array, config) {
    config._useUTC = true;
    config._tzm = offsetFromString(matchShortOffset, input);
  }); // HELPERS
  // timezone chunker
  // '+10:00' > ['10',  '00']
  // '-1530'  > ['-15', '30']

  var chunkOffset = /([\+\-]|\d\d)/gi;

  function offsetFromString(matcher, string) {
    var matches = (string || '').match(matcher),
        chunk,
        parts,
        minutes;

    if (matches === null) {
      return null;
    }

    chunk = matches[matches.length - 1] || [];
    parts = (chunk + '').match(chunkOffset) || ['-', 0, 0];
    minutes = +(parts[1] * 60) + toInt(parts[2]);
    return minutes === 0 ? 0 : parts[0] === '+' ? minutes : -minutes;
  } // Return a moment from input, that is local/utc/zone equivalent to model.


  function cloneWithOffset(input, model) {
    var res, diff;

    if (model._isUTC) {
      res = model.clone();
      diff = (isMoment(input) || isDate(input) ? input.valueOf() : createLocal(input).valueOf()) - res.valueOf(); // Use low-level api, because this fn is low-level api.

      res._d.setTime(res._d.valueOf() + diff);

      hooks.updateOffset(res, false);
      return res;
    } else {
      return createLocal(input).local();
    }
  }

  function getDateOffset(m) {
    // On Firefox.24 Date#getTimezoneOffset returns a floating point.
    // https://github.com/moment/moment/pull/1871
    return -Math.round(m._d.getTimezoneOffset());
  } // HOOKS
  // This function will be called whenever a moment is mutated.
  // It is intended to keep the offset in sync with the timezone.


  hooks.updateOffset = function () {}; // MOMENTS
  // keepLocalTime = true means only change the timezone, without
  // affecting the local hour. So 5:31:26 +0300 --[utcOffset(2, true)]-->
  // 5:31:26 +0200 It is possible that 5:31:26 doesn't exist with offset
  // +0200, so we adjust the time as needed, to be valid.
  //
  // Keeping the time actually adds/subtracts (one hour)
  // from the actual represented time. That is why we call updateOffset
  // a second time. In case it wants us to change the offset again
  // _changeInProgress == true case, then we have to adjust, because
  // there is no such time in the given timezone.


  function getSetOffset(input, keepLocalTime, keepMinutes) {
    var offset = this._offset || 0,
        localAdjust;

    if (!this.isValid()) {
      return input != null ? this : NaN;
    }

    if (input != null) {
      if (typeof input === 'string') {
        input = offsetFromString(matchShortOffset, input);

        if (input === null) {
          return this;
        }
      } else if (Math.abs(input) < 16 && !keepMinutes) {
        input = input * 60;
      }

      if (!this._isUTC && keepLocalTime) {
        localAdjust = getDateOffset(this);
      }

      this._offset = input;
      this._isUTC = true;

      if (localAdjust != null) {
        this.add(localAdjust, 'm');
      }

      if (offset !== input) {
        if (!keepLocalTime || this._changeInProgress) {
          addSubtract(this, createDuration(input - offset, 'm'), 1, false);
        } else if (!this._changeInProgress) {
          this._changeInProgress = true;
          hooks.updateOffset(this, true);
          this._changeInProgress = null;
        }
      }

      return this;
    } else {
      return this._isUTC ? offset : getDateOffset(this);
    }
  }

  function getSetZone(input, keepLocalTime) {
    if (input != null) {
      if (typeof input !== 'string') {
        input = -input;
      }

      this.utcOffset(input, keepLocalTime);
      return this;
    } else {
      return -this.utcOffset();
    }
  }

  function setOffsetToUTC(keepLocalTime) {
    return this.utcOffset(0, keepLocalTime);
  }

  function setOffsetToLocal(keepLocalTime) {
    if (this._isUTC) {
      this.utcOffset(0, keepLocalTime);
      this._isUTC = false;

      if (keepLocalTime) {
        this.subtract(getDateOffset(this), 'm');
      }
    }

    return this;
  }

  function setOffsetToParsedOffset() {
    if (this._tzm != null) {
      this.utcOffset(this._tzm, false, true);
    } else if (typeof this._i === 'string') {
      var tZone = offsetFromString(matchOffset, this._i);

      if (tZone != null) {
        this.utcOffset(tZone);
      } else {
        this.utcOffset(0, true);
      }
    }

    return this;
  }

  function hasAlignedHourOffset(input) {
    if (!this.isValid()) {
      return false;
    }

    input = input ? createLocal(input).utcOffset() : 0;
    return (this.utcOffset() - input) % 60 === 0;
  }

  function isDaylightSavingTime() {
    return this.utcOffset() > this.clone().month(0).utcOffset() || this.utcOffset() > this.clone().month(5).utcOffset();
  }

  function isDaylightSavingTimeShifted() {
    if (!isUndefined(this._isDSTShifted)) {
      return this._isDSTShifted;
    }

    var c = {},
        other;
    copyConfig(c, this);
    c = prepareConfig(c);

    if (c._a) {
      other = c._isUTC ? createUTC(c._a) : createLocal(c._a);
      this._isDSTShifted = this.isValid() && compareArrays(c._a, other.toArray()) > 0;
    } else {
      this._isDSTShifted = false;
    }

    return this._isDSTShifted;
  }

  function isLocal() {
    return this.isValid() ? !this._isUTC : false;
  }

  function isUtcOffset() {
    return this.isValid() ? this._isUTC : false;
  }

  function isUtc() {
    return this.isValid() ? this._isUTC && this._offset === 0 : false;
  } // ASP.NET json date format regex


  var aspNetRegex = /^(-|\+)?(?:(\d*)[. ])?(\d+):(\d+)(?::(\d+)(\.\d*)?)?$/,
      // from http://docs.closure-library.googlecode.com/git/closure_goog_date_date.js.source.html
  // somewhat more in line with 4.4.3.2 2004 spec, but allows decimal anywhere
  // and further modified to allow for strings containing both week and day
  isoRegex = /^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;

  function createDuration(input, key) {
    var duration = input,
        // matching against regexp is expensive, do it on demand
    match = null,
        sign,
        ret,
        diffRes;

    if (isDuration(input)) {
      duration = {
        ms: input._milliseconds,
        d: input._days,
        M: input._months
      };
    } else if (isNumber(input) || !isNaN(+input)) {
      duration = {};

      if (key) {
        duration[key] = +input;
      } else {
        duration.milliseconds = +input;
      }
    } else if (match = aspNetRegex.exec(input)) {
      sign = match[1] === '-' ? -1 : 1;
      duration = {
        y: 0,
        d: toInt(match[DATE]) * sign,
        h: toInt(match[HOUR]) * sign,
        m: toInt(match[MINUTE]) * sign,
        s: toInt(match[SECOND]) * sign,
        ms: toInt(absRound(match[MILLISECOND] * 1000)) * sign // the millisecond decimal point is included in the match

      };
    } else if (match = isoRegex.exec(input)) {
      sign = match[1] === '-' ? -1 : 1;
      duration = {
        y: parseIso(match[2], sign),
        M: parseIso(match[3], sign),
        w: parseIso(match[4], sign),
        d: parseIso(match[5], sign),
        h: parseIso(match[6], sign),
        m: parseIso(match[7], sign),
        s: parseIso(match[8], sign)
      };
    } else if (duration == null) {
      // checks for null or undefined
      duration = {};
    } else if (typeof duration === 'object' && ('from' in duration || 'to' in duration)) {
      diffRes = momentsDifference(createLocal(duration.from), createLocal(duration.to));
      duration = {};
      duration.ms = diffRes.milliseconds;
      duration.M = diffRes.months;
    }

    ret = new Duration(duration);

    if (isDuration(input) && hasOwnProp(input, '_locale')) {
      ret._locale = input._locale;
    }

    if (isDuration(input) && hasOwnProp(input, '_isValid')) {
      ret._isValid = input._isValid;
    }

    return ret;
  }

  createDuration.fn = Duration.prototype;
  createDuration.invalid = createInvalid$1;

  function parseIso(inp, sign) {
    // We'd normally use ~~inp for this, but unfortunately it also
    // converts floats to ints.
    // inp may be undefined, so careful calling replace on it.
    var res = inp && parseFloat(inp.replace(',', '.')); // apply sign while we're at it

    return (isNaN(res) ? 0 : res) * sign;
  }

  function positiveMomentsDifference(base, other) {
    var res = {};
    res.months = other.month() - base.month() + (other.year() - base.year()) * 12;

    if (base.clone().add(res.months, 'M').isAfter(other)) {
      --res.months;
    }

    res.milliseconds = +other - +base.clone().add(res.months, 'M');
    return res;
  }

  function momentsDifference(base, other) {
    var res;

    if (!(base.isValid() && other.isValid())) {
      return {
        milliseconds: 0,
        months: 0
      };
    }

    other = cloneWithOffset(other, base);

    if (base.isBefore(other)) {
      res = positiveMomentsDifference(base, other);
    } else {
      res = positiveMomentsDifference(other, base);
      res.milliseconds = -res.milliseconds;
      res.months = -res.months;
    }

    return res;
  } // TODO: remove 'name' arg after deprecation is removed


  function createAdder(direction, name) {
    return function (val, period) {
      var dur, tmp; //invert the arguments, but complain about it

      if (period !== null && !isNaN(+period)) {
        deprecateSimple(name, 'moment().' + name + '(period, number) is deprecated. Please use moment().' + name + '(number, period). ' + 'See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info.');
        tmp = val;
        val = period;
        period = tmp;
      }

      dur = createDuration(val, period);
      addSubtract(this, dur, direction);
      return this;
    };
  }

  function addSubtract(mom, duration, isAdding, updateOffset) {
    var milliseconds = duration._milliseconds,
        days = absRound(duration._days),
        months = absRound(duration._months);

    if (!mom.isValid()) {
      // No op
      return;
    }

    updateOffset = updateOffset == null ? true : updateOffset;

    if (months) {
      setMonth(mom, get(mom, 'Month') + months * isAdding);
    }

    if (days) {
      set$1(mom, 'Date', get(mom, 'Date') + days * isAdding);
    }

    if (milliseconds) {
      mom._d.setTime(mom._d.valueOf() + milliseconds * isAdding);
    }

    if (updateOffset) {
      hooks.updateOffset(mom, days || months);
    }
  }

  var add = createAdder(1, 'add'),
      subtract = createAdder(-1, 'subtract');

  function isString(input) {
    return typeof input === 'string' || input instanceof String;
  } // type MomentInput = Moment | Date | string | number | (number | string)[] | MomentInputObject | void; // null | undefined


  function isMomentInput(input) {
    return isMoment(input) || isDate(input) || isString(input) || isNumber(input) || isNumberOrStringArray(input) || isMomentInputObject(input) || input === null || input === undefined;
  }

  function isMomentInputObject(input) {
    var objectTest = isObject(input) && !isObjectEmpty(input),
        propertyTest = false,
        properties = ['years', 'year', 'y', 'months', 'month', 'M', 'days', 'day', 'd', 'dates', 'date', 'D', 'hours', 'hour', 'h', 'minutes', 'minute', 'm', 'seconds', 'second', 's', 'milliseconds', 'millisecond', 'ms'],
        i,
        property;

    for (i = 0; i < properties.length; i += 1) {
      property = properties[i];
      propertyTest = propertyTest || hasOwnProp(input, property);
    }

    return objectTest && propertyTest;
  }

  function isNumberOrStringArray(input) {
    var arrayTest = isArray(input),
        dataTypeTest = false;

    if (arrayTest) {
      dataTypeTest = input.filter(function (item) {
        return !isNumber(item) && isString(input);
      }).length === 0;
    }

    return arrayTest && dataTypeTest;
  }

  function isCalendarSpec(input) {
    var objectTest = isObject(input) && !isObjectEmpty(input),
        propertyTest = false,
        properties = ['sameDay', 'nextDay', 'lastDay', 'nextWeek', 'lastWeek', 'sameElse'],
        i,
        property;

    for (i = 0; i < properties.length; i += 1) {
      property = properties[i];
      propertyTest = propertyTest || hasOwnProp(input, property);
    }

    return objectTest && propertyTest;
  }

  function getCalendarFormat(myMoment, now) {
    var diff = myMoment.diff(now, 'days', true);
    return diff < -6 ? 'sameElse' : diff < -1 ? 'lastWeek' : diff < 0 ? 'lastDay' : diff < 1 ? 'sameDay' : diff < 2 ? 'nextDay' : diff < 7 ? 'nextWeek' : 'sameElse';
  }

  function calendar$1(time, formats) {
    // Support for single parameter, formats only overload to the calendar function
    if (arguments.length === 1) {
      if (!arguments[0]) {
        time = undefined;
        formats = undefined;
      } else if (isMomentInput(arguments[0])) {
        time = arguments[0];
        formats = undefined;
      } else if (isCalendarSpec(arguments[0])) {
        formats = arguments[0];
        time = undefined;
      }
    } // We want to compare the start of today, vs this.
    // Getting start-of-today depends on whether we're local/utc/offset or not.


    var now = time || createLocal(),
        sod = cloneWithOffset(now, this).startOf('day'),
        format = hooks.calendarFormat(this, sod) || 'sameElse',
        output = formats && (isFunction(formats[format]) ? formats[format].call(this, now) : formats[format]);
    return this.format(output || this.localeData().calendar(format, this, createLocal(now)));
  }

  function clone() {
    return new Moment(this);
  }

  function isAfter(input, units) {
    var localInput = isMoment(input) ? input : createLocal(input);

    if (!(this.isValid() && localInput.isValid())) {
      return false;
    }

    units = normalizeUnits(units) || 'millisecond';

    if (units === 'millisecond') {
      return this.valueOf() > localInput.valueOf();
    } else {
      return localInput.valueOf() < this.clone().startOf(units).valueOf();
    }
  }

  function isBefore(input, units) {
    var localInput = isMoment(input) ? input : createLocal(input);

    if (!(this.isValid() && localInput.isValid())) {
      return false;
    }

    units = normalizeUnits(units) || 'millisecond';

    if (units === 'millisecond') {
      return this.valueOf() < localInput.valueOf();
    } else {
      return this.clone().endOf(units).valueOf() < localInput.valueOf();
    }
  }

  function isBetween(from, to, units, inclusivity) {
    var localFrom = isMoment(from) ? from : createLocal(from),
        localTo = isMoment(to) ? to : createLocal(to);

    if (!(this.isValid() && localFrom.isValid() && localTo.isValid())) {
      return false;
    }

    inclusivity = inclusivity || '()';
    return (inclusivity[0] === '(' ? this.isAfter(localFrom, units) : !this.isBefore(localFrom, units)) && (inclusivity[1] === ')' ? this.isBefore(localTo, units) : !this.isAfter(localTo, units));
  }

  function isSame(input, units) {
    var localInput = isMoment(input) ? input : createLocal(input),
        inputMs;

    if (!(this.isValid() && localInput.isValid())) {
      return false;
    }

    units = normalizeUnits(units) || 'millisecond';

    if (units === 'millisecond') {
      return this.valueOf() === localInput.valueOf();
    } else {
      inputMs = localInput.valueOf();
      return this.clone().startOf(units).valueOf() <= inputMs && inputMs <= this.clone().endOf(units).valueOf();
    }
  }

  function isSameOrAfter(input, units) {
    return this.isSame(input, units) || this.isAfter(input, units);
  }

  function isSameOrBefore(input, units) {
    return this.isSame(input, units) || this.isBefore(input, units);
  }

  function diff(input, units, asFloat) {
    var that, zoneDelta, output;

    if (!this.isValid()) {
      return NaN;
    }

    that = cloneWithOffset(input, this);

    if (!that.isValid()) {
      return NaN;
    }

    zoneDelta = (that.utcOffset() - this.utcOffset()) * 6e4;
    units = normalizeUnits(units);

    switch (units) {
      case 'year':
        output = monthDiff(this, that) / 12;
        break;

      case 'month':
        output = monthDiff(this, that);
        break;

      case 'quarter':
        output = monthDiff(this, that) / 3;
        break;

      case 'second':
        output = (this - that) / 1e3;
        break;
      // 1000

      case 'minute':
        output = (this - that) / 6e4;
        break;
      // 1000 * 60

      case 'hour':
        output = (this - that) / 36e5;
        break;
      // 1000 * 60 * 60

      case 'day':
        output = (this - that - zoneDelta) / 864e5;
        break;
      // 1000 * 60 * 60 * 24, negate dst

      case 'week':
        output = (this - that - zoneDelta) / 6048e5;
        break;
      // 1000 * 60 * 60 * 24 * 7, negate dst

      default:
        output = this - that;
    }

    return asFloat ? output : absFloor(output);
  }

  function monthDiff(a, b) {
    if (a.date() < b.date()) {
      // end-of-month calculations work correct when the start month has more
      // days than the end month.
      return -monthDiff(b, a);
    } // difference in months


    var wholeMonthDiff = (b.year() - a.year()) * 12 + (b.month() - a.month()),
        // b is in (anchor - 1 month, anchor + 1 month)
    anchor = a.clone().add(wholeMonthDiff, 'months'),
        anchor2,
        adjust;

    if (b - anchor < 0) {
      anchor2 = a.clone().add(wholeMonthDiff - 1, 'months'); // linear across the month

      adjust = (b - anchor) / (anchor - anchor2);
    } else {
      anchor2 = a.clone().add(wholeMonthDiff + 1, 'months'); // linear across the month

      adjust = (b - anchor) / (anchor2 - anchor);
    } //check for negative zero, return zero if negative zero


    return -(wholeMonthDiff + adjust) || 0;
  }

  hooks.defaultFormat = 'YYYY-MM-DDTHH:mm:ssZ';
  hooks.defaultFormatUtc = 'YYYY-MM-DDTHH:mm:ss[Z]';

  function toString() {
    return this.clone().locale('en').format('ddd MMM DD YYYY HH:mm:ss [GMT]ZZ');
  }

  function toISOString(keepOffset) {
    if (!this.isValid()) {
      return null;
    }

    var utc = keepOffset !== true,
        m = utc ? this.clone().utc() : this;

    if (m.year() < 0 || m.year() > 9999) {
      return formatMoment(m, utc ? 'YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]' : 'YYYYYY-MM-DD[T]HH:mm:ss.SSSZ');
    }

    if (isFunction(Date.prototype.toISOString)) {
      // native implementation is ~50x faster, use it when we can
      if (utc) {
        return this.toDate().toISOString();
      } else {
        return new Date(this.valueOf() + this.utcOffset() * 60 * 1000).toISOString().replace('Z', formatMoment(m, 'Z'));
      }
    }

    return formatMoment(m, utc ? 'YYYY-MM-DD[T]HH:mm:ss.SSS[Z]' : 'YYYY-MM-DD[T]HH:mm:ss.SSSZ');
  }
  /**
   * Return a human readable representation of a moment that can
   * also be evaluated to get a new moment which is the same
   *
   * @link https://nodejs.org/dist/latest/docs/api/util.html#util_custom_inspect_function_on_objects
   */


  function inspect() {
    if (!this.isValid()) {
      return 'moment.invalid(/* ' + this._i + ' */)';
    }

    var func = 'moment',
        zone = '',
        prefix,
        year,
        datetime,
        suffix;

    if (!this.isLocal()) {
      func = this.utcOffset() === 0 ? 'moment.utc' : 'moment.parseZone';
      zone = 'Z';
    }

    prefix = '[' + func + '("]';
    year = 0 <= this.year() && this.year() <= 9999 ? 'YYYY' : 'YYYYYY';
    datetime = '-MM-DD[T]HH:mm:ss.SSS';
    suffix = zone + '[")]';
    return this.format(prefix + year + datetime + suffix);
  }

  function format(inputString) {
    if (!inputString) {
      inputString = this.isUtc() ? hooks.defaultFormatUtc : hooks.defaultFormat;
    }

    var output = formatMoment(this, inputString);
    return this.localeData().postformat(output);
  }

  function from(time, withoutSuffix) {
    if (this.isValid() && (isMoment(time) && time.isValid() || createLocal(time).isValid())) {
      return createDuration({
        to: this,
        from: time
      }).locale(this.locale()).humanize(!withoutSuffix);
    } else {
      return this.localeData().invalidDate();
    }
  }

  function fromNow(withoutSuffix) {
    return this.from(createLocal(), withoutSuffix);
  }

  function to(time, withoutSuffix) {
    if (this.isValid() && (isMoment(time) && time.isValid() || createLocal(time).isValid())) {
      return createDuration({
        from: this,
        to: time
      }).locale(this.locale()).humanize(!withoutSuffix);
    } else {
      return this.localeData().invalidDate();
    }
  }

  function toNow(withoutSuffix) {
    return this.to(createLocal(), withoutSuffix);
  } // If passed a locale key, it will set the locale for this
  // instance.  Otherwise, it will return the locale configuration
  // variables for this instance.


  function locale(key) {
    var newLocaleData;

    if (key === undefined) {
      return this._locale._abbr;
    } else {
      newLocaleData = getLocale(key);

      if (newLocaleData != null) {
        this._locale = newLocaleData;
      }

      return this;
    }
  }

  var lang = deprecate('moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.', function (key) {
    if (key === undefined) {
      return this.localeData();
    } else {
      return this.locale(key);
    }
  });

  function localeData() {
    return this._locale;
  }

  var MS_PER_SECOND = 1000,
      MS_PER_MINUTE = 60 * MS_PER_SECOND,
      MS_PER_HOUR = 60 * MS_PER_MINUTE,
      MS_PER_400_YEARS = (365 * 400 + 97) * 24 * MS_PER_HOUR; // actual modulo - handles negative numbers (for dates before 1970):

  function mod$1(dividend, divisor) {
    return (dividend % divisor + divisor) % divisor;
  }

  function localStartOfDate(y, m, d) {
    // the date constructor remaps years 0-99 to 1900-1999
    if (y < 100 && y >= 0) {
      // preserve leap years using a full 400 year cycle, then reset
      return new Date(y + 400, m, d) - MS_PER_400_YEARS;
    } else {
      return new Date(y, m, d).valueOf();
    }
  }

  function utcStartOfDate(y, m, d) {
    // Date.UTC remaps years 0-99 to 1900-1999
    if (y < 100 && y >= 0) {
      // preserve leap years using a full 400 year cycle, then reset
      return Date.UTC(y + 400, m, d) - MS_PER_400_YEARS;
    } else {
      return Date.UTC(y, m, d);
    }
  }

  function startOf(units) {
    var time, startOfDate;
    units = normalizeUnits(units);

    if (units === undefined || units === 'millisecond' || !this.isValid()) {
      return this;
    }

    startOfDate = this._isUTC ? utcStartOfDate : localStartOfDate;

    switch (units) {
      case 'year':
        time = startOfDate(this.year(), 0, 1);
        break;

      case 'quarter':
        time = startOfDate(this.year(), this.month() - this.month() % 3, 1);
        break;

      case 'month':
        time = startOfDate(this.year(), this.month(), 1);
        break;

      case 'week':
        time = startOfDate(this.year(), this.month(), this.date() - this.weekday());
        break;

      case 'isoWeek':
        time = startOfDate(this.year(), this.month(), this.date() - (this.isoWeekday() - 1));
        break;

      case 'day':
      case 'date':
        time = startOfDate(this.year(), this.month(), this.date());
        break;

      case 'hour':
        time = this._d.valueOf();
        time -= mod$1(time + (this._isUTC ? 0 : this.utcOffset() * MS_PER_MINUTE), MS_PER_HOUR);
        break;

      case 'minute':
        time = this._d.valueOf();
        time -= mod$1(time, MS_PER_MINUTE);
        break;

      case 'second':
        time = this._d.valueOf();
        time -= mod$1(time, MS_PER_SECOND);
        break;
    }

    this._d.setTime(time);

    hooks.updateOffset(this, true);
    return this;
  }

  function endOf(units) {
    var time, startOfDate;
    units = normalizeUnits(units);

    if (units === undefined || units === 'millisecond' || !this.isValid()) {
      return this;
    }

    startOfDate = this._isUTC ? utcStartOfDate : localStartOfDate;

    switch (units) {
      case 'year':
        time = startOfDate(this.year() + 1, 0, 1) - 1;
        break;

      case 'quarter':
        time = startOfDate(this.year(), this.month() - this.month() % 3 + 3, 1) - 1;
        break;

      case 'month':
        time = startOfDate(this.year(), this.month() + 1, 1) - 1;
        break;

      case 'week':
        time = startOfDate(this.year(), this.month(), this.date() - this.weekday() + 7) - 1;
        break;

      case 'isoWeek':
        time = startOfDate(this.year(), this.month(), this.date() - (this.isoWeekday() - 1) + 7) - 1;
        break;

      case 'day':
      case 'date':
        time = startOfDate(this.year(), this.month(), this.date() + 1) - 1;
        break;

      case 'hour':
        time = this._d.valueOf();
        time += MS_PER_HOUR - mod$1(time + (this._isUTC ? 0 : this.utcOffset() * MS_PER_MINUTE), MS_PER_HOUR) - 1;
        break;

      case 'minute':
        time = this._d.valueOf();
        time += MS_PER_MINUTE - mod$1(time, MS_PER_MINUTE) - 1;
        break;

      case 'second':
        time = this._d.valueOf();
        time += MS_PER_SECOND - mod$1(time, MS_PER_SECOND) - 1;
        break;
    }

    this._d.setTime(time);

    hooks.updateOffset(this, true);
    return this;
  }

  function valueOf() {
    return this._d.valueOf() - (this._offset || 0) * 60000;
  }

  function unix() {
    return Math.floor(this.valueOf() / 1000);
  }

  function toDate() {
    return new Date(this.valueOf());
  }

  function toArray() {
    var m = this;
    return [m.year(), m.month(), m.date(), m.hour(), m.minute(), m.second(), m.millisecond()];
  }

  function toObject() {
    var m = this;
    return {
      years: m.year(),
      months: m.month(),
      date: m.date(),
      hours: m.hours(),
      minutes: m.minutes(),
      seconds: m.seconds(),
      milliseconds: m.milliseconds()
    };
  }

  function toJSON() {
    // new Date(NaN).toJSON() === null
    return this.isValid() ? this.toISOString() : null;
  }

  function isValid$2() {
    return isValid(this);
  }

  function parsingFlags() {
    return extend({}, getParsingFlags(this));
  }

  function invalidAt() {
    return getParsingFlags(this).overflow;
  }

  function creationData() {
    return {
      input: this._i,
      format: this._f,
      locale: this._locale,
      isUTC: this._isUTC,
      strict: this._strict
    };
  }

  addFormatToken('N', 0, 0, 'eraAbbr');
  addFormatToken('NN', 0, 0, 'eraAbbr');
  addFormatToken('NNN', 0, 0, 'eraAbbr');
  addFormatToken('NNNN', 0, 0, 'eraName');
  addFormatToken('NNNNN', 0, 0, 'eraNarrow');
  addFormatToken('y', ['y', 1], 'yo', 'eraYear');
  addFormatToken('y', ['yy', 2], 0, 'eraYear');
  addFormatToken('y', ['yyy', 3], 0, 'eraYear');
  addFormatToken('y', ['yyyy', 4], 0, 'eraYear');
  addRegexToken('N', matchEraAbbr);
  addRegexToken('NN', matchEraAbbr);
  addRegexToken('NNN', matchEraAbbr);
  addRegexToken('NNNN', matchEraName);
  addRegexToken('NNNNN', matchEraNarrow);
  addParseToken(['N', 'NN', 'NNN', 'NNNN', 'NNNNN'], function (input, array, config, token) {
    var era = config._locale.erasParse(input, token, config._strict);

    if (era) {
      getParsingFlags(config).era = era;
    } else {
      getParsingFlags(config).invalidEra = input;
    }
  });
  addRegexToken('y', matchUnsigned);
  addRegexToken('yy', matchUnsigned);
  addRegexToken('yyy', matchUnsigned);
  addRegexToken('yyyy', matchUnsigned);
  addRegexToken('yo', matchEraYearOrdinal);
  addParseToken(['y', 'yy', 'yyy', 'yyyy'], YEAR);
  addParseToken(['yo'], function (input, array, config, token) {
    var match;

    if (config._locale._eraYearOrdinalRegex) {
      match = input.match(config._locale._eraYearOrdinalRegex);
    }

    if (config._locale.eraYearOrdinalParse) {
      array[YEAR] = config._locale.eraYearOrdinalParse(input, match);
    } else {
      array[YEAR] = parseInt(input, 10);
    }
  });

  function localeEras(m, format) {
    var i,
        l,
        date,
        eras = this._eras || getLocale('en')._eras;

    for (i = 0, l = eras.length; i < l; ++i) {
      switch (typeof eras[i].since) {
        case 'string':
          // truncate time
          date = hooks(eras[i].since).startOf('day');
          eras[i].since = date.valueOf();
          break;
      }

      switch (typeof eras[i].until) {
        case 'undefined':
          eras[i].until = +Infinity;
          break;

        case 'string':
          // truncate time
          date = hooks(eras[i].until).startOf('day').valueOf();
          eras[i].until = date.valueOf();
          break;
      }
    }

    return eras;
  }

  function localeErasParse(eraName, format, strict) {
    var i,
        l,
        eras = this.eras(),
        name,
        abbr,
        narrow;
    eraName = eraName.toUpperCase();

    for (i = 0, l = eras.length; i < l; ++i) {
      name = eras[i].name.toUpperCase();
      abbr = eras[i].abbr.toUpperCase();
      narrow = eras[i].narrow.toUpperCase();

      if (strict) {
        switch (format) {
          case 'N':
          case 'NN':
          case 'NNN':
            if (abbr === eraName) {
              return eras[i];
            }

            break;

          case 'NNNN':
            if (name === eraName) {
              return eras[i];
            }

            break;

          case 'NNNNN':
            if (narrow === eraName) {
              return eras[i];
            }

            break;
        }
      } else if ([name, abbr, narrow].indexOf(eraName) >= 0) {
        return eras[i];
      }
    }
  }

  function localeErasConvertYear(era, year) {
    var dir = era.since <= era.until ? +1 : -1;

    if (year === undefined) {
      return hooks(era.since).year();
    } else {
      return hooks(era.since).year() + (year - era.offset) * dir;
    }
  }

  function getEraName() {
    var i,
        l,
        val,
        eras = this.localeData().eras();

    for (i = 0, l = eras.length; i < l; ++i) {
      // truncate time
      val = this.clone().startOf('day').valueOf();

      if (eras[i].since <= val && val <= eras[i].until) {
        return eras[i].name;
      }

      if (eras[i].until <= val && val <= eras[i].since) {
        return eras[i].name;
      }
    }

    return '';
  }

  function getEraNarrow() {
    var i,
        l,
        val,
        eras = this.localeData().eras();

    for (i = 0, l = eras.length; i < l; ++i) {
      // truncate time
      val = this.clone().startOf('day').valueOf();

      if (eras[i].since <= val && val <= eras[i].until) {
        return eras[i].narrow;
      }

      if (eras[i].until <= val && val <= eras[i].since) {
        return eras[i].narrow;
      }
    }

    return '';
  }

  function getEraAbbr() {
    var i,
        l,
        val,
        eras = this.localeData().eras();

    for (i = 0, l = eras.length; i < l; ++i) {
      // truncate time
      val = this.clone().startOf('day').valueOf();

      if (eras[i].since <= val && val <= eras[i].until) {
        return eras[i].abbr;
      }

      if (eras[i].until <= val && val <= eras[i].since) {
        return eras[i].abbr;
      }
    }

    return '';
  }

  function getEraYear() {
    var i,
        l,
        dir,
        val,
        eras = this.localeData().eras();

    for (i = 0, l = eras.length; i < l; ++i) {
      dir = eras[i].since <= eras[i].until ? +1 : -1; // truncate time

      val = this.clone().startOf('day').valueOf();

      if (eras[i].since <= val && val <= eras[i].until || eras[i].until <= val && val <= eras[i].since) {
        return (this.year() - hooks(eras[i].since).year()) * dir + eras[i].offset;
      }
    }

    return this.year();
  }

  function erasNameRegex(isStrict) {
    if (!hasOwnProp(this, '_erasNameRegex')) {
      computeErasParse.call(this);
    }

    return isStrict ? this._erasNameRegex : this._erasRegex;
  }

  function erasAbbrRegex(isStrict) {
    if (!hasOwnProp(this, '_erasAbbrRegex')) {
      computeErasParse.call(this);
    }

    return isStrict ? this._erasAbbrRegex : this._erasRegex;
  }

  function erasNarrowRegex(isStrict) {
    if (!hasOwnProp(this, '_erasNarrowRegex')) {
      computeErasParse.call(this);
    }

    return isStrict ? this._erasNarrowRegex : this._erasRegex;
  }

  function matchEraAbbr(isStrict, locale) {
    return locale.erasAbbrRegex(isStrict);
  }

  function matchEraName(isStrict, locale) {
    return locale.erasNameRegex(isStrict);
  }

  function matchEraNarrow(isStrict, locale) {
    return locale.erasNarrowRegex(isStrict);
  }

  function matchEraYearOrdinal(isStrict, locale) {
    return locale._eraYearOrdinalRegex || matchUnsigned;
  }

  function computeErasParse() {
    var abbrPieces = [],
        namePieces = [],
        narrowPieces = [],
        mixedPieces = [],
        i,
        l,
        eras = this.eras();

    for (i = 0, l = eras.length; i < l; ++i) {
      namePieces.push(regexEscape(eras[i].name));
      abbrPieces.push(regexEscape(eras[i].abbr));
      narrowPieces.push(regexEscape(eras[i].narrow));
      mixedPieces.push(regexEscape(eras[i].name));
      mixedPieces.push(regexEscape(eras[i].abbr));
      mixedPieces.push(regexEscape(eras[i].narrow));
    }

    this._erasRegex = new RegExp('^(' + mixedPieces.join('|') + ')', 'i');
    this._erasNameRegex = new RegExp('^(' + namePieces.join('|') + ')', 'i');
    this._erasAbbrRegex = new RegExp('^(' + abbrPieces.join('|') + ')', 'i');
    this._erasNarrowRegex = new RegExp('^(' + narrowPieces.join('|') + ')', 'i');
  } // FORMATTING


  addFormatToken(0, ['gg', 2], 0, function () {
    return this.weekYear() % 100;
  });
  addFormatToken(0, ['GG', 2], 0, function () {
    return this.isoWeekYear() % 100;
  });

  function addWeekYearFormatToken(token, getter) {
    addFormatToken(0, [token, token.length], 0, getter);
  }

  addWeekYearFormatToken('gggg', 'weekYear');
  addWeekYearFormatToken('ggggg', 'weekYear');
  addWeekYearFormatToken('GGGG', 'isoWeekYear');
  addWeekYearFormatToken('GGGGG', 'isoWeekYear'); // ALIASES

  addUnitAlias('weekYear', 'gg');
  addUnitAlias('isoWeekYear', 'GG'); // PRIORITY

  addUnitPriority('weekYear', 1);
  addUnitPriority('isoWeekYear', 1); // PARSING

  addRegexToken('G', matchSigned);
  addRegexToken('g', matchSigned);
  addRegexToken('GG', match1to2, match2);
  addRegexToken('gg', match1to2, match2);
  addRegexToken('GGGG', match1to4, match4);
  addRegexToken('gggg', match1to4, match4);
  addRegexToken('GGGGG', match1to6, match6);
  addRegexToken('ggggg', match1to6, match6);
  addWeekParseToken(['gggg', 'ggggg', 'GGGG', 'GGGGG'], function (input, week, config, token) {
    week[token.substr(0, 2)] = toInt(input);
  });
  addWeekParseToken(['gg', 'GG'], function (input, week, config, token) {
    week[token] = hooks.parseTwoDigitYear(input);
  }); // MOMENTS

  function getSetWeekYear(input) {
    return getSetWeekYearHelper.call(this, input, this.week(), this.weekday(), this.localeData()._week.dow, this.localeData()._week.doy);
  }

  function getSetISOWeekYear(input) {
    return getSetWeekYearHelper.call(this, input, this.isoWeek(), this.isoWeekday(), 1, 4);
  }

  function getISOWeeksInYear() {
    return weeksInYear(this.year(), 1, 4);
  }

  function getISOWeeksInISOWeekYear() {
    return weeksInYear(this.isoWeekYear(), 1, 4);
  }

  function getWeeksInYear() {
    var weekInfo = this.localeData()._week;

    return weeksInYear(this.year(), weekInfo.dow, weekInfo.doy);
  }

  function getWeeksInWeekYear() {
    var weekInfo = this.localeData()._week;

    return weeksInYear(this.weekYear(), weekInfo.dow, weekInfo.doy);
  }

  function getSetWeekYearHelper(input, week, weekday, dow, doy) {
    var weeksTarget;

    if (input == null) {
      return weekOfYear(this, dow, doy).year;
    } else {
      weeksTarget = weeksInYear(input, dow, doy);

      if (week > weeksTarget) {
        week = weeksTarget;
      }

      return setWeekAll.call(this, input, week, weekday, dow, doy);
    }
  }

  function setWeekAll(weekYear, week, weekday, dow, doy) {
    var dayOfYearData = dayOfYearFromWeeks(weekYear, week, weekday, dow, doy),
        date = createUTCDate(dayOfYearData.year, 0, dayOfYearData.dayOfYear);
    this.year(date.getUTCFullYear());
    this.month(date.getUTCMonth());
    this.date(date.getUTCDate());
    return this;
  } // FORMATTING


  addFormatToken('Q', 0, 'Qo', 'quarter'); // ALIASES

  addUnitAlias('quarter', 'Q'); // PRIORITY

  addUnitPriority('quarter', 7); // PARSING

  addRegexToken('Q', match1);
  addParseToken('Q', function (input, array) {
    array[MONTH] = (toInt(input) - 1) * 3;
  }); // MOMENTS

  function getSetQuarter(input) {
    return input == null ? Math.ceil((this.month() + 1) / 3) : this.month((input - 1) * 3 + this.month() % 3);
  } // FORMATTING


  addFormatToken('D', ['DD', 2], 'Do', 'date'); // ALIASES

  addUnitAlias('date', 'D'); // PRIORITY

  addUnitPriority('date', 9); // PARSING

  addRegexToken('D', match1to2);
  addRegexToken('DD', match1to2, match2);
  addRegexToken('Do', function (isStrict, locale) {
    // TODO: Remove "ordinalParse" fallback in next major release.
    return isStrict ? locale._dayOfMonthOrdinalParse || locale._ordinalParse : locale._dayOfMonthOrdinalParseLenient;
  });
  addParseToken(['D', 'DD'], DATE);
  addParseToken('Do', function (input, array) {
    array[DATE] = toInt(input.match(match1to2)[0]);
  }); // MOMENTS

  var getSetDayOfMonth = makeGetSet('Date', true); // FORMATTING

  addFormatToken('DDD', ['DDDD', 3], 'DDDo', 'dayOfYear'); // ALIASES

  addUnitAlias('dayOfYear', 'DDD'); // PRIORITY

  addUnitPriority('dayOfYear', 4); // PARSING

  addRegexToken('DDD', match1to3);
  addRegexToken('DDDD', match3);
  addParseToken(['DDD', 'DDDD'], function (input, array, config) {
    config._dayOfYear = toInt(input);
  }); // HELPERS
  // MOMENTS

  function getSetDayOfYear(input) {
    var dayOfYear = Math.round((this.clone().startOf('day') - this.clone().startOf('year')) / 864e5) + 1;
    return input == null ? dayOfYear : this.add(input - dayOfYear, 'd');
  } // FORMATTING


  addFormatToken('m', ['mm', 2], 0, 'minute'); // ALIASES

  addUnitAlias('minute', 'm'); // PRIORITY

  addUnitPriority('minute', 14); // PARSING

  addRegexToken('m', match1to2);
  addRegexToken('mm', match1to2, match2);
  addParseToken(['m', 'mm'], MINUTE); // MOMENTS

  var getSetMinute = makeGetSet('Minutes', false); // FORMATTING

  addFormatToken('s', ['ss', 2], 0, 'second'); // ALIASES

  addUnitAlias('second', 's'); // PRIORITY

  addUnitPriority('second', 15); // PARSING

  addRegexToken('s', match1to2);
  addRegexToken('ss', match1to2, match2);
  addParseToken(['s', 'ss'], SECOND); // MOMENTS

  var getSetSecond = makeGetSet('Seconds', false); // FORMATTING

  addFormatToken('S', 0, 0, function () {
    return ~~(this.millisecond() / 100);
  });
  addFormatToken(0, ['SS', 2], 0, function () {
    return ~~(this.millisecond() / 10);
  });
  addFormatToken(0, ['SSS', 3], 0, 'millisecond');
  addFormatToken(0, ['SSSS', 4], 0, function () {
    return this.millisecond() * 10;
  });
  addFormatToken(0, ['SSSSS', 5], 0, function () {
    return this.millisecond() * 100;
  });
  addFormatToken(0, ['SSSSSS', 6], 0, function () {
    return this.millisecond() * 1000;
  });
  addFormatToken(0, ['SSSSSSS', 7], 0, function () {
    return this.millisecond() * 10000;
  });
  addFormatToken(0, ['SSSSSSSS', 8], 0, function () {
    return this.millisecond() * 100000;
  });
  addFormatToken(0, ['SSSSSSSSS', 9], 0, function () {
    return this.millisecond() * 1000000;
  }); // ALIASES

  addUnitAlias('millisecond', 'ms'); // PRIORITY

  addUnitPriority('millisecond', 16); // PARSING

  addRegexToken('S', match1to3, match1);
  addRegexToken('SS', match1to3, match2);
  addRegexToken('SSS', match1to3, match3);
  var token, getSetMillisecond;

  for (token = 'SSSS'; token.length <= 9; token += 'S') {
    addRegexToken(token, matchUnsigned);
  }

  function parseMs(input, array) {
    array[MILLISECOND] = toInt(('0.' + input) * 1000);
  }

  for (token = 'S'; token.length <= 9; token += 'S') {
    addParseToken(token, parseMs);
  }

  getSetMillisecond = makeGetSet('Milliseconds', false); // FORMATTING

  addFormatToken('z', 0, 0, 'zoneAbbr');
  addFormatToken('zz', 0, 0, 'zoneName'); // MOMENTS

  function getZoneAbbr() {
    return this._isUTC ? 'UTC' : '';
  }

  function getZoneName() {
    return this._isUTC ? 'Coordinated Universal Time' : '';
  }

  var proto = Moment.prototype;
  proto.add = add;
  proto.calendar = calendar$1;
  proto.clone = clone;
  proto.diff = diff;
  proto.endOf = endOf;
  proto.format = format;
  proto.from = from;
  proto.fromNow = fromNow;
  proto.to = to;
  proto.toNow = toNow;
  proto.get = stringGet;
  proto.invalidAt = invalidAt;
  proto.isAfter = isAfter;
  proto.isBefore = isBefore;
  proto.isBetween = isBetween;
  proto.isSame = isSame;
  proto.isSameOrAfter = isSameOrAfter;
  proto.isSameOrBefore = isSameOrBefore;
  proto.isValid = isValid$2;
  proto.lang = lang;
  proto.locale = locale;
  proto.localeData = localeData;
  proto.max = prototypeMax;
  proto.min = prototypeMin;
  proto.parsingFlags = parsingFlags;
  proto.set = stringSet;
  proto.startOf = startOf;
  proto.subtract = subtract;
  proto.toArray = toArray;
  proto.toObject = toObject;
  proto.toDate = toDate;
  proto.toISOString = toISOString;
  proto.inspect = inspect;

  if (typeof Symbol !== 'undefined' && Symbol.for != null) {
    proto[Symbol.for('nodejs.util.inspect.custom')] = function () {
      return 'Moment<' + this.format() + '>';
    };
  }

  proto.toJSON = toJSON;
  proto.toString = toString;
  proto.unix = unix;
  proto.valueOf = valueOf;
  proto.creationData = creationData;
  proto.eraName = getEraName;
  proto.eraNarrow = getEraNarrow;
  proto.eraAbbr = getEraAbbr;
  proto.eraYear = getEraYear;
  proto.year = getSetYear;
  proto.isLeapYear = getIsLeapYear;
  proto.weekYear = getSetWeekYear;
  proto.isoWeekYear = getSetISOWeekYear;
  proto.quarter = proto.quarters = getSetQuarter;
  proto.month = getSetMonth;
  proto.daysInMonth = getDaysInMonth;
  proto.week = proto.weeks = getSetWeek;
  proto.isoWeek = proto.isoWeeks = getSetISOWeek;
  proto.weeksInYear = getWeeksInYear;
  proto.weeksInWeekYear = getWeeksInWeekYear;
  proto.isoWeeksInYear = getISOWeeksInYear;
  proto.isoWeeksInISOWeekYear = getISOWeeksInISOWeekYear;
  proto.date = getSetDayOfMonth;
  proto.day = proto.days = getSetDayOfWeek;
  proto.weekday = getSetLocaleDayOfWeek;
  proto.isoWeekday = getSetISODayOfWeek;
  proto.dayOfYear = getSetDayOfYear;
  proto.hour = proto.hours = getSetHour;
  proto.minute = proto.minutes = getSetMinute;
  proto.second = proto.seconds = getSetSecond;
  proto.millisecond = proto.milliseconds = getSetMillisecond;
  proto.utcOffset = getSetOffset;
  proto.utc = setOffsetToUTC;
  proto.local = setOffsetToLocal;
  proto.parseZone = setOffsetToParsedOffset;
  proto.hasAlignedHourOffset = hasAlignedHourOffset;
  proto.isDST = isDaylightSavingTime;
  proto.isLocal = isLocal;
  proto.isUtcOffset = isUtcOffset;
  proto.isUtc = isUtc;
  proto.isUTC = isUtc;
  proto.zoneAbbr = getZoneAbbr;
  proto.zoneName = getZoneName;
  proto.dates = deprecate('dates accessor is deprecated. Use date instead.', getSetDayOfMonth);
  proto.months = deprecate('months accessor is deprecated. Use month instead', getSetMonth);
  proto.years = deprecate('years accessor is deprecated. Use year instead', getSetYear);
  proto.zone = deprecate('moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/', getSetZone);
  proto.isDSTShifted = deprecate('isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information', isDaylightSavingTimeShifted);

  function createUnix(input) {
    return createLocal(input * 1000);
  }

  function createInZone() {
    return createLocal.apply(null, arguments).parseZone();
  }

  function preParsePostFormat(string) {
    return string;
  }

  var proto$1 = Locale.prototype;
  proto$1.calendar = calendar;
  proto$1.longDateFormat = longDateFormat;
  proto$1.invalidDate = invalidDate;
  proto$1.ordinal = ordinal;
  proto$1.preparse = preParsePostFormat;
  proto$1.postformat = preParsePostFormat;
  proto$1.relativeTime = relativeTime;
  proto$1.pastFuture = pastFuture;
  proto$1.set = set;
  proto$1.eras = localeEras;
  proto$1.erasParse = localeErasParse;
  proto$1.erasConvertYear = localeErasConvertYear;
  proto$1.erasAbbrRegex = erasAbbrRegex;
  proto$1.erasNameRegex = erasNameRegex;
  proto$1.erasNarrowRegex = erasNarrowRegex;
  proto$1.months = localeMonths;
  proto$1.monthsShort = localeMonthsShort;
  proto$1.monthsParse = localeMonthsParse;
  proto$1.monthsRegex = monthsRegex;
  proto$1.monthsShortRegex = monthsShortRegex;
  proto$1.week = localeWeek;
  proto$1.firstDayOfYear = localeFirstDayOfYear;
  proto$1.firstDayOfWeek = localeFirstDayOfWeek;
  proto$1.weekdays = localeWeekdays;
  proto$1.weekdaysMin = localeWeekdaysMin;
  proto$1.weekdaysShort = localeWeekdaysShort;
  proto$1.weekdaysParse = localeWeekdaysParse;
  proto$1.weekdaysRegex = weekdaysRegex;
  proto$1.weekdaysShortRegex = weekdaysShortRegex;
  proto$1.weekdaysMinRegex = weekdaysMinRegex;
  proto$1.isPM = localeIsPM;
  proto$1.meridiem = localeMeridiem;

  function get$1(format, index, field, setter) {
    var locale = getLocale(),
        utc = createUTC().set(setter, index);
    return locale[field](utc, format);
  }

  function listMonthsImpl(format, index, field) {
    if (isNumber(format)) {
      index = format;
      format = undefined;
    }

    format = format || '';

    if (index != null) {
      return get$1(format, index, field, 'month');
    }

    var i,
        out = [];

    for (i = 0; i < 12; i++) {
      out[i] = get$1(format, i, field, 'month');
    }

    return out;
  } // ()
  // (5)
  // (fmt, 5)
  // (fmt)
  // (true)
  // (true, 5)
  // (true, fmt, 5)
  // (true, fmt)


  function listWeekdaysImpl(localeSorted, format, index, field) {
    if (typeof localeSorted === 'boolean') {
      if (isNumber(format)) {
        index = format;
        format = undefined;
      }

      format = format || '';
    } else {
      format = localeSorted;
      index = format;
      localeSorted = false;

      if (isNumber(format)) {
        index = format;
        format = undefined;
      }

      format = format || '';
    }

    var locale = getLocale(),
        shift = localeSorted ? locale._week.dow : 0,
        i,
        out = [];

    if (index != null) {
      return get$1(format, (index + shift) % 7, field, 'day');
    }

    for (i = 0; i < 7; i++) {
      out[i] = get$1(format, (i + shift) % 7, field, 'day');
    }

    return out;
  }

  function listMonths(format, index) {
    return listMonthsImpl(format, index, 'months');
  }

  function listMonthsShort(format, index) {
    return listMonthsImpl(format, index, 'monthsShort');
  }

  function listWeekdays(localeSorted, format, index) {
    return listWeekdaysImpl(localeSorted, format, index, 'weekdays');
  }

  function listWeekdaysShort(localeSorted, format, index) {
    return listWeekdaysImpl(localeSorted, format, index, 'weekdaysShort');
  }

  function listWeekdaysMin(localeSorted, format, index) {
    return listWeekdaysImpl(localeSorted, format, index, 'weekdaysMin');
  }

  getSetGlobalLocale('en', {
    eras: [{
      since: '0001-01-01',
      until: +Infinity,
      offset: 1,
      name: 'Anno Domini',
      narrow: 'AD',
      abbr: 'AD'
    }, {
      since: '0000-12-31',
      until: -Infinity,
      offset: 1,
      name: 'Before Christ',
      narrow: 'BC',
      abbr: 'BC'
    }],
    dayOfMonthOrdinalParse: /\d{1,2}(th|st|nd|rd)/,
    ordinal: function ordinal(number) {
      var b = number % 10,
          output = toInt(number % 100 / 10) === 1 ? 'th' : b === 1 ? 'st' : b === 2 ? 'nd' : b === 3 ? 'rd' : 'th';
      return number + output;
    }
  }); // Side effect imports

  hooks.lang = deprecate('moment.lang is deprecated. Use moment.locale instead.', getSetGlobalLocale);
  hooks.langData = deprecate('moment.langData is deprecated. Use moment.localeData instead.', getLocale);
  var mathAbs = Math.abs;

  function abs() {
    var data = this._data;
    this._milliseconds = mathAbs(this._milliseconds);
    this._days = mathAbs(this._days);
    this._months = mathAbs(this._months);
    data.milliseconds = mathAbs(data.milliseconds);
    data.seconds = mathAbs(data.seconds);
    data.minutes = mathAbs(data.minutes);
    data.hours = mathAbs(data.hours);
    data.months = mathAbs(data.months);
    data.years = mathAbs(data.years);
    return this;
  }

  function addSubtract$1(duration, input, value, direction) {
    var other = createDuration(input, value);
    duration._milliseconds += direction * other._milliseconds;
    duration._days += direction * other._days;
    duration._months += direction * other._months;
    return duration._bubble();
  } // supports only 2.0-style add(1, 's') or add(duration)


  function add$1(input, value) {
    return addSubtract$1(this, input, value, 1);
  } // supports only 2.0-style subtract(1, 's') or subtract(duration)


  function subtract$1(input, value) {
    return addSubtract$1(this, input, value, -1);
  }

  function absCeil(number) {
    if (number < 0) {
      return Math.floor(number);
    } else {
      return Math.ceil(number);
    }
  }

  function bubble() {
    var milliseconds = this._milliseconds,
        days = this._days,
        months = this._months,
        data = this._data,
        seconds,
        minutes,
        hours,
        years,
        monthsFromDays; // if we have a mix of positive and negative values, bubble down first
    // check: https://github.com/moment/moment/issues/2166

    if (!(milliseconds >= 0 && days >= 0 && months >= 0 || milliseconds <= 0 && days <= 0 && months <= 0)) {
      milliseconds += absCeil(monthsToDays(months) + days) * 864e5;
      days = 0;
      months = 0;
    } // The following code bubbles up values, see the tests for
    // examples of what that means.


    data.milliseconds = milliseconds % 1000;
    seconds = absFloor(milliseconds / 1000);
    data.seconds = seconds % 60;
    minutes = absFloor(seconds / 60);
    data.minutes = minutes % 60;
    hours = absFloor(minutes / 60);
    data.hours = hours % 24;
    days += absFloor(hours / 24); // convert days to months

    monthsFromDays = absFloor(daysToMonths(days));
    months += monthsFromDays;
    days -= absCeil(monthsToDays(monthsFromDays)); // 12 months -> 1 year

    years = absFloor(months / 12);
    months %= 12;
    data.days = days;
    data.months = months;
    data.years = years;
    return this;
  }

  function daysToMonths(days) {
    // 400 years have 146097 days (taking into account leap year rules)
    // 400 years have 12 months === 4800
    return days * 4800 / 146097;
  }

  function monthsToDays(months) {
    // the reverse of daysToMonths
    return months * 146097 / 4800;
  }

  function as(units) {
    if (!this.isValid()) {
      return NaN;
    }

    var days,
        months,
        milliseconds = this._milliseconds;
    units = normalizeUnits(units);

    if (units === 'month' || units === 'quarter' || units === 'year') {
      days = this._days + milliseconds / 864e5;
      months = this._months + daysToMonths(days);

      switch (units) {
        case 'month':
          return months;

        case 'quarter':
          return months / 3;

        case 'year':
          return months / 12;
      }
    } else {
      // handle milliseconds separately because of floating point math errors (issue #1867)
      days = this._days + Math.round(monthsToDays(this._months));

      switch (units) {
        case 'week':
          return days / 7 + milliseconds / 6048e5;

        case 'day':
          return days + milliseconds / 864e5;

        case 'hour':
          return days * 24 + milliseconds / 36e5;

        case 'minute':
          return days * 1440 + milliseconds / 6e4;

        case 'second':
          return days * 86400 + milliseconds / 1000;
        // Math.floor prevents floating point math errors here

        case 'millisecond':
          return Math.floor(days * 864e5) + milliseconds;

        default:
          throw new Error('Unknown unit ' + units);
      }
    }
  } // TODO: Use this.as('ms')?


  function valueOf$1() {
    if (!this.isValid()) {
      return NaN;
    }

    return this._milliseconds + this._days * 864e5 + this._months % 12 * 2592e6 + toInt(this._months / 12) * 31536e6;
  }

  function makeAs(alias) {
    return function () {
      return this.as(alias);
    };
  }

  var asMilliseconds = makeAs('ms'),
      asSeconds = makeAs('s'),
      asMinutes = makeAs('m'),
      asHours = makeAs('h'),
      asDays = makeAs('d'),
      asWeeks = makeAs('w'),
      asMonths = makeAs('M'),
      asQuarters = makeAs('Q'),
      asYears = makeAs('y');

  function clone$1() {
    return createDuration(this);
  }

  function get$2(units) {
    units = normalizeUnits(units);
    return this.isValid() ? this[units + 's']() : NaN;
  }

  function makeGetter(name) {
    return function () {
      return this.isValid() ? this._data[name] : NaN;
    };
  }

  var milliseconds = makeGetter('milliseconds'),
      seconds = makeGetter('seconds'),
      minutes = makeGetter('minutes'),
      hours = makeGetter('hours'),
      days = makeGetter('days'),
      months = makeGetter('months'),
      years = makeGetter('years');

  function weeks() {
    return absFloor(this.days() / 7);
  }

  var round = Math.round,
      thresholds = {
    ss: 44,
    // a few seconds to seconds
    s: 45,
    // seconds to minute
    m: 45,
    // minutes to hour
    h: 22,
    // hours to day
    d: 26,
    // days to month/week
    w: null,
    // weeks to month
    M: 11 // months to year

  }; // helper function for moment.fn.from, moment.fn.fromNow, and moment.duration.fn.humanize

  function substituteTimeAgo(string, number, withoutSuffix, isFuture, locale) {
    return locale.relativeTime(number || 1, !!withoutSuffix, string, isFuture);
  }

  function relativeTime$1(posNegDuration, withoutSuffix, thresholds, locale) {
    var duration = createDuration(posNegDuration).abs(),
        seconds = round(duration.as('s')),
        minutes = round(duration.as('m')),
        hours = round(duration.as('h')),
        days = round(duration.as('d')),
        months = round(duration.as('M')),
        weeks = round(duration.as('w')),
        years = round(duration.as('y')),
        a = seconds <= thresholds.ss && ['s', seconds] || seconds < thresholds.s && ['ss', seconds] || minutes <= 1 && ['m'] || minutes < thresholds.m && ['mm', minutes] || hours <= 1 && ['h'] || hours < thresholds.h && ['hh', hours] || days <= 1 && ['d'] || days < thresholds.d && ['dd', days];

    if (thresholds.w != null) {
      a = a || weeks <= 1 && ['w'] || weeks < thresholds.w && ['ww', weeks];
    }

    a = a || months <= 1 && ['M'] || months < thresholds.M && ['MM', months] || years <= 1 && ['y'] || ['yy', years];
    a[2] = withoutSuffix;
    a[3] = +posNegDuration > 0;
    a[4] = locale;
    return substituteTimeAgo.apply(null, a);
  } // This function allows you to set the rounding function for relative time strings


  function getSetRelativeTimeRounding(roundingFunction) {
    if (roundingFunction === undefined) {
      return round;
    }

    if (typeof roundingFunction === 'function') {
      round = roundingFunction;
      return true;
    }

    return false;
  } // This function allows you to set a threshold for relative time strings


  function getSetRelativeTimeThreshold(threshold, limit) {
    if (thresholds[threshold] === undefined) {
      return false;
    }

    if (limit === undefined) {
      return thresholds[threshold];
    }

    thresholds[threshold] = limit;

    if (threshold === 's') {
      thresholds.ss = limit - 1;
    }

    return true;
  }

  function humanize(argWithSuffix, argThresholds) {
    if (!this.isValid()) {
      return this.localeData().invalidDate();
    }

    var withSuffix = false,
        th = thresholds,
        locale,
        output;

    if (typeof argWithSuffix === 'object') {
      argThresholds = argWithSuffix;
      argWithSuffix = false;
    }

    if (typeof argWithSuffix === 'boolean') {
      withSuffix = argWithSuffix;
    }

    if (typeof argThresholds === 'object') {
      th = Object.assign({}, thresholds, argThresholds);

      if (argThresholds.s != null && argThresholds.ss == null) {
        th.ss = argThresholds.s - 1;
      }
    }

    locale = this.localeData();
    output = relativeTime$1(this, !withSuffix, th, locale);

    if (withSuffix) {
      output = locale.pastFuture(+this, output);
    }

    return locale.postformat(output);
  }

  var abs$1 = Math.abs;

  function sign(x) {
    return (x > 0) - (x < 0) || +x;
  }

  function toISOString$1() {
    // for ISO strings we do not use the normal bubbling rules:
    //  * milliseconds bubble up until they become hours
    //  * days do not bubble at all
    //  * months bubble up until they become years
    // This is because there is no context-free conversion between hours and days
    // (think of clock changes)
    // and also not between days and months (28-31 days per month)
    if (!this.isValid()) {
      return this.localeData().invalidDate();
    }

    var seconds = abs$1(this._milliseconds) / 1000,
        days = abs$1(this._days),
        months = abs$1(this._months),
        minutes,
        hours,
        years,
        s,
        total = this.asSeconds(),
        totalSign,
        ymSign,
        daysSign,
        hmsSign;

    if (!total) {
      // this is the same as C#'s (Noda) and python (isodate)...
      // but not other JS (goog.date)
      return 'P0D';
    } // 3600 seconds -> 60 minutes -> 1 hour


    minutes = absFloor(seconds / 60);
    hours = absFloor(minutes / 60);
    seconds %= 60;
    minutes %= 60; // 12 months -> 1 year

    years = absFloor(months / 12);
    months %= 12; // inspired by https://github.com/dordille/moment-isoduration/blob/master/moment.isoduration.js

    s = seconds ? seconds.toFixed(3).replace(/\.?0+$/, '') : '';
    totalSign = total < 0 ? '-' : '';
    ymSign = sign(this._months) !== sign(total) ? '-' : '';
    daysSign = sign(this._days) !== sign(total) ? '-' : '';
    hmsSign = sign(this._milliseconds) !== sign(total) ? '-' : '';
    return totalSign + 'P' + (years ? ymSign + years + 'Y' : '') + (months ? ymSign + months + 'M' : '') + (days ? daysSign + days + 'D' : '') + (hours || minutes || seconds ? 'T' : '') + (hours ? hmsSign + hours + 'H' : '') + (minutes ? hmsSign + minutes + 'M' : '') + (seconds ? hmsSign + s + 'S' : '');
  }

  var proto$2 = Duration.prototype;
  proto$2.isValid = isValid$1;
  proto$2.abs = abs;
  proto$2.add = add$1;
  proto$2.subtract = subtract$1;
  proto$2.as = as;
  proto$2.asMilliseconds = asMilliseconds;
  proto$2.asSeconds = asSeconds;
  proto$2.asMinutes = asMinutes;
  proto$2.asHours = asHours;
  proto$2.asDays = asDays;
  proto$2.asWeeks = asWeeks;
  proto$2.asMonths = asMonths;
  proto$2.asQuarters = asQuarters;
  proto$2.asYears = asYears;
  proto$2.valueOf = valueOf$1;
  proto$2._bubble = bubble;
  proto$2.clone = clone$1;
  proto$2.get = get$2;
  proto$2.milliseconds = milliseconds;
  proto$2.seconds = seconds;
  proto$2.minutes = minutes;
  proto$2.hours = hours;
  proto$2.days = days;
  proto$2.weeks = weeks;
  proto$2.months = months;
  proto$2.years = years;
  proto$2.humanize = humanize;
  proto$2.toISOString = toISOString$1;
  proto$2.toString = toISOString$1;
  proto$2.toJSON = toISOString$1;
  proto$2.locale = locale;
  proto$2.localeData = localeData;
  proto$2.toIsoString = deprecate('toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)', toISOString$1);
  proto$2.lang = lang; // FORMATTING

  addFormatToken('X', 0, 0, 'unix');
  addFormatToken('x', 0, 0, 'valueOf'); // PARSING

  addRegexToken('x', matchSigned);
  addRegexToken('X', matchTimestamp);
  addParseToken('X', function (input, array, config) {
    config._d = new Date(parseFloat(input) * 1000);
  });
  addParseToken('x', function (input, array, config) {
    config._d = new Date(toInt(input));
  }); //! moment.js

  hooks.version = '2.29.0';
  setHookCallback(createLocal);
  hooks.fn = proto;
  hooks.min = min;
  hooks.max = max;
  hooks.now = now;
  hooks.utc = createUTC;
  hooks.unix = createUnix;
  hooks.months = listMonths;
  hooks.isDate = isDate;
  hooks.locale = getSetGlobalLocale;
  hooks.invalid = createInvalid;
  hooks.duration = createDuration;
  hooks.isMoment = isMoment;
  hooks.weekdays = listWeekdays;
  hooks.parseZone = createInZone;
  hooks.localeData = getLocale;
  hooks.isDuration = isDuration;
  hooks.monthsShort = listMonthsShort;
  hooks.weekdaysMin = listWeekdaysMin;
  hooks.defineLocale = defineLocale;
  hooks.updateLocale = updateLocale;
  hooks.locales = listLocales;
  hooks.weekdaysShort = listWeekdaysShort;
  hooks.normalizeUnits = normalizeUnits;
  hooks.relativeTimeRounding = getSetRelativeTimeRounding;
  hooks.relativeTimeThreshold = getSetRelativeTimeThreshold;
  hooks.calendarFormat = getCalendarFormat;
  hooks.prototype = proto; // currently HTML5 input type only supports 24-hour formats

  hooks.HTML5_FMT = {
    DATETIME_LOCAL: 'YYYY-MM-DDTHH:mm',
    // <input type="datetime-local" />
    DATETIME_LOCAL_SECONDS: 'YYYY-MM-DDTHH:mm:ss',
    // <input type="datetime-local" step="1" />
    DATETIME_LOCAL_MS: 'YYYY-MM-DDTHH:mm:ss.SSS',
    // <input type="datetime-local" step="0.001" />
    DATE: 'YYYY-MM-DD',
    // <input type="date" />
    TIME: 'HH:mm',
    // <input type="time" />
    TIME_SECONDS: 'HH:mm:ss',
    // <input type="time" step="1" />
    TIME_MS: 'HH:mm:ss.SSS',
    // <input type="time" step="0.001" />
    WEEK: 'GGGG-[W]WW',
    // <input type="week" />
    MONTH: 'YYYY-MM' // <input type="month" />

  };
  return hooks;
});
/* WEBPACK VAR INJECTION */}.call(this, __webpack_require__(/*! ./../webpack/buildin/module.js */ "YuTi")(module)))

/***/ }),

/***/ "x+ZX":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/refCount.js ***!
  \*******************************************************************/
/*! exports provided: refCount */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "refCount", function() { return refCount; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function refCount() {
  return function refCountOperatorFunction(source) {
    return source.lift(new RefCountOperator(source));
  };
}

var RefCountOperator = /*#__PURE__*/function () {
  function RefCountOperator(connectable) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RefCountOperator);

    this.connectable = connectable;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RefCountOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      var connectable = this.connectable;
      connectable._refCount++;
      var refCounter = new RefCountSubscriber(subscriber, connectable);
      var subscription = source.subscribe(refCounter);

      if (!refCounter.closed) {
        refCounter.connection = connectable.connect();
      }

      return subscription;
    }
  }]);

  return RefCountOperator;
}();

var RefCountSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(RefCountSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(RefCountSubscriber);

  function RefCountSubscriber(destination, connectable) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, RefCountSubscriber);

    _this = _super.call(this, destination);
    _this.connectable = connectable;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(RefCountSubscriber, [{
    key: "_unsubscribe",
    value: function _unsubscribe() {
      var connectable = this.connectable;

      if (!connectable) {
        this.connection = null;
        return;
      }

      this.connectable = null;
      var refCount = connectable._refCount;

      if (refCount <= 0) {
        this.connection = null;
        return;
      }

      connectable._refCount = refCount - 1;

      if (refCount > 1) {
        this.connection = null;
        return;
      }

      var connection = this.connection;
      var sharedConnection = connectable._connection;
      this.connection = null;

      if (sharedConnection && (!connection || sharedConnection === connection)) {
        sharedConnection.unsubscribe();
      }
    }
  }]);

  return RefCountSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "x6pH":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/he.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Hebrew [he]
//! author : Tomer Cohen : https://github.com/tomer
//! author : Moshe Simantov : https://github.com/DevelopmentIL
//! author : Tal Ater : https://github.com/TalAter
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var he = moment.defineLocale('he', {
    months: 'ינואר_פברואר_מרץ_אפריל_מאי_יוני_יולי_אוגוסט_ספטמבר_אוקטובר_נובמבר_דצמבר'.split('_'),
    monthsShort: 'ינו׳_פבר׳_מרץ_אפר׳_מאי_יוני_יולי_אוג׳_ספט׳_אוק׳_נוב׳_דצמ׳'.split('_'),
    weekdays: 'ראשון_שני_שלישי_רביעי_חמישי_שישי_שבת'.split('_'),
    weekdaysShort: 'א׳_ב׳_ג׳_ד׳_ה׳_ו׳_ש׳'.split('_'),
    weekdaysMin: 'א_ב_ג_ד_ה_ו_ש'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D [ב]MMMM YYYY',
      LLL: 'D [ב]MMMM YYYY HH:mm',
      LLLL: 'dddd, D [ב]MMMM YYYY HH:mm',
      l: 'D/M/YYYY',
      ll: 'D MMM YYYY',
      lll: 'D MMM YYYY HH:mm',
      llll: 'ddd, D MMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[היום ב־]LT',
      nextDay: '[מחר ב־]LT',
      nextWeek: 'dddd [בשעה] LT',
      lastDay: '[אתמול ב־]LT',
      lastWeek: '[ביום] dddd [האחרון בשעה] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'בעוד %s',
      past: 'לפני %s',
      s: 'מספר שניות',
      ss: '%d שניות',
      m: 'דקה',
      mm: '%d דקות',
      h: 'שעה',
      hh: function hh(number) {
        if (number === 2) {
          return 'שעתיים';
        }

        return number + ' שעות';
      },
      d: 'יום',
      dd: function dd(number) {
        if (number === 2) {
          return 'יומיים';
        }

        return number + ' ימים';
      },
      M: 'חודש',
      MM: function MM(number) {
        if (number === 2) {
          return 'חודשיים';
        }

        return number + ' חודשים';
      },
      y: 'שנה',
      yy: function yy(number) {
        if (number === 2) {
          return 'שנתיים';
        } else if (number % 10 === 0 && number !== 10) {
          return number + ' שנה';
        }

        return number + ' שנים';
      }
    },
    meridiemParse: /אחה"צ|לפנה"צ|אחרי הצהריים|לפני הצהריים|לפנות בוקר|בבוקר|בערב/i,
    isPM: function isPM(input) {
      return /^(אחה"צ|אחרי הצהריים|בערב)$/.test(input);
    },
    meridiem: function meridiem(hour, minute, isLower) {
      if (hour < 5) {
        return 'לפנות בוקר';
      } else if (hour < 10) {
        return 'בבוקר';
      } else if (hour < 12) {
        return isLower ? 'לפנה"צ' : 'לפני הצהריים';
      } else if (hour < 18) {
        return isLower ? 'אחה"צ' : 'אחרי הצהריים';
      } else {
        return 'בערב';
      }
    }
  });
  return he;
});

/***/ }),

/***/ "xbPD":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/defaultIfEmpty.js ***!
  \*************************************************************************/
/*! exports provided: defaultIfEmpty */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "defaultIfEmpty", function() { return defaultIfEmpty; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function defaultIfEmpty() {
  var defaultValue = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  return function (source) {
    return source.lift(new DefaultIfEmptyOperator(defaultValue));
  };
}

var DefaultIfEmptyOperator = /*#__PURE__*/function () {
  function DefaultIfEmptyOperator(defaultValue) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DefaultIfEmptyOperator);

    this.defaultValue = defaultValue;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DefaultIfEmptyOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new DefaultIfEmptySubscriber(subscriber, this.defaultValue));
    }
  }]);

  return DefaultIfEmptyOperator;
}();

var DefaultIfEmptySubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(DefaultIfEmptySubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(DefaultIfEmptySubscriber);

  function DefaultIfEmptySubscriber(destination, defaultValue) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, DefaultIfEmptySubscriber);

    _this = _super.call(this, destination);
    _this.defaultValue = defaultValue;
    _this.isEmpty = true;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(DefaultIfEmptySubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.isEmpty = false;
      this.destination.next(value);
    }
  }, {
    key: "_complete",
    value: function _complete() {
      if (this.isEmpty) {
        this.destination.next(this.defaultValue);
      }

      this.destination.complete();
    }
  }]);

  return DefaultIfEmptySubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "xgIS":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/fromEvent.js ***!
  \*********************************************************************/
/*! exports provided: fromEvent */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "fromEvent", function() { return fromEvent; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_isArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/isArray */ "DH7j");
/* harmony import */ var _util_isFunction__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/isFunction */ "n6bG");
/* harmony import */ var _operators_map__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../operators/map */ "lJxs");






var toString = function () {
  return Object.prototype.toString;
}();

function fromEvent(target, eventName, options, resultSelector) {
  if (Object(_util_isFunction__WEBPACK_IMPORTED_MODULE_3__["isFunction"])(options)) {
    resultSelector = options;
    options = undefined;
  }

  if (resultSelector) {
    return fromEvent(target, eventName, options).pipe(Object(_operators_map__WEBPACK_IMPORTED_MODULE_4__["map"])(function (args) {
      return Object(_util_isArray__WEBPACK_IMPORTED_MODULE_2__["isArray"])(args) ? resultSelector.apply(void 0, Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(args)) : resultSelector(args);
    }));
  }

  return new _Observable__WEBPACK_IMPORTED_MODULE_1__["Observable"](function (subscriber) {
    function handler(e) {
      if (arguments.length > 1) {
        subscriber.next(Array.prototype.slice.call(arguments));
      } else {
        subscriber.next(e);
      }
    }

    setupSubscription(target, eventName, handler, subscriber, options);
  });
}

function setupSubscription(sourceObj, eventName, handler, subscriber, options) {
  var unsubscribe;

  if (isEventTarget(sourceObj)) {
    var source = sourceObj;
    sourceObj.addEventListener(eventName, handler, options);

    unsubscribe = function unsubscribe() {
      return source.removeEventListener(eventName, handler, options);
    };
  } else if (isJQueryStyleEventEmitter(sourceObj)) {
    var _source = sourceObj;
    sourceObj.on(eventName, handler);

    unsubscribe = function unsubscribe() {
      return _source.off(eventName, handler);
    };
  } else if (isNodeStyleEventEmitter(sourceObj)) {
    var _source2 = sourceObj;
    sourceObj.addListener(eventName, handler);

    unsubscribe = function unsubscribe() {
      return _source2.removeListener(eventName, handler);
    };
  } else if (sourceObj && sourceObj.length) {
    for (var i = 0, len = sourceObj.length; i < len; i++) {
      setupSubscription(sourceObj[i], eventName, handler, subscriber, options);
    }
  } else {
    throw new TypeError('Invalid event target');
  }

  subscriber.add(unsubscribe);
}

function isNodeStyleEventEmitter(sourceObj) {
  return sourceObj && typeof sourceObj.addListener === 'function' && typeof sourceObj.removeListener === 'function';
}

function isJQueryStyleEventEmitter(sourceObj) {
  return sourceObj && typeof sourceObj.on === 'function' && typeof sourceObj.off === 'function';
}

function isEventTarget(sourceObj) {
  return sourceObj && typeof sourceObj.addEventListener === 'function' && typeof sourceObj.removeEventListener === 'function';
}

/***/ }),

/***/ "yCtX":
/*!*********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/fromArray.js ***!
  \*********************************************************************/
/*! exports provided: fromArray */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "fromArray", function() { return fromArray; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");
/* harmony import */ var _util_subscribeToArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util/subscribeToArray */ "ngJS");
/* harmony import */ var _scheduled_scheduleArray__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../scheduled/scheduleArray */ "jZKg");



function fromArray(input, scheduler) {
  if (!scheduler) {
    return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](Object(_util_subscribeToArray__WEBPACK_IMPORTED_MODULE_1__["subscribeToArray"])(input));
  } else {
    return Object(_scheduled_scheduleArray__WEBPACK_IMPORTED_MODULE_2__["scheduleArray"])(input, scheduler);
  }
}

/***/ }),

/***/ "yI9Y":
/*!**************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/max.js ***!
  \**************************************************************/
/*! exports provided: max */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "max", function() { return max; });
/* harmony import */ var _reduce__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduce */ "128B");

function max(comparer) {
  var max = typeof comparer === 'function' ? function (x, y) {
    return comparer(x, y) > 0 ? x : y;
  } : function (x, y) {
    return x > y ? x : y;
  };
  return Object(_reduce__WEBPACK_IMPORTED_MODULE_0__["reduce"])(max);
}

/***/ }),

/***/ "yPMs":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sq.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Albanian [sq]
//! author : Flakërim Ismani : https://github.com/flakerimi
//! author : Menelion Elensúle : https://github.com/Oire
//! author : Oerd Cukalla : https://github.com/oerd
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var sq = moment.defineLocale('sq', {
    months: 'Janar_Shkurt_Mars_Prill_Maj_Qershor_Korrik_Gusht_Shtator_Tetor_Nëntor_Dhjetor'.split('_'),
    monthsShort: 'Jan_Shk_Mar_Pri_Maj_Qer_Kor_Gus_Sht_Tet_Nën_Dhj'.split('_'),
    weekdays: 'E Diel_E Hënë_E Martë_E Mërkurë_E Enjte_E Premte_E Shtunë'.split('_'),
    weekdaysShort: 'Die_Hën_Mar_Mër_Enj_Pre_Sht'.split('_'),
    weekdaysMin: 'D_H_Ma_Më_E_P_Sh'.split('_'),
    weekdaysParseExact: true,
    meridiemParse: /PD|MD/,
    isPM: function isPM(input) {
      return input.charAt(0) === 'M';
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      return hours < 12 ? 'PD' : 'MD';
    },
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD/MM/YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[Sot në] LT',
      nextDay: '[Nesër në] LT',
      nextWeek: 'dddd [në] LT',
      lastDay: '[Dje në] LT',
      lastWeek: 'dddd [e kaluar në] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'në %s',
      past: '%s më parë',
      s: 'disa sekonda',
      ss: '%d sekonda',
      m: 'një minutë',
      mm: '%d minuta',
      h: 'një orë',
      hh: '%d orë',
      d: 'një ditë',
      dd: '%d ditë',
      M: 'një muaj',
      MM: '%d muaj',
      y: 'një vit',
      yy: '%d vite'
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return sq;
});

/***/ }),

/***/ "yuhW":
/*!*******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/throttle.js ***!
  \*******************************************************************/
/*! exports provided: defaultThrottleConfig, throttle */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "defaultThrottleConfig", function() { return defaultThrottleConfig; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "throttle", function() { return throttle; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





var defaultThrottleConfig = {
  leading: true,
  trailing: false
};
function throttle(durationSelector) {
  var config = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultThrottleConfig;
  return function (source) {
    return source.lift(new ThrottleOperator(durationSelector, !!config.leading, !!config.trailing));
  };
}

var ThrottleOperator = /*#__PURE__*/function () {
  function ThrottleOperator(durationSelector, leading, trailing) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ThrottleOperator);

    this.durationSelector = durationSelector;
    this.leading = leading;
    this.trailing = trailing;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ThrottleOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new ThrottleSubscriber(subscriber, this.durationSelector, this.leading, this.trailing));
    }
  }]);

  return ThrottleOperator;
}();

var ThrottleSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(ThrottleSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(ThrottleSubscriber);

  function ThrottleSubscriber(destination, durationSelector, _leading, _trailing) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, ThrottleSubscriber);

    _this = _super.call(this, destination);
    _this.destination = destination;
    _this.durationSelector = durationSelector;
    _this._leading = _leading;
    _this._trailing = _trailing;
    _this._hasValue = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(ThrottleSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this._hasValue = true;
      this._sendValue = value;

      if (!this._throttled) {
        if (this._leading) {
          this.send();
        } else {
          this.throttle(value);
        }
      }
    }
  }, {
    key: "send",
    value: function send() {
      var _hasValue = this._hasValue,
          _sendValue = this._sendValue;

      if (_hasValue) {
        this.destination.next(_sendValue);
        this.throttle(_sendValue);
      }

      this._hasValue = false;
      this._sendValue = undefined;
    }
  }, {
    key: "throttle",
    value: function throttle(value) {
      var duration = this.tryDurationSelector(value);

      if (!!duration) {
        this.add(this._throttled = Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(duration, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](this)));
      }
    }
  }, {
    key: "tryDurationSelector",
    value: function tryDurationSelector(value) {
      try {
        return this.durationSelector(value);
      } catch (err) {
        this.destination.error(err);
        return null;
      }
    }
  }, {
    key: "throttlingDone",
    value: function throttlingDone() {
      var _throttled = this._throttled,
          _trailing = this._trailing;

      if (_throttled) {
        _throttled.unsubscribe();
      }

      this._throttled = undefined;

      if (_trailing) {
        this.send();
      }
    }
  }, {
    key: "notifyNext",
    value: function notifyNext() {
      this.throttlingDone();
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.throttlingDone();
    }
  }]);

  return ThrottleSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "z+Ro":
/*!*****************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/util/isScheduler.js ***!
  \*****************************************************************/
/*! exports provided: isScheduler */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "isScheduler", function() { return isScheduler; });
function isScheduler(value) {
  return value && typeof value.schedule === 'function';
}

/***/ }),

/***/ "z1FC":
/*!*******************************************!*\
  !*** ./node_modules/moment/locale/tzl.js ***!
  \*******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Talossan [tzl]
//! author : Robin van der Vliet : https://github.com/robin0van0der0v
//! author : Iustì Canun
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration
  // After the year there should be a slash and the amount of years since December 26, 1979 in Roman numerals.
  // This is currently too difficult (maybe even impossible) to add.

  var tzl = moment.defineLocale('tzl', {
    months: 'Januar_Fevraglh_Març_Avrïu_Mai_Gün_Julia_Guscht_Setemvar_Listopäts_Noemvar_Zecemvar'.split('_'),
    monthsShort: 'Jan_Fev_Mar_Avr_Mai_Gün_Jul_Gus_Set_Lis_Noe_Zec'.split('_'),
    weekdays: 'Súladi_Lúneçi_Maitzi_Márcuri_Xhúadi_Viénerçi_Sáturi'.split('_'),
    weekdaysShort: 'Súl_Lún_Mai_Már_Xhú_Vié_Sát'.split('_'),
    weekdaysMin: 'Sú_Lú_Ma_Má_Xh_Vi_Sá'.split('_'),
    longDateFormat: {
      LT: 'HH.mm',
      LTS: 'HH.mm.ss',
      L: 'DD.MM.YYYY',
      LL: 'D. MMMM [dallas] YYYY',
      LLL: 'D. MMMM [dallas] YYYY HH.mm',
      LLLL: 'dddd, [li] D. MMMM [dallas] YYYY HH.mm'
    },
    meridiemParse: /d\'o|d\'a/i,
    isPM: function isPM(input) {
      return "d'o" === input.toLowerCase();
    },
    meridiem: function meridiem(hours, minutes, isLower) {
      if (hours > 11) {
        return isLower ? "d'o" : "D'O";
      } else {
        return isLower ? "d'a" : "D'A";
      }
    },
    calendar: {
      sameDay: '[oxhi à] LT',
      nextDay: '[demà à] LT',
      nextWeek: 'dddd [à] LT',
      lastDay: '[ieiri à] LT',
      lastWeek: '[sür el] dddd [lasteu à] LT',
      sameElse: 'L'
    },
    relativeTime: {
      future: 'osprei %s',
      past: 'ja%s',
      s: processRelativeTime,
      ss: processRelativeTime,
      m: processRelativeTime,
      mm: processRelativeTime,
      h: processRelativeTime,
      hh: processRelativeTime,
      d: processRelativeTime,
      dd: processRelativeTime,
      M: processRelativeTime,
      MM: processRelativeTime,
      y: processRelativeTime,
      yy: processRelativeTime
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });

  function processRelativeTime(number, withoutSuffix, key, isFuture) {
    var format = {
      s: ['viensas secunds', "'iensas secunds"],
      ss: [number + ' secunds', '' + number + ' secunds'],
      m: ["'n míut", "'iens míut"],
      mm: [number + ' míuts', '' + number + ' míuts'],
      h: ["'n þora", "'iensa þora"],
      hh: [number + ' þoras', '' + number + ' þoras'],
      d: ["'n ziua", "'iensa ziua"],
      dd: [number + ' ziuas', '' + number + ' ziuas'],
      M: ["'n mes", "'iens mes"],
      MM: [number + ' mesen', '' + number + ' mesen'],
      y: ["'n ar", "'iens ar"],
      yy: [number + ' ars', '' + number + ' ars']
    };
    return isFuture ? format[key][0] : withoutSuffix ? format[key][0] : format[key][1];
  }

  return tzl;
});

/***/ }),

/***/ "z3Vd":
/*!*******************************************!*\
  !*** ./node_modules/moment/locale/tlh.js ***!
  \*******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Klingon [tlh]
//! author : Dominika Kruk : https://github.com/amaranthrose
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var numbersNouns = 'pagh_wa’_cha’_wej_loS_vagh_jav_Soch_chorgh_Hut'.split('_');

  function translateFuture(output) {
    var time = output;
    time = output.indexOf('jaj') !== -1 ? time.slice(0, -3) + 'leS' : output.indexOf('jar') !== -1 ? time.slice(0, -3) + 'waQ' : output.indexOf('DIS') !== -1 ? time.slice(0, -3) + 'nem' : time + ' pIq';
    return time;
  }

  function translatePast(output) {
    var time = output;
    time = output.indexOf('jaj') !== -1 ? time.slice(0, -3) + 'Hu’' : output.indexOf('jar') !== -1 ? time.slice(0, -3) + 'wen' : output.indexOf('DIS') !== -1 ? time.slice(0, -3) + 'ben' : time + ' ret';
    return time;
  }

  function translate(number, withoutSuffix, string, isFuture) {
    var numberNoun = numberAsNoun(number);

    switch (string) {
      case 'ss':
        return numberNoun + ' lup';

      case 'mm':
        return numberNoun + ' tup';

      case 'hh':
        return numberNoun + ' rep';

      case 'dd':
        return numberNoun + ' jaj';

      case 'MM':
        return numberNoun + ' jar';

      case 'yy':
        return numberNoun + ' DIS';
    }
  }

  function numberAsNoun(number) {
    var hundred = Math.floor(number % 1000 / 100),
        ten = Math.floor(number % 100 / 10),
        one = number % 10,
        word = '';

    if (hundred > 0) {
      word += numbersNouns[hundred] + 'vatlh';
    }

    if (ten > 0) {
      word += (word !== '' ? ' ' : '') + numbersNouns[ten] + 'maH';
    }

    if (one > 0) {
      word += (word !== '' ? ' ' : '') + numbersNouns[one];
    }

    return word === '' ? 'pagh' : word;
  }

  var tlh = moment.defineLocale('tlh', {
    months: 'tera’ jar wa’_tera’ jar cha’_tera’ jar wej_tera’ jar loS_tera’ jar vagh_tera’ jar jav_tera’ jar Soch_tera’ jar chorgh_tera’ jar Hut_tera’ jar wa’maH_tera’ jar wa’maH wa’_tera’ jar wa’maH cha’'.split('_'),
    monthsShort: 'jar wa’_jar cha’_jar wej_jar loS_jar vagh_jar jav_jar Soch_jar chorgh_jar Hut_jar wa’maH_jar wa’maH wa’_jar wa’maH cha’'.split('_'),
    monthsParseExact: true,
    weekdays: 'lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj'.split('_'),
    weekdaysShort: 'lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj'.split('_'),
    weekdaysMin: 'lojmItjaj_DaSjaj_povjaj_ghItlhjaj_loghjaj_buqjaj_ghInjaj'.split('_'),
    longDateFormat: {
      LT: 'HH:mm',
      LTS: 'HH:mm:ss',
      L: 'DD.MM.YYYY',
      LL: 'D MMMM YYYY',
      LLL: 'D MMMM YYYY HH:mm',
      LLLL: 'dddd, D MMMM YYYY HH:mm'
    },
    calendar: {
      sameDay: '[DaHjaj] LT',
      nextDay: '[wa’leS] LT',
      nextWeek: 'LLL',
      lastDay: '[wa’Hu’] LT',
      lastWeek: 'LLL',
      sameElse: 'L'
    },
    relativeTime: {
      future: translateFuture,
      past: translatePast,
      s: 'puS lup',
      ss: translate,
      m: 'wa’ tup',
      mm: translate,
      h: 'wa’ rep',
      hh: translate,
      d: 'wa’ jaj',
      dd: translate,
      M: 'wa’ jar',
      MM: translate,
      y: 'wa’ DIS',
      yy: translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 4 // The week that contains Jan 4th is the first week of the year.

    }
  });
  return tlh;
});

/***/ }),

/***/ "z6cu":
/*!**********************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/observable/throwError.js ***!
  \**********************************************************************/
/*! exports provided: throwError */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "throwError", function() { return throwError; });
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../Observable */ "HDdC");

function throwError(error, scheduler) {
  if (!scheduler) {
    return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
      return subscriber.error(error);
    });
  } else {
    return new _Observable__WEBPACK_IMPORTED_MODULE_0__["Observable"](function (subscriber) {
      return scheduler.schedule(dispatch, 0, {
        error: error,
        subscriber: subscriber
      });
    });
  }
}

function dispatch(_ref) {
  var error = _ref.error,
      subscriber = _ref.subscriber;
  subscriber.error(error);
}

/***/ }),

/***/ "zP0r":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/skip.js ***!
  \***************************************************************/
/*! exports provided: skip */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "skip", function() { return skip; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../Subscriber */ "7o/Q");





function skip(count) {
  return function (source) {
    return source.lift(new SkipOperator(count));
  };
}

var SkipOperator = /*#__PURE__*/function () {
  function SkipOperator(total) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SkipOperator);

    this.total = total;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SkipSubscriber(subscriber, this.total));
    }
  }]);

  return SkipOperator;
}();

var SkipSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SkipSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SkipSubscriber);

  function SkipSubscriber(destination, total) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SkipSubscriber);

    _this = _super.call(this, destination);
    _this.total = total;
    _this.count = 0;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SkipSubscriber, [{
    key: "_next",
    value: function _next(x) {
      if (++this.count > this.total) {
        this.destination.next(x);
      }
    }
  }]);

  return SkipSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);

/***/ }),

/***/ "znLP":
/*!**********************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/scheduler/AnimationFrameScheduler.js ***!
  \**********************************************************************************/
/*! exports provided: AnimationFrameScheduler */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "AnimationFrameScheduler", function() { return AnimationFrameScheduler; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _AsyncScheduler__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./AsyncScheduler */ "IjjT");





var AnimationFrameScheduler = /*#__PURE__*/function (_AsyncScheduler) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(AnimationFrameScheduler, _AsyncScheduler);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(AnimationFrameScheduler);

  function AnimationFrameScheduler() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, AnimationFrameScheduler);

    return _super.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(AnimationFrameScheduler, [{
    key: "flush",
    value: function flush(action) {
      this.active = true;
      this.scheduled = undefined;
      var actions = this.actions;
      var error;
      var index = -1;
      var count = actions.length;
      action = action || actions.shift();

      do {
        if (error = action.execute(action.state, action.delay)) {
          break;
        }
      } while (++index < count && (action = actions.shift()));

      this.active = false;

      if (error) {
        while (++index < count && (action = actions.shift())) {
          action.unsubscribe();
        }

        throw error;
      }
    }
  }]);

  return AnimationFrameScheduler;
}(_AsyncScheduler__WEBPACK_IMPORTED_MODULE_4__["AsyncScheduler"]);

/***/ }),

/***/ "zp1y":
/*!*************************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/withLatestFrom.js ***!
  \*************************************************************************/
/*! exports provided: withLatestFrom */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "withLatestFrom", function() { return withLatestFrom; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ "KQm4");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/assertThisInitialized */ "JX7q");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../OuterSubscriber */ "l7GE");
/* harmony import */ var _util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/subscribeToResult */ "ZUHj");








function withLatestFrom() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  return function (source) {
    var project;

    if (typeof args[args.length - 1] === 'function') {
      project = args.pop();
    }

    var observables = args;
    return source.lift(new WithLatestFromOperator(observables, project));
  };
}

var WithLatestFromOperator = /*#__PURE__*/function () {
  function WithLatestFromOperator(observables, project) {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, WithLatestFromOperator);

    this.observables = observables;
    this.project = project;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(WithLatestFromOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new WithLatestFromSubscriber(subscriber, this.observables, this.project));
    }
  }]);

  return WithLatestFromOperator;
}();

var WithLatestFromSubscriber = /*#__PURE__*/function (_OuterSubscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(WithLatestFromSubscriber, _OuterSubscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(WithLatestFromSubscriber);

  function WithLatestFromSubscriber(destination, observables, project) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_4__["default"])(this, WithLatestFromSubscriber);

    _this = _super.call(this, destination);
    _this.observables = observables;
    _this.project = project;
    _this.toRespond = [];
    var len = observables.length;
    _this.values = new Array(len);

    for (var i = 0; i < len; i++) {
      _this.toRespond.push(i);
    }

    for (var _i = 0; _i < len; _i++) {
      var observable = observables[_i];

      _this.add(Object(_util_subscribeToResult__WEBPACK_IMPORTED_MODULE_7__["subscribeToResult"])(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_assertThisInitialized__WEBPACK_IMPORTED_MODULE_1__["default"])(_this), observable, undefined, _i));
    }

    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_5__["default"])(WithLatestFromSubscriber, [{
    key: "notifyNext",
    value: function notifyNext(_outerValue, innerValue, outerIndex) {
      this.values[outerIndex] = innerValue;
      var toRespond = this.toRespond;

      if (toRespond.length > 0) {
        var found = toRespond.indexOf(outerIndex);

        if (found !== -1) {
          toRespond.splice(found, 1);
        }
      }
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {}
  }, {
    key: "_next",
    value: function _next(value) {
      if (this.toRespond.length === 0) {
        var args = [value].concat(Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_0__["default"])(this.values));

        if (this.project) {
          this._tryProject(args);
        } else {
          this.destination.next(args);
        }
      }
    }
  }, {
    key: "_tryProject",
    value: function _tryProject(args) {
      var result;

      try {
        result = this.project.apply(this, args);
      } catch (err) {
        this.destination.error(err);
        return;
      }

      this.destination.next(result);
    }
  }]);

  return WithLatestFromSubscriber;
}(_OuterSubscriber__WEBPACK_IMPORTED_MODULE_6__["OuterSubscriber"]);

/***/ }),

/***/ "zt7V":
/*!******************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/operators/exhaust.js ***!
  \******************************************************************/
/*! exports provided: exhaust */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "exhaust", function() { return exhaust; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../innerSubscribe */ "zx2A");





function exhaust() {
  return function (source) {
    return source.lift(new SwitchFirstOperator());
  };
}

var SwitchFirstOperator = /*#__PURE__*/function () {
  function SwitchFirstOperator() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SwitchFirstOperator);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SwitchFirstOperator, [{
    key: "call",
    value: function call(subscriber, source) {
      return source.subscribe(new SwitchFirstSubscriber(subscriber));
    }
  }]);

  return SwitchFirstOperator;
}();

var SwitchFirstSubscriber = /*#__PURE__*/function (_SimpleOuterSubscribe) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_0__["default"])(SwitchFirstSubscriber, _SimpleOuterSubscribe);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_1__["default"])(SwitchFirstSubscriber);

  function SwitchFirstSubscriber(destination) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_2__["default"])(this, SwitchFirstSubscriber);

    _this = _super.call(this, destination);
    _this.hasCompleted = false;
    _this.hasSubscription = false;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_3__["default"])(SwitchFirstSubscriber, [{
    key: "_next",
    value: function _next(value) {
      if (!this.hasSubscription) {
        this.hasSubscription = true;
        this.add(Object(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["innerSubscribe"])(value, new _innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleInnerSubscriber"](this)));
      }
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.hasCompleted = true;

      if (!this.hasSubscription) {
        this.destination.complete();
      }
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.hasSubscription = false;

      if (this.hasCompleted) {
        this.destination.complete();
      }
    }
  }]);

  return SwitchFirstSubscriber;
}(_innerSubscribe__WEBPACK_IMPORTED_MODULE_4__["SimpleOuterSubscriber"]);

/***/ }),

/***/ "zx2A":
/*!***************************************************************!*\
  !*** ./node_modules/rxjs/_esm2015/internal/innerSubscribe.js ***!
  \***************************************************************/
/*! exports provided: SimpleInnerSubscriber, ComplexInnerSubscriber, SimpleOuterSubscriber, ComplexOuterSubscriber, innerSubscribe */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SimpleInnerSubscriber", function() { return SimpleInnerSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ComplexInnerSubscriber", function() { return ComplexInnerSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "SimpleOuterSubscriber", function() { return SimpleOuterSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "ComplexOuterSubscriber", function() { return ComplexOuterSubscriber; });
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "innerSubscribe", function() { return innerSubscribe; });
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ "1OyB");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ "vuIU");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/inherits */ "Ji7U");
/* harmony import */ var _Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createSuper */ "LK+K");
/* harmony import */ var _Subscriber__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./Subscriber */ "7o/Q");
/* harmony import */ var _Observable__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./Observable */ "HDdC");
/* harmony import */ var _util_subscribeTo__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./util/subscribeTo */ "SeVD");







var SimpleInnerSubscriber = /*#__PURE__*/function (_Subscriber) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(SimpleInnerSubscriber, _Subscriber);

  var _super = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(SimpleInnerSubscriber);

  function SimpleInnerSubscriber(parent) {
    var _this;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SimpleInnerSubscriber);

    _this = _super.call(this);
    _this.parent = parent;
    return _this;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SimpleInnerSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.parent.notifyNext(value);
    }
  }, {
    key: "_error",
    value: function _error(error) {
      this.parent.notifyError(error);
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.parent.notifyComplete();
      this.unsubscribe();
    }
  }]);

  return SimpleInnerSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);
var ComplexInnerSubscriber = /*#__PURE__*/function (_Subscriber2) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(ComplexInnerSubscriber, _Subscriber2);

  var _super2 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(ComplexInnerSubscriber);

  function ComplexInnerSubscriber(parent, outerValue, outerIndex) {
    var _this2;

    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ComplexInnerSubscriber);

    _this2 = _super2.call(this);
    _this2.parent = parent;
    _this2.outerValue = outerValue;
    _this2.outerIndex = outerIndex;
    return _this2;
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(ComplexInnerSubscriber, [{
    key: "_next",
    value: function _next(value) {
      this.parent.notifyNext(this.outerValue, value, this.outerIndex, this);
    }
  }, {
    key: "_error",
    value: function _error(error) {
      this.parent.notifyError(error);
      this.unsubscribe();
    }
  }, {
    key: "_complete",
    value: function _complete() {
      this.parent.notifyComplete(this);
      this.unsubscribe();
    }
  }]);

  return ComplexInnerSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);
var SimpleOuterSubscriber = /*#__PURE__*/function (_Subscriber3) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(SimpleOuterSubscriber, _Subscriber3);

  var _super3 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(SimpleOuterSubscriber);

  function SimpleOuterSubscriber() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, SimpleOuterSubscriber);

    return _super3.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(SimpleOuterSubscriber, [{
    key: "notifyNext",
    value: function notifyNext(innerValue) {
      this.destination.next(innerValue);
    }
  }, {
    key: "notifyError",
    value: function notifyError(err) {
      this.destination.error(err);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete() {
      this.destination.complete();
    }
  }]);

  return SimpleOuterSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);
var ComplexOuterSubscriber = /*#__PURE__*/function (_Subscriber4) {
  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_inherits__WEBPACK_IMPORTED_MODULE_2__["default"])(ComplexOuterSubscriber, _Subscriber4);

  var _super4 = Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createSuper__WEBPACK_IMPORTED_MODULE_3__["default"])(ComplexOuterSubscriber);

  function ComplexOuterSubscriber() {
    Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_0__["default"])(this, ComplexOuterSubscriber);

    return _super4.apply(this, arguments);
  }

  Object(_Users_adam_Code_datariver_dgp_dgp_app_ui_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_1__["default"])(ComplexOuterSubscriber, [{
    key: "notifyNext",
    value: function notifyNext(_outerValue, innerValue, _outerIndex, _innerSub) {
      this.destination.next(innerValue);
    }
  }, {
    key: "notifyError",
    value: function notifyError(error) {
      this.destination.error(error);
    }
  }, {
    key: "notifyComplete",
    value: function notifyComplete(_innerSub) {
      this.destination.complete();
    }
  }]);

  return ComplexOuterSubscriber;
}(_Subscriber__WEBPACK_IMPORTED_MODULE_4__["Subscriber"]);
function innerSubscribe(result, innerSubscriber) {
  if (innerSubscriber.closed) {
    return undefined;
  }

  if (result instanceof _Observable__WEBPACK_IMPORTED_MODULE_5__["Observable"]) {
    return result.subscribe(innerSubscriber);
  }

  return Object(_util_subscribeTo__WEBPACK_IMPORTED_MODULE_6__["subscribeTo"])(result)(innerSubscriber);
}

/***/ }),

/***/ "zx6S":
/*!******************************************!*\
  !*** ./node_modules/moment/locale/sr.js ***!
  \******************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

//! moment.js locale configuration
//! locale : Serbian [sr]
//! author : Milan Janačković<milanjanackovic@gmail.com> : https://github.com/milan-j
//! author : Stefan Crnjaković <stefan@hotmail.rs> : https://github.com/crnjakovic
;

(function (global, factory) {
   true ? factory(__webpack_require__(/*! ../moment */ "wd/R")) : undefined;
})(this, function (moment) {
  'use strict'; //! moment.js locale configuration

  var translator = {
    words: {
      //Different grammatical cases
      ss: ['sekunda', 'sekunde', 'sekundi'],
      m: ['jedan minut', 'jedne minute'],
      mm: ['minut', 'minute', 'minuta'],
      h: ['jedan sat', 'jednog sata'],
      hh: ['sat', 'sata', 'sati'],
      dd: ['dan', 'dana', 'dana'],
      MM: ['mesec', 'meseca', 'meseci'],
      yy: ['godina', 'godine', 'godina']
    },
    correctGrammaticalCase: function correctGrammaticalCase(number, wordKey) {
      return number === 1 ? wordKey[0] : number >= 2 && number <= 4 ? wordKey[1] : wordKey[2];
    },
    translate: function translate(number, withoutSuffix, key) {
      var wordKey = translator.words[key];

      if (key.length === 1) {
        return withoutSuffix ? wordKey[0] : wordKey[1];
      } else {
        return number + ' ' + translator.correctGrammaticalCase(number, wordKey);
      }
    }
  };
  var sr = moment.defineLocale('sr', {
    months: 'januar_februar_mart_april_maj_jun_jul_avgust_septembar_oktobar_novembar_decembar'.split('_'),
    monthsShort: 'jan._feb._mar._apr._maj_jun_jul_avg._sep._okt._nov._dec.'.split('_'),
    monthsParseExact: true,
    weekdays: 'nedelja_ponedeljak_utorak_sreda_četvrtak_petak_subota'.split('_'),
    weekdaysShort: 'ned._pon._uto._sre._čet._pet._sub.'.split('_'),
    weekdaysMin: 'ne_po_ut_sr_če_pe_su'.split('_'),
    weekdaysParseExact: true,
    longDateFormat: {
      LT: 'H:mm',
      LTS: 'H:mm:ss',
      L: 'D. M. YYYY.',
      LL: 'D. MMMM YYYY.',
      LLL: 'D. MMMM YYYY. H:mm',
      LLLL: 'dddd, D. MMMM YYYY. H:mm'
    },
    calendar: {
      sameDay: '[danas u] LT',
      nextDay: '[sutra u] LT',
      nextWeek: function nextWeek() {
        switch (this.day()) {
          case 0:
            return '[u] [nedelju] [u] LT';

          case 3:
            return '[u] [sredu] [u] LT';

          case 6:
            return '[u] [subotu] [u] LT';

          case 1:
          case 2:
          case 4:
          case 5:
            return '[u] dddd [u] LT';
        }
      },
      lastDay: '[juče u] LT',
      lastWeek: function lastWeek() {
        var lastWeekDays = ['[prošle] [nedelje] [u] LT', '[prošlog] [ponedeljka] [u] LT', '[prošlog] [utorka] [u] LT', '[prošle] [srede] [u] LT', '[prošlog] [četvrtka] [u] LT', '[prošlog] [petka] [u] LT', '[prošle] [subote] [u] LT'];
        return lastWeekDays[this.day()];
      },
      sameElse: 'L'
    },
    relativeTime: {
      future: 'za %s',
      past: 'pre %s',
      s: 'nekoliko sekundi',
      ss: translator.translate,
      m: translator.translate,
      mm: translator.translate,
      h: translator.translate,
      hh: translator.translate,
      d: 'dan',
      dd: translator.translate,
      M: 'mesec',
      MM: translator.translate,
      y: 'godinu',
      yy: translator.translate
    },
    dayOfMonthOrdinalParse: /\d{1,2}\./,
    ordinal: '%d.',
    week: {
      dow: 1,
      // Monday is the first day of the week.
      doy: 7 // The week that contains Jan 7th is the first week of the year.

    }
  });
  return sr;
});

/***/ })

}]);
//# sourceMappingURL=vendor.js.map